@@ -23,14 +23,14 @@
 
 #include "kimproxy.h"
 
-#include <qglobal.h>
-#include <qpixmapcache.h>
+#include <QtCore/QBool>
+#include <QtGui/QPixmapCache>
 
 #include <kapplication.h>
 #include <kdbusservicestarter.h>
 #include <kdebug.h>
 #include <kmessagebox.h>
-#include <ksimpleconfig.h>
+#include <kconfig.h>
 #include <kiconloader.h>
 #include <kservice.h>
 #include <kservicetypetrader.h>
@@ -39,10 +39,6 @@
 
 #include <kservicetype.h>
 
-static KStaticDeleter<KIMProxy> _staticDeleter;
-
-KIMProxy * KIMProxy::s_instance = 0L;
-
 struct AppPresenceCurrent
 {
 	QString appId;
@@ -58,8 +54,9 @@ class ContactPresenceListCurrent : public QList<AppPresenceCurrent>
 };
 
 
-struct KIMProxy::Private
+class KIMProxy::Private
 {
+public:
 	// list of the strings in use by KIMIface
 	QStringList presence_strings;
 	// list of the icon names in use by KIMIface
@@ -169,10 +166,9 @@ OrgKdeKIMInterface * findInterface( const QString & app )
         return new OrgKdeKIMInterface( app, "/KIMIface", QDBusConnection::sessionBus() );
 }
 
-KIMProxy * KIMProxy::instance() 
+KIMProxy * KIMProxy::instance()
 {
-	if ( !s_instance )
-		_staticDeleter.setObject( s_instance, new KIMProxy );
+	K_GLOBAL_STATIC(KIMProxy, s_instance)
 	return s_instance;
 }
 
@@ -224,22 +220,22 @@ bool KIMProxy::initialize()
 			QStringList registeredApps = QDBusConnection::sessionBus().interface()->registeredServiceNames();
 			foreach (QString app, registeredApps)
 			{
-				//kDebug( 790 ) << " considering: " << *app << endl;
+				//kDebug( 790 ) << " considering: " << *app;
 				//for each offer
 				for ( offer = offers.begin(); offer != offers.end(); ++offer )
 				{
-					QString dcopService = (*offer)->property("X-DCOP-ServiceName").toString();
+					QString dcopService = (*offer)->property("X-DBUS-ServiceName").toString();
 					if ( !dcopService.isEmpty() )
 					{
-						//kDebug( 790 ) << " is it: " << dcopService << "?" << endl;
+						//kDebug( 790 ) << " is it: " << dcopService << "?";
 						// if the application implements the dcop service, add it
 						if ( app.startsWith( dcopService ) )
 						{
 							m_apps_available = true;
-							//kDebug( 790 ) << " app name: " << (*offer)->name() << ", has instance " << *app << ", dcopService: " << dcopService << endl;
+							//kDebug( 790 ) << " app name: " << (*offer)->name() << ", has instance " << *app << ", dcopService: " << dcopService;
 							if ( !m_im_client_stubs.contains( dcopService ) )
 							{
-								kDebug( 790 ) << "App " << app << ", found, using it for presence info." << endl;
+								kDebug( 790 ) << "App " << app << ", found, using it for presence info.";
 								m_im_client_stubs.insert( app, findInterface( app ) );
 								pollApp( app );
 							}
@@ -257,7 +253,7 @@ void KIMProxy::nameOwnerChanged( const QString & appId, const QString &, const Q
 	// unregister...
 	if ( m_im_client_stubs.contains( appId ) )
 	{
-		kDebug( 790 ) << appId << " quit, removing its presence info." << endl;
+		kDebug( 790 ) << appId << " quit, removing its presence info.";
 
 		PresenceStringMap::Iterator it = d->presence_map.begin();
 		const PresenceStringMap::Iterator end = d->presence_map.end();
@@ -288,32 +284,32 @@ void KIMProxy::nameOwnerChanged( const QString & appId, const QString &, const Q
 		KService::List::const_iterator it;
 		for ( it = offers.begin(); it != offers.end(); ++it )
 		{
-			QString dcopService = (*it)->property("X-DCOP-ServiceName").toString();
+			QString dcopService = (*it)->property("X-DBUS-ServiceName").toString();
 			if ( appId.startsWith( dcopService ) )
 			{
 				// if it's not already known, insert it
 				if ( !m_im_client_stubs.contains( appId ) )
 				{
 					newApp = true;
-					kDebug( 790 ) << "App: " << appId << ", dcopService: " << dcopService << " started, using it for presence info."<< endl;
+					kDebug( 790 ) << "App: " << appId << ", dcopService: " << dcopService << " started, using it for presence info.";
 					m_im_client_stubs.insert( appId, findInterface( appId ) );
 				}
 			}
 			//else
-			//	kDebug( 790 ) << "App doesn't implement our ServiceType" << endl;
+			//	kDebug( 790 ) << "App doesn't implement our ServiceType";
 		}
 		//if ( newApp )
 		//	emit sigPresenceInfoExpired();
 	}
 }
 
-void KIMProxy::contactPresenceChanged( QString uid, QString appId, int presence )
+void KIMProxy::contactPresenceChanged( const QString& uid, const QString& appId, int presence )
 {
 	// update the presence map
-	//kDebug( 790 ) << k_funcinfo << "uid: " << uid << " appId: " << appId << " presence " << presence << endl;
+	//kDebug( 790 ) << "uid: " << uid << " appId: " << appId << " presence " << presence;
 	ContactPresenceListCurrent current;
 	current = d->presence_map[ uid ];
-  //kDebug( 790 ) << "current best presence from : " << current.best().appId << " is: " << current.best().presence << endl;
+  //kDebug( 790 ) << "current best presence from : " << current.best().appId << " is: " << current.best().presence;
 	AppPresenceCurrent newPresence;
 	newPresence.appId = appId;
 	newPresence.presence = presence;
@@ -363,12 +359,12 @@ QPixmap KIMProxy::presenceIcon( const QString& uid )
 	}
 	if ( ap.appId.isEmpty() )
 	{
-		//kDebug( 790 ) << k_funcinfo << "returning a null QPixmap because we were asked for an icon for a uid we know nothing about" << endl;
+		//kDebug( 790 ) << "returning a null QPixmap because we were asked for an icon for a uid we know nothing about";
 		return QPixmap();
 	}
 	else
 	{
-		//kDebug( 790 ) << k_funcinfo << "returning this: " << d->presence_icons[ ap.presence ] << endl;
+		//kDebug( 790 ) << "returning this: " << d->presence_icons[ ap.presence ];
 		return SmallIcon( d->presence_icons[ ap.presence ]);
 	}
 }
@@ -436,7 +432,7 @@ QString KIMProxy::displayName( const QString& uid )
 		if ( OrgKdeKIMInterface* s = stubForUid( uid ) )
 			name = s->displayName( uid );
 	}
-	//kDebug( 790 ) << k_funcinfo << name << endl;
+	//kDebug( 790 ) << name;
     return name;
 }
 
@@ -555,7 +551,7 @@ bool KIMProxy::startPreferredApp()
 	preferences.clear();
 	int result = KDBusServiceStarter::self()->findServiceFor( IM_SERVICE_TYPE, QString("Application"), &error, &dbusService );
 
-	kDebug( 790 ) << k_funcinfo << "error was: " << error << ", dbusService: " << dbusService << endl;
+	kDebug( 790 ) << "error was: " << error << ", dbusService: " << dbusService;
 
 	return ( result == 0 );
 }
@@ -582,7 +578,7 @@ void KIMProxy::pollAll( const QString &uid )
 
 void KIMProxy::pollApp( const QString & appId )
 {
-	//kDebug( 790 ) << k_funcinfo << endl;
+	//kDebug( 790 ) ;
 	OrgKdeKIMInterface * appStub = m_im_client_stubs.value( appId );
 	QStringList contacts = m_im_client_stubs.value( appId )->allContacts();
 	QStringList::iterator it = contacts.begin();
@@ -592,13 +588,16 @@ void KIMProxy::pollApp( const QString & appId )
 		ContactPresenceListCurrent current = d->presence_map[ *it ];
 		AppPresenceCurrent ap;
 		ap.appId = appId;
-		ap.presence = appStub->presenceStatus( *it );
+#ifdef __GNUC__
+# warning "KIMProxy::pollApp( const QString & appId ).presenceStatus() function doesn't exist Need to fix it"
+#endif		
+		//ap.presence = appStub->presenceStatus( *it );
 		current.append( ap );
 
 		d->presence_map.insert( *it, current );
 		if ( current.update( ap ) )
 			emit sigContactPresenceChanged( *it );
-		//kDebug( 790 ) << " uid: " << *it << " presence: " << ap.presence << endl;
+		//kDebug( 790 ) << " uid: " << *it << " presence: " << ap.presence;
 	}
 }
 
@@ -612,6 +611,10 @@ OrgKdeKIMInterface * KIMProxy::stubForUid( const QString &uid )
 
 OrgKdeKIMInterface * KIMProxy::stubForProtocol( const QString &protocol)
 {
+#ifdef __GNUC__
+# warning "KIMProxy::stubForProtocol( const QString &protocol) code disabled: protocols() function doesn't exist. Need to fix it"
+#endif
+#if 0
 	OrgKdeKIMInterface * app;
 	// see if the preferred client supports this protocol
 	QString preferred = preferredApp();
@@ -628,15 +631,16 @@ OrgKdeKIMInterface * KIMProxy::stubForProtocol( const QString &protocol)
 		if ( it.value()->protocols().value().filter( protocol ).count() > 0 )
 			return it.value();
 	}
+#endif
 	return 0L;
 }
 
 QString KIMProxy::preferredApp()
 {
-	KConfig *store = new KSimpleConfig( IM_CLIENT_PREFERENCES_FILE );
-	store->setGroup( IM_CLIENT_PREFERENCES_SECTION );
-	QString preferredApp = store->readEntry( IM_CLIENT_PREFERENCES_ENTRY );
-	//kDebug( 790 ) << k_funcinfo << "found preferred app: " << preferredApp << endl;
+	KConfig cfg( IM_CLIENT_PREFERENCES_FILE, KConfig::OnlyLocal );
+	KConfigGroup cg(&cfg, IM_CLIENT_PREFERENCES_SECTION );
+	QString preferredApp = cg.readEntry( IM_CLIENT_PREFERENCES_ENTRY );
+	//kDebug( 790 ) << "found preferred app: " << preferredApp;
 	return preferredApp;
 }
 
