@@ -19,9 +19,9 @@
 
 #include "kfileaudiopreview.h"
 
-#include <QCheckBox>
-#include <QLayout>
-#include <QGroupBox>
+#include <QtGui/QCheckBox>
+#include <QtGui/QLayout>
+#include <QtGui/QGroupBox>
 
 #include <khbox.h>
 #include <kglobal.h>
@@ -34,12 +34,11 @@
 #include <config-kfile.h>
 
 #include <phonon/mediaobject.h>
-#include <phonon/audiopath.h>
 #include <phonon/audiooutput.h>
-#include <phonon/videopath.h>
+#include <phonon/path.h>
 #include <phonon/backendcapabilities.h>
-#include <phonon/ui/videowidget.h>
-#include <phonon/ui/mediacontrols.h>
+#include <phonon/videowidget.h>
+#include "mediacontrols.h"
 #include <kconfiggroup.h>
 
 class KFileAudioPreviewFactory : public KLibFactory
@@ -65,17 +64,13 @@ class KFileAudioPreview::Private
 public:
     Private()
         : player( 0 )
-        , audioPath( 0 )
         , audioOutput( 0 )
-        , videoPath( 0 )
         , videoWidget( 0 )
     {
     }
 
     MediaObject* player;
-    AudioPath* audioPath;
     AudioOutput* audioOutput;
-    VideoPath* videoPath;
     VideoWidget* videoWidget;
     MediaControls* controls;
 };
@@ -85,7 +80,7 @@ KFileAudioPreview::KFileAudioPreview( QWidget *parent )
     : KPreviewWidgetBase( parent )
     , d( new Private )
 {
-    KGlobal::locale()->insertCatalog("kfileaudiopreview");
+    KGlobal::locale()->insertCatalog("kfileaudiopreview4");
 
     QGroupBox *box = new QGroupBox( i18n("Media Player"), this );
     QVBoxLayout *layout = new QVBoxLayout( this );
@@ -93,18 +88,14 @@ KFileAudioPreview::KFileAudioPreview( QWidget *parent )
 
     (void) new QWidget( box ); // spacer
 
-    setSupportedMimeTypes( BackendCapabilities::knownMimeTypes() );
+    setSupportedMimeTypes(BackendCapabilities::availableMimeTypes());
 
     d->audioOutput = new AudioOutput( Phonon::VideoCategory, this );
-    d->audioPath = new AudioPath( this );
-    d->audioPath->addOutput( d->audioOutput );
 
     KHBox *frame = new KHBox( box );
     frame->setFrameStyle( QFrame::Panel | QFrame::Sunken );
     frame->setSizePolicy( QSizePolicy( QSizePolicy::Expanding, QSizePolicy::Expanding ) );
     d->videoWidget = new VideoWidget( frame );
-    d->videoPath = new VideoPath( this );
-    d->videoPath->addOutput( d->videoWidget );
 
     d->controls = new MediaControls( box );
     d->controls->setEnabled( false );
@@ -136,15 +127,17 @@ void KFileAudioPreview::showPreview( const KUrl &url )
 {
     delete d->player;
     d->player = new MediaObject( this );
-    d->player->setUrl( url );
+    d->player->setCurrentSource(url);
     if( d->player->state() == Phonon::ErrorState )
     {
         delete d->player;
         d->player = 0;
         return;
     }
+    Phonon::createPath(d->player, d->audioOutput);
+    Phonon::createPath(d->player, d->videoWidget);
 
-    d->controls->setMediaProducer( d->player );
+    d->controls->setMediaObject(d->player);
     if( d->player->state() == Phonon::StoppedState )
         d->controls->setEnabled( true );
     else
