@@ -19,8 +19,8 @@
 #ifndef KDELIBS_KTEXTEDITOR_CODECOMPLETIONINTERFACE_H
 #define KDELIBS_KTEXTEDITOR_CODECOMPLETIONINTERFACE_H
 
+#include <ktexteditor/ktexteditor_export.h>
 #include <QtCore/QObject>
-
 #include <ktexteditor/range.h>
 
 namespace KTextEditor {
@@ -79,8 +79,8 @@ class KTEXTEDITOR_EXPORT CodeCompletionInterface
     virtual void setAutomaticInvocationEnabled(bool enabled = true) = 0;
 
   //signals:
-    //void completionExecuted(const Cursor& position, CodeCompletionModel* model, int row);
-    //void completionAborted();
+    //void completionExecuted(KTextEditor::View* view, const KTextEditor::Cursor& position, KTextEditor::CodeCompletionModel* model, int row);
+    //void completionAborted(KTextEditor::View* view);
 };
 
 }
