@@ -20,6 +20,7 @@
 #ifndef KDELIBS_KTEXTEDITOR_DOCUMENT_H
 #define KDELIBS_KTEXTEDITOR_DOCUMENT_H
 
+#include <ktexteditor/ktexteditor_export.h>
 // the very important KTextEditor::Cursor class
 #include <ktexteditor/cursor.h>
 #include <ktexteditor/range.h>
@@ -99,7 +100,7 @@ class View;
  * \ref kte_group_doc_extensions.
  *
  * \see KParts::ReadWritePart, KTextEditor::Editor, KTextEditor::View,
- *      KTextEditor::HighlightingInterface, KTextEditor::MarkInterface,
+ *      KTextEditor::MarkInterface,
  *      KTextEditor::ModificationInterface, KTextEditor::SearchInterface,
  *      KTextEditor::SessionConfigInterface, KTextEditor::SmartInterface,
  *      KTextEditor::VariableInterface
@@ -146,7 +147,7 @@ class KTEXTEDITOR_EXPORT Document : public KParts::ReadWritePart
     virtual View *createView ( QWidget *parent ) = 0;
 
     /**
-     * Return the view which is currently has user focus, if any.
+     * Return the view which currently has user focus, if any.
      */
     virtual View* activeView() const = 0;
 
@@ -580,6 +581,78 @@ class KTEXTEDITOR_EXPORT Document : public KParts::ReadWritePart
      */
     void aboutToClose(KTextEditor::Document *document);
 
+  /*
+   * Access to the mode/highlighting subsystem
+   */
+  public:
+    /**
+     * Return the name of the currently used mode
+     * \return name of the used mode
+     * \see modes(), setMode()
+     */
+    virtual QString mode() const = 0;
+
+    /**
+     * Return the name of the currently used mode
+     * \return name of the used mode
+     * \see highlightingModes(), setHighlightingMode()
+     */
+    virtual QString highlightingMode() const = 0;
+    
+    /**
+     * Return a list of the names of all possible modes
+     * \return list of mode names
+     * \see mode(), setMode()
+     */
+    virtual QStringList modes() const = 0;
+
+    /**
+     * Return a list of the names of all possible modes
+     * \return list of mode names
+     * \see highlightingMode(), setHighlightingMode()
+     */
+    virtual QStringList highlightingModes() const = 0;
+
+    /**
+     * Set the current mode of the document by giving its name
+     * \param name name of the mode to use for this document
+     * \return \e true on success, otherwise \e false
+     * \see mode(), modes(), modeChanged()
+     */
+    virtual bool setMode(const QString &name) = 0;
+
+    /**
+     * Set the current mode of the document by giving its name
+     * \param name name of the mode to use for this document
+     * \return \e true on success, otherwise \e false
+     * \see highlightingMode(), highlightingModes(), highlightingModeChanged()
+     */
+    virtual bool setHighlightingMode(const QString &name) = 0;
+
+  /*
+   * SIGNALS
+   * Following signals should be emitted by the document if the mode
+   * of the document changes
+   */
+  Q_SIGNALS:
+    /**
+     * Warn anyone listening that the current document's mode has
+     * changed.
+     * 
+     * \param document the document whose mode has changed
+     * \see setMode()
+     */
+    void modeChanged(KTextEditor::Document *document);
+    
+    /**
+     * Warn anyone listening that the current document's highlighting mode has
+     * changed.
+     * 
+     * \param document the document which's mode has changed
+     * \see setHighlightingMode()
+     */
+    void highlightingModeChanged(KTextEditor::Document *document);
+
   private:
     class DocumentPrivate* const d;
 
@@ -599,6 +672,7 @@ class KTEXTEDITOR_EXPORT Document : public KParts::ReadWritePart
      */
     bool openingError() const;
     QString openingErrorMessage() const;
+
   protected:
     void setOpeningError(bool errors);
     void setOpeningErrorMessage(const QString& message);
