@@ -20,9 +20,9 @@
 #ifndef KDELIBS_KTEXTEDITOR_PLUGIN_H
 #define KDELIBS_KTEXTEDITOR_PLUGIN_H
 
-#include <qobject.h>
+#include <QtCore/QObject>
 
-#include <kdelibs_export.h>
+#include <ktexteditor/ktexteditor_export.h>
 
 class KConfig;
 
