@@ -18,7 +18,7 @@
 
 #include "smartrange.h"
 
-#include <QStack>
+#include <QtCore/QStack>
 
 #include "document.h"
 #include "view.h"
@@ -133,7 +133,13 @@ void SmartRange::insertChildRange( SmartRange * newChild )
     if (it.peekPrevious()->end() <= newChild->start()) {
       it.insert(newChild);
       if (it.hasNext() && it.peekNext()->start() < newChild->end())
+      {
+          Range oldRange = *it.peekNext();
+          //Give a warning here, because this most probably results in unwanted behavior, and is extremely hard to debug. This at least gives a clue what'is going wrong. The alternative would be an assertion.
           it.peekNext()->start() = newChild->end();
+          
+          kDebug() << "SmartRange warning: " << this << ": Added child-range " << newChild << "(" << *newChild << ") intersects child-range " << it.peekNext() << "(" << oldRange << "), the second one is trimmed to " << *it.peekNext() << endl;
+      }
 
       done = true;
       break;
@@ -144,7 +150,13 @@ void SmartRange::insertChildRange( SmartRange * newChild )
 
   if (!done) {
     if (m_childRanges.count() && m_childRanges.first()->start() < newChild->end())
+    {
+        Range oldRange = *m_childRanges.first();
+        
         m_childRanges.first()->start() = newChild->end();
+        
+        kDebug() << "SmartRange warning: " << this << ": Added child-range " << newChild << "(" << *newChild << ") intersects child-range " << m_childRanges.first() << "(" << oldRange << "), the second one is trimmed to " << *m_childRanges.first() << endl;
+    }
     m_childRanges.prepend(newChild);
   }
 
