@@ -19,11 +19,12 @@
 #ifndef KDELIBS_KTEXTEDITOR_SMARTRANGE_H
 #define KDELIBS_KTEXTEDITOR_SMARTRANGE_H
 
+#include <ktexteditor/ktexteditor_export.h>
 #include <ktexteditor/range.h>
 #include <ktexteditor/smartcursor.h>
 #include <ktexteditor/attribute.h>
 
-#include <QList>
+#include <QtCore/QList>
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 template <class T> class QStack;
@@ -687,14 +688,6 @@ class KTEXTEDITOR_EXPORT SmartRange : public Range
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(SmartRange::InsertBehaviors)
 
-/**
- * kDebug() stream operator.  Writes this range to the debug output in a nicely formatted way.
- */
-inline kdbgstream& operator<<(kdbgstream& s, const SmartRange& range)
-{
-    return s << static_cast<const Range&>(range);
-}
-
 }
 
 #endif
