@@ -19,19 +19,17 @@
 #ifndef KDELIBS_KTEXTEDITOR_TEMPLATEINTERFACE_H
 #define KDELIBS_KTEXTEDITOR_TEMPLATEINTERFACE_H
 
-#include <qstring.h>
-#include <qmap.h>
-#include <qwidget.h>
+#include <QtCore/QString>
+#include <QtCore/QMap>
+#include <QtGui/QImage>
 
-#include <kdelibs_export.h>
+#include <ktexteditor/ktexteditor_export.h>
 #include <ktexteditor/cursor.h>
 
 namespace KTextEditor
 {
 
-class Document;
 class Cursor;
-class View;
 
 /**
  * This is an interface for inserting template strings with user editable
