@@ -38,28 +38,26 @@
 #include <kmimetype.h>
 #include <kmimetypechooser.h>
 #include <krun.h>
-#include <kstaticdeleter.h>
 #include <kurl.h>
 
-#include <qcheckbox.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qlineedit.h>
-#include <q3listview.h>
-#include <qpushbutton.h>
-#include <qtoolbutton.h>
-#include <qregexp.h>
+#include <QtGui/QCheckBox>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtGui/QLineEdit>
+#include <Qt3Support/Q3ListView>
+#include <QtGui/QPushButton>
+#include <QtGui/QToolButton>
+#include <QtCore/QRegExp>
 //Added by qt3to4:
-#include <QPixmap>
-#include <QGridLayout>
-#include <QHBoxLayout>
-#include <QVBoxLayout>
+#include <QtGui/QPixmap>
+#include <QtGui/QGridLayout>
+#include <QtGui/QBoxLayout>
 
 //#include <kdebug.h>
 //END includes
 
 //BEGIN AutoBookmarker
-K_EXPORT_COMPONENT_FACTORY( ktexteditor_autobookmarker, KGenericFactory<AutoBookmarker>( "ktexteditor_autobookmarker" ) )
+K_EXPORT_COMPONENT_FACTORY( ktexteditor_autobookmarker, KGenericFactory<AutoBookmarker>( "ktexteditor_autobookmarker", "ktexteditor_plugins" ) )
 
 AutoBookmarker::AutoBookmarker( QObject *parent,
                             const char* name,
@@ -173,8 +171,6 @@ void AutoBookmarker::applyEntity( AutoBookmarkEnt *e )
 //END
 
 //BEGIN ABGlobal
-ABGlobal *ABGlobal::s_self = 0;
-
 ABGlobal::ABGlobal()
 {
   m_ents = new ABEntityList;
@@ -186,13 +182,9 @@ ABGlobal::~ABGlobal()
   delete m_ents;
 }
 
-static KStaticDeleter<ABGlobal> sdSelf;
-
 ABGlobal *ABGlobal::self()
 {
-  if ( ! s_self )
-    sdSelf.setObject(s_self, new ABGlobal());
-
+  K_STATIC_DELETER(ABGlobal, s_self)
   return s_self;
 }
 
@@ -207,12 +199,12 @@ void ABGlobal::readConfig()
   uint n( 0 );
   while ( config->hasGroup( QString("autobookmark%1").arg( n ) ) )
   {
-    config->setGroup( QString("autobookmark%1").arg( n ) );
-    QStringList filemask = config->readEntry( "filemask", QStringList(), ';' );
-    QStringList mimemask = config->readEntry( "mimemask", QStringList(), ';' );
-    int flags = config->readEntry( "flags", 1 );
+    KConfigGroup cg( config, QString("autobookmark%1").arg( n ) );
+    QStringList filemask = cg.readEntry( "filemask", QStringList(), ';' );
+    QStringList mimemask = cg.readEntry( "mimemask", QStringList(), ';' );
+    int flags = cg.readEntry( "flags", 1 );
     AutoBookmarkEnt *e = new AutoBookmarkEnt(
-        config->readEntry( "pattern", "" ),
+        cg.readEntry( "pattern", "" ),
         filemask,
         mimemask,
         flags
@@ -239,11 +231,11 @@ void ABGlobal::writeConfig()
   for ( uint i = 0; i < m_ents->count(); i++ )
   {
     AutoBookmarkEnt *e = m_ents->at( i );
-    config->setGroup( QString("autobookmark%1").arg( i ) );
-    config->writeEntry( "pattern", e->pattern );
-    config->writeEntry( "filemask", e->filemask, ';' );
-    config->writeEntry( "mimemask", e->mimemask, ';' );
-    config->writeEntry( "flags", e->flags );
+    KConfigGroup cg( config, QString("autobookmark%1").arg( i ) );
+    cg.writeEntry( "pattern", e->pattern );
+    cg.writeEntry( "filemask", e->filemask, ';' );
+    cg.writeEntry( "mimemask", e->mimemask, ';' );
+    cg.writeEntry( "flags", e->flags );
   }
 
   config->sync(); // explicit -- this is supposedly handled by the d'tor
@@ -399,12 +391,12 @@ AutoBookmarkerConfigPage::AutoBookmarkerConfigPage( QWidget *parent, const char
   l->setBuddy( lvPatterns );
   lvPatterns->setWhatsThis(i18n(
       "<p>This list shows your configured autobookmark entities. When a document "
-      "is opened, each entity is used in the following way: "
+      "is opened, each entity is used in the following way:<p>"
       "<ol>"
       "<li>The entity is dismissed, if a mime and/or filename mask is defined, "
       "and neither matches the document.</li>"
       "<li>Otherwise each line of the document is tried against the pattern, "
-      "and a bookmark is set on matching lines.</li></ul>"
+      "and a bookmark is set on matching lines.</li></ol>"
       "<p>Use the buttons below to manage your collection of entities.</p>") );
 
   QHBoxLayout *lo1 = new QHBoxLayout ( lo );
