@@ -20,9 +20,9 @@
 #define _KATE_KDATATOOL_
 
 #include <ktexteditor/plugin.h>
-#include <qstringlist.h>
+#include <QtCore/QStringList>
 #include <kxmlguiclient.h>
-#include <qpointer.h>
+#include <QtCore/QPointer>
 
 class KActionMenu;
 class KDataToolInfo;
@@ -37,7 +37,7 @@ class KDataToolPlugin : public KTextEditor::Plugin
 	Q_OBJECT
 
 public:
-	KDataToolPlugin( QObject *parent = 0, const QStringList &args = QStringList() );
+	explicit KDataToolPlugin( QObject *parent = 0, const QStringList &args = QStringList() );
 	virtual ~KDataToolPlugin();
 	void addView (KTextEditor::View *view);
 	void removeView (KTextEditor::View *view);
