@@ -48,15 +48,15 @@
 #include <ktoggleaction.h>
 #include <kconfiggroup.h>
 
-#include <qregexp.h>
-#include <qstring.h>
-#include <QSet>
-#include <qspinbox.h>
-#include <qlabel.h>
-#include <qlayout.h>
+#include <QtCore/QRegExp>
+#include <QtCore/QString>
+#include <QtCore/QSet>
+#include <QtGui/QSpinBox>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
 
 #include <kvbox.h>
-#include <qcheckbox.h>
+#include <QtGui/QCheckBox>
 
 #include <kdebug.h>
 //END
@@ -89,8 +89,8 @@ QVariant DocWordCompletionModel::data(const QModelIndex& index, int role) const
       return (int)FirstProperty|LastProperty|Public;
     case ScopeIndex:
       return 0;
-    case MatchType:
-      return true;
+    case MatchQuality:
+      return 10;
     case HighlightingMethod:
       return QVariant::Invalid;
     case InheritanceDepth:
@@ -160,68 +160,17 @@ const QStringList DocWordCompletionModel::allMatches( KTextEditor::View *view, c
 //END DocWordCompletionModel
 
 //BEGIN DocWordCompletionPlugin
-K_EXPORT_COMPONENT_FACTORY( ktexteditor_docwordcompletion, KGenericFactory<DocWordCompletionPlugin>( "ktexteditor_docwordcompletion" ) )
+DocWordCompletionPlugin *DocWordCompletionPlugin::plugin = 0;
+K_PLUGIN_FACTORY_DECLARATION(DocWordCompletionFactory)
 DocWordCompletionPlugin::DocWordCompletionPlugin( QObject *parent,
-                            const QStringList& /*args*/ )
+                            const QVariantList& /*args*/ )
   : KTextEditor::Plugin ( parent )
 {
+  plugin = this;
   m_dWCompletionModel = new DocWordCompletionModel( this );
   readConfig();
 }
 
-void DocWordCompletionPlugin::configDialog (QWidget *parent)
-{
- // If we have only one page, we use a simple dialog, else an icon list type
-  KPageDialog::FaceType ft = configPages() > 1 ? KPageDialog::List :     // still untested
-                                                 KPageDialog::Plain;
-
-  KPageDialog *kd = new KPageDialog ( parent );
-  kd->setFaceType( ft );
-  kd->setCaption( i18n("Configure") );
-  kd->setButtons( KDialog::Ok | KDialog::Cancel | KDialog::Help );
-  kd->setDefaultButton( KDialog::Ok );
-
-  QList<KTextEditor::ConfigPage*> editorPages;
-
-  for (uint i = 0; i < configPages (); i++)
-  {
-    QWidget *page = new QWidget(0);
-
-    KPageWidgetItem *item = new KPageWidgetItem( page, configPageName( i ) );
-    item->setHeader( configPageFullName( i ) );
-// FIXME: set the icon here      item->setIcon();
-
-    kd->addPage( item );
-
-    editorPages.append( configPage( i, page ) );
-  }
-
-  if (kd->exec())
-  {
-
-    for( int i=0; i<editorPages.count(); i++ )
-    {
-      editorPages.at( i )->apply();
-    }
-  }
-
-  delete kd;
-}
-
-void DocWordCompletionPlugin::readConfig()
-{
-  KConfigGroup cg(KGlobal::config(), "DocWordCompletion Plugin" );
-  m_treshold = cg.readEntry( "treshold", 3 );
-  m_autopopup = cg.readEntry( "autopopup", true );
-}
-
-void DocWordCompletionPlugin::writeConfig()
-{
-  KConfigGroup cg(KGlobal::config(), "DocWordCompletion Plugin" );
-  cg.writeEntry("autopopup", m_autopopup );
-  cg.writeEntry("treshold", m_treshold );
-}
-
 void DocWordCompletionPlugin::addView(KTextEditor::View *view)
 {
   DocWordCompletionPluginView *nview = new DocWordCompletionPluginView (m_treshold, m_autopopup, view, m_dWCompletionModel );
@@ -239,26 +188,55 @@ void DocWordCompletionPlugin::removeView(KTextEditor::View *view)
     }
 }
 
-KTextEditor::ConfigPage* DocWordCompletionPlugin::configPage( uint, QWidget *parent )
+void DocWordCompletionPlugin::readConfig()
 {
-  return new DocWordCompletionConfigPage( this, parent );
+  KConfigGroup cg(KGlobal::config(), "DocWordCompletion Plugin" );
+  m_treshold = cg.readEntry( "treshold", 3 );
+  m_autopopup = cg.readEntry( "autopopup", true );
 }
 
-QString DocWordCompletionPlugin::configPageName( uint ) const
+void DocWordCompletionPlugin::writeConfig()
 {
-  return i18n("Word Completion Plugin");
+  KConfigGroup cg(KGlobal::config(), "DocWordCompletion Plugin" );
+  cg.writeEntry("autopopup", m_autopopup );
+  cg.writeEntry("treshold", m_treshold );
 }
 
-QString DocWordCompletionPlugin::configPageFullName( uint ) const
+uint DocWordCompletionPlugin::treshold() const
 {
-  return i18n("Configure the Word Completion Plugin");
+    return m_treshold;
 }
 
-// FIXME provide sucn a icon
-       QPixmap DocWordCompletionPlugin::configPagePixmap( uint, int size ) const
+void DocWordCompletionPlugin::setTreshold(uint t)
 {
-  return UserIcon( "kte_wordcompletion", size );
+    m_treshold = t;
+
+    // If the property has been set for the plugin in general, let's set that
+    // property to that value on all views where the plugin has been loaded.
+    foreach (DocWordCompletionPluginView *view, m_views)
+    {
+        view->setTreshold(t);
+    }
 }
+
+bool DocWordCompletionPlugin::autoPopupEnabled() const
+{
+    return m_autopopup;
+}
+
+void DocWordCompletionPlugin::setAutoPopupEnabled(bool enable)
+{
+    m_autopopup = enable;
+
+    // If the property has been set for the plugin in general, let's set that
+    // property to that value on all views where the plugin has been loaded.
+    foreach (DocWordCompletionPluginView *view, m_views)
+    {
+        view->setAutoPopupEnabled(enable);
+        view->toggleAutoPopup();
+    }
+}
+
 //END
 
 //BEGIN DocWordCompletionPluginView
@@ -327,7 +305,7 @@ DocWordCompletionPluginView::DocWordCompletionPluginView( uint treshold,
     connect( action, SIGNAL( triggered() ), this, SLOT(shellComplete()) );
   }
 
-  setComponentData( KGenericFactory<DocWordCompletionPlugin>::componentData() );
+  setComponentData( DocWordCompletionFactory::componentData() );
 
   action = new KAction( i18n("Reuse Word Above"), this );
   actionCollection()->addAction( "doccomplete_bw", action );
@@ -348,8 +326,8 @@ DocWordCompletionPluginView::DocWordCompletionPluginView( uint treshold,
     if ( ! e.isEmpty() )
       d->autopopup->setEnabled( e == "true" );
 
-    connect( view->document(), SIGNAL(variableChanged(const QString &, const QString &)),
-             this, SLOT(slotVariableChanged(const QString &, const QString &)) );
+    connect( view->document(), SIGNAL(variableChanged(KTextEditor::Document*,const QString &, const QString &)),
+             this, SLOT(slotVariableChanged(KTextEditor::Document *,const QString &, const QString &)) );
   }
 }
 
@@ -363,11 +341,16 @@ DocWordCompletionPluginView::~DocWordCompletionPluginView()
   d=0;
 }
 
-void DocWordCompletionPluginView::settreshold( uint t )
+void DocWordCompletionPluginView::setTreshold( uint t )
 {
   d->treshold = t;
 }
 
+void DocWordCompletionPluginView::setAutoPopupEnabled( bool enable )
+{
+  d->autopopup->setChecked(enable);
+}
+
 void DocWordCompletionPluginView::completeBackwards()
 {
   complete( false );
@@ -464,7 +447,7 @@ void DocWordCompletionPluginView::complete( bool fw )
           */
   if ( r.start() == d->dcRange.start() && r.end() >= d->dcRange.end() )
   {
-    //kDebug()<<"CONTINUE "<<d->dcRange<<endl;
+    //kDebug()<<"CONTINUE "<<d->dcRange;
     // this is a repeted activation
 
     // if we are back to where we started, reset.
@@ -488,7 +471,7 @@ void DocWordCompletionPluginView::complete( bool fw )
   }
   else // new completion, reset all
   {
-    //kDebug()<<"RESET FOR NEW"<<endl;
+    //kDebug()<<"RESET FOR NEW";
     d->dcRange = r;
     d->liRange->setRange( KTextEditor::Range( r.end(), 0 ) );
     d->dcCursor = r.start();
@@ -501,14 +484,14 @@ void DocWordCompletionPluginView::complete( bool fw )
 
   while ( true )
   {
-    //kDebug()<<"SEARCHING FOR "<<d->re.pattern()<<" "<<ln<<" at "<<d->dcCursor<<endl;
+    //kDebug()<<"SEARCHING FOR "<<d->re.pattern()<<" "<<ln<<" at "<<d->dcCursor;
     pos = fw ?
       d->re.indexIn( ln, d->dcCursor.column() ) :
       d->re.lastIndexIn( ln, d->dcCursor.column() );
 
     if ( pos > -1 ) // we matched a word
     {
-      //kDebug()<<"USABLE MATCH"<<endl;
+      //kDebug()<<"USABLE MATCH";
       QString m = d->re.cap( 1 );
       if ( m != doc->text( *d->liRange ) )
       {
@@ -524,7 +507,7 @@ void DocWordCompletionPluginView::complete( bool fw )
       // equal to last one, continue
       else
       {
-        //kDebug()<<"SKIPPING, EQUAL MATCH"<<endl;
+        //kDebug()<<"SKIPPING, EQUAL MATCH";
         d->dcCursor.setColumn( pos ); // for next try
 
         if ( fw )
@@ -555,7 +538,7 @@ void DocWordCompletionPluginView::complete( bool fw )
 
     else  // no match
     {
-      //kDebug()<<"NO MATCH"<<endl;
+      //kDebug()<<"NO MATCH";
       if ( (! fw && d->dcCursor.line() == 0 ) || ( fw && d->dcCursor.line() >= doc->lines() ) )
       {
         KNotification::beep();
@@ -608,7 +591,7 @@ const KTextEditor::Range DocWordCompletionPluginView::range() const
 {
   KTextEditor::Cursor end = m_view->cursorPosition();
 
-  if ( ! end.column() ) return KTextEditor::Range::Range(); // no word
+  if ( ! end.column() ) return KTextEditor::Range(); // no word
   int line = end.line();
   int col = end.column();
 
@@ -625,10 +608,10 @@ const KTextEditor::Range DocWordCompletionPluginView::range() const
     break;
   }
 
-  return KTextEditor::Range::Range( KTextEditor::Cursor( line, col ), end );
+  return KTextEditor::Range( KTextEditor::Cursor( line, col ), end );
 }
 
-void DocWordCompletionPluginView::slotVariableChanged( const QString &var, const QString &val )
+void DocWordCompletionPluginView::slotVariableChanged( KTextEditor::Document*,const QString &var, const QString &val )
 {
   if ( var == "wordcompletion-autopopup" )
     d->autopopup->setEnabled( val == "true" );
@@ -637,70 +620,12 @@ void DocWordCompletionPluginView::slotVariableChanged( const QString &var, const
 }
 //END
 
-//BEGIN DocWordCompletionConfigPage
-DocWordCompletionConfigPage::DocWordCompletionConfigPage( DocWordCompletionPlugin *completion, QWidget *parent )
-  : KTextEditor::ConfigPage( parent )
-  , m_completion( completion )
-{
-  QVBoxLayout *lo = new QVBoxLayout( this );
-  lo->setSpacing( KDialog::spacingHint() );
-
-  cbAutoPopup = new QCheckBox( i18n("Automatically &show completion list"), this );
-  lo->addWidget( cbAutoPopup );
-
-  KHBox *hb = new KHBox( this );
-  hb->setSpacing( KDialog::spacingHint() );
-  lo->addWidget( hb );
-  QLabel *l = new QLabel( i18nc(
-      "Translators: This is the first part of two strings which will comprise the "
-      "sentence 'Show completions when a word is at least N characters'. The first "
-      "part is on the right side of the N, which is represented by a spinbox "
-      "widget, followed by the second part: 'characters long'. Characters is a "
-      "ingeger number between and including 1 and 30. Feel free to leave the "
-      "second part of the sentence blank if it suits your language better. ",
-      "Show completions &when a word is at least"), hb );
-  sbAutoPopup = new QSpinBox( hb );
-  sbAutoPopup->setRange( 1, 30 );
-  sbAutoPopup->setSingleStep( 1 );
-  l->setBuddy( sbAutoPopup );
-  lSbRight = new QLabel( i18nc(
-      "This is the second part of two strings that will comprise the sentence "
-      "'Show completions when a word is at least N characters'",
-      "characters long."), hb );
-
-  cbAutoPopup->setWhatsThis(i18n(
-      "Enable the automatic completion list popup as default. The popup can "
-      "be disabled on a view basis from the 'Tools' menu.") );
-  sbAutoPopup->setWhatsThis(i18n(
-      "Define the length a word should have before the completion list "
-      "is displayed.") );
-
-  cbAutoPopup->setChecked( m_completion->autoPopupEnabled() );
-  sbAutoPopup->setValue( m_completion->treshold() );
-
-  lo->addStretch();
-}
-
-void DocWordCompletionConfigPage::apply()
-{
-  m_completion->setAutoPopupEnabled( cbAutoPopup->isChecked() );
-  m_completion->setTreshold( sbAutoPopup->value() );
-  m_completion->writeConfig();
-}
-
-void DocWordCompletionConfigPage::reset()
-{
-  cbAutoPopup->setChecked( m_completion->autoPopupEnabled() );
-  sbAutoPopup->setValue( m_completion->treshold() );
-}
-
-void DocWordCompletionConfigPage::defaults()
-{
-  cbAutoPopup->setChecked( true );
-  sbAutoPopup->setValue( 3 );
-}
-
-//END DocWordCompletionConfigPage
+#include "docwordcompletion_config.h"
+K_PLUGIN_FACTORY_DEFINITION(DocWordCompletionFactory,
+        registerPlugin<DocWordCompletionConfig>();
+        registerPlugin<DocWordCompletionPlugin>();
+        )
+K_EXPORT_PLUGIN(DocWordCompletionFactory("ktexteditor_docwordcompletion", "ktexteditor_plugins"))
 
 #include "docwordcompletion.moc"
 // kate: space-indent on; indent-width 2; replace-tabs on; mixed-indent off;
