@@ -36,9 +36,9 @@
 #include <ktexteditor/configpage.h>
 #include <kxmlguiclient.h>
 
-#include <QEvent>
-#include <QObject>
-#include <QList>
+#include <QtCore/QEvent>
+#include <QtCore/QObject>
+#include <QtCore/QList>
 
 #include <kdebug.h>
 
@@ -70,9 +70,11 @@ class DocWordCompletionPlugin
   Q_OBJECT
 
   public:
-    DocWordCompletionPlugin( QObject *parent = 0,
-                            const QStringList &args = QStringList() );
-    virtual ~DocWordCompletionPlugin(){kDebug()<<"~DocWordCompletionPlugin"<<endl;};
+    explicit DocWordCompletionPlugin( QObject *parent,
+                            const QVariantList &args );
+    virtual ~DocWordCompletionPlugin(){kDebug()<<"~DocWordCompletionPlugin";}
+
+    static DocWordCompletionPlugin *self() { return plugin; }
 
     void addView (KTextEditor::View *view);
     void removeView (KTextEditor::View *view);
@@ -82,23 +84,13 @@ class DocWordCompletionPlugin
 
     virtual void readConfig (KConfig *) {}
     virtual void writeConfig (KConfig *) {}
-    virtual void configDialog (QWidget *parent);
-
-    // ConfigInterfaceExtention
-    uint configPages() const { return 1; }
-    bool configDialogSupported () const { return true; }
-    KTextEditor::ConfigPage * configPage( uint number, QWidget *parent );
-    QString configPageName( uint ) const;
-    QString configPageFullName( uint ) const;
-    QPixmap configPagePixmap( uint, int ) const;
-
-    uint treshold() const { return m_treshold; };
-    void setTreshold( uint t ) { m_treshold = t; };
-    bool autoPopupEnabled() const { return m_autopopup; };
-    void setAutoPopupEnabled( bool enable ) { m_autopopup = enable; };
-
 
+    uint treshold() const;
+    void setTreshold( uint t );
+    bool autoPopupEnabled() const;
+    void setAutoPopupEnabled( bool enable );
   private:
+    static DocWordCompletionPlugin *plugin;
     QList<class DocWordCompletionPluginView*> m_views;
     uint m_treshold;
     bool m_autopopup;
@@ -112,13 +104,17 @@ class DocWordCompletionPluginView
   Q_OBJECT
 
   public:
-    DocWordCompletionPluginView( uint treshold=3,
+    explicit DocWordCompletionPluginView( uint treshold=3,
                                  bool autopopup=true,
                                  KTextEditor::View *view=0,
                                  DocWordCompletionModel *completionModel=0 );
     ~DocWordCompletionPluginView();
 
-    void settreshold( uint treshold );
+    void setTreshold( uint treshold );
+    void setAutoPopupEnabled( bool enable );
+
+  public Q_SLOTS:
+    void toggleAutoPopup();
 
   private Q_SLOTS:
     void completeBackwards();
@@ -127,9 +123,8 @@ class DocWordCompletionPluginView
 
     void popupCompletionList();
     void autoPopupCompletionList();
-    void toggleAutoPopup();
 
-    void slotVariableChanged( const QString &, const QString & );
+    void slotVariableChanged(KTextEditor::Document*, const QString &, const QString & );
 
   private:
     void complete( bool fw=true );
@@ -144,23 +139,5 @@ class DocWordCompletionPluginView
     struct DocWordCompletionPluginViewPrivate *d;
 };
 
-class DocWordCompletionConfigPage : public KTextEditor::ConfigPage
-{
-  Q_OBJECT
-  public:
-    DocWordCompletionConfigPage( DocWordCompletionPlugin *completion, QWidget *parent );
-    virtual ~DocWordCompletionConfigPage() {}
-
-    virtual void apply();
-    virtual void reset();
-    virtual void defaults();
-
-  private:
-    DocWordCompletionPlugin *m_completion;
-    class QCheckBox *cbAutoPopup;
-    class QSpinBox *sbAutoPopup;
-    class QLabel *lSbRight;
-};
-
 #endif // _DocWordCompletionPlugin_h_
 // kate: space-indent on; indent-width 2; replace-tabs on; mixed-indent off;
