@@ -34,14 +34,15 @@
 #include <kaboutapplicationdialog.h>
 #include <kicon.h>
 #include <kencodingfiledialog.h>
-#include <kdiroperator.h>
 #include <kiconloader.h>
 #include <kstandarddirs.h>
 #include <kaboutdata.h>
 #include <kstatusbar.h>
 #include <kstandardaction.h>
 #include <kaction.h>
+#include <ktoggleaction.h>
 #include <kdebug.h>
+#include <kconfiggroup.h>
 #include <kglobal.h>
 #include <kapplication.h>
 #include <klocale.h>
@@ -49,7 +50,7 @@
 #include <kconfig.h>
 #include <kcmdlineargs.h>
 #include <kmessagebox.h>
-#include <kkeydialog.h>
+#include <kshortcutsdialog.h>
 #include <kedittoolbar.h>
 #include <kparts/event.h>
 #include <kmenubar.h>
@@ -58,21 +59,20 @@
 #include <krecentfilesaction.h>
 #include <kactioncollection.h>
 
-#include <QStackedWidget>
-#include <qpainter.h>
-#include <qlabel.h>
-#include <qcursor.h>
-#include <QMenu>
-#include <qpixmap.h>
-#include <qtimer.h>
-#include <qtextcodec.h>
-#include <qlayout.h>
+#include <QtGui/QStackedWidget>
+#include <QtGui/QPainter>
+#include <QtGui/QLabel>
+#include <QtGui/QCursor>
+#include <QtGui/QMenu>
+#include <QtGui/QPixmap>
+#include <QtCore/QTimer>
+#include <QtCore/QTextCodec>
+#include <QtGui/QLayout>
 //Added by qt3to4:
-#include <QDragEnterEvent>
-#include <QVBoxLayout>
-#include <Q3ValueList>
-#include <QDropEvent>
-#include <QTextIStream>
+#include <QtGui/QKeyEvent>
+#include <QtGui/QBoxLayout>
+#include <Qt3Support/Q3ValueList>
+#include <QtCore/QTextStream>
 
 #include <kxmlguifactory.h>
 
@@ -133,7 +133,7 @@ KWrite::KWrite (KTextEditor::Document *doc)
   if (KTextEditor::ModificationInterface* modiface = qobject_cast<KTextEditor::ModificationInterface*>(m_view->document()))
     connect(m_view->document(), SIGNAL(modifiedOnDisk(KTextEditor::Document*, bool, KTextEditor::ModificationInterface::ModifiedOnDiskReason)), this, SLOT(modifiedChanged()) );
   else
-    kWarning() << k_funcinfo << "Modification interface not supported." << endl;
+    kWarning() << "Modification interface not supported.";
   connect(m_view->document(), SIGNAL(documentNameChanged(KTextEditor::Document *)), this, SLOT(documentNameChanged()));
 
   setAcceptDrops(true);
@@ -194,7 +194,7 @@ void KWrite::setupActions()
     actionCollection()->addAction(m_recentFiles->objectName(), m_recentFiles);
     m_recentFiles->setWhatsThis(i18n("This lists files which you have opened recently, and allows you to easily open them again."));
 
-    QAction *a = new KAction(KIcon("window_new"), i18n("&New Window"), this);
+    QAction *a = new KAction(KIcon("window-new"), i18n("&New Window"), this);
     actionCollection()->addAction("view_new_view", a);
     connect(a, SIGNAL(triggered(bool)), SLOT(newView()));
     a->setWhatsThis(i18n("Create another view containing the current document"));
@@ -217,7 +217,6 @@ void KWrite::setupActions()
     m_paShowPath = new KToggleAction(i18n("Sho&w Path"), this);
     actionCollection()->addAction("set_showPath", m_paShowPath);
     m_paShowPath->setShortcuts(KShortcut());
-    m_paShowPath->setCheckedState(KGuiItem(i18n("Hide Path")));
     m_paShowPath->setWhatsThis(i18n("Show the complete document path in the window caption"));
     connect(m_paShowPath, SIGNAL(triggered()), this, SLOT(documentNameChanged()));
 
@@ -321,7 +320,7 @@ void KWrite::slotOpen( const KUrl& url )
 {
   if (url.isEmpty()) return;
 
-  if (!KIO::NetAccess::exists(url, true, this))
+  if (!KIO::NetAccess::exists(url, KIO::NetAccess::SourceSide, this))
   {
     KMessageBox::error (this, i18n("The given file could not be read, check if it exists or if it is readable for the current user."));
     return;
@@ -361,16 +360,16 @@ void KWrite::toggleStatusBar()
 
 void KWrite::editKeys()
 {
-  KKeyDialog dlg;
-  dlg.insert(actionCollection());
+  KShortcutsDialog dlg;
+  dlg.addCollection(actionCollection());
   if( m_view )
-    dlg.insert(m_view->actionCollection());
+    dlg.addCollection(m_view->actionCollection());
   dlg.configure();
 }
 
 void KWrite::editToolbars()
 {
-  KEditToolbar *dlg = new KEditToolbar(guiFactory());
+  KEditToolBar *dlg = new KEditToolBar(guiFactory());
 
   if (dlg->exec())
   {
@@ -426,16 +425,14 @@ void KWrite::slotEnableActions( bool enable )
 }
 
 //common config
-void KWrite::readConfig(KConfig *config)
+void KWrite::readConfig(const KConfigGroup &config)
 {
-  config->setGroup("General Options");
+  m_paShowStatusBar->setChecked( config.readEntry("ShowStatusBar", false) );
+  m_paShowPath->setChecked( config.readEntry("ShowPath", false) );
 
-  m_paShowStatusBar->setChecked( config->readEntry("ShowStatusBar", false) );
-  m_paShowPath->setChecked( config->readEntry("ShowPath", false) );
+  m_recentFiles->loadEntries(KConfigGroup(config.config(), "Recent Files"));
 
-  m_recentFiles->loadEntries(config, "Recent Files");
-
-  m_view->document()->editor()->readConfig(config);
+  m_view->document()->editor()->readConfig();
 
   if( m_paShowStatusBar->isChecked() )
     statusBar()->show();
@@ -443,31 +440,31 @@ void KWrite::readConfig(KConfig *config)
     statusBar()->hide();
 }
 
-void KWrite::writeConfig(KConfig *config)
+void KWrite::writeConfig(KConfigGroup &config)
 {
-  config->setGroup("General Options");
+  config.writeEntry("ShowStatusBar",m_paShowStatusBar->isChecked());
+  config.writeEntry("ShowPath",m_paShowPath->isChecked());
 
-  config->writeEntry("ShowStatusBar",m_paShowStatusBar->isChecked());
-  config->writeEntry("ShowPath",m_paShowPath->isChecked());
+  config.changeGroup("Recent Files");
+  m_recentFiles->saveEntries(config);
 
-  m_recentFiles->saveEntries(config, "Recent Files");
+  m_view->document()->editor()->writeConfig(dynamic_cast<KConfig*>(config.config()));
 
-  m_view->document()->editor()->writeConfig(config);
-
-  config->sync ();
+  config.sync ();
 }
 
 //config file
 void KWrite::readConfig()
 {
   KSharedConfig::Ptr config = KGlobal::config();
-  readConfig(config.data());
+  readConfig(config->group("General Options"));
 }
 
 void KWrite::writeConfig()
 {
   KSharedConfig::Ptr config = KGlobal::config();
-  writeConfig(config.data());
+  KConfigGroup go(config, "General Options");
+  writeConfig(go);
 }
 
 // session management
@@ -476,32 +473,33 @@ void KWrite::restore(KConfig *config, int n)
   readPropertiesInternal(config, n);
 }
 
-void KWrite::readProperties(KConfig *config)
+void KWrite::readProperties(const KConfigGroup &config)
 {
   readConfig(config);
 
   if (KTextEditor::SessionConfigInterface *iface = qobject_cast<KTextEditor::SessionConfigInterface *>(m_view))
-    iface->readSessionConfig(config);
+    iface->readSessionConfig(KConfigGroup(config.config(), "SOMEGROUP"));
 }
 
-void KWrite::saveProperties(KConfig *config)
+void KWrite::saveProperties(KConfigGroup & config)
 {
-  writeConfig(config);
-  config->writeEntry("DocumentNumber",docList.indexOf(m_view->document()) + 1);
+  writeConfig();
+  config.writeEntry("DocumentNumber",docList.indexOf(m_view->document()) + 1);
 
+  KConfigGroup cg(config.config(), "SOMEGROUP");
   if (KTextEditor::SessionConfigInterface *iface = qobject_cast<KTextEditor::SessionConfigInterface *>(m_view))
-    iface->writeSessionConfig(config);
+    iface->writeSessionConfig(cg);
 }
 
-void KWrite::saveGlobalProperties(KConfig *config) //save documents
+void KWrite::saveGlobalProperties(KConfig *_config) //save documents
 {
-  config->setGroup("Number");
-  config->writeEntry("NumberOfDocuments",docList.count());
+  KConfigGroup config(_config, "Number");
+  config.writeEntry("NumberOfDocuments",docList.count());
 
   for (int z = 1; z <= docList.count(); z++)
   {
      QString buf = QString("Document %1").arg(z);
-     config->setGroup(buf);
+     config.changeGroup(buf);
 
      KTextEditor::Document *doc = docList.at(z - 1);
 
@@ -512,9 +510,9 @@ void KWrite::saveGlobalProperties(KConfig *config) //save documents
   for (int z = 1; z <= winList.count(); z++)
   {
      QString buf = QString("Window %1").arg(z);
-     config->setGroup(buf);
+     config.changeGroup(buf);
 
-     config->writeEntry("DocumentNumber",docList.indexOf(winList.at(z-1)->view()->document()) + 1);
+     config.writeEntry("DocumentNumber",docList.indexOf(winList.at(z-1)->view()->document()) + 1);
   }
 }
 
@@ -540,26 +538,26 @@ void KWrite::restore()
   KTextEditor::Document *doc;
   KWrite *t;
 
-  config->setGroup("Number");
-  docs = config->readEntry("NumberOfDocuments", 0);
-  windows = config->readEntry("NumberOfWindows", 0);
+  KConfigGroup cg(config, "Number");
+  docs = cg.readEntry("NumberOfDocuments", 0);
+  windows = cg.readEntry("NumberOfWindows", 0);
 
   for (int z = 1; z <= docs; z++)
   {
      buf = QString("Document %1").arg(z);
-     config->setGroup(buf);
+     cg.changeGroup(buf);
      doc=editor->createDocument(0);
 
      if (KTextEditor::SessionConfigInterface *iface = qobject_cast<KTextEditor::SessionConfigInterface *>(doc))
-       iface->readSessionConfig(config);
+       iface->readSessionConfig(cg);
      docList.append(doc);
   }
 
   for (int z = 1; z <= windows; z++)
   {
     buf = QString("Window %1").arg(z);
-    config->setGroup(buf);
-    t = new KWrite(docList.at(config->readEntry("DocumentNumber", 0) - 1));
+    KConfigGroup cg( config, buf);
+    t = new KWrite(docList.at(cg.readEntry("DocumentNumber", 0) - 1));
     t->restore(config,z);
   }
 }
@@ -660,68 +658,63 @@ void KWrite::documentNameChanged ()
   }
 }
 
-static KCmdLineOptions options[] =
-{
-  { "stdin",    I18N_NOOP("Read the contents of stdin"), 0},
-  { "encoding <argument>",      I18N_NOOP("Set encoding for the file to open"), 0 },
-  { "line <argument>",      I18N_NOOP("Navigate to this line"), 0 },
-  { "column <argument>",      I18N_NOOP("Navigate to this column"), 0 },
-  { "+[URL]",   I18N_NOOP("Document to open"), 0 },
-  KCmdLineLastOption
-};
-
 extern "C" KDE_EXPORT int main(int argc, char **argv)
 {
-  KLocale::setMainCatalog("kate");         //lukas: set this to have the kwritepart translated using kate message catalog
+  KCmdLineOptions options;
+  options.add("stdin", ki18n("Read the contents of stdin"));
+  options.add("encoding <argument>", ki18n("Set encoding for the file to open"));
+  options.add("line <argument>", ki18n("Navigate to this line"));
+  options.add("column <argument>", ki18n("Navigate to this column"));
+  options.add("+[URL]", ki18n("Document to open"));
 
   // here we go, construct the KWrite version
   QString kWriteVersion  = QString ("%1.%2.%3").arg(KDE::versionMajor() + 1).arg(KDE::versionMinor()).arg(KDE::versionRelease());
 
-  KAboutData aboutData ( "kwrite",
-                         I18N_NOOP("KWrite"),
-                         kWriteVersion.toLatin1().constData(),
-                         I18N_NOOP( "KWrite - Text Editor" ), KAboutData::License_LGPL_V2,
-                         I18N_NOOP( "(c) 2000-2005 The Kate Authors" ), 0, "http://kate.kde.org" );
+  KAboutData aboutData ( "kwrite", "kate",
+                         ki18n("KWrite"),
+                         kWriteVersion.toLatin1(),
+                         ki18n( "KWrite - Text Editor" ), KAboutData::License_LGPL_V2,
+                         ki18n( "(c) 2000-2005 The Kate Authors" ), KLocalizedString(), "http://kate.kde.org" );
 
-  aboutData.addAuthor ("Christoph Cullmann", I18N_NOOP("Maintainer"), "cullmann@kde.org", "http://www.babylon2k.de");
-  aboutData.addAuthor ("Anders Lund", I18N_NOOP("Core Developer"), "anders@alweb.dk", "http://www.alweb.dk");
-  aboutData.addAuthor ("Joseph Wenninger", I18N_NOOP("Core Developer"), "jowenn@kde.org","http://stud3.tuwien.ac.at/~e9925371");
-  aboutData.addAuthor ("Hamish Rodda",I18N_NOOP("Core Developer"), "rodda@kde.org");
-  aboutData.addAuthor ("Waldo Bastian", I18N_NOOP( "The cool buffersystem" ), "bastian@kde.org" );
-  aboutData.addAuthor ("Charles Samuels", I18N_NOOP("The Editing Commands"), "charles@kde.org");
-  aboutData.addAuthor ("Matt Newell", I18N_NOOP("Testing, ..."), "newellm@proaxis.com");
-  aboutData.addAuthor ("Michael Bartl", I18N_NOOP("Former Core Developer"), "michael.bartl1@chello.at");
-  aboutData.addAuthor ("Michael McCallum", I18N_NOOP("Core Developer"), "gholam@xtra.co.nz");
-  aboutData.addAuthor ("Jochen Wilhemly", I18N_NOOP( "KWrite Author" ), "digisnap@cs.tu-berlin.de" );
-  aboutData.addAuthor ("Michael Koch",I18N_NOOP("KWrite port to KParts"), "koch@kde.org");
-  aboutData.addAuthor ("Christian Gebauer", 0, "gebauer@kde.org" );
-  aboutData.addAuthor ("Simon Hausmann", 0, "hausmann@kde.org" );
-  aboutData.addAuthor ("Glen Parker",I18N_NOOP("KWrite Undo History, Kspell integration"), "glenebob@nwlink.com");
-  aboutData.addAuthor ("Scott Manson",I18N_NOOP("KWrite XML Syntax highlighting support"), "sdmanson@alltel.net");
-  aboutData.addAuthor ("John Firebaugh",I18N_NOOP("Patches and more"), "jfirebaugh@kde.org");
+  aboutData.addAuthor (ki18n("Christoph Cullmann"), ki18n("Maintainer"), "cullmann@kde.org", "http://www.babylon2k.de");
+  aboutData.addAuthor (ki18n("Anders Lund"), ki18n("Core Developer"), "anders@alweb.dk", "http://www.alweb.dk");
+  aboutData.addAuthor (ki18n("Joseph Wenninger"), ki18n("Core Developer"), "jowenn@kde.org","http://stud3.tuwien.ac.at/~e9925371");
+  aboutData.addAuthor (ki18n("Hamish Rodda"),ki18n("Core Developer"), "rodda@kde.org");
+  aboutData.addAuthor (ki18n("Waldo Bastian"), ki18n( "The cool buffersystem" ), "bastian@kde.org" );
+  aboutData.addAuthor (ki18n("Charles Samuels"), ki18n("The Editing Commands"), "charles@kde.org");
+  aboutData.addAuthor (ki18n("Matt Newell"), ki18n("Testing, ..."), "newellm@proaxis.com");
+  aboutData.addAuthor (ki18n("Michael Bartl"), ki18n("Former Core Developer"), "michael.bartl1@chello.at");
+  aboutData.addAuthor (ki18n("Michael McCallum"), ki18n("Core Developer"), "gholam@xtra.co.nz");
+  aboutData.addAuthor (ki18n("Jochen Wilhemly"), ki18n( "KWrite Author" ), "digisnap@cs.tu-berlin.de" );
+  aboutData.addAuthor (ki18n("Michael Koch"),ki18n("KWrite port to KParts"), "koch@kde.org");
+  aboutData.addAuthor (ki18n("Christian Gebauer"), KLocalizedString(), "gebauer@kde.org" );
+  aboutData.addAuthor (ki18n("Simon Hausmann"), KLocalizedString(), "hausmann@kde.org" );
+  aboutData.addAuthor (ki18n("Glen Parker"),ki18n("KWrite Undo History, Kspell integration"), "glenebob@nwlink.com");
+  aboutData.addAuthor (ki18n("Scott Manson"),ki18n("KWrite XML Syntax highlighting support"), "sdmanson@alltel.net");
+  aboutData.addAuthor (ki18n("John Firebaugh"),ki18n("Patches and more"), "jfirebaugh@kde.org");
 
-  aboutData.addCredit ("Matteo Merli",I18N_NOOP("Highlighting for RPM Spec-Files, Perl, Diff and more"), "merlim@libero.it");
-  aboutData.addCredit ("Rocky Scaletta",I18N_NOOP("Highlighting for VHDL"), "rocky@purdue.edu");
-  aboutData.addCredit ("Yury Lebedev",I18N_NOOP("Highlighting for SQL"),"");
-  aboutData.addCredit ("Chris Ross",I18N_NOOP("Highlighting for Ferite"),"");
-  aboutData.addCredit ("Nick Roux",I18N_NOOP("Highlighting for ILERPG"),"");
-  aboutData.addCredit ("Carsten Niehaus", I18N_NOOP("Highlighting for LaTeX"),"");
-  aboutData.addCredit ("Per Wigren", I18N_NOOP("Highlighting for Makefiles, Python"),"");
-  aboutData.addCredit ("Jan Fritz", I18N_NOOP("Highlighting for Python"),"");
-  aboutData.addCredit ("Daniel Naber","","");
-  aboutData.addCredit ("Roland Pabel",I18N_NOOP("Highlighting for Scheme"),"");
-  aboutData.addCredit ("Cristi Dumitrescu",I18N_NOOP("PHP Keyword/Datatype list"),"");
-  aboutData.addCredit ("Carsten Pfeiffer", I18N_NOOP("Very nice help"), "");
-  aboutData.addCredit (I18N_NOOP("All people who have contributed and I have forgotten to mention"),"","");
+  aboutData.addCredit (ki18n("Matteo Merli"),ki18n("Highlighting for RPM Spec-Files, Perl, Diff and more"), "merlim@libero.it");
+  aboutData.addCredit (ki18n("Rocky Scaletta"),ki18n("Highlighting for VHDL"), "rocky@purdue.edu");
+  aboutData.addCredit (ki18n("Yury Lebedev"),ki18n("Highlighting for SQL"),"");
+  aboutData.addCredit (ki18n("Chris Ross"),ki18n("Highlighting for Ferite"),"");
+  aboutData.addCredit (ki18n("Nick Roux"),ki18n("Highlighting for ILERPG"),"");
+  aboutData.addCredit (ki18n("Carsten Niehaus"), ki18n("Highlighting for LaTeX"),"");
+  aboutData.addCredit (ki18n("Per Wigren"), ki18n("Highlighting for Makefiles, Python"),"");
+  aboutData.addCredit (ki18n("Jan Fritz"), ki18n("Highlighting for Python"),"");
+  aboutData.addCredit (ki18n("Daniel Naber"));
+  aboutData.addCredit (ki18n("Roland Pabel"),ki18n("Highlighting for Scheme"),"");
+  aboutData.addCredit (ki18n("Cristi Dumitrescu"),ki18n("PHP Keyword/Datatype list"),"");
+  aboutData.addCredit (ki18n("Carsten Pfeiffer"), ki18n("Very nice help"), "");
+  aboutData.addCredit (ki18n("All people who have contributed and I have forgotten to mention"));
 
-  aboutData.setTranslator(I18N_NOOP2("NAME OF TRANSLATORS","Your names"), I18N_NOOP2("EMAIL OF TRANSLATORS","Your emails"));
+  aboutData.setTranslator(ki18nc("NAME OF TRANSLATORS","Your names"), ki18nc("EMAIL OF TRANSLATORS","Your emails"));
 
   KCmdLineArgs::init( argc, argv, &aboutData );
   KCmdLineArgs::addCmdLineOptions( options );
 
   KApplication a;
 
-  KGlobal::locale()->insertCatalog("katepart");
+  KGlobal::locale()->insertCatalog("katepart4");
 #if 0
   DCOPClient *client = KApplication::dcopClient();
   if (!client->isRegistered())
@@ -741,7 +734,7 @@ extern "C" KDE_EXPORT int main(int argc, char **argv)
     bool nav = false;
     int line = 0, column = 0;
 
-    QTextCodec *codec = args->isSet("encoding") ? QTextCodec::codecForName(args->getOption("encoding")) : 0;
+    QTextCodec *codec = args->isSet("encoding") ? QTextCodec::codecForName(args->getOption("encoding").toUtf8()) : 0;
 
     if (args->isSet ("line"))
     {
