@@ -23,13 +23,12 @@
 #include <unistd.h>
 #include <stdlib.h>
 
-#include <qdatetime.h>
-#include <qfile.h>
-#include <qtextstream.h>
-#include <qtextcodec.h>
+#include <QtCore/QDate>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
+#include <QtCore/QTextCodec>
 
 #include <kconfig.h>
-#include <ksimpleconfig.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
 #include <kglobal.h>
@@ -39,14 +38,6 @@
 #include <ktemporaryfile.h>
 #include <kurl.h>
 
-static KCmdLineOptions options[] =
-{
-        { "debug", I18N_NOOP("Keep output results from scripts"), 0 },
-	{ "check <update-file>", I18N_NOOP("Check whether config file itself requires updating"), 0 },
-	{ "+[file]", I18N_NOOP("File to read update instructions from"), 0 },
-        KCmdLineLastOption
-};
-
 class KonfUpdate
 {
 public:
@@ -81,6 +72,7 @@ protected:
    KConfig *config;
    QString currentFilename;
    bool skip;
+   bool skipFile;
    bool debug;
    QString id;
 
@@ -115,6 +107,7 @@ KonfUpdate::KonfUpdate()
    newConfig = 0;
 
    config = new KConfig("kconf_updaterc");
+   KConfigGroup cg(config, QString());
 
    QStringList updateFiles;
    KCmdLineArgs *args=KCmdLineArgs::parsedArgs();
@@ -125,11 +118,11 @@ KonfUpdate::KonfUpdate()
    if (args->isSet("check"))
    {
       m_bUseConfigInfo = true;
-      QString file = KStandardDirs::locate("data", "kconf_update/"+QFile::decodeName(args->getOption("check")));
+      QString file = KStandardDirs::locate("data", "kconf_update/"+args->getOption("check"));
       if (file.isEmpty())
       {
-         qWarning("File '%s' not found.", args->getOption("check").data());
-         log() << "File '" << QFile::decodeName(args->getOption("check")) << "' passed on command line not found" << endl;
+         qWarning("File '%s' not found.", args->getOption("check").toLocal8Bit().data());
+         log() << "File '" << args->getOption("check") << "' passed on command line not found" << endl;
          return;
       }
       updateFiles.append(file);
@@ -140,13 +133,13 @@ KonfUpdate::KonfUpdate()
       {
          KUrl url = args->url(i);
          if (!url.isLocalFile())
-            KCmdLineArgs::usage(i18n("Only local files are supported."));
+            KCmdLineArgs::usageError(i18n("Only local files are supported."));
          updateFiles.append(url.path());
       }
    }
    else
    {
-      if (config->readEntry("autoUpdateDisabled", false))
+      if (cg.readEntry("autoUpdateDisabled", false))
          return;
       updateFiles = findUpdateFiles(true);
       updateAll = true;
@@ -160,10 +153,9 @@ KonfUpdate::KonfUpdate()
       updateFile(file);
    }
 
-   config->setGroup(QString());
-   if (updateAll && !config->readEntry("updateInfoAdded", false))
+   if (updateAll && !cg.readEntry("updateInfoAdded", false))
    {
-       config->writeEntry("updateInfoAdded", true);
+       cg.writeEntry("updateInfoAdded", true);
        updateFiles = findUpdateFiles(false);
 
        for(QStringList::ConstIterator it = updateFiles.begin();
@@ -223,9 +215,9 @@ QStringList KonfUpdate::findUpdateFiles(bool dirtyOnly)
          int i = file.lastIndexOf('/');
          if (i != -1)
             file = file.mid(i+1);
-         config->setGroup(file);
-         time_t ctime = config->readEntry("ctime", 0);
-         time_t mtime = config->readEntry("mtime", 0);
+         KConfigGroup cg(config, file);
+         time_t ctime = cg.readEntry("ctime", 0);
+         time_t mtime = cg.readEntry("mtime", 0);
          if (!dirtyOnly ||
              (ctime != buff.st_ctime) || (mtime != buff.st_mtime))
          {
@@ -282,13 +274,13 @@ void KonfUpdate::checkGotFile(const QString &_file, const QString &id)
 
 //   qDebug("File %s, id %s", file.toLatin1().constData(), id.toLatin1().constData());
 
-   KSimpleConfig cfg(file);
-   cfg.setGroup("$Version");
-   QStringList ids = cfg.readEntry("update_info", QStringList());
+   KConfig cfg(file, KConfig::OnlyLocal);
+   KConfigGroup cg(&cfg, "$Version");
+   QStringList ids = cg.readEntry("update_info", QStringList());
    if (ids.contains(id))
        return;
    ids.append(id);
-   cfg.writeEntry("update_info", ids);
+   cg.writeEntry("update_info", ids);
 }
 
 /**
@@ -341,6 +333,8 @@ bool KonfUpdate::updateFile(const QString &filename)
          gotOptions(m_line.mid(8));
       else if (m_line.startsWith("File="))
          gotFile(m_line.mid(5));
+      else if(skipFile)
+         continue;
       else if (m_line.startsWith("Group="))
          gotGroup(m_line.mid(6));
       else if (m_line.startsWith("RemoveGroup="))
@@ -385,10 +379,10 @@ bool KonfUpdate::updateFile(const QString &filename)
 
    struct stat buff;
    stat( QFile::encodeName(filename), &buff);
-   config->setGroup(currentFilename);
-   config->writeEntry("ctime", int(buff.st_ctime));
-   config->writeEntry("mtime", int(buff.st_mtime));
-   config->sync();
+   KConfigGroup cg(config, currentFilename);
+   cg.writeEntry("ctime", int(buff.st_ctime));
+   cg.writeEntry("mtime", int(buff.st_mtime));
+   cg.sync();
    return true;
 }
 
@@ -398,21 +392,22 @@ void KonfUpdate::gotId(const QString &_id)
 {
    if (!id.isEmpty() && !skip)
    {
-       config->setGroup(currentFilename);
-       QStringList ids = config->readEntry("done", QStringList());
+       KConfigGroup cg(config, currentFilename);
+
+       QStringList ids = cg.readEntry("done", QStringList());
        if (!ids.contains(id))
        {
           ids.append(id);
-          config->writeEntry("done", ids);
-          config->sync();
+          cg.writeEntry("done", ids);
+          cg.sync();
        }
    }
 
    // Flush pending changes
    gotFile(QString());
+   KConfigGroup cg(config, currentFilename);
 
-   config->setGroup(currentFilename);
-   QStringList ids = config->readEntry("done", QStringList());
+   QStringList ids = cg.readEntry("done", QStringList());
    if (!_id.isEmpty())
    {
        if (ids.contains(_id))
@@ -425,6 +420,7 @@ void KonfUpdate::gotId(const QString &_id)
           }
        }
        skip = false;
+       skipFile = false;
        id = _id;
        if (m_bUseConfigInfo)
           log() << currentFilename << ": Checking update '" << _id << "'" << endl;
@@ -444,15 +440,15 @@ void KonfUpdate::gotFile(const QString &_file)
       delete oldConfig1;
       oldConfig1 = 0;
 
-      oldConfig2->setGroup("$Version");
-      QStringList ids = oldConfig2->readEntry("update_info", QStringList());
+      KConfigGroup cg(oldConfig2, "$Version");
+      QStringList ids = cg.readEntry("update_info", QStringList());
       QString cfg_id = currentFilename + ':' + id;
       if (!ids.contains(cfg_id) && !skip)
       {
          ids.append(cfg_id);
-         oldConfig2->writeEntry("update_info", ids);
+         cg.writeEntry("update_info", ids);
       }
-      oldConfig2->sync();
+      cg.sync();
       delete oldConfig2;
       oldConfig2 = 0;
 
@@ -472,13 +468,13 @@ void KonfUpdate::gotFile(const QString &_file)
    if (!newFile.isEmpty())
    {
       // Close new file.
-      newConfig->setGroup("$Version");
-      QStringList ids = newConfig->readEntry("update_info", QStringList());
+      KConfigGroup cg(newConfig, "$Version");
+      QStringList ids = cg.readEntry("update_info", QStringList());
       QString cfg_id = currentFilename + ':' + id;
       if (!ids.contains(cfg_id) && !skip)
       {
          ids.append(cfg_id);
-         newConfig->writeEntry("update_info", ids);
+         cg.writeEntry("update_info", ids);
       }
       newConfig->sync();
       delete newConfig;
@@ -503,10 +499,10 @@ void KonfUpdate::gotFile(const QString &_file)
 
    if (!oldFile.isEmpty())
    {
-      oldConfig2 = new KConfig(oldFile, false, false);
+      oldConfig2 = new KConfig(oldFile, KConfig::NoGlobals);
       QString cfg_id = currentFilename + ':' + id;
-      oldConfig2->setGroup("$Version");
-      QStringList ids = oldConfig2->readEntry("update_info", QStringList());
+      KConfigGroup cg(oldConfig2, "$Version");
+      QStringList ids = cg.readEntry("update_info", QStringList());
       if (ids.contains(cfg_id))
       {
          skip = true;
@@ -516,9 +512,9 @@ void KonfUpdate::gotFile(const QString &_file)
 
       if (!newFile.isEmpty())
       {
-         newConfig = new KConfig(newFile, false, false);
-         newConfig->setGroup("$Version");
-         ids = newConfig->readEntry("update_info", QStringList());
+         newConfig = new KConfig(newFile, KConfig::NoGlobals);
+         KConfigGroup cg(newConfig, "$Version");
+         ids = cg.readEntry("update_info", QStringList());
          if (ids.contains(cfg_id))
          {
             skip = true;
@@ -530,7 +526,7 @@ void KonfUpdate::gotFile(const QString &_file)
          newConfig = oldConfig2;
       }
 
-      oldConfig1 = new KConfig(oldFile, true, false);
+      oldConfig1 = new KConfig(oldFile, KConfig::NoGlobals);
    }
    else
    {
@@ -539,6 +535,18 @@ void KonfUpdate::gotFile(const QString &_file)
    newFileName = newFile;
    if (newFileName.isEmpty())
       newFileName = oldFile;
+
+   skipFile = false;
+   if( !oldFile.isEmpty())
+   { // if File= is specified, it doesn't exist, is empty or contains only kconf_update's [$Version] group, skip
+      if( oldConfig1 != NULL
+          && ( oldConfig1->groupList().isEmpty()
+              || ( oldConfig1->groupList().count() == 1 && oldConfig1->groupList().first() == "$Version" )))
+      {
+         log() << currentFilename << ": File '" << oldFile << "' does not exist or empty, skipping" << endl;
+         skipFile = true;
+      }
+   }
 }
 
 void KonfUpdate::gotGroup(const QString &_group)
@@ -598,18 +606,18 @@ void KonfUpdate::gotKey(const QString &_key)
       log() << currentFilename << ": !! Key without previous File specification in line " << m_lineCount << " : '" << m_line << "'" << endl;
       return;
    }
-   oldConfig1->setGroup(oldGroup);
-   if (!oldConfig1->hasKey(oldKey))
+   KConfigGroup cg1( oldConfig1, oldGroup);
+   if (!cg1.hasKey(oldKey))
       return;
-   QString value = oldConfig1->readEntry(oldKey, QString());
-   newConfig->setGroup(newGroup);
-   if (!m_bOverwrite && newConfig->hasKey(newKey))
+   QString value = cg1.readEntry(oldKey, QString());
+   KConfigGroup newFGroup( newConfig, newGroup);
+   if (!m_bOverwrite && newFGroup.hasKey(newKey))
    {
       log() << currentFilename << ": Skipping " << newFileName << ":" << newGroup << ":" << newKey << ", already exists."<< endl;
       return;
    }
    log() << currentFilename << ": Updating " << newFileName << ":" << newGroup << ":" << newKey << " to '" << value << "'" << endl;
-   newConfig->writeEntry(newKey, value);
+   newFGroup.writeEntry(newKey, value);
 
    if (m_bCopy)
       return; // Done.
@@ -619,8 +627,8 @@ void KonfUpdate::gotKey(const QString &_key)
        (oldGroup == newGroup) &&
        (oldKey == newKey))
       return; // Don't delete!
-   oldConfig2->setGroup(oldGroup);
-   oldConfig2->deleteEntry(oldKey);
+   KConfigGroup oldGroup2( oldConfig2, oldGroup);
+   oldGroup2.deleteEntry(oldKey);
    log() << currentFilename << ": Removing " << oldFile << ":" << oldGroup << ":" << oldKey << ", moved." << endl;
    /*if (oldConfig2->deleteGroup(oldGroup, KConfigBase::Normal)) { // Delete group if empty.
       log() << currentFilename << ": Removing empty group " << oldFile << ":" << oldGroup << endl;
@@ -643,14 +651,14 @@ void KonfUpdate::gotRemoveKey(const QString &_key)
       return;
    }
 
-   oldConfig1->setGroup(oldGroup);
-   if (!oldConfig1->hasKey(oldKey))
+   KConfigGroup cg1(oldConfig1, oldGroup);
+   if (!cg1.hasKey(oldKey))
       return;
    log() << currentFilename << ": RemoveKey removes " << oldFile << ":" << oldGroup << ":" << oldKey << endl;
 
    // Delete old entry
-   oldConfig2->setGroup(oldGroup);
-   oldConfig2->deleteEntry(oldKey);
+   KConfigGroup cg2( oldConfig2, oldGroup);
+   cg2.deleteEntry(oldKey);
    /*if (oldConfig2->deleteGroup(oldGroup, KConfigBase::Normal)) { // Delete group if empty.
       log() << currentFilename << ": Removing empty group " << oldFile << ":" << oldGroup << endl;
    }   (this should be automatic)*/
@@ -708,13 +716,13 @@ void KonfUpdate::gotOptions(const QString &_options)
 void KonfUpdate::copyGroup(KConfigBase *cfg1, const QString &group1,
                            KConfigBase *cfg2, const QString &group2)
 {
-   cfg1->setGroup(group1);
-   cfg2->setGroup(group2);
-   QMap<QString, QString> list = cfg1->entryMap(group1);
+   KConfigGroup cg1(cfg1, group1);
+   KConfigGroup cg2(cfg2, group2);
+   QMap<QString, QString> list = cg1.entryMap();
    for(QMap<QString, QString>::Iterator it = list.begin();
        it != list.end(); ++it)
    {
-      cfg2->writeEntry(it.key(), cfg1->readEntry(it.key(), QString()));
+      cg2.writeEntry(it.key(), cg1.readEntry(it.key(), QString()));
    }
 }
 
@@ -793,7 +801,7 @@ void KonfUpdate::gotScript(const QString &_script)
            tmp1.setAutoRemove(false);
            log() << "Script input stored in " << tmp1.fileName() << endl;
        }
-       KSimpleConfig cfg(tmp1.fileName());
+       KConfig cfg(tmp1.fileName(), KConfig::OnlyLocal);
 
        if (oldGroup.isEmpty())
        {
@@ -860,7 +868,7 @@ void KonfUpdate::gotScript(const QString &_script)
        while(!ts.atEnd())
        {
          QString line = ts.readLine();
-         if (line.startsWith("["))
+         if (line.startsWith('['))
          {
             int j = line.indexOf(']')+1;
             if (j > 0)
@@ -878,8 +886,8 @@ void KonfUpdate::gotScript(const QString &_script)
                   key = key.mid(j);
                }
             }
-            oldConfig2->setGroup(group);
-            oldConfig2->deleteEntry(key);
+            KConfigGroup cg(oldConfig2, group);
+            cg.deleteEntry(key);
             log() << currentFilename << ": Script removes " << oldFile << ":" << group << ":" << key << endl;
             /*if (oldConfig2->deleteGroup(group, KConfigBase::Normal)) { // Delete group if empty.
                log() << currentFilename << ": Removing empty group " << oldFile << ":" << group << endl;
@@ -909,7 +917,7 @@ void KonfUpdate::gotScript(const QString &_script)
      KConfig *saveOldConfig1 = oldConfig1;
      QString saveOldGroup = oldGroup;
      QString saveNewGroup = newGroup;
-     oldConfig1 = new KConfig(tmp2.fileName(), true, false);
+     oldConfig1 = new KConfig(tmp2.fileName(), KConfig::NoGlobals);
 
      // For all groups...
      QStringList grpList = oldConfig1->groupList();
@@ -941,13 +949,18 @@ void KonfUpdate::resetOptions()
 
 extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
 {
-   KAboutData aboutData("kconf_update", I18N_NOOP("KConf Update"),
-                        "1.0.2",
-                        I18N_NOOP("KDE Tool for updating user configuration files"),
-                        KAboutData::License_GPL,
-                        "(c) 2001, Waldo Bastian");
+   KCmdLineOptions options;
+   options.add("debug", ki18n("Keep output results from scripts"));
+   options.add("check <update-file>", ki18n("Check whether config file itself requires updating"));
+   options.add("+[file]", ki18n("File to read update instructions from"));
 
-   aboutData.addAuthor("Waldo Bastian", 0, "bastian@kde.org");
+   KAboutData aboutData("kconf_update", 0, ki18n("KConf Update"),
+                        "1.0.2",
+                        ki18n("KDE Tool for updating user configuration files"),
+                        KAboutData::License_GPL,
+                        ki18n("(c) 2001, Waldo Bastian"));
+
+   aboutData.addAuthor(ki18n("Waldo Bastian"), KLocalizedString(), "bastian@kde.org");
 
    KCmdLineArgs::init(argc, argv, &aboutData);
    KCmdLineArgs::addCmdLineOptions(options);
