@@ -19,6 +19,8 @@
    Boston, MA 02110-1301, USA.
 */
 
+#include "k3passworddialog.h"
+
 #include <sys/time.h>
 #include <sys/resource.h>
 
@@ -42,7 +44,6 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 
-#include "k3passworddialog.h"
 #include <kconfiggroup.h>
 
 /*
@@ -145,6 +146,11 @@ K3PasswordEdit::~K3PasswordEdit()
     delete_d(this);
 }
 
+const char *K3PasswordEdit::password() const
+{
+    return m_Password;
+}
+
 void K3PasswordEdit::insert(const QString &txt)
 {
     const QByteArray localTxt = txt.toLocal8Bit();
@@ -330,7 +336,7 @@ void K3PasswordDialog::init()
 
     // Row 1: pixmap + prompt
     QLabel *lbl;
-    const QPixmap pix( KIconLoader::global()->loadIcon( d->iconName, K3Icon::NoGroup, K3Icon::SizeHuge, 0, 0, true));
+    const QPixmap pix( KIconLoader::global()->loadIcon( d->iconName, K3Icon::NoGroup, K3Icon::SizeHuge, 0, QStringList(), 0, true));
     if (!pix.isNull()) {
 	lbl = new QLabel(m_pMain);
 	lbl->setPixmap(pix);
@@ -526,6 +532,11 @@ void K3PasswordDialog::slotKeep(bool keep)
     m_Keep = keep;
 }
 
+bool K3PasswordDialog::checkPassword(const char *)
+{
+    return true;
+}
+
 
 int K3PasswordDialog::getPassword(QWidget *parent, QByteArray &password, const QString &caption,
     const QString &prompt, bool *keep)
@@ -715,4 +726,14 @@ int K3PasswordDialog::passwordStrengthWarningLevel() const {
     return d->passwordStrengthWarningLevel;
 }
 
+const char *K3PasswordDialog::password() const
+{
+    return m_pEdit->password();
+}
+
+bool K3PasswordDialog::keep() const
+{
+    return m_Keep;
+}
+
 #include "k3passworddialog.moc"
