@@ -16,13 +16,18 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef _KPOPUP_H
-#define _KPOPUP_H
+#ifndef _K3POPUPMENU_H
+#define _K3POPUPMENU_H
+
+#ifndef QT3_SUPPORT
+#define QT3_SUPPORT
+#endif
+
+#include <kde3support_export.h>
+#include <kpixmapeffect.h>
 
 #include <Qt3Support/Q3PopupMenu>
 #include <QtGui/QMenuItem>
-#include <kpixmapeffect.h>
-#include <kdelibs_export.h>
 
 /**
  * @short A menu with keyboard searching and convenience methods for title items.
@@ -185,7 +190,7 @@ public:
 
     /**
      * Helper for porting things. Returns ID of action, or -1 if passed null.
-     * ### KDE4: remove once we've cleaned up stuff
+     * ### KDE4: should be able to remove on Monday
      */
     static int actionId(QAction* action)
     {
