@@ -17,13 +17,14 @@
    Boston, MA 02110-1301, USA.
 */
 
+#include "k3sconfig.h"
 
-#include <qcheckbox.h>
-#include <qcombobox.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qfileinfo.h>
-#include <qdir.h>
+#include <QtGui/QCheckBox>
+#include <QtGui/QComboBox>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtCore/QFileInfo>
+#include <QtCore/QDir>
 
 #include <ktoolinvocation.h>
 #include <kconfig.h>
@@ -36,7 +37,7 @@
 #include <kpushbutton.h>
 #include <kstandardguiitem.h>
 
-#include "k3sconfig.h"
+#include <config.h>
 #include <kconfiggroup.h>
 
 class K3SpellConfigPrivate
@@ -57,7 +58,7 @@ K3SpellConfig::K3SpellConfig (const K3SpellConfig &_ksc)
   , clientcombo(0)
   , d(new K3SpellConfigPrivate)
 {
-  kDebug(750) << "Entering K3SpellConfig::K3SpellConfig(K3SpellConfig&)" << endl;
+  kDebug(750) << "Entering K3SpellConfig::K3SpellConfig(K3SpellConfig&)";
   setDoSpellChecking( _ksc.doSpellChecking() );
   setReplaceAllList( _ksc.replaceAllList() );
   setNoRootAffix( _ksc.noRootAffix() );
@@ -105,18 +106,18 @@ K3SpellConfig::K3SpellConfig( QWidget *parent,
 
   QGridLayout *glay = new QGridLayout( this );
   glay->setSpacing( KDialog::spacingHint() );
-  cb0 = new QCheckBox( i18n("Do SpellChecking"), this );
+  cb0 = new QCheckBox( i18nc("@option:check", "Do SpellChecking"), this );
   cb0->setObjectName( "DoSpellChecking" );
   connect( cb0, SIGNAL(toggled(bool)), SLOT(sDoSpell()) );
-  cb1 = new QCheckBox( i18n("Create &root/affix combinations"
-                            " not in dictionary"), this );
+  cb1 = new QCheckBox( i18nc("@option:check",
+                             "Create &root/affix combinations not in dictionary"), this );
   cb1->setObjectName( "NoRootAffix" );
   connect( cb1, SIGNAL(toggled(bool)), SLOT(sNoAff(bool)) );
   glay->addWidget( cb0, 0, 0, 1, 3 );
   glay->addWidget( cb1, 1, 0, 1, 3 );
 
-  cb2 = new QCheckBox( i18n("Consider run-together &words"
-			    " as spelling errors"), this );
+  cb2 = new QCheckBox( i18nc("@option:check",
+                             "Consider run-together &words as spelling errors"), this );
   cb2->setObjectName( "RunTogether" );
   connect( cb2, SIGNAL(toggled(bool)), SLOT(sRunTogether(bool)) );
   glay->addWidget( cb2, 2, 0, 1, 3 );
@@ -128,7 +129,7 @@ K3SpellConfig::K3SpellConfig( QWidget *parent,
 	   this, SLOT (sSetDictionary(int)) );
   glay->addWidget( dictcombo, 3, 1, 1, 2 );
 
-  dictlist = new QLabel( i18n("&Dictionary:"), this );
+  dictlist = new QLabel( i18nc("@label:listbox", "&Dictionary:"), this );
   dictlist->setBuddy( dictcombo );
   glay->addWidget( dictlist, 3 ,0 );
 
@@ -155,22 +156,22 @@ K3SpellConfig::K3SpellConfig( QWidget *parent,
 	   SLOT(sChangeEncoding(int)) );
   glay->addWidget( encodingcombo, 4, 1, 1, 2 );
 
-  QLabel *tmpQLabel = new QLabel( i18n("&Encoding:"), this);
+  QLabel *tmpQLabel = new QLabel( i18nc("@label:listbox", "&Encoding:"), this);
   tmpQLabel->setBuddy( encodingcombo );
   glay->addWidget( tmpQLabel, 4, 0 );
 
 
   clientcombo = new QComboBox( this );
   clientcombo->setObjectName( "Client" );
-  clientcombo->addItem( i18n("International Ispell") );
-  clientcombo->addItem( i18n("Aspell") );
-  clientcombo->addItem( i18n("Hspell") );
-  clientcombo->addItem( i18n("Zemberek") );
+  clientcombo->addItem( i18nc("@item:inlistbox Spell checker", "International <application>Ispell</application>") );
+  clientcombo->addItem( i18nc("@item:inlistbox Spell checker", "<application>Aspell</application>") );
+  clientcombo->addItem( i18nc("@item:inlistbox Spell checker", "<application>Hspell</application>") );
+  clientcombo->addItem( i18nc("@item:inlistbox Spell checker", "<application>Zemberek</application>") );
   connect( clientcombo, SIGNAL (activated(int)), this,
 	   SLOT (sChangeClient(int)) );
   glay->addWidget( clientcombo, 5, 1, 1, 2 );
 
-  tmpQLabel = new QLabel( i18n("&Client:"), this );
+  tmpQLabel = new QLabel( i18nc("@label:listbox", "&Client:"), this );
   tmpQLabel->setBuddy( clientcombo );
   glay->addWidget( tmpQLabel, 5, 0 );
 
@@ -199,7 +200,7 @@ K3SpellConfig::dictFromList() const
 bool
 K3SpellConfig::readGlobalSettings()
 {
-  kDebug(750) << "Entering K3SpellConfig::readGlobalSettings (see k3sconfig.cpp)" << endl;
+  kDebug(750) << "Entering K3SpellConfig::readGlobalSettings (see k3sconfig.cpp)";
   KConfigGroup cg( kc,"K3Spell" );
 
   setDoSpellChecking ( cg.readEntry("K3Spell_DoSpellChecking", false ) );
@@ -233,7 +234,7 @@ K3SpellConfig::writeGlobalSettings ()
 void
 K3SpellConfig::sChangeEncoding( int i )
 {
-  kDebug(750) << "K3SpellConfig::sChangeEncoding(" << i << ")" << endl;
+  kDebug(750) << "K3SpellConfig::sChangeEncoding(" << i << ")";
   setEncoding( i );
   emit configChanged();
 }
@@ -251,12 +252,12 @@ K3SpellConfig::sChangeClient( int i )
     {
       langfnames.clear();
       dictcombo->clear();
-      dictcombo->addItem( i18n("Hebrew") );
+      dictcombo->addItem( i18nc("@item Spelling dictionary", "Hebrew") );
       sChangeEncoding( KS_E_CP1255 );
     } else if ( iclient == KS_CLIENT_ZEMBEREK ) {
       langfnames.clear();
       dictcombo->clear();
-      dictcombo->addItem( i18n("Turkish") );
+      dictcombo->addItem( i18nc("@item Spelling dictionary", "Turkish") );
       sChangeEncoding( KS_E_UTF8 );
     }
     else
@@ -271,11 +272,11 @@ K3SpellConfig::interpret( const QString &fname, QString &lname,
 
 {
 
-  kDebug(750) << "K3SpellConfig::interpret [" << fname << "]" << endl;
+  kDebug(750) << "K3SpellConfig::interpret [" << fname << "]";
 
   QString dname( fname );
 
-  if( dname.endsWith( "+" ) )
+  if( dname.endsWith( '+' ) )
     dname.remove( dname.length()-1, 1 );
 
   if( dname.endsWith("sml") || dname.endsWith("med") || dname.endsWith("lrg") ||
@@ -295,12 +296,12 @@ K3SpellConfig::interpret( const QString &fname, QString &lname,
   // but since aspell 0.6 also 3-character ISO-codes can be used
   if ( (dname.length() == 2) || (dname.length() == 3) ) {
     lname = dname;
-    hname = KGlobal::locale()->twoAlphaToLanguageName( lname );
+    hname = KGlobal::locale()->languageCodeToName( lname );
   }
   else if ( (dname.length() == 5) && (dname[2] == '_') ) {
     lname = dname.left(2);
-    hname = KGlobal::locale()->twoAlphaToLanguageName(lname);
-    QString country = KGlobal::locale()->twoAlphaToCountryName( dname.right(2) );
+    hname = KGlobal::locale()->languageCodeToName( lname );
+    QString country = KGlobal::locale()->countryCodeToName( dname.right(2) );
     if ( extension.isEmpty() )
       extension = country;
     else
@@ -309,71 +310,71 @@ K3SpellConfig::interpret( const QString &fname, QString &lname,
   //These are mostly the ispell-langpack defaults
   else if ( dname=="english" || dname=="american" ||
             dname=="british" || dname=="canadian" ) {
-    lname="en"; hname=i18n("English");
+    lname="en"; hname=i18nc("@item Spelling dictionary", "English");
   }
   else if ( dname == "espa~nol" || dname == "espanol" ) {
-    lname="es"; hname=i18n("Spanish");
+    lname="es"; hname=i18nc("@item Spelling dictionary", "Spanish");
   }
   else if (dname=="dansk") {
-    lname="da"; hname=i18n("Danish");
+    lname="da"; hname=i18nc("@item Spelling dictionary", "Danish");
   }
   else if (dname=="deutsch") {
-    lname="de"; hname=i18n("German");
+    lname="de"; hname=i18nc("@item Spelling dictionary", "German");
   }
   else if (dname=="german") {
-    lname="de"; hname=i18n("German (new spelling)");
+    lname="de"; hname=i18nc("@item Spelling dictionary", "German (new spelling)");
   }
   else if (dname=="portuguesb" || dname=="br") {
-    lname="br"; hname=i18n("Brazilian Portuguese");
+    lname="br"; hname=i18nc("@item Spelling dictionary", "Brazilian Portuguese");
   }
   else if (dname=="portugues") {
-    lname="pt"; hname=i18n("Portuguese");
+    lname="pt"; hname=i18nc("@item Spelling dictionary", "Portuguese");
   }
   else if (dname=="esperanto") {
-    lname="eo"; hname=i18n("Esperanto");
+    lname="eo"; hname=i18nc("@item Spelling dictionary", "Esperanto");
   }
   else if (dname=="norsk") {
-    lname="no"; hname=i18n("Norwegian");
+    lname="no"; hname=i18nc("@item Spelling dictionary", "Norwegian");
   }
   else if (dname=="polish") {
-    lname="pl"; hname=i18n("Polish"); sChangeEncoding(KS_E_LATIN2);
+    lname="pl"; hname=i18nc("@item Spelling dictionary", "Polish"); sChangeEncoding(KS_E_LATIN2);
   }
   else if (dname=="russian") {
-    lname="ru"; hname=i18n("Russian");
+    lname="ru"; hname=i18nc("@item Spelling dictionary", "Russian");
   }
   else if (dname=="slovensko") {
-    lname="si"; hname=i18n("Slovenian"); sChangeEncoding(KS_E_LATIN2);
+    lname="si"; hname=i18nc("@item Spelling dictionary", "Slovenian"); sChangeEncoding(KS_E_LATIN2);
   }
   else if (dname=="slovak"){
-    lname="sk"; hname=i18n("Slovak"); sChangeEncoding(KS_E_LATIN2);
+    lname="sk"; hname=i18nc("@item Spelling dictionary", "Slovak"); sChangeEncoding(KS_E_LATIN2);
   }
   else if (dname=="czech") {
-    lname="cs"; hname=i18n("Czech"); sChangeEncoding(KS_E_LATIN2);
+    lname="cs"; hname=i18nc("@item Spelling dictionary", "Czech"); sChangeEncoding(KS_E_LATIN2);
   }
   else if (dname=="svenska") {
-    lname="sv"; hname=i18n("Swedish");
+    lname="sv"; hname=i18nc("@item Spelling dictionary", "Swedish");
   }
   else if (dname=="swiss") {
-    lname="de"; hname=i18n("Swiss German");
+    lname="de"; hname=i18nc("@item Spelling dictionary", "Swiss German");
   }
   else if (dname=="ukrainian") {
-    lname="uk"; hname=i18n("Ukrainian");
+    lname="uk"; hname=i18nc("@item Spelling dictionary", "Ukrainian");
   }
   else if (dname=="lietuviu" || dname=="lithuanian") {
-     lname="lt"; hname=i18n("Lithuanian");
+     lname="lt"; hname=i18nc("@item Spelling dictionary", "Lithuanian");
   }
   else if (dname=="francais" || dname=="french") {
-    lname="fr"; hname=i18n("French");
+    lname="fr"; hname=i18nc("@item Spelling dictionary", "French");
   }
   else if (dname=="belarusian") {  // waiting for post 2.2 to not dissapoint translators
-    lname="be"; hname=i18n("Belarusian");
+    lname="be"; hname=i18nc("@item Spelling dictionary", "Belarusian");
   }
   else if( dname == "magyar" ) {
-    lname="hu"; hname=i18n("Hungarian");
+    lname="hu"; hname=i18nc("@item Spelling dictionary", "Hungarian");
     sChangeEncoding(KS_E_LATIN2);
   }
   else {
-    lname=""; hname=i18nc("Unknown ispell dictionary", "Unknown");
+    lname=""; hname=i18nc("@item Spelling dictionary", "Unknown");
   }
   if (!extension.isEmpty())
   {
@@ -395,7 +396,7 @@ K3SpellConfig::fillInDialog ()
   if ( nodialog )
     return;
 
-  kDebug(750) << "K3SpellConfig::fillinDialog" << endl;
+  kDebug(750) << "K3SpellConfig::fillinDialog";
 
   cb0->setChecked( doSpellChecking() );
   cb1->setChecked( noRootAffix() );
@@ -411,12 +412,12 @@ K3SpellConfig::fillInDialog ()
     langfnames.clear();
     dictcombo->clear();
     langfnames.append(""); // Default
-    dictcombo->addItem( i18n("Hebrew") );
+    dictcombo->addItem( i18nc("@item Spelling dictionary", "Hebrew") );
   } else if ( iclient == KS_CLIENT_ZEMBEREK ) {
     langfnames.clear();
     dictcombo->clear();
     langfnames.append("");
-    dictcombo->addItem( i18n("Turkish") );
+    dictcombo->addItem( i18nc("@item Spelling dictionary", "Turkish") );
   }
   else
     getAvailDictsAspell();
@@ -456,7 +457,8 @@ void K3SpellConfig::getAvailDictsIspell () {
   langfnames.clear();
   dictcombo->clear();
   langfnames.append(""); // Default
-  dictcombo->addItem( i18n("ISpell Default") );
+  dictcombo->addItem( i18nc("@item Spelling dictionary",
+                            "<application>ISpell</application> Default") );
 
   // dictionary path
   QFileInfo dir ("/usr/lib/ispell");
@@ -466,6 +468,8 @@ void K3SpellConfig::getAvailDictsIspell () {
     dir.setFile ("/usr/local/share/ispell");
   if (!dir.exists() || !dir.isDir())
     dir.setFile ("/usr/share/ispell");
+  if (!dir.exists() || !dir.isDir())
+    dir.setFile ("/usr/pkg/lib");
   /* TODO get them all instead of just one of them.
    * If /usr/local/lib exists, it skips the rest
   if (!dir.exists() || !dir.isDir())
@@ -479,7 +483,7 @@ void K3SpellConfig::getAvailDictsIspell () {
   const QDir thedir (dir.filePath(),"*.hash");
   const QStringList entryList = thedir.entryList();
 
-  kDebug(750) << "K3SpellConfig" << thedir.path() << "\n" << endl;
+  kDebug(750) << "K3SpellConfig" << thedir.path() << "\n";
   kDebug(750) << "entryList().count()="
 	       << entryList.count() << endl;
 
@@ -501,8 +505,8 @@ void K3SpellConfig::getAvailDictsIspell () {
       langfnames.removeFirst();
       langfnames.prepend ( fname );
 
-      hname=i18nc("default spelling dictionary"
-                 ,"Default - %1 [%2]", hname, fname);
+      hname=i18nc("@item Spelling dictionary: %1 dictionary name, %2 file name",
+                  "Default - %1 [%2]", hname, fname);
 
       dictcombo->setItemText (0,hname);
     }
@@ -522,19 +526,22 @@ void K3SpellConfig::getAvailDictsAspell () {
   dictcombo->clear();
 
   langfnames.append(""); // Default
-  dictcombo->addItem (i18n("ASpell Default"));
+  dictcombo->addItem (i18nc("@item Spelling dictionary",
+                            "<application>ASpell</application> Default"));
 
   // dictionary path
   // FIXME: use "aspell dump config" to find out the dict-dir
-  QFileInfo dir ("/usr/lib/aspell");
+  QFileInfo dir ("/usr/lib" KDELIBSUFF "/aspell");
   if (!dir.exists() || !dir.isDir())
-    dir.setFile ("/usr/lib/aspell-0.60");
+    dir.setFile ("/usr/lib" KDELIBSUFF "/aspell-0.60");
   if (!dir.exists() || !dir.isDir())
-    dir.setFile ("/usr/local/lib/aspell");
+    dir.setFile ("/usr/local/lib" KDELIBSUFF "/aspell");
   if (!dir.exists() || !dir.isDir())
     dir.setFile ("/usr/share/aspell");
   if (!dir.exists() || !dir.isDir())
     dir.setFile ("/usr/local/share/aspell");
+  if (!dir.exists() || !dir.isDir())
+    dir.setFile ("/usr/pkg/lib/aspell");
   if (!dir.exists() || !dir.isDir()) return;
 
   kDebug(750) << "K3SpellConfig::getAvailDictsAspell "
@@ -543,7 +550,7 @@ void K3SpellConfig::getAvailDictsAspell () {
   const QDir thedir (dir.filePath(),"*");
   const QStringList entryList = thedir.entryList();
 
-  kDebug(750) << "K3SpellConfig" << thedir.path() << "\n" << endl;
+  kDebug(750) << "K3SpellConfig" << thedir.path() << "\n";
   kDebug(750) << "entryList().count()="
 	       << entryList.count() << endl;
 
@@ -584,8 +591,8 @@ void K3SpellConfig::getAvailDictsAspell () {
         langfnames.erase ( langfnames.begin() );
         langfnames.prepend ( fname );
 
-        hname=i18nc("default spelling dictionary"
-                   ,"Default - %1", hname);
+        hname=i18nc("@item Spelling dictionary: %1 dictionary name",
+                    "Default - %1", hname);
 
         dictcombo->setItemText (0,hname);
       }
@@ -606,7 +613,8 @@ K3SpellConfig::fillDicts( QComboBox* box, QStringList* dictionaries )
     if ( iclient == KS_CLIENT_ISPELL ) {
       box->clear();
       langfnames.append(""); // Default
-      box->addItem( i18n("ISpell Default") );
+      box->addItem( i18nc("@item Spelling dictionary",
+                          "<application>ISpell</application> Default") );
 
       // dictionary path
       QFileInfo dir ("/usr/lib/ispell");
@@ -616,6 +624,8 @@ K3SpellConfig::fillDicts( QComboBox* box, QStringList* dictionaries )
         dir.setFile ("/usr/local/share/ispell");
       if (!dir.exists() || !dir.isDir())
         dir.setFile ("/usr/share/ispell");
+      if (!dir.exists() || !dir.isDir())
+        dir.setFile ("/usr/pkg/lib");
       /* TODO get them all instead of just one of them.
        * If /usr/local/lib exists, it skips the rest
        if (!dir.exists() || !dir.isDir())
@@ -629,7 +639,7 @@ K3SpellConfig::fillDicts( QComboBox* box, QStringList* dictionaries )
       const QDir thedir (dir.filePath(),"*.hash");
       const QStringList entryList = thedir.entryList();
 
-      kDebug(750) << "K3SpellConfig" << thedir.path() << "\n" << endl;
+      kDebug(750) << "K3SpellConfig" << thedir.path() << "\n";
       kDebug(750) << "entryList().count()="
                    << entryList.count() << endl;
 
@@ -651,8 +661,8 @@ K3SpellConfig::fillDicts( QComboBox* box, QStringList* dictionaries )
           langfnames.erase ( langfnames.begin() );
           langfnames.prepend ( fname );
 
-          hname=i18nc("default spelling dictionary"
-                     ,"Default - %1 [%2]", hname, fname);
+          hname=i18nc("@item Spelling dictionary: %1 dictionary name, %2 file name",
+                      "Default - %1 [%2]", hname, fname);
 
           box->setItemText (0,hname);
         }
@@ -666,31 +676,34 @@ K3SpellConfig::fillDicts( QComboBox* box, QStringList* dictionaries )
       }
     } else if ( iclient == KS_CLIENT_HSPELL ) {
       box->clear();
-      box->addItem( i18n("Hebrew") );
+      box->addItem( i18nc("@item Spelling dictionary", "Hebrew") );
       langfnames.append(""); // Default
       sChangeEncoding( KS_E_CP1255 );
     } else if ( iclient == KS_CLIENT_ZEMBEREK ) {
       box->clear();
-      box->addItem( i18n("Turkish") );
+      box->addItem( i18nc("@item Spelling dictionary", "Turkish") );
       langfnames.append("");
       sChangeEncoding( KS_E_UTF8 );
     }
     else {
       box->clear();
       langfnames.append(""); // Default
-      box->addItem (i18n("ASpell Default"));
+      box->addItem (i18nc("@item Spelling dictionary",
+                          "<application>ASpell</application> Default"));
 
       // dictionary path
       // FIXME: use "aspell dump config" to find out the dict-dir
-      QFileInfo dir ("/usr/lib/aspell");
+      QFileInfo dir ("/usr/lib" KDELIBSUFF "/aspell");
       if (!dir.exists() || !dir.isDir())
-        dir.setFile ("/usr/lib/aspell-0.60");
+        dir.setFile ("/usr/lib" KDELIBSUFF "/aspell-0.60");
       if (!dir.exists() || !dir.isDir())
-        dir.setFile ("/usr/local/lib/aspell");
+        dir.setFile ("/usr/local/lib" KDELIBSUFF "/aspell");
       if (!dir.exists() || !dir.isDir())
         dir.setFile ("/usr/share/aspell");
       if (!dir.exists() || !dir.isDir())
         dir.setFile ("/usr/local/share/aspell");
+      if (!dir.exists() || !dir.isDir())
+        dir.setFile ("/usr/pkg/lib/aspell");
       if (!dir.exists() || !dir.isDir()) return;
 
       kDebug(750) << "K3SpellConfig::getAvailDictsAspell "
@@ -699,7 +712,7 @@ K3SpellConfig::fillDicts( QComboBox* box, QStringList* dictionaries )
       const QDir thedir (dir.filePath(),"*");
       const QStringList entryList = thedir.entryList();
 
-      kDebug(750) << "K3SpellConfig" << thedir.path() << "\n" << endl;
+      kDebug(750) << "K3SpellConfig" << thedir.path() << "\n";
       kDebug(750) << "entryList().count()="
                    << entryList.count() << endl;
 
@@ -740,8 +753,8 @@ K3SpellConfig::fillDicts( QComboBox* box, QStringList* dictionaries )
             langfnames.erase ( langfnames.begin() );
             langfnames.prepend ( fname );
 
-            hname=i18nc("default spelling dictionary"
-                       ,"Default - %1", hname);
+            hname=i18nc("@item Spelling dictionary: %1 dictionary name",
+                        "Default - %1", hname);
 
             box->setItemText (0,hname);
           }
