@@ -19,6 +19,8 @@
    Boston, MA 02110-1301, USA.
 */
 
+#include "k3spelldlg.h"
+
 #include <QProgressBar>
 
 #include <kconfig.h>
@@ -26,7 +28,6 @@
 #include <klocale.h>
 
 #include "k3sconfig.h"
-#include "k3spelldlg.h"
 #include "ui_k3spellui.h"
 #include <kconfiggroup.h>
 
@@ -51,8 +52,8 @@ K3SpellDlg::K3SpellDlg( QWidget * parent, bool _progressbar, bool _modal )
   setButtonText( Cancel, i18n("&Finished") );
 
   KConfigGroup cg( KGlobal::config(),"K3Spell" );
-  kDebug() << (cg.readEntry("K3Spell_DoSpellChecking")) << endl;
-  kDebug() << "dospellchecking is " << cg.readEntry("K3Spell_DoSpellChecking", false)  << endl;
+  kDebug() << (cg.readEntry("K3Spell_DoSpellChecking"));
+  kDebug() << "dospellchecking is " << cg.readEntry("K3Spell_DoSpellChecking", false);
   if ( (cg.readEntry("K3Spell_DoSpellChecking", false) == true) )  //dospellcheck ?
   {
     Q_UNUSED( _progressbar );
@@ -109,6 +110,11 @@ K3SpellDlg::~K3SpellDlg()
   delete d;
 }
 
+QString K3SpellDlg::replacement() const
+{
+    return newword;
+}
+
 void
 K3SpellDlg::init( const QString & _word, QStringList * _sugg )
 {
@@ -122,7 +128,7 @@ K3SpellDlg::init( const QString & _word, QStringList * _sugg )
                                              d->ui.m_suggestions->lastItem() );
     item->setText( 0, *it );
   }
-  kDebug(750) << "K3SpellDlg::init [" << word << "]" << endl;
+  kDebug(750) << "K3SpellDlg::init [" << word << "]";
 
   emit ready( true );
 
@@ -157,7 +163,7 @@ K3SpellDlg::init( const QString& _word, QStringList* _sugg,
       item->setText( 0, *it );
   }
 
-  kDebug(750) << "K3SpellDlg::init [" << word << "]" << endl;
+  kDebug(750) << "K3SpellDlg::init [" << word << "]";
 
   emit ready( true );
 
@@ -178,6 +184,11 @@ K3SpellDlg::init( const QString& _word, QStringList* _sugg,
   }
 }
 
+void K3SpellDlg::standby()
+{
+    ready( false );
+}
+
 void
 K3SpellDlg::slotProgress( unsigned int p )
 {
