@@ -19,8 +19,8 @@
 
 #include "k3wizard.h"
 
-#include <qpushbutton.h>
-#include <qstring.h>
+#include <QtGui/QPushButton>
+#include <QtCore/QCharRef>
 
 #include <kiconloader.h>
 #include <klocale.h>
@@ -41,9 +41,9 @@ K3Wizard::K3Wizard( QWidget *parent, const char *name, bool modal, Qt::WFlags f
     backButton()->setIcon( back.icon() );
     nextButton()->setIcon( forward.icon() );
 
-    finishButton()->setIcon( KIcon( "apply" ) );
-    cancelButton()->setIcon( KIcon( "button_cancel" ) );
-    helpButton()->setIcon( KIcon( "help" ) );
+    finishButton()->setIcon( KIcon( "dialog-apply" ) );
+    cancelButton()->setIcon( KIcon( "dialog-cancel" ) );
+    helpButton()->setIcon( KIcon( "help-contents" ) );
 
     backButton()->setText( i18n( "&Back" ) );
     nextButton()->setText( i18nc( "Opposite to Back","&Next" ) );
