@@ -6,7 +6,7 @@
 * Licensed under the GNU General Public License version 2
 */
 
-#include <QLayout>
+#include <QtGui/QLayout>
 
 #include <kaboutdata.h>
 #include <kapplication.h>
@@ -31,7 +31,7 @@ KActiveLabelTest::KActiveLabelTest(QWidget *parent)
 
 int main( int argc, char ** argv )
 {
-  KAboutData about( "KActiveLabelTest", "KActiveLabelTest", "version");
+  KAboutData about( "KActiveLabelTest", 0, ki18n("KActiveLabelTest"), "version");
   KCmdLineArgs::init(argc, argv, &about);
 
   KApplication app;
