@@ -1,27 +1,24 @@
-#define KDE3_SUPPORT 
-
 #include "kdockwidgetdemo.h"
 
-#include <q3header.h>
-#include <qtoolbutton.h>
-#include <qtooltip.h>
-#include <q3textview.h>
-#include <qfileinfo.h>
-#include <qfile.h>
-#include <qtextstream.h>
-#include <qlabel.h>
-#include <q3multilineedit.h>
-#include <qevent.h>
-#include <q3popupmenu.h>
-#include <qpushbutton.h>
-#include <qpoint.h>
-#include <qmessagebox.h>
-#include <qmime.h>
-#include <q3strlist.h>
-#include <qpainter.h>
+#include <Qt3Support/Q3Header>
+#include <QtGui/QToolButton>
+
+#include <Qt3Support/Q3TextView>
+#include <QtCore/QFileInfo>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
+#include <QtGui/QLabel>
+#include <Qt3Support/Q3MultiLineEdit>
+#include <QtGui/QKeyEvent>
+#include <Qt3Support/Q3PopupMenu>
+#include <QtGui/QPushButton>
+#include <QtCore/QPoint>
+#include <QtGui/QMessageBox>
+#include <QtGui/QMacMime>
+#include <Qt3Support/Q3StrList>
+#include <QtGui/QPainter>
 //Added by qt3to4:
-#include <QPixmap>
-#include <QShowEvent>
+#include <QtGui/QPixmap>
 
 #include <kconfig.h>
 #include <kaboutdata.h>
@@ -89,14 +86,13 @@ SFileDialog::SFileDialog( QString initially, const QStringList& filter, const ch
 {
   setObjectName(name);
   setModal(true);
-  KSharedConfig::Ptr config = KGlobal::config();
-  config->setGroup( QLatin1String("SFileDialogData:") + name );
+  KConfigGroup config( KGlobal::config(), QLatin1String("SFileDialogData:") + name );
   if ( initially.isNull() ){
-    initially = config->readPathEntry( "InitiallyDir", QDir::currentPath() );
+    initially = config.readPathEntry( "InitiallyDir", QDir::currentPath() );
   }
 
   QStringList bookmark;
-  bookmark = config->readEntry( "Bookmarks",QStringList() );
+  bookmark = config.readEntry( "Bookmarks",QStringList() );
 
   dockManager = new K3DockManager(this);
 
@@ -174,9 +170,8 @@ void SFileDialog::dockChange()
 
 SFileDialog::~SFileDialog()
 {
-  KSharedConfig::Ptr config = KGlobal::config();
-  config->setGroup( QString("SFileDialogData:") + objectName() );
-  config->writeEntry( "Bookmarks", fd->getBookmark() );
+  KConfigGroup config(KGlobal::config(), QString("SFileDialogData:") + objectName() );
+  config.writeEntry( "Bookmarks", fd->getBookmark() );
 
   qDebug("write config");
   dockManager->writeConfig( 0L , objectName() );
@@ -196,9 +191,8 @@ void SFileDialog::setDockDefaultPos( K3DockWidget* d )
 void SFileDialog::changeDir( const QString& f )
 {
   if ( !f.isEmpty() ){
-    KSharedConfig::Ptr config = KGlobal::config();
-    config->setGroup( QString("SFileDialogData:") + objectName() );
-    config->writePathEntry( "InitiallyDir", f );
+    KConfigGroup config( KGlobal::config(), QString("SFileDialogData:") + objectName() );
+    config.writePathEntry( "InitiallyDir", f );
   }
 }
 
@@ -278,7 +272,7 @@ void Preview::showPreview( const QString &str )
 	    raiseWidget( normalText );
 	    return;
 	}
-	
+
 	QPixmap pix( path );
 	if ( pix.isNull() ) {
 	    if ( fi.isFile() ) {
@@ -289,11 +283,11 @@ void Preview::showPreview( const QString &str )
 		    f.close();
 		    if ( fi.suffix().toLower().contains( "htm" ) ) {
 			QString url = html->mimeSourceFactory()->makeAbsolute( path, html->context() );
-			html->setText( text, url ); 	
+			html->setText( text, url );
 			raiseWidget( html );
 			return;
 		    } else {
-			normalText->setText( text ); 	
+			normalText->setText( text );
 			raiseWidget( normalText );
 			return;
 		    }
@@ -770,7 +764,7 @@ QString DirectoryView::selectedDir()
 /**********************************************************************************************/
 
 int main(int argc, char* argv[]) {
-  KAboutData about("kdockwidgetdemo", "kdockwidgetdemo", "version");
+  KAboutData about("kdockwidgetdemo", 0, ki18n("kdockwidgetdemo"), "version");
   KCmdLineArgs::init(argc, argv, &about);
 
   KApplication app;
@@ -787,8 +781,8 @@ int main(int argc, char* argv[]) {
 #endif
 
 #if 1
-  QStringList s = SFileDialog::getOpenFileNames( QString(), 
-          QStringList(QLatin1String("All (*)")), 
+  QStringList s = SFileDialog::getOpenFileNames( QString(),
+          QStringList(QLatin1String("All (*)")),
           QLatin1String("DockWidget Demo"), "dialog1" );
   QStringList::Iterator it = s.begin();
   for ( ; it != s.end(); ++it ){
