@@ -1,6 +1,6 @@
 /*
     This file is part of the KDE libraries
-    Copyright (c) 2005,2006 David Jarvie <software@astrojar.org.uk>
+    Copyright (c) 2005-2007 David Jarvie <software@astrojar.org.uk>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -26,10 +26,10 @@
 #ifndef _KDATETIME_H_
 #define _KDATETIME_H_
 
-#include <QtCore/QSharedDataPointer>
+#include <kdecore_export.h>
+#include <ktimezone.h>
 
-#include <ktimezones.h>
-#include "kdelibs_export.h"
+#include <QtCore/QSharedDataPointer>
 
 class QDataStream;
 class KDateTimePrivate;
@@ -51,10 +51,10 @@ class KDateTimeSpecPrivate;
  * can also be set to represent a date-only value with no associated time.
  *
  * The class uses QDateTime internally to represent date/time values, and
- * therefore can only be used for dates in the Gregorian calendar, with a year
- * in the range -4712 (4713 BC) upwards. (The upper limit is actually > 11,000,000,
- * which seems unlikely to cause problems for the majority of applications!) The
- * Gregorian calendar started in 1582, but adoption was slow; the last European
+ * therefore uses the Gregorian calendar for dates starting from 15 October 1582,
+ * and the Julian calendar for dates up to 4 October 1582. The minimum year
+ * number is -4712 (4713 BC), while the upper limit is more than 11,000,000. The
+ * actual adoption of the Gregorian calendar after 1582 was slow; the last European
  * country to adopt it, Greece, did so only in 1923. See QDateTime Considerations
  * section below for further discussion of the date range limitations.
  *
@@ -137,12 +137,13 @@ class KDateTimeSpecPrivate;
  * considered:
  *
  * - there are significant problems in the representation of dates before the
- *   Gregorian calendar was adopted. The numbering of dates - even to some
- *   extent year numbering - varied from place to place. So any date/time
- *   system which attempted to represent dates as actually used in history
- *   would be too specialized to belong to the core KDE libraries. Date/time
- *   systems for scientific applications can be much simpler, but may differ
- *   from historical records.
+ *   Gregorian calendar was adopted. The date of adoption of the Gregorian
+ *   calendar varied from place to place, and in the Julian calendar the
+ *   date of the new year varied so that in different places the year number
+ *   could differ by one. So any date/time system which attempted to represent
+ *   dates as actually used in history would be too specialized to belong to
+ *   the core KDE libraries. Date/time systems for scientific applications can
+ *   be much simpler, but may differ from historical records.
  *
  * - time zones were not invented until the middle of the 19th century. Before
  *   that, solar time was used.
@@ -156,7 +157,7 @@ class KDateTimeSpecPrivate;
  * @see <a href="http://www.w3.org/TR/timezone/">W3C: Working with Time Zones</a>
  * @author David Jarvie \<software@astrojar.org.uk\>.
  */
-class KDECORE_EXPORT KDateTime
+class KDECORE_EXPORT KDateTime //krazy:exclude=dpointer (implicitly shared)
 {
   public:
     /**
@@ -218,11 +219,11 @@ class KDECORE_EXPORT KDateTime
 
         /**
          * Constructs a time specification for a given time zone.
-         * If @p tz is KTimeZones::utc(), the time specification type is set to @c UTC.
+         * If @p tz is KTimeZone::utc(), the time specification type is set to @c UTC.
          *
          * @param tz  time zone
          */
-        Spec(const KTimeZone *tz);   // allow implicit conversion
+        Spec(const KTimeZone &tz);   // allow implicit conversion
 
         /**
          * Constructs a time specification.
@@ -262,10 +263,10 @@ class KDECORE_EXPORT KDateTime
          * - @c UTC       : a UTC time zone is returned.
          * - @c LocalZone : the current local time zone is returned.
          *
-         * @return time zone as defined above, or null in all other cases
+         * @return time zone as defined above, or invalid in all other cases
          * @see isUtc(), isLocal()
          */
-        const KTimeZone *timeZone() const;
+        KTimeZone timeZone() const;
 
         /**
          * Returns the time specification type, i.e. whether it is
@@ -330,7 +331,7 @@ class KDECORE_EXPORT KDateTime
          *                  is invalid here.
          * @param utcOffset number of seconds to add to UTC to get the local
          *                  time. Ignored if @p spec is not @c OffsetFromUTC.
-         * @see type(), setType(const KTimeZone*)
+         * @see type(), setType(const KTimeZone&)
          */
         void setType(SpecType type, int utcOffset = 0);
 
@@ -343,7 +344,7 @@ class KDECORE_EXPORT KDateTime
          * @param tz new time zone
          * @see timeZone(), setType(SpecType)
          */
-        void setType(const KTimeZone *tz);
+        void setType(const KTimeZone &tz);
 
         /**
          * Comparison operator.
@@ -374,13 +375,13 @@ class KDECORE_EXPORT KDateTime
          * The UTC time specification.
          * Provided as a shorthand for KDateTime::Spec(KDateTime::UTC).
          */
-        static const Spec UTC;
+        static Spec UTC();
 
         /**
          * The ClockTime time specification.
          * Provided as a shorthand for KDateTime::Spec(KDateTime::ClockTime).
          */
-        static const Spec ClockTime;
+        static Spec ClockTime();
 
         /**
          * Returns a UTC offset time specification.
@@ -415,10 +416,10 @@ class KDECORE_EXPORT KDateTime
                      *   [±]YYYYMMDD (without time zone specifier) are used. All
                      *   formats may contain a day of the year instead of day
                      *   and month.
-		     *   To allow for years past 9999, the year may optionally
-		     *   contain more than 4 digits. To avoid ambiguity, this is
-		     *   not allowed in the basic format containing a day
-		     *   of the year (i.e. when the date part is [±]YYYYDDD).
+                     *   To allow for years past 9999, the year may optionally
+                     *   contain more than 4 digits. To avoid ambiguity, this is
+                     *   not allowed in the basic format containing a day
+                     *   of the year (i.e. when the date part is [±]YYYYDDD).
                      */
         RFCDate,    /**< RFC 2822 format,
                      *   i.e. "[Wdy,] DD Mon YYYY hh:mm[:ss] ±hhmm". This format
@@ -463,19 +464,19 @@ class KDECORE_EXPORT KDateTime
         Before  = 0x01, /**< This KDateTime is strictly earlier than the other,
                          *   i.e. e1 < s2.
                          */
-	AtStart = 0x02, /**< This KDateTime starts at the same time as the other,
+        AtStart = 0x02, /**< This KDateTime starts at the same time as the other,
                          *   and ends before the end of the other,
                          *   i.e. s1 = s2, e1 < e2.
                          */
-	Inside  = 0x04, /**< This KDateTime starts after the start of the other,
+        Inside  = 0x04, /**< This KDateTime starts after the start of the other,
                          *   and ends before the end of the other,
                          *   i.e. s1 > s2, e1 < e2.
                          */
-	AtEnd   = 0x08, /**< This KDateTime starts after the start of the other,
+        AtEnd   = 0x08, /**< This KDateTime starts after the start of the other,
                          *   and ends at the same time as the other,
                          *   i.e. s1 > s2, e1 = e2.
                          */
-	After   = 0x10, /**< This KDateTime is strictly later than the other,
+        After   = 0x10, /**< This KDateTime is strictly later than the other,
                          *   i.e. s1 > e2.
                          */
         Equal = AtStart | Inside | AtEnd,
@@ -486,12 +487,12 @@ class KDECORE_EXPORT KDateTime
                          *   and ends after the end of the other,
                          *   i.e. s1 < s2, e1 > e2.
                          */
- 	StartsAt = AtStart | Inside | AtEnd | After,
+        StartsAt = AtStart | Inside | AtEnd | After,
                         /**< This KDateTime starts at the same time as the other,
                          *   and ends after the end of the other,
                          *   i.e. s1 = s2, e1 > e2.
                          */
- 	EndsAt = Before | AtStart | Inside | AtEnd
+        EndsAt = Before | AtStart | Inside | AtEnd
                         /**< This KDateTime starts before the start of the other,
                          *   and ends at the same time as the other,
                          *   i.e. s1 < s2, e1 = e2.
@@ -646,11 +647,11 @@ class KDECORE_EXPORT KDateTime
      * Returns the time zone for the date/time. If the date/time is specified
      * as a UTC time, a UTC time zone is always returned.
      *
-     * @return time zone, or null if a local time at a fixed UTC offset or a
+     * @return time zone, or invalid if a local time at a fixed UTC offset or a
      *         local clock time
      * @see isUtc(), isLocal()
      */
-    const KTimeZone *timeZone() const;
+    KTimeZone timeZone() const;
 
     /**
      * Returns the time specification of the date/time, i.e. whether it is
@@ -815,7 +816,7 @@ class KDECORE_EXPORT KDateTime
      * @return converted time
      * @see toUtc(), toOffsetFromUtc(), toLocalZone(), toTimeSpec(), KTimeZone::convert()
      */
-    KDateTime toZone(const KTimeZone *zone) const;
+    KDateTime toZone(const KTimeZone &zone) const;
 
     /**
      * Returns the time converted to a new time specification.
@@ -1276,11 +1277,11 @@ class KDECORE_EXPORT KDateTime
      * toString(). However, some codes which are distinct in toString() have
      * the same function as each other here.
      *
-     * All numeric values permit, but do not require, leading zeroes. The
-     * maximum number of digits consumed by a numeric code is the minimum needed
-     * to cover the possible range of the number (e.g. for minutes, the range is
-     * 0 - 59, so the maximum number of digits consumed is 2). All non-numeric
-     * values are case insensitive.
+     * Numeric values without a stated number of digits permit, but do not
+     * require, leading zeroes. The maximum number of digits consumed by a
+     * numeric code is the minimum needed to cover the possible range of the
+     * number (e.g. for minutes, the range is 0 - 59, so the maximum number of
+     * digits consumed is 2). All non-numeric values are case insensitive.
      *
      * \b Date
      *
@@ -1288,15 +1289,15 @@ class KDECORE_EXPORT KDateTime
      *        while years 51 - 99 return 1951 - 1999.
      * - %Y   full year number (4 digits with optional sign)
      * - %:Y  full year number (>= 4 digits with optional sign)
-     * - %:m
-     * - %m   month number (1 - 12)
+     * - %:m  month number (1 - 12)
+     * - %m   month number, 2 digits (01 - 12)
      * - %b
      * - %B   month name in the current locale or, if no match, in English,
      *        abbreviated or in full
      * - %:b
      * - %:B  month name in English, abbreviated or in full
-     * - %e
-     * - %d   day of the month (1 - 31)
+     * - %e   day of the month (1 - 31)
+     * - %d   day of the month, 2 digits (01 - 31)
      * - %a
      * - %A   weekday name in the current locale or, if no match, in English,
      *        abbreviated or in full
@@ -1305,12 +1306,14 @@ class KDECORE_EXPORT KDateTime
      *
      * \b Time
      *
-     * - %H
+     * - %H   hour in the 24 hour clock, 2 digits (00 - 23)
      * - %k   hour in the 24 hour clock (0 - 23)
-     * - %I
+     * - %I   hour in the 12 hour clock, 2 digits (01 - 12)
      * - %l   hour in the 12 hour clock (1 - 12)
-     * - %M   minute (0 - 59)
-     * - %S   seconds (0 - 59)
+     * - %M   minute, 2 digits (00 - 59)
+     * - %:M  minute (0 - 59)
+     * - %S   seconds, 2 digits (00 - 59)
+     * - %s   seconds (0 - 59)
      * - %:S  optional seconds value (0 - 59) preceded with ':'. If no colon is
      *        found in @p string, no input is consumed and the seconds value is
      *        set to zero.
