@@ -41,11 +41,11 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-#include <qdir.h>
-#include <qstringlist.h>
-#include <qregexp.h>
-#include <qmimedata.h>
-#include <qtextcodec.h>
+#include <QtCore/QDir>
+#include <QtCore/QMutableStringListIterator>
+#include <QtCore/QRegExp>
+#include <QtCore/QMimeData>
+#include <QtCore/QTextCodec>
 
 static QString cleanpath( const QString &_path, bool cleanDirSeparator, bool decodeDots )
 {
@@ -164,7 +164,7 @@ KUrl::List::List(const QStringList &list)
 {
   for (QStringList::ConstIterator it = list.begin();
        it != list.end();
-       it++)
+       ++it)
     {
       append( KUrl(*it) );
     }
@@ -175,7 +175,7 @@ QStringList KUrl::List::toStringList() const
   QStringList lst;
    for( KUrl::List::ConstIterator it = begin();
         it != end();
-        it++)
+        ++it)
    {
       lst.append( (*it).url() );
    }
@@ -294,6 +294,11 @@ KUrl::List KUrl::List::fromMimeData( const QMimeData *mimeData, KUrl::MetaDataMa
     return uris;
 }
 
+KUrl::List::operator QVariant() const
+{
+  return qVariantFromValue(*this);
+}
+
 ////
 
 KUrl::KUrl()
@@ -311,18 +316,18 @@ KUrl::KUrl( const QString &str )
 {
   if ( !str.isEmpty() ) {
 #ifdef Q_WS_WIN
-   kDebug(126) << "KUrl::KUrl " << str.toAscii().data() << endl;
+   kDebug(126) << "KUrl::KUrl " << str.toAscii().data();
     if ( str.startsWith("file:///") ) {
-      kDebug(126) << "KUrl::KUrl " << "converting file schema from: " << str.toAscii().data() << " to: " << QUrl::fromPercentEncoding( str.mid(8).toLatin1() ) << endl;
+      kDebug(126) << "KUrl::KUrl " << "converting file schema from: " << str.toAscii().data() << " to: " << QUrl::fromPercentEncoding( str.mid(8).toLatin1() );
       setPath( QUrl::fromPercentEncoding( str.mid(8).toLatin1() ) );
    	}
-    else if ( str.startsWith("file://") && str[7].isLetter() && str[8] == QLatin1Char(':') ) {
-      kDebug(126) << "KUrl::KUrl " << "converting file schema from: " << str.toAscii().data() << " to: " << QUrl::fromPercentEncoding( str.mid(7).toLatin1() ) << endl;
+    else if ( str.length() > 9 && str.startsWith("file://") && str[7].isLetter() && str[8] == QLatin1Char(':') ) {
+      kDebug(126) << "KUrl::KUrl " << "converting file schema from: " << str.toAscii().data() << " to: " << QUrl::fromPercentEncoding( str.mid(7).toLatin1() );
       setPath( QUrl::fromPercentEncoding( str.mid(7).toLatin1() ) );
     }
-    else if ( str[0] == QLatin1Char('/') && str[1].isLetter() && str[2] == QLatin1Char(':') )
+    else if ( str.length() > 2 && str[0] == QLatin1Char('/') && str[1].isLetter() && str[2] == QLatin1Char(':') )
       setPath(str.mid(2));
-    else if ( str[0].isLetter() &&  str[1] == QLatin1Char(':') )
+    else if ( str.length() > 2 && str[0].isLetter() &&  str[1] == QLatin1Char(':') )
       setPath( str );
 #else
     if ( str[0] == QLatin1Char('/') || str[0] == QLatin1Char('~') )
@@ -338,7 +343,7 @@ KUrl::KUrl( const char * str )
 {
   if ( str && str[0] ) {
 #ifdef Q_WS_WIN
-    kDebug(126) << "KUrl::KUrl " << " " << str << endl;
+    kDebug(126) << "KUrl::KUrl " << " " << str;
 
     if ( str[0] == '/' && (str[1] >= 'A' && str[1] <= 'Z' || str[1] >= 'a' && str[1] <= 'z') && str[2] == ':' )
     	setPath( QString::fromUtf8( str+1 ) );
@@ -358,7 +363,7 @@ KUrl::KUrl( const QByteArray& str )
 {
   if ( !str.isEmpty() ) {
 #ifdef Q_WS_WIN
-    kDebug(126) << "KUrl::KUrl " << " " << str.data() << endl;
+    kDebug(126) << "KUrl::KUrl " << " " << str.data();
     if ( str[0] == '/' && (str[1] >= 'A' && str[1] <= 'Z' || str[1] >= 'a' && str[1] <= 'z') && str[2] == ':' )
     	  setPath( QString::fromUtf8( str.mid(2) ) );
     else if ( (str[0] >= 'A' && str[0] <= 'Z' || str[0] >= 'a' && str[0] <= 'z')  &&  str[1] == ':' )
@@ -376,7 +381,7 @@ KUrl::KUrl( const KUrl& _u )
     : QUrl( _u ), d(0)
 {
 #ifdef Q_WS_WIN
-    kDebug(126) << "KUrl::KUrl(KUrl) " << " path " << _u.path() << " toLocalFile " << _u.toLocalFile() << endl;
+    kDebug(126) << "KUrl::KUrl(KUrl) " << " path " << _u.path() << " toLocalFile " << _u.toLocalFile();
 #endif
 }
 
@@ -384,7 +389,7 @@ KUrl::KUrl( const QUrl &u )
     : QUrl( u ), d(0)
 {
 #ifdef Q_WS_WIN
-    kDebug(126) << "KUrl::KUrl(Qurl) " << " path " << u.path() << " toLocalFile " << u.toLocalFile() << endl;
+    kDebug(126) << "KUrl::KUrl(Qurl) " << " path " << u.path() << " toLocalFile " << u.toLocalFile();
 #endif
 }
 
@@ -392,7 +397,7 @@ KUrl::KUrl( const KUrl& _u, const QString& _rel_url )
    : QUrl(), d(0)
 {
 #ifdef Q_WS_WIN
-    kDebug(126) << "KUrl::KUrl(KUrl,QString rel_url) " << " path " << _u.path() << " toLocalFile " << _u.toLocalFile() << endl;
+    kDebug(126) << "KUrl::KUrl(KUrl,QString rel_url) " << " path " << _u.path() << " toLocalFile " << _u.toLocalFile();
 #endif
 #if 0
   if (_u.hasSubUrl()) // Operate on the last suburl, not the first
@@ -467,16 +472,16 @@ KUrl::KUrl( const KUrl& _u, const QString& _rel_url )
 #endif
     }
     setPath( strPath );
-    //kDebug(126) << "url()=" << url() << " rUrl=" << rUrl << endl;
+    //kDebug(126) << "url()=" << url() << " rUrl=" << rUrl;
     KUrl tmp( url() + rUrl);
-    //kDebug(126) << "assigning tmp=" << tmp.url() << endl;
+    //kDebug(126) << "assigning tmp=" << tmp.url();
     *this = tmp;
     cleanPath(KeepDirSeparators);
   }
   else
   {
     KUrl tmp( rUrl );
-    //kDebug(126) << "not relative; assigning tmp=" << tmp.url() << endl;
+    //kDebug(126) << "not relative; assigning tmp=" << tmp.url();
     *this = tmp;
     // Preserve userinfo if applicable.
     if (!_u.userInfo().isEmpty() && userInfo().isEmpty()
@@ -505,6 +510,11 @@ bool KUrl::operator==( const QString& _u ) const
   return ( *this == u );
 }
 
+KUrl::operator QVariant() const
+{
+  return qVariantFromValue(*this);
+}
+
 bool KUrl::cmp( const KUrl &u, bool ignore_trailing ) const
 {
   return equals( u, ignore_trailing ? CompareWithoutTrailingSlash : EqualsOptions(0) );
@@ -534,6 +544,63 @@ bool KUrl::equals( const KUrl &_u, const EqualsOptions& options ) const
   return ( *this == _u );
 }
 
+QString KUrl::protocol() const
+{
+    return scheme().toLower();
+}
+
+void KUrl::setProtocol( const QString& proto )
+{
+    setScheme( proto );
+}
+
+QString KUrl::user() const
+{
+    return userName();
+}
+
+void KUrl::setUser( const QString& user )
+{
+    setUserName( user );
+}
+
+bool KUrl::hasUser() const
+{
+    return !userName().isEmpty();
+}
+
+QString KUrl::pass() const
+{
+    return password();
+}
+
+void KUrl::setPass( const QString& pass )
+{
+    setPassword( pass );
+}
+
+bool KUrl::hasPass() const
+{
+    return !password().isEmpty();
+}
+
+bool KUrl::hasHost() const
+{
+    return !host().isEmpty();
+}
+
+bool KUrl::hasPath() const
+{
+    return !path().isEmpty();
+}
+
+KUrl KUrl::fromPath( const QString& text )
+{
+    KUrl u;
+    u.setPath( text );
+    return u;
+}
+
 void KUrl::setFileName( const QString& _txt )
 {
   setFragment( QString() );
@@ -587,11 +654,13 @@ void KUrl::cleanPath( const CleanPathOption& options )
 
 static QString trailingSlash( KUrl::AdjustPathOption trailing, const QString &path )
 {
+  if ( trailing == KUrl::LeaveTrailingSlash ) {
+    return path;
+  }
+
   QString result = path;
 
-  if ( trailing == KUrl::LeaveTrailingSlash )
-    return result;
-  else if ( trailing == KUrl::AddTrailingSlash )
+  if ( trailing == KUrl::AddTrailingSlash )
   {
     int len = result.length();
     if ( (len == 0) || (result[ len - 1 ] != QLatin1Char('/')) )
@@ -658,11 +727,7 @@ QString KUrl::encodedPathAndQuery( AdjustPathOption trailing , const EncodedPath
      tmp = QString::fromLatin1( QUrl::toPercentEncoding( tmp, "!$&'()*+,;=:@/" ) );
   }
 
-#if defined( QT_KDE_QT_COPY ) || QT_VERSION >= 0x040200
   if (hasQuery())
-#else
-  if (!query().isEmpty())
-#endif
   {
       tmp += query(); // includes the '?'
   }
@@ -701,7 +766,7 @@ void KUrl::setEncodedPathAndQuery( const QString& _txt )
 
 QString KUrl::path( AdjustPathOption trailing ) const
 {
-  return trailingSlash( trailing, path() );
+  return trailingSlash( trailing, QUrl::path() );
 }
 
 QString KUrl::toLocalFile( AdjustPathOption trailing ) const
@@ -826,23 +891,74 @@ QString KUrl::url( AdjustPathOption trailing ) const
   return QString::fromLatin1( toEncoded( trailing == RemoveTrailingSlash ? StripTrailingSlash : None ) ); // ## check encoding
 }
 
+static QString toPrettyPercentEncoding(const QString &input)
+{
+  QString result;
+  for (int i = 0; i < input.length(); ++i) {
+    QChar c = input.at(i);
+    register short u = c.unicode();
+    if (u < 0x20 || u == '?' || u == '#' || u == '%'
+        || (u == ' ' && (i+1 == input.length() || input.at(i+1) == ' '))) {
+      static const char hexdigits[] = "0123456789ABCDEF";
+      result += QLatin1Char('%');
+      result += QLatin1Char(hexdigits[(u & 0xf0) >> 4]);
+      result += QLatin1Char(hexdigits[u & 0xf]);
+    } else {
+      result += c;
+    }
+  }
+
+  return result;
+}
+
 QString KUrl::prettyUrl( AdjustPathOption trailing ) const
 {
-  // Can't use toString(), it breaks urls with %23 in them (becomes '#', which is parsed back as a fragment)
-  // So prettyUrl is just url, with the password removed.
-  // TODO: we could consider a "toLocalFile or URL" behavior, now that the KUrl constructor can take local paths.
-  // We could replace some chars, like "%20" -> ' ', though?
-  if ( password().isEmpty() )
-    return url( trailing );
+  // reconstruct the URL in a "pretty" form
+  // a "pretty" URL is NOT suitable for data transfer. It's only for showing data to the user.
+  // however, it must be parseable back to its original state, since
+  // notably Konqueror displays it in the Location address.
 
-  QUrl newUrl( *this );
-  newUrl.setPassword( QString() );
-  if ( trailing == AddTrailingSlash && !path().endsWith( QLatin1Char('/') ) ) {
-      // -1 and 0 are provided by QUrl, but not +1.
-      newUrl.setPath( path() + QLatin1Char('/') );
-      return QString::fromLatin1( newUrl.toEncoded() );
+  // A pretty URL is the same as a normal URL, except that:
+  // - the password is removed
+  // - the hostname is shown in Unicode (as opposed to ACE/Punycode)
+  // - the pathname and fragment parts are shown in Unicode (as opposed to %-encoding)
+  QString result = scheme();
+  if (!result.isEmpty())
+    result += QLatin1String("://");
+
+  QString tmp = userName();
+  if (!tmp.isEmpty()) {
+    result += QUrl::toPercentEncoding(tmp);
+    result += QLatin1Char('@');
   }
-  return QString::fromLatin1( newUrl.toEncoded(  trailing == RemoveTrailingSlash ? StripTrailingSlash : None ) ); // ## check encoding
+
+  result += host();
+
+  if (port() != -1) {
+    result += QLatin1Char(':');
+    result += QString::number(port());
+  }
+
+  tmp = path();
+  result += toPrettyPercentEncoding(tmp);
+
+  // adjust the trailing slash, if necessary
+  if (trailing == AddTrailingSlash && !tmp.endsWith(QLatin1Char('/')))
+    result += QLatin1Char('/');
+  else if (trailing == RemoveTrailingSlash && tmp.length() > 1 && tmp.endsWith(QLatin1Char('/')))
+    result.chop(1);
+
+  if (hasQuery()) {
+    result += QLatin1Char('?');
+    result += QLatin1String(encodedQuery());
+  }
+
+  if (hasFragment()) {
+    result += QLatin1Char('#');
+    result += toPrettyPercentEncoding(fragment());
+  }
+
+  return result;
 }
 
 #if 0
@@ -928,11 +1044,7 @@ KUrl::List KUrl::split( const KUrl& _url )
      else
      {
         ref = url.fragment();
-#if defined( QT_KDE_QT_COPY ) || QT_VERSION >= 0x040200
         hasRef = url.hasFragment();
-#else
-        hasRef = !ref.isEmpty();
-#endif
         break;
      }
   }
@@ -1075,7 +1187,7 @@ void KUrl::addPath( const QString& _txt )
   }
 
   setPath( strPath + _txt.mid( i ) );
-  //kDebug(126)<<"addPath: resultpath="<<path()<<endl;
+  //kDebug(126)<<"addPath: resultpath="<<path();
 }
 
 QString KUrl::directory( const DirectoryOptions& options ) const
@@ -1251,7 +1363,7 @@ bool KUrl::hasHTMLRef() const
 
 void KUrl::setDirectory( const QString &dir)
 {
-  if ( dir.endsWith("/"))
+  if ( dir.endsWith('/'))
      setPath(dir);
   else
      setPath(dir+'/');
@@ -1267,18 +1379,18 @@ void KUrl::setQuery( const QString &_txt )
 
 void KUrl::_setQuery( const QString& query )
 {
-  setEncodedQuery( query.isNull() ? QByteArray() : query.toLatin1() ); // ### TODO encoding ok?
+    if ( query.isNull() ) {
+        setEncodedQuery( QByteArray() );
+    } else if ( query.isEmpty() ) {
+        setEncodedQuery( "" );
+    } else {
+        setEncodedQuery( query.toLatin1() ); // already percent-escaped, so toLatin1 is ok
+    }
 }
 
 QString KUrl::query() const
 {
-#if defined( QT_KDE_QT_COPY ) || QT_VERSION >= 0x040200
-  if (!hasQuery())
-#else
-  // For now we'll ignore the case of "a query but it's empty", waiting for Qt-4.2
-  if (query().isEmpty())
-#endif
-  {
+  if (!hasQuery()) {
     return QString();
   }
   return QString( QChar( '?' ) ) + QString::fromAscii( encodedQuery() );
@@ -1452,7 +1564,7 @@ QString KUrl::relativeUrl(const KUrl &base_url, const KUrl &url)
 void KUrl::setPath( const QString& _path )
 {
 #ifdef Q_WS_WIN
-    kDebug(126) << "KUrl::setPath " << " " << _path.toAscii().data() << endl;
+    kDebug(126) << "KUrl::setPath " << " " << _path.toAscii().data();
 #endif
     if ( scheme().isEmpty() )
         setScheme( "file" );
@@ -1557,12 +1669,7 @@ void KUrl::populateMimeData( QMimeData* mimeData,
 
 bool KUrl::hasRef() const
 {
-#if defined( QT_KDE_QT_COPY ) || QT_VERSION >= 0x040200
   return hasFragment();
-#else
-  // For now we'll ignore the case of "a fragment but it's empty", waiting for Qt-4.2
-  return !fragment().isEmpty();
-#endif
 }
 
 void KUrl::setRef( const QString& fragment )
