@@ -23,17 +23,18 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include <QCoreApplication>
-#include <QFile>
-#include <QFileInfo>
-#include <QSettings>
-#include <QTextStream>
-#include <QDomDocument>
-#include <QRegExp>
-#include <QStringList>
+#include <QtCore/QCoreApplication>
+#include <QtCore/QFile>
+#include <QtCore/QFileInfo>
+#include <QtCore/QSettings>
+#include <QtCore/QTextStream>
+#include <QtXml/QDomAttr>
+#include <QtCore/QRegExp>
+#include <QtCore/QStringList>
 
 #include <ostream>
 #include <iostream>
+#include <stdlib.h>
 
 
 static inline std::ostream &operator<<(std::ostream &o, const QString &str)
@@ -74,7 +75,7 @@ static void parseArgs(const QStringList &args, QString &directory, QString &file
             std::cout << "under the terms of the GNU Library Public License." << std::endl;
             std::cout << "For more information about these matters, see the file named COPYING." << std::endl;
             exit(0);
-        } else if (args.at(i).startsWith("-")) {
+        } else if (args.at(i).startsWith('-')) {
             std::cerr << "Unknown option: " << qPrintable(args.at(i)) << std::endl;
             exit(1);
         } else if (fileCount == 0) {
@@ -95,6 +96,7 @@ static void parseArgs(const QStringList &args, QString &directory, QString &file
 }
 
 bool globalEnums;
+bool useEnumTypes;
 bool itemAccessors;
 bool dpointer;
 QStringList allNames;
@@ -121,19 +123,40 @@ class CfgEntry
     struct Choice
     {
       QString name;
+      QString context;
       QString label;
       QString whatsThis;
     };
+    class Choices
+    {
+      public:
+        Choices() {}
+        Choices( const QList<Choice> &d, const QString &n, const QString &p )
+             : prefix(p), choices(d), mName(n)
+        {
+          int i = n.indexOf("::");
+          if (i >= 0)
+            mExternalQual = n.left(i + 2);
+        }
+	QString prefix;
+        QList<Choice> choices;
+	const QString& name() const  { return mName; }
+	const QString& externalQualifier() const  { return mExternalQual; }
+	bool external() const  { return !mExternalQual.isEmpty(); }
+      private:
+        QString mName;
+        QString mExternalQual;
+    };
 
     CfgEntry( const QString &group, const QString &type, const QString &key,
-              const QString &name, const QString &label,
+              const QString &name, const QString &context, const QString &label,
               const QString &whatsThis, const QString &code,
-              const QString &defaultValue, const QList<Choice> &choices, const QList<Signal> signalList,
+              const QString &defaultValue, const Choices &choices, const QList<Signal> signalList,
               bool hidden )
       : mGroup( group ), mType( type ), mKey( key ), mName( name ),
-        mLabel( label ), mWhatsThis( whatsThis ), mCode( code ),
-        mDefaultValue( defaultValue ), mChoices(choices),
-	mSignalList(signalList), mHidden( hidden )
+        mContext( context ), mLabel( label ), mWhatsThis( whatsThis ),
+        mCode( code ), mDefaultValue( defaultValue ), mChoices( choices ),
+        mSignalList(signalList), mHidden( hidden )
     {
     }
 
@@ -149,6 +172,9 @@ class CfgEntry
     void setName( const QString &name ) { mName = name; }
     QString name() const { return mName; }
 
+    void setContext( const QString &context ) { mContext = context; }
+    QString context() const { return mContext; }
+
     void setLabel( const QString &label ) { mLabel = label; }
     QString label() const { return mLabel; }
 
@@ -176,8 +202,8 @@ class CfgEntry
     void setParamType( const QString &d ) { mParamType = d; }
     QString paramType() const { return mParamType; }
 
-    void setChoices( const QList<Choice> &d ) { mChoices = d; }
-    QList<Choice> choices() const { return mChoices; }
+    void setChoices( const QList<Choice> &d, const QString &n, const QString &p ) { mChoices = Choices( d, n, p ); }
+    Choices choices() const { return mChoices; }
 
     void setParamValues( const QStringList &d ) { mParamValues = d; }
     QStringList paramValues() const { return mParamValues; }
@@ -200,6 +226,7 @@ class CfgEntry
       std::cerr << "  type: " << qPrintable(mType) << std::endl;
       std::cerr << "  key: " << qPrintable(mKey) << std::endl;
       std::cerr << "  name: " << qPrintable(mName) << std::endl;
+      std::cerr << "  context: " << qPrintable(mContext) << std::endl;
       std::cerr << "  label: " << qPrintable(mLabel) << std::endl;
 // whatsthis
       std::cerr << "  code: " << qPrintable(mCode) << std::endl;
@@ -223,6 +250,7 @@ class CfgEntry
     QString mType;
     QString mKey;
     QString mName;
+    QString mContext;
     QString mLabel;
     QString mWhatsThis;
     QString mCode;
@@ -230,7 +258,7 @@ class CfgEntry
     QString mParam;
     QString mParamName;
     QString mParamType;
-    QList<Choice> mChoices;
+    Choices mChoices;
     QList<Signal> mSignalList;
     QStringList mParamValues;
     QStringList mParamDefaultValues;
@@ -277,11 +305,48 @@ static QString varPath(const QString &n)
 
 static QString enumName(const QString &n)
 {
-  QString result = "Enum"+n;
+  QString result = "Enum" + n;
   result[4] = result[4].toUpper();
   return result;
 }
 
+static QString enumName(const QString &n, const CfgEntry::Choices &c)
+{
+  QString result = c.name();
+  if ( result.isEmpty() )
+  {
+    result = "Enum" + n;
+    result[4] = result[4].toUpper();
+  }
+  return result;
+}
+
+static QString enumType(const CfgEntry *e)
+{
+  QString result = e->choices().name();
+  if ( result.isEmpty() )
+  {
+    result = "Enum" + e->name() + "::type";
+    result[4] = result[4].toUpper();
+  }
+  return result;
+}
+
+static QString enumTypeQualifier(const QString &n, const CfgEntry::Choices &c)
+{
+  QString result = c.name();
+  if ( result.isEmpty() )
+  {
+    result = "Enum" + n + "::";
+    result[4] = result[4].toUpper();
+  }
+  else if ( c.external() )
+    result = c.externalQualifier();
+  else
+    result.clear();
+  return result;
+}
+
 static QString setFunction(const QString &n, const QString &className = QString())
 {
   QString result = "set"+n;
@@ -363,7 +428,7 @@ static QString signalEnumName(const QString &signalName)
 
 static void preProcessDefault( QString &defaultValue, const QString &name,
                                const QString &type,
-                               const QList<CfgEntry::Choice> &choices,
+                               const CfgEntry::Choices &choices,
                                QString &code )
 {
     if ( type == "String" && !defaultValue.isEmpty() ) {
@@ -398,13 +463,14 @@ static void preProcessDefault( QString &defaultValue, const QString &name,
       }
 
     } else if ( type == "Enum" ) {
-      if ( !globalEnums ) {
-        QList<CfgEntry::Choice>::ConstIterator it;
-        for( it = choices.begin(); it != choices.end(); ++it ) {
-          if ( (*it).name == defaultValue ) {
-            defaultValue.prepend( enumName(name) + "::");
-            break;
-          }
+      QList<CfgEntry::Choice>::ConstIterator it;
+      for( it = choices.choices.begin(); it != choices.choices.end(); ++it ) {
+        if ( (*it).name == defaultValue ) {
+          if ( globalEnums && choices.name().isEmpty() )
+            defaultValue.prepend( choices.prefix );
+          else
+            defaultValue.prepend( enumTypeQualifier(name, choices) + choices.prefix );
+          break;
         }
       }
 
@@ -435,6 +501,7 @@ CfgEntry *parseEntry( const QString &group, const QDomElement &element )
   QString name = element.attribute( "name" );
   QString key = element.attribute( "key" );
   QString hidden = element.attribute( "hidden" );
+  QString context = element.attribute( "context" );
   QString label;
   QString whatsThis;
   QString defaultValue;
@@ -442,7 +509,7 @@ CfgEntry *parseEntry( const QString &group, const QDomElement &element )
   QString param;
   QString paramName;
   QString paramType;
-  QList<CfgEntry::Choice> choices;
+  CfgEntry::Choices choices;
   QList<Signal> signalList;
   QStringList paramValues;
   QStringList paramDefaultValues;
@@ -452,8 +519,14 @@ CfgEntry *parseEntry( const QString &group, const QDomElement &element )
 
   for ( QDomElement e = element.firstChildElement(); !e.isNull(); e = e.nextSiblingElement() ) {
     QString tag = e.tagName();
-    if ( tag == "label" ) label = e.text();
-    else if ( tag == "whatsthis" ) whatsThis = e.text();
+    if ( tag == "label" ) {
+      label = e.text();
+      context = e.attribute( "context" );
+    }
+    else if ( tag == "whatsthis" ) {
+      whatsThis = e.text();
+      context = e.attribute( "context" );
+    }
     else if ( tag == "min" ) minValue = e.text();
     else if ( tag == "max" ) maxValue = e.text();
     else if ( tag == "code" ) code = e.text();
@@ -519,6 +592,9 @@ CfgEntry *parseEntry( const QString &group, const QDomElement &element )
       }
     }
     else if ( tag == "choices" ) {
+      QString name = e.attribute( "name" );
+      QString prefix = e.attribute( "prefix" );
+      QList<CfgEntry::Choice> chlist;
       for( QDomElement e2 = e.firstChildElement(); !e2.isNull(); e2 = e2.nextSiblingElement() ) {
         if ( e2.tagName() == "choice" ) {
           CfgEntry::Choice choice;
@@ -527,12 +603,19 @@ CfgEntry *parseEntry( const QString &group, const QDomElement &element )
             std::cerr << "Tag <choice> requires attribute 'name'." << std::endl;
           }
           for( QDomElement e3 = e2.firstChildElement(); !e3.isNull(); e3 = e3.nextSiblingElement() ) {
-            if ( e3.tagName() == "label" ) choice.label = e3.text();
-            if ( e3.tagName() == "whatsthis" ) choice.whatsThis = e3.text();
+            if ( e3.tagName() == "label" ) {
+              choice.label = e3.text();
+              choice.context = e3.attribute( "context" );
+            }
+            if ( e3.tagName() == "whatsthis" ) {
+              choice.whatsThis = e3.text();
+              choice.context = e3.attribute( "context" );
+            }
           }
-          choices.append( choice );
+          chlist.append( choice );
         }
       }
+      choices = CfgEntry::Choices( chlist, name, prefix );
     }
    else if ( tag == "emit" ) {
     QDomNode signalNode;
@@ -657,7 +740,7 @@ CfgEntry *parseEntry( const QString &group, const QDomElement &element )
     preProcessDefault(defaultValue, name, type, choices, code);
   }
 
-  CfgEntry *result = new CfgEntry( group, type, key, name, label, whatsThis,
+  CfgEntry *result = new CfgEntry( group, type, key, name, context, label, whatsThis,
                                    code, defaultValue, choices, signalList,
                                    hidden == "true" );
   if (!param.isEmpty())
@@ -699,6 +782,8 @@ QString param( const QString &type )
     else if ( type == "Path" )        return "const QString &";
     else if ( type == "PathList" )    return "const QStringList &";
     else if ( type == "Password" )    return "const QString &";
+    else if ( type == "Url" )         return "const KUrl &";
+    else if ( type == "UrlList" )     return "const KUrl::List &";
     else {
         std::cerr <<"kconfig_compiler does not support type \""<< type <<"\""<<std::endl;
         return "QString"; //For now, but an assert would be better
@@ -729,6 +814,8 @@ QString cppType( const QString &type )
     else if ( type == "Path" )        return "QString";
     else if ( type == "PathList" )    return "QStringList";
     else if ( type == "Password" )    return "QString";
+    else if ( type == "Url" )         return "KUrl";
+    else if ( type == "UrlList" )     return "KUrl::List";
     else {
         std::cerr<<"kconfig_compiler does not support type \""<< type <<"\""<<std::endl;
         return "QString"; //For now, but an assert would be better
@@ -756,6 +843,8 @@ QString defaultValue( const QString &type )
     else if ( type == "Path" )        return "\"\""; // Use empty string, not null string!
     else if ( type == "PathList" )    return "QStringList()";
     else if ( type == "Password" )    return "\"\""; // Use empty string, not null string!
+    else if ( type == "Url" )         return "KUrl()";
+    else if ( type == "UrlList" )     return "KUrl::List()";
     else {
         std::cerr<<"Error, kconfig_compiler doesn't support the \""<< type <<"\" type!"<<std::endl;
         return "QString"; //For now, but an assert would be better
@@ -889,7 +978,11 @@ QString userTextsFunctions( CfgEntry *e, QString itemVarStr=QString(), QString i
   QString txt;
   if (itemVarStr.isNull()) itemVarStr=itemPath(e);
   if ( !e->label().isEmpty() ) {
-    txt += "  " + itemVarStr + "->setLabel( i18n(";
+    txt += "  " + itemVarStr + "->setLabel( ";
+    if ( !e->context().isEmpty() )
+      txt += "i18nc(" + quoteString(e->context()) + ", ";
+    else
+      txt += "i18n(";
     if ( !e->param().isEmpty() )
       txt += quoteString(e->label().replace("$("+e->param()+')', i));
     else
@@ -897,7 +990,11 @@ QString userTextsFunctions( CfgEntry *e, QString itemVarStr=QString(), QString i
     txt+= ") );\n";
   }
   if ( !e->whatsThis().isEmpty() ) {
-    txt += "  " + itemVarStr + "->setWhatsThis( i18n(";
+    txt += "  " + itemVarStr + "->setWhatsThis( ";
+    if ( !e->context().isEmpty() )
+      txt += "i18nc(" + quoteString(e->context()) + ", ";
+    else
+      txt += "i18n(";
     if ( !e->param().isEmpty() )
       txt += quoteString(e->whatsThis().replace("$("+e->param()+')', i));
     else
@@ -916,9 +1013,16 @@ QString memberAccessorBody( CfgEntry *e )
     QTextStream out(&result, QIODevice::WriteOnly);
     QString n = e->name();
     QString t = e->type();
+    bool useEnumType = useEnumTypes && t == "Enum";
 
-    out << "return " << This << varPath(n);
-    if (!e->param().isEmpty()) out << "[i]";
+    out << "return ";
+    if (useEnumType)
+      out << "static_cast<" << enumType(e) << ">(";
+    out << This << varPath(n);
+    if (!e->param().isEmpty())
+      out << "[i]";
+    if (useEnumType)
+      out << ")";
     out << ";" << endl;
 
     return result;
@@ -1041,9 +1145,9 @@ int main( int argc, char **argv )
 
   QString baseDir = directoryName;
 #ifdef Q_OS_WIN
-  if (!baseDir.endsWith("/") && !baseDir.endsWith("\\"))
+  if (!baseDir.endsWith('/') && !baseDir.endsWith('\\'))
 #else
-  if (!baseDir.endsWith("/"))
+  if (!baseDir.endsWith('/'))
 #endif
     baseDir.append("/");
 
@@ -1062,6 +1166,7 @@ int main( int argc, char **argv )
   QString inherits = codegenConfig.value("Inherits").toString();
   QString visibility = codegenConfig.value("Visibility").toString();
   if (!visibility.isEmpty()) visibility+=' ';
+  bool forceStringFilename = codegenConfig.value("ForceStringFilename", false).toBool();
   bool singleton = codegenConfig.value("Singleton", false).toBool();
   bool staticAccessors = singleton;
   //bool useDPointer = codegenConfig.readEntry("DPointer", false);
@@ -1076,6 +1181,7 @@ int main( int argc, char **argv )
   bool setUserTexts = codegenConfig.value("SetUserTexts", false).toBool();
 
   globalEnums = codegenConfig.value("GlobalEnums", false).toBool();
+  useEnumTypes = codegenConfig.value("UseEnumTypes", false).toBool();
 
   dpointer = (memberVariables == "dpointer");
 
@@ -1146,30 +1252,30 @@ int main( int argc, char **argv )
       }
     }
     else if ( tag == "signal" ) {
-     QString signalName = e.attribute( "name" );
-     if ( signalName.isEmpty() ) {
-       std::cerr << "Signal without name." << std::endl;
-       return 1;
-     }
-     Signal theSignal;
-     theSignal.name = signalName;
+      QString signalName = e.attribute( "name" );
+      if ( signalName.isEmpty() ) {
+        std::cerr << "Signal without name." << std::endl;
+        return 1;
+      }
+      Signal theSignal;
+      theSignal.name = signalName;
 
-     for( QDomElement e2 = e.firstChildElement(); !e2.isNull(); e2 = e2.nextSiblingElement() ) {
-       if ( e2.tagName() == "argument") {
-         SignalArguments argument;
-         argument.type = e2.attribute("type");
-         if ( argument.type.isEmpty() ) {
-           std::cerr << "Signal argument without type." << std::endl;
-           return 1;
+      for( QDomElement e2 = e.firstChildElement(); !e2.isNull(); e2 = e2.nextSiblingElement() ) {
+        if ( e2.tagName() == "argument") {
+          SignalArguments argument;
+          argument.type = e2.attribute("type");
+          if ( argument.type.isEmpty() ) {
+            std::cerr << "Signal argument without type." << std::endl;
+            return 1;
+          }
+          argument.variableName = e2.text();
+          theSignal.arguments.append(argument);
+        }
+        else if( e2.tagName() == "label") {
+          theSignal.label = e2.text();
         }
-       argument.variableName = e2.text();
-       theSignal.arguments.append(argument);
       }
-      else if( e2.tagName() == "label") {
-        theSignal.label = e2.text();
-      }
-     }
-     signalList.append(theSignal);
+      signalList.append(theSignal);
     }
   }
 
@@ -1262,21 +1368,28 @@ int main( int argc, char **argv )
   // enums
   QList<CfgEntry*>::ConstIterator itEntry;
   for( itEntry = entries.begin(); itEntry != entries.end(); ++itEntry ) {
-    QList<CfgEntry::Choice> choices = (*itEntry)->choices();
-    if ( !choices.isEmpty() ) {
+    const CfgEntry::Choices &choices = (*itEntry)->choices();
+    QList<CfgEntry::Choice> chlist = choices.choices;
+    if ( !chlist.isEmpty() ) {
       QStringList values;
       QList<CfgEntry::Choice>::ConstIterator itChoice;
-      for( itChoice = choices.begin(); itChoice != choices.end(); ++itChoice ) {
-        values.append( (*itChoice).name );
+      for( itChoice = chlist.begin(); itChoice != chlist.end(); ++itChoice ) {
+        values.append( choices.prefix + (*itChoice).name );
       }
-      if ( globalEnums ) {
-        h << "    enum { " << values.join( ", " ) << " };" << endl;
-      } else {
-        h << "    class " << enumName( (*itEntry)->name() ) << endl;
-        h << "    {" << endl;
-        h << "      public:" << endl;
-        h << "      enum type { " << values.join( ", " ) << ", COUNT };" << endl;
-        h << "    };" << endl;
+      if ( choices.name().isEmpty() ) {
+        if ( globalEnums ) {
+          h << "    enum { " << values.join( ", " ) << " };" << endl;
+        } else {
+          // Create an automatically named enum
+          h << "    class " << enumName( (*itEntry)->name(), (*itEntry)->choices() ) << endl;
+          h << "    {" << endl;
+          h << "      public:" << endl;
+          h << "      enum type { " << values.join( ", " ) << ", COUNT };" << endl;
+          h << "    };" << endl;
+        }
+      } else if ( !choices.external() ) {
+        // Create a named enum
+        h << "    enum " << enumName( (*itEntry)->name(), (*itEntry)->choices() ) << " { " << values.join( ", " ) << " };" << endl;
       }
     }
     QStringList values = (*itEntry)->paramValues();
@@ -1302,24 +1415,35 @@ int main( int argc, char **argv )
     }
   }
   if ( hasSignals ) {
-   h << "    enum { ";
+   h << "\n    enum {" << endl;
+   unsigned val = 1;
    QList<Signal>::ConstIterator it, itEnd = signalList.constEnd();
-   for ( it = signalList.constBegin(); it != itEnd; ) {
+   for ( it = signalList.constBegin(); it != itEnd; val <<= 1) {
+     if ( !val ) {
+       std::cerr << "Too many signals to create unique bit masks" << std::endl;
+       exit(1);
+     }
      Signal signal = *it;
-     h << signalEnumName(signal.name);
+     h << "      " << signalEnumName(signal.name) << " = 0x" << hex << val;
      if ( ++it != itEnd )
-      h << ", ";
+      h << ",";
+     h << endl;
    }
-   h << " };" << endl;
+   h << " };" << dec << endl;
   }
   h << endl;
-
   // Constructor or singleton accessor
   if ( !singleton ) {
     h << "    " << className << "(";
     if (cfgFileNameArg)
-       h << " KSharedConfig::Ptr config"
-         << (parameters.isEmpty() ? " = KGlobal::config()" : ", ");
+    {
+        if(forceStringFilename)
+            h << " const QString &cfgfilename"
+                << (parameters.isEmpty() ? " = QString()" : ", ");
+        else
+            h << " KSharedConfig::Ptr config"
+                << (parameters.isEmpty() ? " = KGlobal::config()" : ", ");
+    }
     for (QList<Param>::ConstIterator it = parameters.begin();
          it != parameters.end(); ++it)
     {
@@ -1331,7 +1455,9 @@ int main( int argc, char **argv )
   } else {
     h << "    static " << className << " *self();" << endl;
     if (cfgFileNameArg)
-      h << "    static void instance(const char * cfgfilename);" << endl;
+    {
+      h << "    static void instance(const QString& cfgfilename);" << endl;
+    }
   }
 
   // Destructor
@@ -1358,7 +1484,11 @@ int main( int argc, char **argv )
       h << "    void " << setFunction(n) << "( ";
       if (!(*itEntry)->param().isEmpty())
         h << cppType((*itEntry)->paramType()) << " i, ";
-      h << param( t ) << " v )";
+      if (useEnumTypes && t == "Enum")
+        h << enumType(*itEntry);
+      else
+        h << param( t );
+      h << " v )";
       // function body inline only if not using dpointer
       // for BC mode
       if ( !dpointer )
@@ -1379,7 +1509,12 @@ int main( int argc, char **argv )
     h << "    */" << endl;
     if (staticAccessors)
       h << "    static" << endl;
-    h << "    " << cppType(t) << " " << getFunction(n) << "(";
+    h << "    ";
+    if (useEnumTypes && t == "Enum")
+      h << enumType(*itEntry);
+    else
+      h << cppType(t);
+    h << " " << getFunction(n) << "(";
     if (!(*itEntry)->param().isEmpty())
       h << " " << cppType((*itEntry)->paramType()) <<" i ";
     h << ")" << Const;
@@ -1424,14 +1559,6 @@ int main( int argc, char **argv )
     h << endl;
   }
 
-  // Static writeConfig method for singleton
-  if ( singleton ) {
-    h << "    static" << endl;
-    h << "    void writeConfig()" << endl;
-    h << "    {" << endl;
-    h << "      static_cast<KConfigSkeleton*>(self())->writeConfig();" << endl;
-    h << "    }" << endl;
-  }
 
   // Signal definition.
   if( hasSignals ) {
@@ -1448,7 +1575,16 @@ int main( int argc, char **argv )
       QList<SignalArguments>::ConstIterator it, itEnd = signal.arguments.constEnd();
       for ( it = signal.arguments.constBegin(); it != itEnd; ) {
         SignalArguments argument = *it;
-        h << param(argument.type) << " " << argument.variableName;
+        QString type = param(argument.type);
+        if ( useEnumTypes && argument.type == "Enum" ) {
+          for ( int i = 0, end = entries.count(); i < end; ++i ) {
+            if ( entries[i]->name() == argument.variableName ) {
+              type = enumType(entries[i]);
+              break;
+            }
+          }
+        }
+        h << type << " " << argument.variableName;
         if ( ++it != itEnd ) {
          h << ", ";
         }
@@ -1464,9 +1600,9 @@ int main( int argc, char **argv )
   if ( singleton ) {
     h << "    " << className << "(";
     if ( cfgFileNameArg )
-      h << "const char *arg";
+      h << "const QString& arg";
     h << ");" << endl;
-    h << "    static " << className << " *mSelf;" << endl << endl;
+    h << "    friend class " << className << "Helper;" << endl << endl;
   }
 
   if ( hasSignals ) {
@@ -1555,7 +1691,7 @@ int main( int argc, char **argv )
 
   // Header required by singleton implementation
   if ( singleton )
-    cpp << "#include <kstaticdeleter.h>" << endl << endl;
+    cpp << "#include <kglobal.h>" << endl << "#include <QtCore/QFile>" << endl << endl;
   if ( singleton && cfgFileNameArg )
     cpp << "#include <kdebug.h>" << endl << endl;
 
@@ -1567,6 +1703,8 @@ int main( int argc, char **argv )
   // private class implementation
   if ( dpointer )
   {
+    if ( !nameSpace.isEmpty() )
+      cpp << "namespace " << nameSpace << " {" << endl;
     cpp << "class " << className << "Private" << endl;
     cpp << "{" << endl;
     cpp << "  public:" << endl;
@@ -1594,36 +1732,48 @@ int main( int argc, char **argv )
     }
 
     cpp << "};" << endl << endl;
+    if ( !nameSpace.isEmpty() )
+      cpp << "}" << endl << endl;
   }
 
   // Singleton implementation
   if ( singleton ) {
-    cpp << className << " *" << className << "::mSelf = 0;" << endl;
-    cpp << "static KStaticDeleter<" << className << "> static" << className << "Deleter;" << endl << endl;
+    if( !nameSpace.isEmpty() )
+      cpp << "namespace " << nameSpace << " {" << endl;
+    cpp << "class " << className << "Helper" << endl;
+    cpp << '{' << endl;
+    cpp << "  public:" << endl;
+    cpp << "    " << className << "Helper() : q(0) {}" << endl;
+    cpp << "    ~" << className << "Helper() { delete q; }" << endl;
+    cpp << "    " << className << " *q;" << endl;
+    cpp << "};" << endl;
+    if( !nameSpace.isEmpty() )
+      cpp << "}" << endl;
+    cpp << "K_GLOBAL_STATIC(" << className << "Helper, s_global" << className << ")" << endl;
 
     cpp << className << " *" << className << "::self()" << endl;
     cpp << "{" << endl;
     if ( cfgFileNameArg ) {
-      cpp << "  if (!mSelf)" << endl;
-      cpp << "     kFatal() << \"you need to call " << className << "::instance before using\" << endl;" << endl;
+      cpp << "  if (!s_global" << className << "->q)" << endl;
+      cpp << "     kFatal() << \"you need to call " << className << "::instance before using\";" << endl;
     } else {
-    cpp << "  if ( !mSelf ) {" << endl;
-    cpp << "    static" << className << "Deleter.setObject( mSelf, new " << className << "() );" << endl;
-    cpp << "    mSelf->readConfig();" << endl;
-    cpp << "  }" << endl << endl;
+      cpp << "  if (!s_global" << className << "->q) {" << endl;
+      cpp << "    new " << className << ';' << endl;
+      cpp << "    s_global" << className << "->q->readConfig();" << endl;
+      cpp << "  }" << endl << endl;
     }
-    cpp << "  return mSelf;" << endl;
+    cpp << "  return s_global" << className << "->q;" << endl;
     cpp << "}" << endl << endl;
 
     if ( cfgFileNameArg ) {
-      cpp << "void " << className << "::instance(const char *cfgfilename)" << endl;
+      cpp << "void " << className << "::instance(const QString& cfgfilename)" << endl;
       cpp << "{" << endl;
-      cpp << "  if (mSelf) {" << endl;
-      cpp << "     kDebug() << \"" << className << "::instance called after the first use - ignoring\" << endl;" << endl;
+      cpp << "  if (s_global" << className << "->q) {" << endl;
+      cpp << "     kDebug() << \"" << className << "::instance called after the first use - ignoring\";" << endl;
       cpp << "     return;" << endl;
       cpp << "  }" << endl;
-      cpp << "  static" << className << "Deleter.setObject( mSelf, new " << className << "(cfgfilename) );" << endl;
-      cpp << "  mSelf->readConfig();" << endl;
+      cpp << "  new " << className << "(cfgfilename);" << endl;
+      cpp << "  s_global" << className << "->q->readConfig();" << endl;
       cpp << "}" << endl << endl;
     }
   }
@@ -1634,10 +1784,10 @@ int main( int argc, char **argv )
   // Constructor
   cpp << className << "::" << className << "( ";
   if ( cfgFileNameArg ) {
-    if ( !singleton )
+    if ( !singleton && ! forceStringFilename)
       cpp << " KSharedConfig::Ptr config";
     else
-      cpp << " const char *config";
+      cpp << " const QString& config";
     cpp << (parameters.isEmpty() ? " " : ", ");
   }
 
@@ -1669,8 +1819,10 @@ int main( int argc, char **argv )
     cpp << "  d = new " + className + "Private;" << endl;
   // Needed in case the singleton class is used as baseclass for
   // another singleton.
-  if ( singleton )
-    cpp << "  mSelf = this;" << endl;
+  if (singleton) {
+    cpp << "  Q_ASSERT(!s_global" << className << "->q);" << endl;
+    cpp << "  s_global" << className << "->q = this;" << endl;
+  }
 
   group.clear();
 
@@ -1689,17 +1841,28 @@ int main( int argc, char **argv )
     if ( (*itEntry)->type() == "Enum" ) {
       cpp << "  QList<KConfigSkeleton::ItemEnum::Choice> values"
           << (*itEntry)->name() << ";" << endl;
-      QList<CfgEntry::Choice> choices = (*itEntry)->choices();
+      QList<CfgEntry::Choice> choices = (*itEntry)->choices().choices;
       QList<CfgEntry::Choice>::ConstIterator it;
       for( it = choices.begin(); it != choices.end(); ++it ) {
         cpp << "  {" << endl;
         cpp << "    KConfigSkeleton::ItemEnum::Choice choice;" << endl;
         cpp << "    choice.name = QLatin1String( \"" << (*it).name << "\" );" << endl;
         if ( setUserTexts ) {
-          if ( !(*it).label.isEmpty() )
-            cpp << "    choice.label = i18n(" << quoteString((*it).label) << ");" << endl;
+          if ( !(*it).label.isEmpty() ) {
+            cpp << "    choice.label = ";
+            if ( !(*it).context.isEmpty() )
+              cpp << "i18nc(" + quoteString((*it).context) + ", ";
+            else
+              cpp << "i18n(";
+            cpp << quoteString((*it).label) << ");" << endl;
+          }
           if ( !(*it).whatsThis.isEmpty() )
-            cpp << "    choice.whatsThis = i18n(" << quoteString((*it).whatsThis) << ");" << endl;
+            cpp << "    choice.whatsThis = ";
+            if ( !(*it).context.isEmpty() )
+              cpp << "i18nc(" + quoteString((*it).context) + ", ";
+            else
+              cpp << "i18n(";
+            cpp << quoteString((*it).whatsThis) << ");" << endl;
         }
         cpp << "    values" << (*itEntry)->name() << ".append( choice );" << endl;
         cpp << "  }" << endl;
@@ -1780,7 +1943,11 @@ int main( int argc, char **argv )
         cpp << "void " << setFunction(n, className) << "( ";
         if ( !(*itEntry)->param().isEmpty() )
           cpp << cppType( (*itEntry)->paramType() ) << " i, ";
-        cpp << param( t ) << " v )" << endl;
+        if (useEnumTypes && t == "Enum")
+          cpp << enumType(*itEntry);
+        else
+          cpp << param( t );
+        cpp << " v )";
         // function body inline only if not using dpointer
         // for BC mode
         cpp << "{" << endl;
@@ -1789,7 +1956,11 @@ int main( int argc, char **argv )
       }
 
       // Accessor
-      cpp << cppType(t) << " " << getFunction(n, className) << "(";
+      if (useEnumTypes && t == "Enum")
+        cpp << enumType(*itEntry);
+      else
+        cpp << cppType(t);
+      cpp << " " << getFunction(n, className) << "(";
       if ( !(*itEntry)->param().isEmpty() )
         cpp << " " << cppType( (*itEntry)->paramType() ) <<" i ";
       cpp << ")" << Const << endl;
@@ -1824,21 +1995,32 @@ int main( int argc, char **argv )
   if ( singleton ) {
     if ( dpointer )
       cpp << "  delete d;" << endl;
-    cpp << "  if ( mSelf == this )" << endl;
-    cpp << "    static" << className << "Deleter.setObject( mSelf, 0, false );" << endl;
   }
   cpp << "}" << endl << endl;
 
   if ( hasSignals ) {
     cpp << "void " << className << "::" << "usrWriteConfig()" << endl;
     cpp << "{" << endl;
+    cpp << "  " << inherits << "::usrWriteConfig();" << endl << endl;
     foreach(const Signal &signal, signalList) {
       cpp << "  if ( " << varPath("settingsChanged") << " & " << signalEnumName(signal.name) << " ) " << endl;
       cpp << "    emit " << signal.name << "(";
       QList<SignalArguments>::ConstIterator it, itEnd = signal.arguments.constEnd();
       for ( it = signal.arguments.constBegin(); it != itEnd; ) {
         SignalArguments argument = *it;
+        bool cast = false;
+        if ( useEnumTypes && argument.type == "Enum" ) {
+          for ( int i = 0, end = entries.count(); i < end; ++i ) {
+            if ( entries[i]->name() == argument.variableName ) {
+              cpp << "static_cast<" << enumType(entries[i]) << ">(";
+              cast = true;
+              break;
+            }
+          }
+        }
         cpp << varPath(argument.variableName);
+        if ( cast )
+          cpp << ")";
         if ( ++it != itEnd )
           cpp << ", ";
       }
