@@ -21,37 +21,41 @@
    Boston, MA 02110-1301, USA.
 */
 
-#include <config.h>
-
 #include "klocale.h"
 
+#include <config.h>
+
 #include <stdlib.h> // getenv
 
-#include <qtextcodec.h>
-#include <qfile.h>
-#include <qprinter.h>
-#include <qfileinfo.h>
-#include <qregexp.h>
+#ifdef HAVE_SYS_TIME_H
+#include <sys/time.h>
+#endif
+#ifdef HAVE_TIME_H
+#include <time.h>
+#endif
+
+#include <QtCore/QTextCodec>
+#include <QtCore/QFile>
+#include <QtGui/QPrinter>
+#include <QtCore/QFileInfo>
+#include <QtCore/QRegExp>
 
 #include "kcatalog.h"
 #include "kglobal.h"
 #include "kstandarddirs.h"
-#include "ksimpleconfig.h"
-#include "kcomponentdata.h"
 #include "kconfig.h"
+#include "kcomponentdata.h"
 #include "kdebug.h"
 #include "kdatetime.h"
 #include "kcalendarsystem.h"
-#include "kcalendarsystemfactory.h"
 #include "klocalizedstring.h"
+#include "ktranslit_p.h"
 #include "kconfiggroup.h"
 
 #ifdef Q_WS_WIN
 #include <windows.h>
 #endif
 
-static const char * const SYSTEM_MESSAGES = "kdelibs";
-
 static const char *maincatalog = 0;
 
 class KLocalePrivate
@@ -151,6 +155,16 @@ public:
    */
   bool isApplicationTranslatedInto( const QString & language);
 
+  /**
+   * @internal Formats a date/time according to specified format.
+   */
+  static QString formatDateTime(const KLocale *locale, const QDateTime &dateTime,
+                                KLocale::DateFormat, bool includeSeconds, int daysToNow);
+  /**
+   * @internal Formats a date as a 'fancy' date.
+   */
+  static QString fancyDate(const KLocale *locale, const QDate &date, int daysToNow);
+
   // Numbers and money
   QString decimalSymbol;
   QString thousandsSeparator;
@@ -180,6 +194,7 @@ public:
   QStringList catalogNames; // list of all catalogs (regardless of language)
   QList<KCatalog> catalogs; // list of all found catalogs, one instance per catalog name and language
   int numberOfSysCatalogs; // number of catalogs that each app draws from
+  bool useTranscript; // indicates if scripted messages are to be executed
 
   // Misc
   QString encoding;
@@ -187,7 +202,6 @@ public:
   KSharedConfig::Ptr config;
   int pageSize;
   KLocale::MeasureSystem measureSystem;
-  QStringList langTwoAlpha;
   KConfigBase * languages;
 
   QString calendarType;
@@ -224,6 +238,8 @@ KLocale::KLocale( const QString & catalog, KSharedConfig::Ptr config )
   d->appName = catalog;
   d->initLanguageList(cfg.data(), !config);
   d->initMainCatalogs(catalog);
+
+  d->useTranscript = false;
 }
 
 QString KLocale::_initLanguage(KConfigBase *config)
@@ -253,10 +269,11 @@ void KLocalePrivate::initMainCatalogs(const QString & catalog)
     catalogNames.append( mainCatalog );   // application catalog
 
     // catalogs from which each application can draw translations
-    numberOfSysCatalogs = 2;
-    catalogNames.append( "kdeqt" ); // always include kdeqt.gmo
-    catalogNames.append( SYSTEM_MESSAGES ); // always include kdelibs.gmo
-    catalogNames.append( "kio" );            // always include kio.gmo
+    numberOfSysCatalogs = 4;
+    catalogNames.append("kdeqt");
+    catalogNames.append("kdelibs4");
+    catalogNames.append("kio4");
+    catalogNames.append("libphonon");
 
     updateCatalogs(); // evaluate this for all languages
   }
@@ -266,44 +283,66 @@ void KLocalePrivate::initLanguageList(KConfigBase *config, bool useEnv)
 {
   KConfigGroup cg(config, "Locale");
 
-  country = cg.readEntry( "Country" );
-  if ( country.isEmpty() )
-    country = KLocale::defaultCountry();
+  // Set the country as specified by the KDE config or use default,
+  // do not consider environment variables.
+  country = cg.readEntry("Country");
+  if (country.isEmpty())
+      country = KLocale::defaultCountry();
 
-  // Reset the list and add the new languages
+  // Collect possible languages by decreasing priority.
+  // The priority is as follows:
+  // - KDE_LANG environment variable (can be a list)
+  // - KDE configuration (can be a list)
+  // - environment variables considered by gettext(3)
+  // The environment variables are not considered if useEnv is false.
   QStringList list;
-  if ( useEnv )
-    list += QFile::decodeName( ::getenv("KDE_LANG") ).split(':');
 
+  // Collect languages set by KDE_LANG.
+  if (useEnv)
+    list += QFile::decodeName(getenv("KDE_LANG")).split(':');
+
+  // Collect languages set by KDE config.
   list += cg.readEntry("Language", QStringList(), ':');
 
-  // same order as setlocale use
-  if ( useEnv )
-    {
-      // HPB: Only run splitLocale on the environment variables..
-      QStringList langs;
+  // Collect languages read from environment variables by gettext(3).
+  if (useEnv) {
+    // Collect by same order of priority as for gettext(3).
+    QStringList rawList;
+    rawList += QFile::decodeName(getenv("LANGUAGE")).split(':');
+    rawList += QFile::decodeName(getenv("LC_ALL"));
+    rawList += QFile::decodeName(getenv("LC_MESSAGES"));
+    rawList += QFile::decodeName(getenv("LANG")).split(':');
 
-      langs << QFile::decodeName( ::getenv("LC_ALL") );
-      langs << QFile::decodeName( ::getenv("LC_MESSAGES") );
-      langs << QFile::decodeName( ::getenv("LANG") );
+    // Process the raw list to create possible fallback combinations.
+    foreach (const QString &ln, rawList) {
+      QString lang, ctry, modf, cset;
+      KLocale::splitLocale(ln, lang, ctry, modf, cset);
 
-      foreach (const QString &lang, langs)
-	{
-	  QString ln, aCountry, chrset;
-	  KLocale::splitLocale(lang, ln, aCountry, chrset);
-
-	  if (!aCountry.isEmpty()) {
-	    list += ln + '_' + aCountry;
-	    if (!chrset.isEmpty())
-	      list += ln + '_' + aCountry + '.' + chrset;
-	  }
-	  list += ln;
-	  list += lang;
-	}
+      if (!ctry.isEmpty() && !modf.isEmpty()) {
+        list += lang + '_' + ctry + '@' + modf;
+      }
+      // NOTE: The priority is tricky in case both ctry and modf are present.
+      // Should really lang@modf be of higher priority than lang_ctry?
+      // For at least one case (Serbian language), it is better this way.
+      if (!modf.isEmpty()) {
+        list += lang + '@' + modf;
+      }
+      if (!ctry.isEmpty()) {
+        list += lang + '_' + ctry;
+      }
+      list += lang;
     }
+  }
 
-  // now we have a language list -- let's use the first OK language
-  setLanguage( list );
+  // Insert possible transliteration fallbacks after each collected language.
+  QStringList nlist;
+  foreach (const QString &lang, list) {
+    nlist += lang;
+    nlist += KTranslit::fallbackList(lang);
+  }
+
+  // Send the list to filter for really present languages on the system.
+  setLanguage(nlist);
 }
 
 void KLocalePrivate::doFormatInit(const KLocale *parent)
@@ -322,7 +361,7 @@ void KLocalePrivate::initFormat(KLocale *parent)
     }
     Q_ASSERT(config);
 
-  kDebug(173) << "KLocale::initFormat" << endl;
+  kDebug(173) << "KLocale::initFormat";
 
   // make sure the config files are read using the correct locale
   // ### Why not add a KConfigBase::setLocale( const KLocale * )?
@@ -332,10 +371,10 @@ void KLocalePrivate::initFormat(KLocale *parent)
 
   KConfigGroup cg(config, "Locale");
 
-  KSimpleConfig entry(KStandardDirs::locate("locale",
+  KConfig entryFile(KStandardDirs::locate("locale",
                                            QString::fromLatin1("l10n/%1/entry.desktop")
-                                           .arg(country)), true);
-  entry.setGroup("KCM Locale");
+                                           .arg(country)));
+  KConfigGroup entry(&entryFile, "KCM Locale");
 
   // Numeric
 #define readConfigEntry(key, default, save) \
@@ -349,7 +388,7 @@ void KLocalePrivate::initFormat(KLocale *parent)
   readConfigEntry("DecimalSymbol", ".", decimalSymbol);
   readConfigEntry("ThousandsSeparator", ",", thousandsSeparator);
   thousandsSeparator.replace( QString::fromLatin1("$0"), QString() );
-  //kDebug(173) << "thousandsSeparator=" << thousandsSeparator << endl;
+  //kDebug(173) << "thousandsSeparator=" << thousandsSeparator;
 
   readConfigEntry("PositiveSign", "", positiveSign);
   readConfigEntry("NegativeSign", "-", negativeSign);
@@ -386,12 +425,14 @@ void KLocalePrivate::initFormat(KLocale *parent)
   delete calendar;
   calendar = 0; // ### HPB Is this the correct place?
 
+  readConfigEntry("Transcript", true, useTranscript);
+
   //Grammatical
   //Precedence here is l10n / i18n / config file
-  KSimpleConfig lang(KStandardDirs::locate("locale",
-                                           QString::fromLatin1("%1/entry.desktop")
-                                           .arg(language)), true);
-  lang.setGroup("KCM Locale");
+  KConfig langCfg(KStandardDirs::locate("locale",
+                                        QString::fromLatin1("%1/entry.desktop")
+                                        .arg(language)));
+  KConfigGroup lang(&langCfg,"KCM Locale");
 #define read3ConfigBoolEntry(key, default, save) \
   save = entry.readEntry(key, default); \
   save = lang.readEntry(key, save); \
@@ -465,14 +506,15 @@ bool KLocalePrivate::setLanguage(const QStringList & languages)
          && isApplicationTranslatedInto( language ) )
       list.append( language );
 
-  if ( list.isEmpty() ) {
-	// user picked no language, so we assume he/she speaks English.
-	list.append( KLocale::defaultLanguage() );
+  if ( !list.contains( KLocale::defaultLanguage() ) ) {
+    // English should always be added as final possibility; this is important
+    // for proper initialization of message text post-processors which are
+    // needed for English too, like semantic to visual formatting, etc.
+    list.append( KLocale::defaultLanguage() );
   }
   language = list.first(); // keep this for shortcut evaluations
 
   languageList = list; // keep this new list of languages to use
-  langTwoAlpha.clear(); // Flush cache
 
   // important when called from the outside and harmless when called before populating the
   // catalog name list
@@ -481,6 +523,11 @@ bool KLocalePrivate::setLanguage(const QStringList & languages)
   return true; // we found something. Maybe it's only English, but we found something
 }
 
+bool KLocale::isApplicationTranslatedInto( const QString & lang)
+{
+  return d->isApplicationTranslatedInto( lang );
+}
+
 bool KLocalePrivate::isApplicationTranslatedInto( const QString & lang)
 {
   if ( lang.isEmpty() ) {
@@ -495,40 +542,58 @@ bool KLocalePrivate::isApplicationTranslatedInto( const QString & lang)
   if (maincatalog) {
     appName = QString::fromLatin1(maincatalog);
   }
-  return ! KCatalog::catalogLocaleDir( appName, lang ).isEmpty();
+
+  // Check for this language and possible transliteration fallbacks.
+  QStringList possibles;
+  possibles += lang;
+  possibles += KTranslit::fallbackList(lang);
+  foreach (const QString &lang, possibles) {
+    if ( ! KCatalog::catalogLocaleDir( appName, lang ).isEmpty() ) {
+        return true;
+    }
+  }
+  return false;
 }
 
-void KLocale::splitLocale(const QString & aStr,
-			  QString & language,
-			  QString & country,
-			  QString & chrset)
+void KLocale::splitLocale(const QString &aLocale,
+                          QString &language,
+                          QString &country,
+                          QString &modifier,
+                          QString &charset)
 {
-  QString str = aStr;
+  QString locale = aLocale;
 
-  // just in case, there is another language appended
-  int f = str.indexOf(':');
-  if (f >= 0)
-    str.truncate(f);
-
-  country.clear();
-  chrset.clear();
   language.clear();
+  country.clear();
+  modifier.clear();
+  charset.clear();
 
-  f = str.indexOf('.');
-  if (f >= 0)
-    {
-      chrset = str.mid(f + 1);
-      str.truncate(f);
-    }
+  // In case there are several concatenated locale specifications,
+  // truncate all but first.
+  int f = locale.indexOf(':');
+  if (f >= 0) {
+    locale.truncate(f);
+  }
 
-  f = str.indexOf('_');
-  if (f >= 0)
-    {
-      country = str.mid(f + 1);
-      str.truncate(f);
-    }
+  f = locale.indexOf('.');
+  if (f >= 0) {
+    charset = locale.mid(f + 1);
+    locale.truncate(f);
+  }
 
-  language = str;
+  f = locale.indexOf('@');
+  if (f >= 0) {
+    modifier = locale.mid(f + 1);
+    locale.truncate(f);
+  }
+
+  f = locale.indexOf('_');
+  if (f >= 0) {
+    country = locale.mid(f + 1);
+    locale.truncate(f);
+  }
+
+  language = locale;
 }
 
 QString KLocale::language() const
@@ -570,8 +635,11 @@ void KLocalePrivate::updateCatalogs( )
       if ( ! KCatalog::catalogLocaleDir( name, lang ).isEmpty() )
       {
         catalogs.append( KCatalog( name, lang ) );
-        //kDebug(173) << "Catalog: " << name << ":" << lang << endl;
+        //kDebug(173) << "Catalog: " << name << ":" << lang;
       }
+
+  // notify KLocalizedString of catalog update.
+  KLocalizedString::notifyCatalogsUpdated(languageList, catalogNames);
 }
 
 void KLocale::removeCatalog(const QString &catalog)
@@ -609,6 +677,9 @@ void KLocalePrivate::translate_priv(const char *msgctxt,
   if ( !msgid || !msgid[0] ) {
     kWarning() << "KLocale: trying to look up \"\" in catalog. "
                << "Fix the program" << endl;
+    *language = QString();
+    *translation = QString();
+    return;
   }
   if ( msgctxt && !msgctxt[0] ) {
     kWarning() << "KLocale: trying to use \"\" as context to message. "
@@ -650,15 +721,15 @@ void KLocalePrivate::translate_priv(const char *msgctxt,
 
     QString text;
     if ( msgctxt != NULL && msgid_plural != NULL )
-        text = (*it).translate( msgctxt, msgid, msgid_plural, n );
+        text = (*it).translateStrict( msgctxt, msgid, msgid_plural, n );
     else if ( msgid_plural != NULL )
-        text = (*it).translate( msgid, msgid_plural, n );
+        text = (*it).translateStrict( msgid, msgid_plural, n );
     else if ( msgctxt != NULL )
-        text = (*it).translate( msgctxt, msgid );
+        text = (*it).translateStrict( msgctxt, msgid );
     else
-        text = (*it).translate( msgid );
+        text = (*it).translateStrict( msgid );
 
-    if ( text != fallback ) {
+    if ( !text.isEmpty() ) {
       // we found it
       if ( language )
         *language = (*it).language();
@@ -694,37 +765,66 @@ void KLocale::translateRaw(const char *ctxt, const char *singular, const char *p
   d->translate_priv(ctxt, singular, plural, n, lang, trans);
 }
 
-QString KLocale::translateQt( const char *context, const char *source,
-			      const char *message) const
+QString KLocale::translateQt(const char *context, const char *sourceText,
+                             const char *comment) const
 {
-  if (!source || !source[0]) {
+  // Qt's context is normally the name of the class of the method which makes
+  // the tr(sourceText) call. However, it can also be manually supplied via
+  // translate(context, sourceText) call.
+  //
+  // Qt's sourceText is the actual message displayed to the user.
+  //
+  // Qt's comment is an optional argument of tr() and translate(), like
+  // tr(sourceText, comment) and translate(context, sourceText, comment).
+  //
+  // We handle this in the following way:
+  //
+  // If the comment is given, then it is considered gettext's msgctxt, so a
+  // context call is made.
+  //
+  // If the comment is not given, but context is given, then we treat it as
+  // msgctxt only if it was manually supplied (the one in translate()) -- but
+  // we don't know this, so we first try a context call, and if translation
+  // is not found, we fallback to ordinary call.
+  //
+  // If neither comment nor context are given, it's just an ordinary call
+  // on sourceText.
+
+  if (!sourceText || !sourceText[0]) {
     kWarning() << "KLocale: trying to look up \"\" in catalog. "
-		<< "Fix the program" << endl;
+               << "Fix the program" << endl;
     return QString();
   }
 
-  if ( d->useDefaultLanguage() ) {
+  if (d->useDefaultLanguage()) {
     return QString();
   }
 
+  QString translation;
   QString language;
 
-  if ( message && message[0]) {
-    d->translate_priv(source, message, 0, 0, &language, 0);
+  // NOTE: Condition (language != defaultLanguage()) means that translation
+  // was found, otherwise we got the original string back as translation.
+
+  if (comment && comment[0]) {
+    // Comment given, go for context call.
+    d->translate_priv(comment, sourceText, 0, 0, &language, &translation);
     if (language != defaultLanguage())
-      return i18nc(source, message);
+      return translation;
+  }
+  else {
+    // Comment not given, go for try-fallback with context.
+    if (context && context[0]) {
+      d->translate_priv(context, sourceText, 0, 0, &language, &translation);
+      if (language != defaultLanguage())
+        return translation;
+    }
+    d->translate_priv(0, sourceText, 0, 0, &language, &translation);
+    if (language != defaultLanguage())
+      return translation;
   }
 
-  if ( context && context[0] && message && message[0]) {
-    d->translate_priv(context, message, 0, 0, &language, 0);
-    if (language != defaultLanguage())
-      return i18nc(context, message);
-  }
-
-  d->translate_priv(0, source, 0, 0, &language, 0);
-  if (language != defaultLanguage())
-    return i18n(source);
-
+  // No proper translation found, return empty according to Qt's expectation.
   return QString();
 }
 
@@ -1023,7 +1123,7 @@ QString KLocale::formatNumber(const QString &numStr, bool round,
   const bool neg = (tmpString[0] == '-');
   if (neg || tmpString[0] == '+') tmpString.remove(0, 1);
 
-  //kDebug(173)<<"tmpString:"<<tmpString<<endl;
+  //kDebug(173)<<"tmpString:"<<tmpString;
 
   // Split off exponential part (including 'e'-symbol)
   const int expPos = tmpString.indexOf('e'); // -1 if not found
@@ -1035,8 +1135,8 @@ QString KLocale::formatNumber(const QString &numStr, bool round,
       expString.clear();
   }
 
-  //kDebug(173)<<"mantString:"<<mantString<<endl;
-  //kDebug(173)<<"expString:"<<expString<<endl;
+  //kDebug(173)<<"mantString:"<<mantString;
+  //kDebug(173)<<"expString:"<<expString;
   if (mantString.isEmpty() || !mantString[0].isDigit()) // invalid number
     mantString = "0";
 
@@ -1121,9 +1221,17 @@ QString KLocale::formatDuration( unsigned long mSec) const
 
    return i18n( "%1 milliseconds", formatNumber(mSec, 0));
 }
-QString KLocale::formatDate(const QDate &pDate, bool shortFormat) const
+
+QString KLocale::formatDate(const QDate &pDate, DateFormat format) const
 {
-  const QString rst = shortFormat?dateFormatShort():dateFormat();
+  if (format == FancyShortDate || format == FancyLongDate)
+  {
+    int days = pDate.daysTo(QDate::currentDate());
+    if (days >= 0 && days < 7)
+      return KLocalePrivate::fancyDate(this, pDate, days);
+    format = (format == FancyShortDate) ? ShortDate : LongDate;
+  }
+  const QString rst = (format == ShortDate) ? dateFormatShort() : dateFormat();
 
   QString buffer;
 
@@ -1150,41 +1258,41 @@ QString KLocale::formatDate(const QDate &pDate, bool shortFormat) const
 	    case '%':
 	      buffer.append(QLatin1Char('%'));
 	      break;
-	    case 'Y':
-	      buffer.append(calendar()->yearString(pDate, false));
+	    case 'Y':  //Long year numeric
+	      buffer.append(calendar()->yearString(pDate, KCalendarSystem::LongFormat));
 	      break;
-	    case 'y':
-	      buffer.append(calendar()->yearString(pDate, true));
+	    case 'y':  //Short year numeric
+	      buffer.append(calendar()->yearString(pDate, KCalendarSystem::ShortFormat));
 	      break;
-	    case 'n':
-              buffer.append(calendar()->monthString(pDate, true));
+	    case 'n':  //Short month numeric
+              buffer.append(calendar()->monthString(pDate, KCalendarSystem::ShortFormat));
 	      break;
-	    case 'e':
-              buffer.append(calendar()->dayString(pDate, true));
+	    case 'e':  //Short day numeric
+              buffer.append(calendar()->dayString(pDate, KCalendarSystem::ShortFormat));
 	      break;
-	    case 'm':
-              buffer.append(calendar()->monthString(pDate, false));
+	    case 'm':  //Long month numeric
+              buffer.append(calendar()->monthString(pDate, KCalendarSystem::LongFormat));
 	      break;
-	    case 'b':
+	    case 'b':  //Short month name
 	      if (d->nounDeclension && d->dateMonthNamePossessive)
-		buffer.append(calendar()->monthNamePossessive(month, year, true));
+		buffer.append(calendar()->monthName(month, year, KCalendarSystem::ShortNamePossessive));
 	      else
-		buffer.append(calendar()->monthName(month, year, true));
+		buffer.append(calendar()->monthName(month, year, KCalendarSystem::ShortName));
 	      break;
-	    case 'B':
+	    case 'B':  //Long month name
 	      if (d->nounDeclension && d->dateMonthNamePossessive)
-		buffer.append(calendar()->monthNamePossessive(month, year, false));
+		buffer.append(calendar()->monthName(month, year, KCalendarSystem::LongNamePossessive));
 	      else
-		buffer.append(calendar()->monthName(month, year, false));
+		buffer.append(calendar()->monthName(month, year, KCalendarSystem::LongName));
 	      break;
-	    case 'd':
-              buffer.append(calendar()->dayString(pDate, false));
+	    case 'd':  //Long day numeric
+              buffer.append(calendar()->dayString(pDate, KCalendarSystem::LongFormat));
 	      break;
-	    case 'a':
-	      buffer.append(calendar()->weekDayName(pDate, true));
+	    case 'a':  //Short weekday name
+	      buffer.append(calendar()->weekDayName(pDate, KCalendarSystem::ShortDayName));
 	      break;
-	    case 'A':
-	      buffer.append(calendar()->weekDayName(pDate, false));
+	    case 'A':  //Long weekday name
+	      buffer.append(calendar()->weekDayName(pDate, KCalendarSystem::LongDayName));
 	      break;
 	    default:
 	      buffer.append(rst.at(format_index));
@@ -1196,6 +1304,19 @@ QString KLocale::formatDate(const QDate &pDate, bool shortFormat) const
   return buffer;
 }
 
+QString KLocalePrivate::fancyDate(const KLocale *locale, const QDate &date, int days)
+{
+  switch (days)
+  {
+    case 0:
+      return i18n("Today");
+    case 1:
+      return i18n("Yesterday");
+    default:
+      return locale->calendar()->weekDayName(date);
+  }
+}
+
 void KLocale::setMainCatalog(const char *catalog)
 {
   maincatalog = catalog;
@@ -1397,7 +1518,7 @@ QDate KLocale::readDate(const QString &intstr, ReadDateFlags flags, bool* ok) co
 
 QDate KLocale::readDate(const QString &intstr, const QString &fmt, bool* ok) const
 {
-  //kDebug(173) << "KLocale::readDate intstr=" << intstr << " fmt=" << fmt << endl;
+  //kDebug(173) << "KLocale::readDate intstr=" << intstr << " fmt=" << fmt;
   QString str = intstr.simplified().toLower();
   int day = -1, month = -1;
   // allow the year to be omitted if not in the format
@@ -1436,7 +1557,12 @@ QDate KLocale::readDate(const QString &intstr, const QString &fmt, bool* ok) con
             error = true;
       j = 1;
       while (error && (j < 8)) {
-        QString s = calendar()->weekDayName(j, c == 'a').toLower();
+        QString s;
+        if ( c == 'a') {
+            s = calendar()->weekDayName(j, KCalendarSystem::ShortDayName).toLower();
+        } else {
+            s = calendar()->weekDayName(j, KCalendarSystem::LongDayName).toLower();
+        }
         int len = s.length();
         if (str.mid(strpos, len) == s)
               {
@@ -1453,7 +1579,12 @@ QDate KLocale::readDate(const QString &intstr, const QString &fmt, bool* ok) con
       if (d->nounDeclension && d->dateMonthNamePossessive) {
         j = 1;
         while (error && (j < 13)) {
-          QString s = calendar()->monthNamePossessive(j, year, c == 'b').toLower();
+          QString s;
+          if ( c == 'b' ) {
+              s = calendar()->monthName(j, year, KCalendarSystem::ShortNamePossessive).toLower();
+          } else {
+              s = calendar()->monthName(j, year, KCalendarSystem::LongNamePossessive).toLower();
+          }
           int len = s.length();
           if (str.mid(strpos, len) == s) {
             month = j;
@@ -1465,7 +1596,12 @@ QDate KLocale::readDate(const QString &intstr, const QString &fmt, bool* ok) con
       }
       j = 1;
       while (error && (j < 13)) {
-        QString s = calendar()->monthName(j, year, c == 'b').toLower();
+        QString s;
+        if ( c == 'b' ) {
+            s = calendar()->monthName(j, year, KCalendarSystem::ShortName).toLower();
+        } else {
+            s = calendar()->monthName(j, year, KCalendarSystem::LongName).toLower();
+        }
         int len = s.length();
         if (str.mid(strpos, len) == s) {
           month = j;
@@ -1509,7 +1645,7 @@ QDate KLocale::readDate(const QString &intstr, const QString &fmt, bool* ok) con
       error = true;
     }
 
-    //kDebug(173) << "KLocale::readDate day=" << day << " month=" << month << " year=" << year << endl;
+    //kDebug(173) << "KLocale::readDate day=" << day << " month=" << month << " year=" << year;
     if ( year != -1 && month != -1 && day != -1 && !error)
     {
       if (ok) *ok = true;
@@ -1738,36 +1874,68 @@ QStringList KLocale::languageList() const
   return d->languageList;
 }
 
-QString KLocale::formatDateTime(const QDateTime &pDateTime,
-				bool shortFormat,
-				bool includeSeconds) const
+QString KLocalePrivate::formatDateTime(const KLocale *locale, const QDateTime &dateTime,
+                                KLocale::DateFormat format, bool includeSeconds, int daysTo)
 {
-  return i18nc( "concatenation of dates and time", "%1 %2",
-                formatDate( pDateTime.date(), shortFormat ),
-                formatTime( pDateTime.time(), includeSeconds ) );
+  QString dateStr = (format == KLocale::FancyShortDate || format == KLocale::FancyLongDate)
+                  ? KLocalePrivate::fancyDate(locale, dateTime.date(), daysTo)
+                  : locale->formatDate(dateTime.date(), format);
+  return i18nc("concatenation of dates and time", "%1 %2",
+               dateStr, locale->formatTime(dateTime.time(), includeSeconds));
 }
 
-QString KLocale::formatDateTime(const KDateTime &pDateTime,
-				bool shortFormat,
-				bool includeSeconds,
-                                bool includeTimeZone) const
+QString KLocale::formatDateTime(const QDateTime &dateTime, DateFormat format,
+                                bool includeSeconds) const
+{
+  QString dateStr;
+  int days = -1;
+  if (format == FancyShortDate || format == FancyLongDate)
+  {
+    QDateTime now = QDateTime::currentDateTime();
+    days = dateTime.date().daysTo(now.date());
+    if ((days == 0 && now.secsTo(dateTime) <= 3600)   // not more than an hour in the future
+    ||  (days > 0 && days < 7))
+      ;  // use fancy date format
+    else
+      format = (format == FancyShortDate) ? ShortDate : LongDate;  // fancy date not applicable
+  }
+  return KLocalePrivate::formatDateTime(this, dateTime, format, includeSeconds, days);
+}
+
+QString KLocale::formatDateTime(const KDateTime &dateTime, DateFormat format,
+                                DateTimeFormatOptions options) const
 {
   QString dt;
-  if (pDateTime.isDateOnly())
-    dt = formatDate( pDateTime.date(), shortFormat );
+  if (dateTime.isDateOnly())
+    dt = formatDate( dateTime.date(), format );
   else
-    dt = formatDateTime( pDateTime.dateTime(), shortFormat, includeSeconds );
-  if (includeTimeZone)
+  {
+    int days = -1;
+    if (format == FancyShortDate || format == FancyLongDate)
+    {
+      // Use the time specification (i.e. time zone, etc.) of 'dateTime' to
+      // check whether it's less than a week ago.
+      KDateTime now = KDateTime::currentDateTime(dateTime.timeSpec());
+      days = dateTime.date().daysTo(now.date());
+      if ((days == 0 && now.secsTo(dateTime) <= 3600)   // not more than an hour in the future
+      ||  (days > 0 && days < 7))
+        ;  // use fancy date format
+      else
+        format = (format == FancyShortDate) ? ShortDate : LongDate;  // fancy date not applicable
+    }
+    dt = KLocalePrivate::formatDateTime(this, dateTime.dateTime(), format, (options & Seconds), days);
+  }
+  if (options & TimeZone)
   {
     QString tz;
-    switch (pDateTime.timeType())
+    switch (dateTime.timeType())
     {
       case KDateTime::OffsetFromUTC:
-        tz = i18n(pDateTime.toString("%z").toUtf8());
+        tz = i18n(dateTime.toString("%z").toUtf8());
         break;
       case KDateTime::UTC:
       case KDateTime::TimeZone:
-        tz = i18n(pDateTime.toString(shortFormat ? "%Z" : "%:Z").toUtf8());
+        tz = i18n(dateTime.toString((format == ShortDate) ? "%Z" : "%:Z").toUtf8());
         break;
       case KDateTime::ClockTime:
       default:
@@ -1779,24 +1947,6 @@ QString KLocale::formatDateTime(const KDateTime &pDateTime,
     return dt;
 }
 
-void KLocale::initInstance()
-{
-    if (KGlobal::hasLocale()) {
-        return;
-    }
-
-    KComponentData app = KGlobal::mainComponent();
-    if (app.isValid()) {
-        KLocale *locale = new KLocale(QString::fromLatin1(app.componentName()));
-        KGlobal::setLocale(locale);
-
-        // only do this for the global instance
-        QTextCodec::setCodecForLocale(locale->codecForEncoding());
-    } else {
-        kDebug(173) << "no app name available using KLocale - nothing to do\n";
-    }
-}
-
 QString KLocale::langLookup(const QString &fname, const char *rtype)
 {
   QStringList search;
@@ -1819,7 +1969,7 @@ QString KLocale::langLookup(const QString &fname, const char *rtype)
   QStringList::Iterator it;
   for (it = search.begin(); it != search.end(); ++it)
     {
-      kDebug(173) << "Looking for help in: " << *it << endl;
+      kDebug(173) << "Looking for help in: " << *it;
 
       QFileInfo info(*it);
       if (info.exists() && info.isFile() && info.isReadable())
@@ -1843,7 +1993,7 @@ void KLocalePrivate::initEncoding(KConfigBase *)
 
   if ( ! codecForEncoding )
     {
-      kWarning(173) << " Defaulting to ISO 8859-1 encoding." << endl;
+      kWarning(173) << " Defaulting to ISO 8859-1 encoding.";
       setEncoding(mibDefault);
     }
 
@@ -2034,6 +2184,12 @@ QString KLocale::defaultCountry()
   return QString::fromLatin1("C");
 }
 
+bool KLocale::useTranscript() const
+{
+  d->doFormatInit(this);
+  return d->useTranscript;
+}
+
 const QByteArray KLocale::encoding() const
 {
 #ifdef Q_WS_WIN
@@ -2082,69 +2238,24 @@ bool KLocalePrivate::setEncoding(int mibEnum)
   return codec != 0;
 }
 
-QStringList KLocale::languagesTwoAlpha() const
-{
-  if (d->langTwoAlpha.count())
-     return d->langTwoAlpha;
-
-  const QStringList &origList = languageList();
-
-  QStringList result;
-
-  KConfig config(QString::fromLatin1("language.codes"), true, false);
-  config.setGroup("TwoLetterCodes");
-
-  for ( QStringList::ConstIterator it = origList.begin();
-	it != origList.end();
-	++it )
-    {
-      QString lang = *it;
-      QStringList langLst;
-      if (config.hasKey( lang ))
-         langLst = config.readEntry( lang, QStringList() );
-      else
-      {
-         int i = lang.indexOf('_');
-         if (i >= 0)
-            lang.truncate(i);
-         langLst << lang;
-      }
-
-      for ( QStringList::ConstIterator langIt = langLst.begin();
-	    langIt != langLst.end();
-	    ++langIt )
-	{
-	  if ( !(*langIt).isEmpty() && !result.contains( *langIt ) )
-	    result += *langIt;
-	}
-    }
-  d->langTwoAlpha = result;
-  return result;
-}
-
-QStringList KLocale::allLanguagesTwoAlpha() const
+QStringList KLocale::allLanguagesList() const
 {
   if (!d->languages)
-    d->languages = new KConfig("all_languages", true, false, "locale");
+    d->languages = new KConfig("locale", "all_languages", KConfig::NoGlobals);
 
   return d->languages->groupList();
 }
 
-QString KLocale::twoAlphaToLanguageName(const QString &code) const
+QString KLocale::languageCodeToName(const QString &language) const
 {
   if (!d->languages)
-    d->languages = new KConfig("all_languages", true, false, "locale");
+    d->languages = new KConfig("locale", "all_languages", KConfig::NoGlobals);
 
-  QString groupName = code;
-  int i = groupName.indexOf('_');
-  if (i < 0) i = groupName.size();
-  groupName.replace(0, i, groupName.left(i).toLower());
-
-  d->languages->setGroup(groupName);
-  return d->languages->readEntry("Name");
+  KConfigGroup cg(d->languages, language);
+  return cg.readEntry("Name");
 }
 
-QStringList KLocale::allCountriesTwoAlpha() const
+QStringList KLocale::allCountriesList() const
 {
   QStringList countries;
   QStringList paths = KGlobal::dirs()->findAllResources("locale", "l10n/*/entry.desktop");
@@ -2158,11 +2269,16 @@ QStringList KLocale::allCountriesTwoAlpha() const
   return countries;
 }
 
-QString KLocale::twoAlphaToCountryName(const QString &code) const
+QString KLocale::countryCodeToName(const QString &country) const
 {
-  KConfig cfg("l10n/"+code.toLower()+"/entry.desktop", true, false, "locale");
-  cfg.setGroup("KCM Locale");
-  return cfg.readEntry("Name");
+  QString countryName;
+  QString entryFile = KStandardDirs::locate("locale", "l10n/"+country.toLower()+"/entry.desktop");
+  if (!entryFile.isEmpty()) {
+    KConfig cfg(entryFile);
+    KConfigGroup cg(&cfg, "KCM Locale");
+    countryName = cg.readEntry("Name");
+  }
+  return countryName;
 }
 
 void KLocale::setCalendar(const QString & calType)
@@ -2188,7 +2304,7 @@ const KCalendarSystem * KLocale::calendar() const
 
   // Check if it's the correct calendar?!?
   if ( !d->calendar )
-    d->calendar = KCalendarSystemFactory::create( d->calendarType, this );
+    d->calendar = KCalendarSystem::create( d->calendarType, this );
 
   return d->calendar;
 }
