@@ -22,10 +22,11 @@
 #ifndef KLOCALE_H
 #define KLOCALE_H
 
-#include <qstring.h>
-#include <kdelibs_export.h>
+#include <kdecore_export.h>
 #include <klocalizedstring.h>
-#include <kconfig.h>
+#include <ksharedconfig.h>
+
+#include <QtCore/QString>
 
 class QStringList;
 class QTextCodec;
@@ -34,9 +35,9 @@ class QTime;
 class QDateTime;
 
 class KDateTime;
-class KGlobal;
-class KCatalog;
 class KCalendarSystem;
+
+class KLocale;
 class KLocalePrivate;
 
 /**
@@ -51,13 +52,14 @@ class KLocalePrivate;
   * KLocale supports translating, as well as specifying the format
   * for numbers, currency, time, and date.
   *
+  * Use KGlobal::locale() to get pointer to the global KLocale object
+  *
   * @author Stephan Kulow <coolo@kde.org>, Preston Brown <pbrown@kde.org>,
   * Hans Petter Bieker <bieker@kde.org>, Lukas Tinkl <lukas.tinkl@suse.cz>
   * @short class for supporting locale settings and national language
   */
 class KDECORE_EXPORT KLocale
 {
-  friend class KGlobal; // for initInstance()
 public:
   /**
    * Constructs a KLocale with the given catalog name.
@@ -194,22 +196,22 @@ public:
    * unchanged if failed. It will force a reload of the country specific
    * configuration as well.
    *
-   * @param language The language code.
+   * @param language the language code
    *
-   * @return True on success.
+   * @return true on success
    */
-  bool setLanguage(const QString & language);
+  bool setLanguage(const QString &language);
 
   /**
-   * Changes the list of prefed languages for the locale. The first valid
-   * language in the list will be used, or the default (en_US) language
-   * will be used if non of the specified languages were available.
+   * Changes the list of preferred languages for the locale. The first valid
+   * language in the list will be used, or the default language (en_US)
+   * if none of the specified languages were available.
    *
-   * @param languages The list of language codes.
+   * @param languages the list of language codes
    *
-   * @return True if one of the specified languages were used.
+   * @return true if one of the specified languages were used
    */
-  bool setLanguage(const QStringList & languages);
+  bool setLanguage(const QStringList &languages);
 
   /**
    * Changes the current country. The current country will be left
@@ -442,16 +444,65 @@ public:
    */
    bool nounDeclension() const;
 
+  /**
+   * Format for date string.
+   */
+  enum DateFormat {
+    ShortDate,      /**< Short (numeric) date format, e.g. 08-04-2007 */
+    LongDate,       /**< Long (text) date format, e.g. Sunday 08 April 2007 */
+    FancyShortDate, /**< Same as ShortDate for dates a week or more ago. For more
+                         recent dates, it is represented as Today, Yesterday, or
+                         the weekday name. */
+    FancyLongDate   /**< Same as LongDate for dates a week or more ago. For more
+                         recent dates, it is represented as Today, Yesterday, or
+                         the weekday name. */
+  };
+
   /**
    * Returns a string formatted to the current locale's conventions
    * regarding dates.
    *
-   * @param pDate The date to be formatted.
-   * @param shortFormat True for non text dates.
+   * @param date the date to be formatted.
+   * @param format category of date format to use
    *
    * @return The date as a string
    */
-  QString formatDate(const QDate &pDate, bool shortFormat = false) const;
+  QString formatDate(const QDate &date, DateFormat format = LongDate) const;
+
+  /**
+   * Returns a string formatted to the current locale's conventions
+   * regarding both date and time.
+   *
+   * @param dateTime the date and time to be formatted
+   * @param format category of date format to use
+   * @param options additional output options
+   *
+   * @return The date and time as a string
+   */
+  QString formatDateTime(const QDateTime &dateTime, DateFormat format = ShortDate,
+                         bool includeSecs = false) const;
+
+  /**
+   * Options for formatting date-time values.
+   */
+  enum DateTimeFormatOption {
+    TimeZone = 0x01,    /**< Include a time zone string */
+    Seconds  = 0x02     /**< Include the seconds value */
+  };
+  Q_DECLARE_FLAGS(DateTimeFormatOptions, DateTimeFormatOption)
+
+  /**
+   * Returns a string formatted to the current locale's conventions
+   * regarding both date and time.
+   *
+   * @param dateTime the date and time to be formatted
+   * @param format category of date format to use
+   * @param options additional output options
+   *
+   * @return The date and time as a string
+   */
+  QString formatDateTime(const KDateTime &dateTime, DateFormat format = ShortDate,
+                         DateTimeFormatOptions options = 0) const;
 
   /**
    * Use this to determine whether in dates a possessive form of month
@@ -514,36 +565,6 @@ public:
    */
   void setCalendar(const QString & calendarType);
 
-  /**
-   * Returns a string formatted to the current locale's conventions
-   * regarding both date and time.
-   *
-   * @param pDateTime the date and time to be formatted
-   * @param shortFormat using the short date format
-   * @param includeSecs include the seconds value
-   *
-   * @return The date and time as a string
-   */
-  QString formatDateTime(const QDateTime &pDateTime,
-			 bool shortFormat = true,
-			 bool includeSecs = false) const;
-
-  /**
-   * Returns a string formatted to the current locale's conventions
-   * regarding both date and time.
-   *
-   * @param pDateTime the date and time to be formatted
-   * @param shortFormat using the short date format
-   * @param includeSecs include the seconds value
-   * @param includeTimeZone include a time zone string
-   *
-   * @return The date and time as a string
-   */
-  QString formatDateTime(const KDateTime &pDateTime,
-			 bool shortFormat = true,
-			 bool includeSecs = false,
-                         bool includeTimeZone = false) const;
-
   /**
    * Converts a localized monetary string to a double.
    *
@@ -643,11 +664,16 @@ public:
   QTime readTime(const QString &str, ReadTimeFlags flags, bool *ok = 0) const;
 
   /**
-   * Returns the language used by this object. The domain AND the
+   * Returns the language code used by this object. The domain AND the
    * library translation must be available in this language.
    * defaultLanguage() is returned by default, if no other available.
    *
-   * @return The currently used language.
+   * Use languageCodeToName(language) to get human readable, localized
+   * language name.
+   *
+   * @return the currently used language code
+   *
+   * @see languageCodeToName
    */
   QString language() const;
 
@@ -655,32 +681,25 @@ public:
    * Returns the country code of the country where the user lives.
    * defaultCountry() is returned by default, if no other available.
    *
-   * @return The country code for the user.
+   * Use countryCodeToName(country) to get human readable, localized
+   * country names.
+   *
+   * @return the country code for the user
+   *
+   * @see countryCodeToName
    */
   QString country() const;
 
   /**
-   * Returns the preferred languages as ISO 639-1 codes. This means
-   * that information about country is removed. If the internal language
-   * code might be represented by more than one 639-1 code, they will all be
-   * listed (but only once).
+   * Returns the language codes selected by user, ordered by decreasing
+   * priority.
    *
-   * If the selected languages are "nn, nb, pt_BR", you will get:
-   * "nn, no, nb, pt".
+   * Use languageCodeToName(language) to get human readable, localized
+   * language name.
    *
-   * @return List of language codes
+   * @return list of language codes
    *
-   * @see languageList
-   */
-  QStringList languagesTwoAlpha() const;
-
-  /**
-   * Returns the languages selected by user. The codes returned here is the
-   * internal language codes.
-   *
-   * @return List of language codes
-   *
-   * @see languagesTwoAlpha
+   * @see languageCodeToName
    */
   QStringList languageList() const;
 
@@ -973,47 +992,79 @@ public:
    **/
   QString translateQt(const char *context,
 		      const char *sourceText,
-		      const char *message) const;
+		      const char *comment) const;
 
   /**
-   * Returns list of all known ISO 639-1 codes.
-   * @return a list of all language codes
-   */
-  QStringList allLanguagesTwoAlpha() const;
-
-  /**
-   * Convert a ISO 639-1 code to a human readable form.
-   * @param code the language ISO 639-1 code
-   * @return the human readable form
-   */
-  QString twoAlphaToLanguageName(const QString &code) const;
-
-  /**
-   * Returns list of all known country codes.
-   * @return a list of all country codes
-   */
-  QStringList allCountriesTwoAlpha() const;
-
-  /**
-   * Convert a country code to a human readable form.
-   * @param code the country code
-   * @return the human readable form of the country name
-   */
-  QString twoAlphaToCountryName(const QString &code) const;
-
-  /**
-   * Returns the parts of the parameter str understood as language setting
-   * the format is language_COUNTRY.charset
+   * Provides list of all known language codes.
    *
-   * @param str The string to split.
-   * @param language This will be set to the language part of the string.
-   * @param country This will be set to the country part of the string.
-   * @param charset This will be set to the charset part of the string.
+   * Use languageCodeToName(language) to get human readable, localized
+   * language names.
+   *
+   * @return list of all language codes
+   *
+   * @see languageCodeToName
    */
-  static void splitLocale(const QString & str,
-			  QString & language,
-			  QString & country,
-			  QString & charset);
+  QStringList allLanguagesList() const;
+
+  /**
+   * Convert a known language code to a human readable, localized form.
+   * If an unknown language code is supplied, empty string is returned;
+   * this will never happen if the code has been obtained by one of the
+   * KLocale methods.
+   *
+   * @param language the language code
+   *
+   * @return the human readable and localized form if the code is known,
+   *         empty otherwise
+   *
+   * @see language
+   * @see languageList
+   * @see allLanguagesList
+   */
+  QString languageCodeToName(const QString &language) const;
+
+  /**
+   * Provides list of all known country codes.
+   *
+   * Use countryCodeToName(country) to get human readable, localized
+   * country names.
+   *
+   * @return a list of all country codes
+   *
+   * @see countryCodeToName
+   */
+  QStringList allCountriesList() const;
+
+  /**
+   * Convert a known country code to a human readable, localized form.
+   * If an unknown country code is supplied, empty string is returned;
+   * this will never happen if the code has been obtained by one of the
+   * KLocale methods.
+   *
+   * @param code the country code
+   *
+   * @return the human readable and localized form of the country name
+   *
+   * @see country
+   * @see allCountriesList
+   */
+  QString countryCodeToName(const QString &country) const;
+
+  /**
+   * Parses locale string into distinct parts.
+   * The format of locale is language_COUNTRY@modifier.CHARSET
+   *
+   * @param locale the locale string to split
+   * @param language set to the language part of the locale
+   * @param country set to the country part of the locale
+   * @param modifier set to the modifer part of the locale
+   * @param charset set to the charset part of the locale
+   */
+  static void splitLocale(const QString &locale,
+                          QString &language,
+                          QString &country,
+                          QString &modifier,
+                          QString &charset);
 
   /**
    * Use this as main catalog for *all* KLocales, if not the appname
@@ -1047,22 +1098,30 @@ public:
    */
   static QString defaultCountry();
 
+  /**
+   * Reports whether evaluation of translation scripts is enabled.
+   *
+   * @return true if script evaluation is enabled, false otherwise.
+   */
+  bool useTranscript() const;
+
+  /**
+   * Checks whether or not the active catalog is found for the given language.
+   *
+   * @param language language to check
+   */
+  bool isApplicationTranslatedInto( const QString & language);
+
 
   /**
    * @internal Called from KConfigBackend to initialize language.
    */
   static QString _initLanguage(KConfigBase *config);
 
-
-protected:
-  /**
-   * @internal Creates a KLocale object for KGlobal and inits the locale
-   * pointer.
-   */
-  static void initInstance();
-
 private:
   KLocalePrivate * const d;
 };
 
+Q_DECLARE_OPERATORS_FOR_FLAGS(KLocale::DateTimeFormatOptions)
+
 #endif
