@@ -19,8 +19,12 @@
 #ifndef KLOCALIZEDSTRING_H
 #define KLOCALIZEDSTRING_H
 
-#include <qstring.h>
-#include <kdelibs_export.h>
+#include <kdecore_export.h>
+
+
+#include <QtCore/QChar>
+#include <QtCore/QLatin1Char>
+#include <QtCore/QStringList>
 
 class KLocale;
 class KLocalizedStringPrivate;
@@ -75,6 +79,7 @@ class KLocalizedStringPrivate;
  *  - @ref gen_usage
  *  - @ref spec_usage
  *  - @ref subs_notes
+ *  - @ref other_ref
  *
  * \section gen_usage General Usage
  *
@@ -192,7 +197,23 @@ class KLocalizedStringPrivate;
  * \li If none of the arguments supplied to a plural call is integer-valued,
  *     you will get an error mark in message at runtime (in debug mode).
  *
- * @see <a href="http://developer.kde.org/documentation/library/">[[Here goes the link to Programmer's i18n howto, sec. How to prepare the code]]</a>
+ * \section other_ref Further References
+ *
+ * <a href="http://techbase.kde.org/">KDE Techbase</a> contains a
+ * <a href="http://techbase.kde.org/Development/Tutorials/Localization/i18n">
+ * series of tutorials</a> on preparing the code for localization (and on
+ * internationalization process in general), where the intended patterns of
+ * usage of i18n API are covered in great detail.
+ *
+ * All i18n'd messages, whether sent to widgets expecting plain text or
+ * allowing Qt rich text (HTML), support the new KDE semantic markup for
+ * user interface text, KUIT in short. Semantic markup both increases the
+ * consistency of visual presentation for the end user, and provides extra
+ * information to translators, so that translations can be of higher quality.
+ * KUIT is documented in an
+ * <a href="http://techbase.kde.org/Development/Tutorials/Localization/i18n_Semantics">
+ * Techbase article</a> as well.
+ *
  * @see KLocale
  * @author Chusslove Illich \<caslav.ilic@gmx.net\>
  */
@@ -397,6 +418,12 @@ public:
     KLocalizedString subs (const QString &a, int fieldWidth = 0,
                            const QChar &fillChar = QLatin1Char(' ')) const;
 
+    /**
+     * @internal Called from KLocale on addition or removal of catalogs.
+     */
+    static void notifyCatalogsUpdated (const QStringList &languages,
+                                       const QStringList &catalogs);
+
 private:
     KLocalizedString (const char *ctxt,
                       const char *msg, const char *plural);
@@ -458,14 +485,20 @@ extern KLocalizedString KDECORE_EXPORT ki18np (const char *singular, const char
 extern KLocalizedString KDECORE_EXPORT ki18ncp (const char *ctxt, const char *singular, const char *plural);
 
 /**
- * Qt's uic generates i18n( "msg", "comment" ) calls which conflict
- * with our i18n method. We use uic -tr tr2i18n to redirect
- * to the right i18n() function
+ * Qt's uic generated translation calls go through numerous indirections
+ * unnecessary in our case. So we use uic -tr tr2i18n to redirect them
+ * to our i18n API.
 **/
-inline QString tr2i18n(const char* message, const char* =0) {
-    if (!message || !message[0])
+inline QString tr2i18n (const char *message, const char *comment = 0) {
+    if (comment && comment[0] && message && message[0]) {
+        return ki18nc(comment, message).toString();
+    }
+    else if (message && message[0]) {
+        return ki18n(message).toString();
+    }
+    else {
         return QString();
-    return ki18n(message).toString();
+    }
 }
 
 #ifndef NDEBUG
