@@ -28,7 +28,7 @@
 #include <unistd.h>
 #include <arpa/inet.h>
 
-#include <qglobal.h>
+#include <QtCore/QBool>
 
 #include <kdebug.h>
 
@@ -37,15 +37,15 @@
 // broken getaddrinfo
 #include <netdb.h>
 
-#include "config.h"
-#include "config-network.h"
+#include <config.h>
+#include <config-network.h>
 #include "klocale.h"
 
 #ifndef IN6_IS_ADDR_V4MAPPED
 #define NEED_IN6_TESTS
 #endif
 #undef CLOBBER_IN6
-#include "netsupp.h"
+#include "netsupp.h" //krazy:exclude=includes (netsupp.h not installed; KDE3 compat code)
 
 #if defined(__hpux) || defined(_HPUX_SOURCE)
 extern int h_errno;
@@ -883,6 +883,7 @@ void freeaddrinfo(struct addrinfo *p)
   dofreeaddrinfo(p);
 }
 
+#ifndef HAVE_GAI_STRERROR_PROTO
 char *gai_strerror(int errorcode)
 {
   static const char messages[] =
@@ -916,6 +917,7 @@ char *gai_strerror(int errorcode)
   strcpy(buffer, i18n(messages + messages_indices[errorcode]).toLocal8Bit());
   return buffer;
 }
+#endif
 
 static void findport(unsigned short port, char *serv, size_t servlen, int flags)
 {
