@@ -26,15 +26,16 @@
 #include <unistd.h>
 #include <stdlib.h>
 
-#include <qstring.h>
-#include <qfile.h>
-#include <qdir.h>
-#include <qmap.h>
+#include <QtCore/QCharRef>
+#include <QtCore/QFile>
+#include <QtCore/QDir>
+#include <QtCore/QMap>
 
 #include <kauthorized.h>
 #include <kdebug.h>
 #include <kdesktopfile.h>
 #include <kglobal.h>
+#include <kconfiggroup.h>
 #include <kstandarddirs.h>
 
 #include "kservicefactory.h"
@@ -78,15 +79,16 @@ void KService::Private::init( const KDesktopFile *config, KService* q )
     const QString entryPath = q->entryPath();
     bool absPath = !QDir::isRelativePath(entryPath);
 
-    QMap<QString, QString> entryMap = config->entryMap(config->group());
+    // TODO: it makes sense to have a KConstConfigGroup I guess
+    KConfigGroup desktopGroup = const_cast<KDesktopFile*>(config)->desktopGroup();
+    QMap<QString, QString> entryMap = desktopGroup.entryMap();
 
     entryMap.remove("Encoding"); // reserved as part of Desktop Entry Standard
     entryMap.remove("Version");  // reserved as part of Desktop Entry Standard
 
-    q->m_bDeleted = config->readEntry("Hidden", false);
+    q->setDeleted( desktopGroup.readEntry("Hidden", false) );
     entryMap.remove("Hidden");
-    if (q->m_bDeleted)
-    {
+    if ( q->isDeleted() ) {
         m_bValid = false;
         return;
     }
@@ -95,7 +97,7 @@ void KService::Private::init( const KDesktopFile *config, KService* q )
     entryMap.remove("Name");
     if ( m_strName.isEmpty() )
     {
-        if (config->readEntry( "Exec" ).isEmpty())
+        if (desktopGroup.readEntry( "Exec" ).isEmpty())
         {
             m_bValid = false;
             return;
@@ -109,7 +111,7 @@ void KService::Private::init( const KDesktopFile *config, KService* q )
             m_strName = m_strName.left(i);
     }
 
-    m_strType = config->readEntry( "Type" );
+    m_strType = desktopGroup.readEntry( "Type" );
     entryMap.remove("Type");
     if ( m_strType.isEmpty() )
     {
@@ -130,7 +132,7 @@ void KService::Private::init( const KDesktopFile *config, KService* q )
 
     // In case Try Exec is set, check if the application is available
     if (!config->tryExec()) {
-        q->m_bDeleted = true;
+        q->setDeleted( true );
         m_bValid = false;
         return;
     }
@@ -169,7 +171,7 @@ void KService::Private::init( const KDesktopFile *config, KService* q )
     if (pos != -1)
         _name = _name.left(pos);
 
-    m_strExec = config->readPathEntry( "Exec" );
+    m_strExec = desktopGroup.readPathEntry( "Exec" );
     entryMap.remove("Exec");
     if (m_strType == "Application" && m_strExec.isEmpty())
     {
@@ -177,42 +179,42 @@ void KService::Private::init( const KDesktopFile *config, KService* q )
                        << " has Type=" << m_strType << " but has no Exec field." << endl;
     }
 
-    m_strIcon = config->readEntry( "Icon" );
+    m_strIcon = desktopGroup.readEntry( "Icon" );
     entryMap.remove("Icon");
-    m_bTerminal = config->readEntry( "Terminal", false); // should be a property IMHO
+    m_bTerminal = desktopGroup.readEntry( "Terminal", false); // should be a property IMHO
     entryMap.remove("Terminal");
-    m_strTerminalOptions = config->readEntry( "TerminalOptions" ); // should be a property IMHO
+    m_strTerminalOptions = desktopGroup.readEntry( "TerminalOptions" ); // should be a property IMHO
     entryMap.remove("TerminalOptions");
-    m_strPath = config->readPathEntry( "Path" );
+    m_strPath = desktopGroup.readPathEntry( "Path" );
     entryMap.remove("Path");
     m_strComment = config->readComment();
     entryMap.remove("Comment");
     m_strGenName = config->readGenericName();
     entryMap.remove("GenericName");
-    QString _untranslatedGenericName = config->readEntryUntranslated( "GenericName" );
+    QString _untranslatedGenericName = desktopGroup.readEntryUntranslated( "GenericName" );
     entryMap.insert("UntranslatedGenericName", _untranslatedGenericName);
 
-    m_lstKeywords = config->readEntry("Keywords", QStringList());
+    m_lstKeywords = desktopGroup.readEntry("Keywords", QStringList());
     entryMap.remove("Keywords");
-    categories = config->readEntry("Categories", QStringList(), ';');
+    categories = desktopGroup.readEntry("Categories", QStringList(), ';');
     entryMap.remove("Categories");
-    m_strLibrary = config->readEntry( "X-KDE-Library" );
+    m_strLibrary = desktopGroup.readEntry( "X-KDE-Library" );
     entryMap.remove("X-KDE-Library");
 
-    m_lstServiceTypes = config->readEntry( "ServiceTypes", QStringList() );
+    m_lstServiceTypes = desktopGroup.readEntry( "ServiceTypes", QStringList() );
     entryMap.remove("ServiceTypes");
-    m_lstServiceTypes += config->readEntry( "MimeType", QStringList(), ';' ); // freedesktop.org standard
+    m_lstServiceTypes += desktopGroup.readEntry( "MimeType", QStringList(), ';' ); // freedesktop.org standard
     entryMap.remove("MimeType");
 
     if ( m_strType == "Application" && !m_lstServiceTypes.contains("Application") )
         // Applications implement the service type "Application" ;-)
         m_lstServiceTypes += "Application";
 
-    QString dbusStartupType = config->readEntry("X-DBUS-StartupType").toLower();
+    QString dbusStartupType = desktopGroup.readEntry("X-DBUS-StartupType").toLower();
     //Compatibility
-    if( dbusStartupType.isEmpty() && config->hasKey("X-DCOP-ServiceType"))
+    if( dbusStartupType.isEmpty() && desktopGroup.hasKey("X-DCOP-ServiceType"))
     {
-        dbusStartupType = config->readEntry("X-DCOP-ServiceType").toLower();
+        dbusStartupType = desktopGroup.readEntry("X-DCOP-ServiceType").toLower();
         entryMap.remove("X-DCOP-ServiceType");
     }
     entryMap.remove("X-DBUS-StartupType");
@@ -227,10 +229,10 @@ void KService::Private::init( const KDesktopFile *config, KService* q )
 
     m_strDesktopEntryName = _name.toLower();
 
-    m_bAllowAsDefault = config->readEntry("AllowDefault", true);
+    m_bAllowAsDefault = desktopGroup.readEntry("AllowDefault", true);
     entryMap.remove("AllowDefault");
 
-    m_initialPreference = config->readEntry( "InitialPreference", 1 );
+    m_initialPreference = desktopGroup.readEntry( "InitialPreference", 1 );
     entryMap.remove("InitialPreference");
 
     // Store all additional entries in the property map.
@@ -374,7 +376,7 @@ bool KService::hasMimeType( const KServiceType* ptr ) const
         it->toInt(&isNumber);
         if (isNumber)
             continue;
-        //kDebug(7012) << "    has " << (*it) << endl;
+        //kDebug(7012) << "    has " << (*it);
         if ( *it == ptr->name() )
             return true;
         // also the case of parent servicetypes
@@ -392,6 +394,7 @@ bool KService::hasMimeType( const KServiceType* ptr ) const
     return false;
 }
 
+//TODO: make this a KConfigBackend instead
 class KServiceReadProperty : public KConfigBase
 {
 public:
@@ -415,6 +418,11 @@ public:
 
    KEntry lookupData(const KEntryKey &) const
    { KEntry entry; entry.mValue = value; return entry; }
+
+   template <typename T>
+      T readEntry( const QString& pKey, const T& aDefault) const
+   { return internalGroup().readEntry(pKey.toUtf8().constData(), aDefault); }
+
 protected:
    QString key;
    QByteArray value;
@@ -491,7 +499,7 @@ QVariant KService::property( const QString& _name, QVariant::Type t ) const
     QMap<QString,QVariant>::ConstIterator it = d->m_mapProps.find( _name );
     if ( (it == d->m_mapProps.end()) || (!it->isValid()))
     {
-        //kDebug(7012) << "Property not found " << _name << endl;
+        //kDebug(7012) << "Property not found " << _name;
         return QVariant(); // No property set.
     }
 
@@ -521,6 +529,7 @@ QVariant KService::property( const QString& _name, QVariant::Type t ) const
     }
     default:
         // All others
+        // For instance properties defined as StringList, like MimeTypes.
         KServiceReadProperty ksrp(_name, it->toString().toUtf8());
         return ksrp.readEntry(_name, QVariant(t));
     }
@@ -573,8 +582,8 @@ KService::Ptr KService::serviceByDesktopPath( const QString& _name )
 KService::Ptr KService::serviceByDesktopName( const QString& _name )
 {
     KService::Ptr s = KServiceFactory::self()->findServiceByDesktopName( _name.toLower() );
-    if (!s && !_name.startsWith("kde-"))
-        s = KServiceFactory::self()->findServiceByDesktopName( "kde-"+_name.toLower() );
+    if (!s && !_name.startsWith("kde4-"))
+        s = KServiceFactory::self()->findServiceByDesktopName( "kde4-"+_name.toLower() );
     return s;
 }
 
@@ -675,6 +684,16 @@ QString KService::parentApp() const {
     return it->toString();
 }
 
+QString KService::pluginKeyword() const
+{
+    QMap<QString,QVariant>::ConstIterator it = d->m_mapProps.find("X-KDE-PluginKeyword");
+    if ((it == d->m_mapProps.end()) || (!it->isValid())) {
+        return QString();
+    }
+
+    return it->toString();
+}
+
 bool KService::allowMultipleFiles() const {
     // Can we pass multiple files on the command line or do we have to start the application for every single file ?
     return (d->m_strExec.contains( "%F" ) || d->m_strExec.contains( "%U" ) ||
@@ -717,7 +736,7 @@ QString KService::newServicePath(bool showInMenu, const QString &suggestedName,
 {
     QString base = suggestedName;
     if (!showInMenu)
-        base.prepend("kde-");
+        base.prepend("kde4-");
 
     QString result;
     for(int i = 1; true; i++)
@@ -742,7 +761,7 @@ QString KService::newServicePath(bool showInMenu, const QString &suggestedName,
         }
         else
         {
-            QString file = result.mid(4); // Strip "kde-"
+            QString file = result.mid(5); // Strip "kde4-"
             if (!KStandardDirs::locate("apps", ".hidden/"+file).isEmpty())
                 continue;
         }
@@ -757,7 +776,7 @@ QString KService::newServicePath(bool showInMenu, const QString &suggestedName,
         return KStandardDirs::locateLocal("xdgdata-apps", result);
     }
 
-    QString file = result.mid(4); // Strip "kde-"
+    QString file = result.mid(5); // Strip "kde4-"
     return KStandardDirs::locateLocal("apps", ".hidden/"+file);
 }
 
