@@ -41,6 +41,7 @@ class KDesktopFile;
  *
  * For a tutorial on how to build a plugin-loading mechanism and how to write plugins
  * in general, see http://developer.kde.org/documentation/tutorials/developing-a-plugin-structure/index.html#developing_plugins
+ * (todo: port to kde4, create techbase article)
  *
  * @see KServiceType
  * @see KServiceGroup
@@ -337,6 +338,13 @@ public:
      */
     QString parentApp() const;
 
+    /**
+     * The keyword to be used when constructing the plugin using KPluginFactory. The keyword is
+     * defined with X-KDE-PluginKeyword in the .desktop file and with K_REGISTER_PLUGIN_WITH_KEYWORD
+     * when implementing the plugin.
+     */
+    QString pluginKeyword() const;
+
     /**
      * Returns the requested property. Some often used properties
      * have convenience access functions like exec(),
@@ -509,9 +517,30 @@ public:
      *         factory was unable to create an object of the given type.
      */
     template <class T>
+    static T *createInstance(const KService::Ptr &service, QObject *parent = 0,
+            const QVariantList &args = QVariantList(), QString *error = 0)
+    {
+        KPluginLoader pluginLoader(service->library());
+        KPluginFactory *factory = pluginLoader.factory();
+        if (factory) {
+            const QString keyword = service->pluginKeyword();
+            T *o = factory->create<T>(keyword, parent, args);
+            delete factory;
+            if (o) {
+                return o;
+            }
+        }
+        if (error) {
+            *error = pluginLoader.errorString();
+        }
+        return 0;
+    }
+
+    template <class T>
+    KDE_DEPRECATED
     static T *createInstance( const KService::Ptr &service,
-                              QObject *parent = 0,
-                              const QStringList &args = QStringList(),
+                              QObject *parent,
+                              const QStringList &args,
                               int *error = 0 )
     {
         const QString library = service->library();
@@ -521,8 +550,7 @@ public:
             return 0;
         }
 
-        return KLibLoader::createInstance<T>( library.toLocal8Bit().constData(), parent,
-                                              args, error );
+        return KLibLoader::createInstance<T>( library, parent, args, error );
     }
 
     /**
@@ -539,9 +567,31 @@ public:
      *         factory was unable to create an object of the given type.
      */
     template <class T, class ServiceIterator>
+    static T *createInstance(ServiceIterator begin, ServiceIterator end, QObject *parent = 0,
+            const QVariantList &args = QVariantList(), QString *error = 0)
+    {
+        for (; begin != end; ++begin) {
+            KService::Ptr service = *begin;
+            if (error) {
+                *error = QString();
+            }
+
+            T *component = createInstance<T>(service, parent, args, error);
+            if (component) {
+                return component;
+            }
+        }
+        if (error) {
+            *error = KLibLoader::errorString(KLibLoader::ErrNoServiceFound);
+        }
+        return 0;
+    }
+
+    template <class T, class ServiceIterator>
+    KDE_DEPRECATED
     static T *createInstance( ServiceIterator begin, ServiceIterator end,
-                              QObject *parent = 0,
-                              const QStringList &args = QStringList(),
+                              QObject *parent,
+                              const QStringList &args,
                               int *error = 0 )
     {
         for (; begin != end; ++begin ) {
