@@ -22,14 +22,14 @@
 #include "kfilterbase.h"
 #include <unistd.h>
 #include <limits.h>
-#include <qfile.h>
-#include <qtextstream.h>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
 #include <kdebug.h>
 #include "kfiltertest.h"
-#include <qdir.h>
-#include <qfileinfo.h>
+#include <QtCore/QDir>
+#include <QtCore/QFileInfo>
 
-QTEST_KDEMAIN(KFilterTest, NoGUI)
+QTEST_KDEMAIN_CORE(KFilterTest)
 
 void KFilterTest::initTestCase()
 {
@@ -59,11 +59,11 @@ void KFilterTest::test_block_write( const QString & fileName )
 
 void KFilterTest::test_block_write()
 {
-    kDebug() << " -- test_block_write gzip -- " << endl;
+    kDebug() << " -- test_block_write gzip -- ";
     test_block_write(pathgz);
     QCOMPARE( QFileInfo( pathgz ).size(), 33LL ); // size of test.gz
 
-    kDebug() << " -- test_block_write bzip2 -- " << endl;
+    kDebug() << " -- test_block_write bzip2 -- ";
     test_block_write(pathbz2);
     QCOMPARE( QFileInfo( pathbz2 ).size(), 52LL ); // size of test.bz2
 }
@@ -82,14 +82,14 @@ void KFilterTest::test_block_read( const QString & fileName )
     {
         QVERIFY( n > 0 );
         read += QByteArray( array, n );
-        //kDebug() << "read returned " << n << endl;
-        //kDebug() << "read='" << read << "'" << endl;
+        //kDebug() << "read returned " << n;
+        //kDebug() << "read='" << read << "'";
 
         // pos() has no real meaning on sequential devices
         // Ah, but kzip uses kfilterdev as a non-sequential device...
 
         QCOMPARE( (int)dev->pos(), (int)read.size() );
-        //kDebug() << "dev.at = " << dev->at() << endl;
+        //kDebug() << "dev.at = " << dev->at();
     }
     QCOMPARE( read, testData );
 
@@ -106,9 +106,9 @@ void KFilterTest::test_block_read( const QString & fileName )
 
 void KFilterTest::test_block_read()
 {
-    kDebug() << " -- test_block_read gzip -- " << endl;
+    kDebug() << " -- test_block_read gzip -- ";
     test_block_read(pathgz);
-    kDebug() << " -- test_block_read bzip2 -- " << endl;
+    kDebug() << " -- test_block_read bzip2 -- ";
     test_block_read(pathbz2);
 }
 
@@ -131,9 +131,9 @@ void KFilterTest::test_getch( const QString & fileName )
 
 void KFilterTest::test_getch()
 {
-    kDebug() << " -- test_getch gzip -- " << endl;
+    kDebug() << " -- test_getch gzip -- ";
     test_getch(pathgz);
-    kDebug() << " -- test_getch bzip2 -- " << endl;
+    kDebug() << " -- test_getch bzip2 -- ";
     test_getch(pathbz2);
 }
 
@@ -154,9 +154,9 @@ void KFilterTest::test_textstream(  const QString & fileName )
 
 void KFilterTest::test_textstream()
 {
-    kDebug() << " -- test_textstream gzip -- " << endl;
+    kDebug() << " -- test_textstream gzip -- ";
     test_textstream(pathgz);
-    kDebug() << " -- test_textstream bzip2 -- " << endl;
+    kDebug() << " -- test_textstream bzip2 -- ";
     test_textstream(pathbz2);
 }
 
@@ -173,10 +173,24 @@ void KFilterTest::test_readall( const QString & fileName, const QString& mimeTyp
 
 void KFilterTest::test_readall()
 {
-    kDebug() << " -- test_readall gzip -- " << endl;
+    kDebug() << " -- test_readall gzip -- ";
     test_readall(pathgz, QString::fromLatin1("application/x-gzip"));
-    kDebug() << " -- test_readall bzip2 -- " << endl;
-    test_readall(pathbz2, QString::fromLatin1("application/x-bzip2"));
+    kDebug() << " -- test_readall bzip2 -- ";
+    test_readall(pathbz2, QString::fromLatin1("application/x-bzip"));
+}
+
+void KFilterTest::test_uncompressed()
+{
+    // Can KFilterDev handle uncompressed data even when using gzip decompression?
+    kDebug() << " -- test_uncompressed -- ";
+    QBuffer buffer(&testData);
+    buffer.open(QIODevice::ReadOnly);
+    QIODevice *flt = KFilterDev::device(&buffer, QString::fromLatin1("application/x-gzip"), false);
+    bool ok = flt->open( QIODevice::ReadOnly );
+    QVERIFY(ok);
+    QByteArray read = flt->readAll();
+    QCOMPARE( read.size(), testData.size() );
+    QCOMPARE( read, testData );
 }
 
 #include "kfiltertest.moc"
