@@ -20,10 +20,10 @@
 #include "qtest_kde.h"
 #include "kjobtest.h"
 
-#include <qtimer.h>
-#include <qsignalspy.h>
+#include <QtCore/QTimer>
+#include <QtTest/QSignalSpy>
 
-QTEST_KDEMAIN( KJobTest, NoGUI )
+QTEST_KDEMAIN_CORE( KJobTest )
 
 
 KJobTest::KJobTest()
@@ -81,8 +81,8 @@ void KJobTest::testProgressTracking()
     qRegisterMetaType<KJob*>("KJob*");
     qRegisterMetaType<qulonglong>("qulonglong");
 
-    QSignalSpy processed_spy( job, SIGNAL( processedSize( KJob*, qulonglong ) ) );
-    QSignalSpy total_spy( job, SIGNAL( totalSize( KJob*, qulonglong ) ) );
+    QSignalSpy processed_spy( job, SIGNAL( processedAmount( KJob*, KJob::Unit, qulonglong ) ) );
+    QSignalSpy total_spy( job, SIGNAL( totalAmount( KJob*, KJob::Unit, qulonglong ) ) );
     QSignalSpy percent_spy( job, SIGNAL( percent( KJob*, unsigned long ) ) );
 
 
@@ -94,7 +94,7 @@ void KJobTest::testProgressTracking()
 
     QCOMPARE( processed_spy.size(), 1 );
     QCOMPARE( processed_spy.at( 0 ).at( 0 ).value<KJob*>(), job );
-    QCOMPARE( processed_spy.at( 0 ).at( 1 ).value<qulonglong>(), ( qulonglong )1 );
+    QCOMPARE( processed_spy.at( 0 ).at( 2 ).value<qulonglong>(), ( qulonglong )1 );
     QCOMPARE( total_spy.size(), 0 );
     QCOMPARE( percent_spy.size(), 1 );
     QCOMPARE( percent_spy.at( 0 ).at( 0 ).value<KJob*>(), job );
@@ -109,7 +109,7 @@ void KJobTest::testProgressTracking()
     QCOMPARE( processed_spy.size(), 1 );
     QCOMPARE( total_spy.size(), 1 );
     QCOMPARE( total_spy.at( 0 ).at( 0 ).value<KJob*>(), job );
-    QCOMPARE( total_spy.at( 0 ).at( 1 ).value<qulonglong>(), ( qulonglong )10 );
+    QCOMPARE( total_spy.at( 0 ).at( 2 ).value<qulonglong>(), ( qulonglong )10 );
     QCOMPARE( percent_spy.size(), 2 );
     QCOMPARE( percent_spy.at( 1 ).at( 0 ).value<KJob*>(), job );
     QCOMPARE( percent_spy.at( 1 ).at( 1 ).value<unsigned long>(), ( unsigned long )10 );
@@ -134,7 +134,7 @@ void KJobTest::testProgressTracking()
 
     QCOMPARE( processed_spy.size(), 2 );
     QCOMPARE( processed_spy.at( 1 ).at( 0 ).value<KJob*>(), job );
-    QCOMPARE( processed_spy.at( 1 ).at( 1 ).value<qulonglong>(), ( qulonglong )3 );
+    QCOMPARE( processed_spy.at( 1 ).at( 2 ).value<qulonglong>(), ( qulonglong )3 );
     QCOMPARE( total_spy.size(), 1 );
     QCOMPARE( percent_spy.size(), 4 );
     QCOMPARE( percent_spy.at( 3 ).at( 0 ).value<KJob*>(), job );
@@ -158,7 +158,7 @@ void KJobTest::testProgressTracking()
 
     QCOMPARE( processed_spy.size(), 3 );
     QCOMPARE( processed_spy.at( 2 ).at( 0 ).value<KJob*>(), job );
-    QCOMPARE( processed_spy.at( 2 ).at( 1 ).value<qulonglong>(), ( qulonglong )0 );
+    QCOMPARE( processed_spy.at( 2 ).at( 2 ).value<qulonglong>(), ( qulonglong )0 );
     QCOMPARE( total_spy.size(), 1 );
     QCOMPARE( percent_spy.size(), 5 );
     QCOMPARE( percent_spy.at( 4 ).at( 0 ).value<KJob*>(), job );
@@ -174,7 +174,7 @@ void KJobTest::testProgressTracking()
 
     QCOMPARE( processed_spy.size(), 4 );
     QCOMPARE( processed_spy.at( 3 ).at( 0 ).value<KJob*>(), job );
-    QCOMPARE( processed_spy.at( 3 ).at( 1 ).value<qulonglong>(), ( qulonglong )15 );
+    QCOMPARE( processed_spy.at( 3 ).at( 2 ).value<qulonglong>(), ( qulonglong )15 );
     QCOMPARE( total_spy.size(), 1 );
     QCOMPARE( percent_spy.size(), 6 );
     QCOMPARE( percent_spy.at( 5 ).at( 0 ).value<KJob*>(), job );
@@ -224,13 +224,19 @@ void KJobTest::testKill_data()
     QTest::addColumn<int>("killVerbosity");
     QTest::addColumn<int>("errorCode");
     QTest::addColumn<QString>("errorText");
+    QTest::addColumn<int>("resultEmitCount");
+    QTest::addColumn<int>("finishedEmitCount");
 
     QTest::newRow("killed with result") << (int)KJob::EmitResult
                                         << (int)KJob::KilledJobError
-                                        << QString();
+                                        << QString()
+                                        << 1
+                                        << 1;
     QTest::newRow("killed quietly") << (int)KJob::Quietly
-                                    << (int)KJob::NoError
-                                    << QString();
+                                    << (int)KJob::KilledJobError
+                                    << QString()
+                                    << 0
+                                    << 1;
 }
 
 void KJobTest::testKill()
@@ -239,13 +245,19 @@ void KJobTest::testKill()
 
     connect( job, SIGNAL( result( KJob* ) ),
              this, SLOT( slotResult( KJob* ) ) );
+    connect( job, SIGNAL( finished( KJob* ) ),
+             this, SLOT( slotFinished( KJob* ) ) );
 
     m_lastError = KJob::NoError;
     m_lastErrorText = QString();
+    m_resultCount = 0;
+    m_finishedCount = 0;
 
     QFETCH(int, killVerbosity);
     QFETCH(int, errorCode);
     QFETCH(QString, errorText);
+    QFETCH(int, resultEmitCount);
+    QFETCH(int, finishedEmitCount);
 
     QSignalSpy destroyed_spy( job, SIGNAL( destroyed( QObject* ) ) );
 
@@ -258,6 +270,9 @@ void KJobTest::testKill()
     QCOMPARE( job->error(),  errorCode );
     QCOMPARE( job->errorText(),  errorText );
 
+    QCOMPARE(m_resultCount, resultEmitCount);
+    QCOMPARE(m_finishedCount, finishedEmitCount);
+
     // Verify that the job is not deleted immediately...
     QCOMPARE( destroyed_spy.size(), 0 );
     QTimer::singleShot( 0, &loop, SLOT( quit() ) );
@@ -294,9 +309,23 @@ void KJobTest::slotResult( KJob *job )
         m_lastErrorText = QString();
     }
 
+    m_resultCount++;
     loop.quit();
 }
 
+void KJobTest::slotFinished(KJob *job)
+{
+    if (job->error()) {
+        m_lastError = job->error();
+        m_lastErrorText = job->errorText();
+    } else {
+        m_lastError = KJob::NoError;
+        m_lastErrorText = QString();
+    }
+
+    m_finishedCount++;
+}
+
 TestJob::TestJob() : KJob()
 {
 
@@ -329,12 +358,12 @@ void TestJob::setErrorText( const QString &errorText )
 
 void TestJob::setProcessedSize( qulonglong size )
 {
-    KJob::setProcessedSize( size );
+    KJob::setProcessedAmount( KJob::Bytes, size );
 }
 
 void TestJob::setTotalSize( qulonglong size )
 {
-    KJob::setTotalSize( size );
+    KJob::setTotalAmount( KJob::Bytes, size );
 }
 
 void TestJob::setPercent( unsigned long percentage )
