@@ -20,11 +20,11 @@
 #include "klibloadertest.h"
 #include "klibloadertest.moc"
 
-QTEST_KDEMAIN( KLibLoaderTest, NoGUI )
+QTEST_KDEMAIN_CORE( KLibLoaderTest )
 
 #include <klibloader.h>
 #include <kstandarddirs.h>
-#include <qdir.h>
+#include <QtCore/QDir>
 #include <kdebug.h>
 
 void KLibLoaderTest::initTestCase()
@@ -41,7 +41,7 @@ void KLibLoaderTest::testNonWorking()
     QCOMPARE( obj, (QObject*)0 );
     QCOMPARE( error, (int)KLibLoader::ErrNoLibrary );
     QString errorString = KLibLoader::errorString( error );
-    kDebug() << errorString << endl;
+    kDebug() << errorString;
     QVERIFY( !errorString.isEmpty() );
 }
 
@@ -66,8 +66,10 @@ void KLibLoaderTest::testWorking()
     int error = 0;
     QObject* obj = KLibLoader::createInstance<QObject>( s_module, 0, QStringList(), &error );
     if ( error )
-        kWarning() << "error=" << error << " lastErrorMessage=" << KLibLoader::self()->lastErrorMessage() << endl;
+        kWarning() << "error=" << error << " lastErrorMessage=" << KLibLoader::self()->lastErrorMessage();
     QVERIFY( obj != 0 );
+    // Usually you should delete obj, too. But if you don't, KLibLoader deletes it on exit anyway.
+    //delete obj;
 }
 
 void KLibLoaderTest::testWorking4()
@@ -75,8 +77,10 @@ void KLibLoaderTest::testWorking4()
     int error = 0;
     QObject* obj = KLibLoader::createInstance<QObject>( "libklibloadertestmodule4", 0, QStringList(), &error );
     if ( error )
-        kWarning() << "error=" << error << " lastErrorMessage=" << KLibLoader::self()->lastErrorMessage() << endl;
+        kWarning() << "error=" << error << " lastErrorMessage=" << KLibLoader::self()->lastErrorMessage();
     QVERIFY( obj != 0 );
+    // Usually you should delete obj, too. But if you don't, KLibLoader deletes it on exit anyway.
+    //delete obj;
 }
 
 void KLibLoaderTest::testWrongClass()
@@ -87,6 +91,8 @@ void KLibLoaderTest::testWrongClass()
     QCOMPARE( obj, (KLibLoaderTest*)0 );
     QCOMPARE( error, (int)KLibLoader::ErrNoComponent );
     QString errorString = KLibLoader::errorString( error );
-    kDebug() << errorString << endl;
+    kDebug() << errorString;
     QVERIFY( !errorString.isEmpty() );
+    // Usually you should delete obj, too. But if you don't, KLibLoader deletes it on exit anyway.
+    //delete obj;
 }
