@@ -25,7 +25,7 @@
 #include "kglobal.h"
 #include "klocale.h"
 #include "klocalizedstring.h"
-#include <qstring.h>
+#include <QtCore/QString>
 
 #include "klocalizedstringtest.moc"
 
@@ -135,4 +135,4 @@ void KLocalizedStringTest::miscMethods ()
     QVERIFY(k.isEmpty());
 }
 
-QTEST_KDEMAIN(KLocalizedStringTest, NoGUI)
+QTEST_KDEMAIN_CORE(KLocalizedStringTest)
