@@ -28,7 +28,7 @@
 #include <kservicetype.h>
 #include <kservicetypeprofile.h>
 
-#include <qprocess.h>
+#include <QtCore/Q_PID>
 
 void KServiceTest::initTestCase()
 {
@@ -39,14 +39,9 @@ void KServiceTest::initTestCase()
     profilerc = KStandardDirs::locateLocal( "config", "servicetype_profilerc" );
     if ( !profilerc.isEmpty() )
         QFile::remove( profilerc );
-
-    if ( !KSycoca::isAvailable() ) {
-        // Create ksycoca in ~/.kde-unit-test
-        QProcess::execute( KStandardDirs::findExe("kbuildsycoca"), QStringList() << "--noincremental" );
-    }
 }
 
-QTEST_KDEMAIN( KServiceTest, NoGUI )
+QTEST_KDEMAIN_CORE( KServiceTest )
 
 void KServiceTest::testByName()
 {
@@ -56,6 +51,34 @@ void KServiceTest::testByName()
     KServiceType::Ptr s0 = KServiceType::serviceType("KParts/ReadOnlyPart");
     QVERIFY( s0 );
     QCOMPARE( s0->name(), QString::fromLatin1("KParts/ReadOnlyPart") );
+
+    KService::Ptr kdeprintd = KService::serviceByDesktopPath("kded/kdeprintd.desktop");
+    QCOMPARE( kdeprintd->name(), QString::fromLatin1("KDE Print Daemon"));
+}
+
+
+void KServiceTest::testProperty()
+{
+    KService::Ptr kdeprintd = KService::serviceByDesktopPath("kded/kdeprintd.desktop");
+    QVERIFY(kdeprintd);
+    QCOMPARE(kdeprintd->desktopEntryPath(), QString("kded/kdeprintd.desktop"));
+
+    QCOMPARE(kdeprintd->property("ServiceTypes").toStringList().join(","), QString("KDEDModule"));
+    QCOMPARE(kdeprintd->property("X-KDE-Kded-autoload").toBool(), false);
+    QCOMPARE(kdeprintd->property("X-KDE-Kded-load-on-demand").toBool(), true);
+
+    KService::Ptr kjavaappletviewer = KService::serviceByDesktopPath("kjavaappletviewer.desktop");
+    QVERIFY(kjavaappletviewer);
+    QCOMPARE(kjavaappletviewer->property("X-KDE-BrowserView-PluginsInfo").toString(), QString("kjava/pluginsinfo"));
+
+    // Test property("MimeTypes"), which triggers the KServiceReadProperty code.
+    // Didn't find any desktop file in kdelibs that had a stringlist property, so this one needs kdebase/workspace installed.
+    KService::Ptr fontthumbnail = KService::serviceByDesktopPath("fontthumbnail.desktop");
+    if (fontthumbnail) {
+        QVERIFY(fontthumbnail->property("MimeTypes").toStringList().contains("application/x-font-ttf"));
+    } else {
+        qDebug("Skipping property(\"MimeTypes\") test, fontthumbnail.desktop not found (kdebase/workspace not installed)");
+    }
 }
 
 void KServiceTest::testAllServiceTypes()
@@ -134,6 +157,17 @@ static bool offerListHasService( const KService::List& offers,
     return found;
 }
 
+void KServiceTest::testDBUSStartupType()
+{
+    if ( !KSycoca::isAvailable() )
+        QSKIP( "ksycoca not available", SkipAll );
+    KService::Ptr konsole = KService::serviceByDesktopName( "konsole" );
+    if ( !konsole )
+        QSKIP( "konsole.desktop not found", SkipAll );
+    //qDebug() << konsole->desktopEntryPath();
+    QCOMPARE((int)konsole->DBUSStartupType(), (int)KService::DBUS_Unique);
+}
+
 void KServiceTest::testServiceTypeTraderForReadOnlyPart()
 {
     if ( !KSycoca::isAvailable() )
@@ -153,7 +187,6 @@ void KServiceTest::testServiceTypeTraderForReadOnlyPart()
     QVERIFY( offerListHasService( offers, "khtml.desktop" ) );
     QVERIFY( offerListHasService( offers, "khtmlimage.desktop" ) );
     QVERIFY( offerListHasService( offers, "kjavaappletviewer.desktop" ) );
-    QVERIFY( offerListHasService( offers, "kcertpart.desktop" ) );
 
     // Check ordering according to InitialPreference
     int lastPreference = -1;
@@ -175,10 +208,20 @@ void KServiceTest::testServiceTypeTraderForReadOnlyPart()
 
     // Now look for any KTextEditor/Plugin
     offers = KServiceTypeTrader::self()->query("KTextEditor/Plugin");
-    QVERIFY( offerListHasService( offers, "ktexteditor_isearch.desktop" ) );
+    QVERIFY( offerListHasService( offers, "ktexteditor_docwordcompletion.desktop" ) );
     QVERIFY( offerListHasService( offers, "ktexteditor_insertfile.desktop" ) );
 }
 
+void KServiceTest::testTraderConstraints()
+{
+    if ( !KSycoca::isAvailable() )
+        QSKIP( "ksycoca not available", SkipAll );
+
+    KService::List offers = KServiceTypeTrader::self()->query("KTextEditor/Plugin", "Library == 'ktexteditor_docwordcompletion'");
+    QCOMPARE(offers.count(), 1);
+    QVERIFY( offerListHasService( offers, "ktexteditor_docwordcompletion.desktop" ) );
+}
+
 void KServiceTest::testHasServiceType1() // with services constructed with a full path (rare)
 {
     QString katepartPath = KStandardDirs::locate( "services", "katepart.desktop" );
@@ -187,11 +230,11 @@ void KServiceTest::testHasServiceType1() // with services constructed with a ful
     QVERIFY( katepart.hasServiceType( "KParts/ReadOnlyPart" ) );
     QVERIFY( katepart.hasServiceType( "KParts/ReadWritePart" ) );
 
-    QString ktexteditor_isearchPath = KStandardDirs::locate( "services", "ktexteditor_isearch.desktop" );
-    QVERIFY( !ktexteditor_isearchPath.isEmpty() );
-    KService ktexteditor_isearch( ktexteditor_isearchPath );
-    QVERIFY( ktexteditor_isearch.hasServiceType( "KTextEditor/Plugin" ) );
-    QVERIFY( !ktexteditor_isearch.hasServiceType( "KParts/ReadOnlyPart" ) );
+    QString ktexteditor_docwordcompletionPath = KStandardDirs::locate( "services", "ktexteditor_docwordcompletion.desktop" );
+    QVERIFY( !ktexteditor_docwordcompletionPath.isEmpty() );
+    KService ktexteditor_docwordcompletion( ktexteditor_docwordcompletionPath );
+    QVERIFY( ktexteditor_docwordcompletion.hasServiceType( "KTextEditor/Plugin" ) );
+    QVERIFY( !ktexteditor_docwordcompletion.hasServiceType( "KParts/ReadOnlyPart" ) );
 }
 
 void KServiceTest::testHasServiceType2() // with services coming from ksycoca
@@ -201,10 +244,10 @@ void KServiceTest::testHasServiceType2() // with services coming from ksycoca
     QVERIFY( katepart->hasServiceType( "KParts/ReadOnlyPart" ) );
     QVERIFY( katepart->hasServiceType( "KParts/ReadWritePart" ) );
 
-    KService::Ptr ktexteditor_isearch = KService::serviceByDesktopPath( "ktexteditor_isearch.desktop" );
-    QVERIFY( !ktexteditor_isearch.isNull() );
-    QVERIFY( ktexteditor_isearch->hasServiceType( "KTextEditor/Plugin" ) );
-    QVERIFY( !ktexteditor_isearch->hasServiceType( "KParts/ReadOnlyPart" ) );
+    KService::Ptr ktexteditor_docwordcompletion = KService::serviceByDesktopPath( "ktexteditor_docwordcompletion.desktop" );
+    QVERIFY( !ktexteditor_docwordcompletion.isNull() );
+    QVERIFY( ktexteditor_docwordcompletion->hasServiceType( "KTextEditor/Plugin" ) );
+    QVERIFY( !ktexteditor_docwordcompletion->hasServiceType( "KParts/ReadOnlyPart" ) );
 }
 
 void KServiceTest::testWriteServiceTypeProfile()
@@ -213,7 +256,6 @@ void KServiceTest::testWriteServiceTypeProfile()
     KService::List services, disabledServices;
     services.append(KService::serviceByDesktopPath("khtmlimage.desktop"));
     services.append(KService::serviceByDesktopPath("katepart.desktop"));
-    services.append(KService::serviceByDesktopPath("kcertpart.desktop"));
     disabledServices.append(KService::serviceByDesktopPath("khtml.desktop"));
 
     KServiceTypeProfile::writeServiceTypeProfile( serviceType, services, disabledServices );
@@ -232,7 +274,6 @@ void KServiceTest::testWriteServiceTypeProfile()
     QVERIFY( offers.count() >= 3 ); // at least 3, even
     QCOMPARE( offers[0]->desktopEntryPath(), QString("khtmlimage.desktop") );
     QCOMPARE( offers[1]->desktopEntryPath(), QString("katepart.desktop") );
-    QCOMPARE( offers[2]->desktopEntryPath(), QString("kcertpart.desktop") );
     QVERIFY( offerListHasService( offers, "kmultipart.desktop" ) ); // should still be somewhere in there
     QVERIFY( !offerListHasService( offers, "khtml.desktop" ) ); // it got disabled above
 }
