@@ -18,7 +18,7 @@
 #ifndef KSERVICETEST_H
 #define KSERVICETEST_H
 
-#include <QObject>
+#include <QtCore/QObject>
 
 class KServiceTest : public QObject
 {
@@ -26,14 +26,17 @@ class KServiceTest : public QObject
 private Q_SLOTS:
     void initTestCase();
     void testByName();
+    void testProperty();
     void testAllServiceTypes();
     void testAllServices();
     void testServiceTypeTraderForReadOnlyPart();
+    void testTraderConstraints();
     void testHasServiceType1();
     void testHasServiceType2();
     void testWriteServiceTypeProfile();
     void testDefaultOffers();
     void testDeleteServiceTypeProfile();
+    void testDBUSStartupType();
 
 private:
     QString m_firstOffer;
