@@ -20,13 +20,14 @@
 #include "kstandarddirstest.h"
 #include "kstandarddirstest.moc"
 
-QTEST_KDEMAIN( KStandarddirsTest, NoGUI )
+QTEST_KDEMAIN_CORE( KStandarddirsTest )
 
 #include <kdebug.h>
 #include <kstandarddirs.h>
 #include <kconfig.h>
 #include <kglobal.h>
-#include <QDebug>
+#include <QtCore/QDebug>
+#include <config.h>
 
 void KStandarddirsTest::testLocateLocal()
 {
@@ -68,19 +69,13 @@ void KStandarddirsTest::testFindResource()
 #endif
     const QString bin = KGlobal::dirs()->findResource( "exe", "kioslave" EXT );
     QVERIFY( !bin.isEmpty() );
-    QVERIFY( bin.endsWith( "bin/kioslave" EXT ) );
-#ifndef Q_WS_WIN
-		// @TODO unix specific
-    QVERIFY( bin.startsWith( "/" ) );
-#endif
+    QVERIFY( bin.endsWith( "kde4/libexec/kioslave" EXT ) );
+    QVERIFY( !QDir::isRelativePath(bin) );
 
     const QString data = KGlobal::dirs()->findResource( "data", "katepart/syntax/sql.xml" );
     QVERIFY( !data.isEmpty() );
     QVERIFY( data.endsWith( "share/apps/katepart/syntax/sql.xml" ) );
-#ifndef Q_WS_WIN
-		// @TODO unix specific
-    QVERIFY( data.startsWith( "/" ) );
-#endif
+    QVERIFY( !QDir::isRelativePath(data) );
 }
 
 static bool oneEndsWith( const QStringList& lst, const QString& str)
@@ -124,12 +119,12 @@ void KStandarddirsTest::testFindAllResources()
 #if 0
     list = t.findAllResources("html", "en/*/index.html", false);
     for (QStringList::ConstIterator it = list.begin(); it != list.end(); ++it) {
-        kDebug() << "docs " << (*it).toAscii().constData() << endl;
+        kDebug() << "docs " << (*it).toAscii().constData();
     }
 
     list = t.findAllResources("html", "*/*/*.html", false);
     for (QStringList::ConstIterator it = list.begin(); it != list.end(); ++it) {
-        kDebug() << "docs " << (*it).toAscii().constData() << endl;
+        kDebug() << "docs " << (*it).toAscii().constData();
     }
 #endif
 }
@@ -163,7 +158,7 @@ void KStandarddirsTest::testFindExe()
 
     const QString bin = KGlobal::dirs()->findExe( "lnusertemp" );
     QVERIFY( !bin.isEmpty() );
-    QVERIFY( bin.endsWith( "lib/kde4/libexec/lnusertemp" EXT ) );
+    QVERIFY( bin.endsWith( "lib" KDELIBSUFF "/kde4/libexec/lnusertemp" EXT ) );
 
     // Check the "exe" resource too
     QCOMPARE( KGlobal::dirs()->realFilePath(bin),
@@ -187,3 +182,27 @@ void KStandarddirsTest::testRelativeLocation()
     QCOMPARE( KGlobal::dirs()->relativeLocation( "config", located ), file );
 }
 
+void KStandarddirsTest::testAddResourceType()
+{
+    if ( !isKdelibsInstalled() )
+        QSKIP( "kdelibs not installed", SkipAll );
+
+    QString ret = KStandardDirs::locate( "dtd", "customization/catalog" );
+    QCOMPARE(ret, QString()); // normal, there's no "dtd" resource in kstandarddirs by default
+
+    KGlobal::dirs()->addResourceType("dtd", "data", "ksgmltools2/");
+    ret = KStandardDirs::locate( "dtd", "customization/catalog" );
+    QVERIFY(!ret.isEmpty());
+}
+
+void KStandarddirsTest::testAddResourceDir()
+{
+    const QString dir = QString::fromLatin1(KDESRCDIR);
+    const QString file = "Cairo";
+    QString ret = KStandardDirs::locate( "here", file );
+    QCOMPARE(ret, QString()); // not set up yet
+
+    KGlobal::dirs()->addResourceDir("here", dir);
+    ret = KStandardDirs::locate( "here", file );
+    QCOMPARE(ret, KStandardDirs::realPath(dir) + "Cairo");
+}
