@@ -22,7 +22,7 @@
 #include "kurltest.h"
 #include "kurltest.moc"
 
-QTEST_KDEMAIN( KUrlTest, NoGUI )
+QTEST_KDEMAIN_CORE( KUrlTest )
 
 #include <config.h>
 #include <kcmdlineargs.h>
@@ -32,9 +32,9 @@ QTEST_KDEMAIN( KUrlTest, NoGUI )
 #include <kglobal.h>
 #include <kcharsets.h>
 #include <kuser.h>
-#include <qtextcodec.h>
-#include <qdatastream.h>
-#include <qmap.h>
+#include <QtCore/QTextCodec>
+#include <QtCore/QDataStream>
+#include <QtCore/QMap>
 #include <stdio.h>
 #include <stdlib.h>
 
@@ -99,9 +99,9 @@ void KUrlTest::testSetQuery()
   url1.setQuery( "?kde=rocks&a=b" );
   QCOMPARE( url1.query(), QString("?kde=rocks&a=b") );
   url1.setQuery( "?" );
-  QCOMPARE( url1.query(), QString() ); // KDE3 difference: I expected QString("?"), but QUrl::setEncodedQuery translates empty to no query. Is that a problem though?
+  QCOMPARE( url1.query(), QString("?") );
   url1.setQuery( "" );
-  QCOMPARE( url1.query(), QString() ); // idem
+  QCOMPARE( url1.query(), QString("?") );
   url1.setQuery( QString() );
   QCOMPARE( url1.query(), QString() );
 }
@@ -297,6 +297,13 @@ void KUrlTest::testSimpleMethods() // to test parsing, mostly
   carsten.setPath("/home/gis/src/kde/kdelibs/kfile/.#kfiledetailview.cpp.1.18");
   QCOMPARE( carsten.path(), QString("/home/gis/src/kde/kdelibs/kfile/.#kfiledetailview.cpp.1.18") );
 
+  KUrl whitespaceInUser("http://www.google.com%20%20%20%20%20@foobar.com/");
+  QCOMPARE(whitespaceInUser.prettyUrl(), QString("http://www.google.com%20%20%20%20%20@foobar.com/"));
+  KUrl whitespaceInPath("http://www.google.com/foo%20bar/");
+  QCOMPARE(whitespaceInPath.prettyUrl(), QString("http://www.google.com/foo bar/"));
+  KUrl whitespaceInPath2("http://www.google.com/foo%20%20%20%20%20%20%20bar/");
+  QCOMPARE(whitespaceInPath2.prettyUrl(), QString("http://www.google.com/foo%20%20%20%20%20%20 bar/"));
+
   KUrl charles;
   charles.setPath( "/home/charles/foo%20moo" );
   QCOMPARE( charles.path(), QString("/home/charles/foo%20moo") );
@@ -505,7 +512,7 @@ void KUrlTest::testPathAndQuery()
 
 void KUrlTest::testSetFileName() // and addPath
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
   KUrl u2( "file:/home/dfaure/my%20tar%20file.tgz#gzip:/#tar:/README" );
   //qDebug( "* URL is %s", qPrintable( u2.url() ) );
 
@@ -608,23 +615,18 @@ void KUrlTest::testDirectory()
   QCOMPARE( u2.url(), QString("ftp://ftp.kde.org/") );
 }
 
-// In KDE4, prettyUrl does pretty much the same as url(), except for removing passwords from URLs.
-// We don't have a way to decode %20 into ' ' and still avoid decoding everything (e.g. %23 must remain %23)
-// but we don't really need it anymore; it was primarily for paths in konq's locationbar, but it uses pathOrUrl() now.
 void KUrlTest::testPrettyURL()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
   KUrl notPretty("http://ferret.lmh.ox.ac.uk/%7Ekdecvs/");
   QCOMPARE( notPretty.prettyUrl(), QString("http://ferret.lmh.ox.ac.uk/~kdecvs/") );
   KUrl notPretty2("file:/home/test/directory%20with%20spaces");
-  // KDE3: QCOMPARE( notPretty2.prettyUrl(), QString("file:///home/test/directory with spaces") );
-  QCOMPARE( notPretty2.prettyUrl(), QString("file:///home/test/directory%20with%20spaces") );
+  QCOMPARE( notPretty2.prettyUrl(), QString("file:///home/test/directory with spaces") );
 
   KUrl notPretty3("fish://foo/%23README%23");
   QCOMPARE( notPretty3.prettyUrl(), QString("fish://foo/%23README%23") );
   KUrl url15581("http://alain.knaff.linux.lu/bug-reports/kde/spaces in url.html");
-  // KDE3: QCOMPARE( url15581.prettyUrl(), QString("http://alain.knaff.linux.lu/bug-reports/kde/spaces in url.html") );
-  QCOMPARE( url15581.prettyUrl(), QString("http://alain.knaff.linux.lu/bug-reports/kde/spaces%20in%20url.html") );
+  QCOMPARE( url15581.prettyUrl(), QString("http://alain.knaff.linux.lu/bug-reports/kde/spaces in url.html") );
   QCOMPARE( url15581.url(), QString("http://alain.knaff.linux.lu/bug-reports/kde/spaces%20in%20url.html") );
 
   // KDE3 test was for parsing "percentage%in%url.html", but this is not supported; too broken.
@@ -639,7 +641,7 @@ void KUrlTest::testPrettyURL()
 
 void KUrlTest::testIsRelative()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
   QVERIFY( !KUrl::isRelativeUrl("man:mmap") );
   QVERIFY( !KUrl::isRelativeUrl("javascript:doSomething()") );
   QVERIFY( !KUrl::isRelativeUrl("file:///blah") );
@@ -738,7 +740,7 @@ void KUrlTest::testAdjustPath()
 
 void KUrlTest::testIPV6()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
   // IPV6
   KUrl waba1( "http://[::FFFF:129.144.52.38]:81/index.html" );
   QCOMPARE( waba1.host(), QString("::ffff:129.144.52.38") );
@@ -786,7 +788,7 @@ void KUrlTest::testIPV6()
 
 void KUrlTest::testBaseURL() // those are tests for the KUrl(base,relative) constructor
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
   KUrl com1(KUrl("http://server.com/dir/"), ".");
   QCOMPARE( com1.url(), QString("http://server.com/dir/") );
 
@@ -966,7 +968,7 @@ void KUrlTest::testBaseURL() // those are tests for the KUrl(base,relative) cons
 
 void KUrlTest::testSubURL()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
   QString u1 = "file:/home/dfaure/my%20tar%20file.tgz#gzip:/#tar:/#myref";
   KUrl url1(u1);
   QCOMPARE( url1.url(), QString("file:///home/dfaure/my%20tar%20file.tgz#gzip:/%23tar:/%23myref") ); // KDE3 would say # 3 times
@@ -978,7 +980,7 @@ void KUrlTest::testSubURL()
 
   const KUrl::List splitted = KUrl::split( url1 );
   QCOMPARE( splitted.count(), 3 );
-  kDebug() << splitted.toStringList() << endl;
+  kDebug() << splitted.toStringList();
   QCOMPARE( splitted[0].url(), QString("file:///home/dfaure/my%20tar%20file.tgz#myref") );
   QCOMPARE( splitted[1].url(), QString("gzip:/#myref") );
   QCOMPARE( splitted[2].url(), QString("tar:/#myref") );
@@ -1062,7 +1064,7 @@ void KUrlTest::testSetUser()
 
 void KUrlTest::testComparisons()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
   /// Comparisons
   QString ucmp1 = "ftp://ftp.de.kde.org/dir";
   QString ucmp2 = "ftp://ftp.de.kde.org/dir/";
@@ -1109,7 +1111,7 @@ void KUrlTest::testComparisons()
 
 void KUrlTest::testStreaming()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
   // Streaming operators
   KUrl origURL( "http://www.website.com/directory/?#ref" );
   KUrl empty( "" );
@@ -1144,7 +1146,7 @@ void KUrlTest::testStreaming()
 
 void KUrlTest::testBrokenStuff()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
   // Broken stuff
   KUrl waba1( "file:a" );
   QCOMPARE( waba1.path(), QString("a") );
@@ -1290,7 +1292,7 @@ void KUrlTest::testBrokenStuff()
 
 void KUrlTest::testMailto()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
   KUrl umail1 ( "mailto:faure@kde.org" );
   QCOMPARE( umail1.protocol(), QString("mailto") );
   QCOMPARE( umail1.path(), QString("faure@kde.org") );
@@ -1316,7 +1318,7 @@ void KUrlTest::testMailto()
 
 void KUrlTest::testSmb()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
   KUrl smb("smb://domain;username:password@server/share");
   QVERIFY( smb.isValid() );
   QCOMPARE( smb.user(), QString("domain;username") );
@@ -1333,7 +1335,7 @@ void KUrlTest::testSmb()
 
 void KUrlTest::testOtherProtocols()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
   KUrl about("about:konqueror");
   QCOMPARE(about.path(),QString("konqueror") );
 
@@ -1353,7 +1355,7 @@ void KUrlTest::testOtherProtocols()
 
 void KUrlTest::testUtf8()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
   QTextCodec* codec = QTextCodec::codecForName( "ISO-8859-1" );
   QVERIFY( codec != 0 );
   QTextCodec::setCodecForLocale( codec );
@@ -1372,7 +1374,7 @@ void KUrlTest::testUtf8()
   uloc.setPath( QString::fromUtf8( "/home/dfaure/Matériel" ) );
   QCOMPARE( uloc.url(), QString( "file:///home/dfaure/Mat%C3%A9riel") ); // KDE3 would say %E9 here; but from now on URLs are always utf8 encoded.
   QCOMPARE( uloc.path(), QString::fromUtf8( "/home/dfaure/Matériel") );
-  QCOMPARE( uloc.prettyUrl(), QString( "file:///home/dfaure/Mat%C3%A9riel") ); // KDE3 wouldn't escape the letters here...
+  QCOMPARE( uloc.prettyUrl(), QString::fromUtf8( "file:///home/dfaure/Matériel") );
   QCOMPARE( uloc.pathOrUrl(), QString::fromUtf8( "/home/dfaure/Matériel") );             // ... but that's why pathOrUrl is nicer.
   QCOMPARE( uloc.url(), QString( "file:///home/dfaure/Mat%C3%A9riel") );
   uloc = KUrl("file:///home/dfaure/Mat%C3%A9riel");
@@ -1388,7 +1390,7 @@ void KUrlTest::testUtf8()
 
 void KUrlTest::testOtherEncodings()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
   QTextCodec::setCodecForLocale( KGlobal::charsets()->codecForName( "koi8-r" ) );
   KUrl baseURL( "file:/home/coolo" );
   KUrl russian = KUrl::fromPath( baseURL.directory(KUrl::AppendTrailingSlash) + QString::fromUtf8( "фгн7" ) );
@@ -1408,7 +1410,7 @@ void KUrlTest::testOtherEncodings()
 
 void KUrlTest::testPathOrURL()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
   // passing path or url to the constructor: both work
   KUrl uloc( "/home/dfaure/konqtests/Mat%C3%A9riel" );
   QCOMPARE( uloc.path(), QString("/home/dfaure/konqtests/Mat%C3%A9riel") );
@@ -1440,18 +1442,16 @@ void KUrlTest::testPathOrURL()
   uloc = "http://www.kde.org";
   QCOMPARE( uloc.url(), QString("http://www.kde.org") );
   uloc = "file:///home/dfaure/konq%20tests/Mat%C3%A9riel#ref";
-  // KDE3 difference: we don't decode accents and spaces in URLs anymore;
-  // only in paths.
-  QCOMPARE( uloc.pathOrUrl(), QString("file:///home/dfaure/konq%20tests/Mat%C3%A9riel#ref" ) );
+  QCOMPARE( uloc.pathOrUrl(), QString::fromUtf8("file:///home/dfaure/konq tests/Matériel#ref" ) );
   uloc = "file:///home/dfaure/konq%20tests/Mat%C3%A9riel?query";
-  QCOMPARE( uloc.pathOrUrl(), QString("file:///home/dfaure/konq%20tests/Mat%C3%A9riel?query" ) );
+  QCOMPARE( uloc.pathOrUrl(), QString::fromUtf8("file:///home/dfaure/konq tests/Matériel?query" ) );
   uloc = KUrl( "/home/dfaure/file#with#hash" );
   QCOMPARE( uloc.pathOrUrl(), QString("/home/dfaure/file#with#hash" ) );
 }
 
 void KUrlTest::testAssignment()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
   // passing path or url to the constructor: both work
   KUrl uloc;
   uloc = "/home/dfaure/konqtests/Mat%C3%A9riel";
@@ -1493,7 +1493,7 @@ void KUrlTest::testAssignment()
 
 void KUrlTest::testQueryItem()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
   KUrl theKow( "http://www.google.de/search?q=frerich&hlx=xx&hl=de&empty=&lr=lang+de&test=%2B%20%3A%25" );
   QCOMPARE( theKow.queryItem("q"), QString("frerich") );
   QCOMPARE( theKow.queryItem("hl"), QString("de") );
@@ -1524,7 +1524,7 @@ void KUrlTest::testQueryItem()
 
 void KUrlTest::testEncodeString()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
   // Needed for #49616
   QCOMPARE( KUrl::toPercentEncoding( "C++" ), QByteArray("C%2B%2B") );
   QCOMPARE( KUrl::fromPercentEncoding( "C%2B%2B" ), QString("C++") );
@@ -1536,7 +1536,7 @@ void KUrlTest::testEncodeString()
 
 void KUrlTest::testIdn()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
 
   //qDebug( "trying QUrl with fromPercentEncoding" );
   QUrl qurltest( QUrl::fromPercentEncoding( "http://\303\244.de" ) ); // a+trema in utf8
@@ -1567,7 +1567,7 @@ void KUrlTest::testIdn()
 
 void KUrlTest::testUriMode()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
   KUrl url1;
 #if 0 // ###### TODO KUri
   url1 = "http://www.foobar.com/";
