@@ -25,7 +25,7 @@
 int
 main(int argc, char *argv[])
 {
-   KAboutData about("ktoolinvocationtest", "ktoolinvocationtest", "version");
+   KAboutData about("ktoolinvocationtest", 0, ki18n("ktoolinvocationtest"), "version");
    KComponentData cData(&about);
    //KCmdLineArgs::init(argc, argv, &about);
    //KApplication a;
@@ -34,7 +34,7 @@ main(int argc, char *argv[])
    QString dbusService;
    int pid;
    KToolInvocation::startServiceByDesktopPath( "kio_uiserver.desktop", QString(), &error, &dbusService, &pid );
-   kDebug() << "Started. error=" << error << " dbusService=" << dbusService << " pid=" << pid << endl;
+   kDebug() << "Started. error=" << error << " dbusService=" << dbusService << " pid=" << pid;
 
    return 0;
 }
