@@ -16,16 +16,14 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
-#include "config.h"
 #include "klibloader.h"
 
-#include <qclipboard.h>
-#include <qfile.h>
-#include <qdir.h>
-#include <qtimer.h>
-#include <qlibrary.h>
+#include <QtCore/QFile>
+#include <QtCore/QDir>
+#include <QtCore/QTimer>
+#include <QtCore/QLibrary>
 #include <QStack>
-#include <qapplication.h>
+#include <QtCore/QCoreApplication>
 
 #include "kstandarddirs.h"
 #include "kcomponentdata.h"
@@ -72,7 +70,7 @@ public:
         for (QHash<QString, KLibWrapPrivate*>::Iterator it = m_libs.begin(); it != m_libs.end(); ++it)
         {
             Q_ASSERT((*it) != 0);
-            kDebug(150) << "The KLibLoader contains the library " << (*it)->name
+            kDebug(150).nospace() << "The KLibLoader contains the library " << (*it)->name
                 << " (" << (*it)->lib << ")" << endl;
             pending_close.append(*it);
         }
@@ -97,27 +95,6 @@ K_GLOBAL_STATIC(KLibLoaderPrivate, kLibLoaderPrivate)
 
 // -------------------------------------------------------------------------
 
-KLibFactory::KLibFactory( QObject* _parent )
-    : QObject( _parent ), d(0)
-{
-}
-
-KLibFactory::~KLibFactory()
-{
-//    kDebug(150) << "Deleting KLibFactory " << this << endl;
-}
-
-QObject* KLibFactory::create( QObject* _parent, const char* classname, const QStringList &args )
-{
-    QObject* obj = createObject( _parent, classname, args );
-    if ( obj )
-	emit objectCreated( obj );
-    return obj;
-}
-
-
-// -----------------------------------------------
-
 class KLibraryPrivate
 {
 public:
@@ -125,13 +102,13 @@ public:
     KLibrary *q;
     QString libname;
     QString filename;
-    QHash<QByteArray, KLibFactory*> factories;
+    QHash<QByteArray, KPluginFactory*> factories;
     QLibrary* handle;
     QList<QObject*> objs;
     QTimer* timer;
 
-    KLibFactory *kde3Factory(const QByteArray &factoryname);
-    KLibFactory *kde4Factory();
+    KPluginFactory *kde3Factory(const QByteArray &factoryname);
+    KPluginFactory *kde4Factory();
 };
 
 KLibrary::KLibrary( const QString& libname, const QString& filename, QLibrary * handle )
@@ -147,7 +124,7 @@ KLibrary::KLibrary( const QString& libname, const QString& filename, QLibrary *
 
 KLibrary::~KLibrary()
 {
-//    kDebug(150) << "Deleting KLibrary " << this << "  " << d->libname << endl;
+//    kDebug(150) << "Deleting KLibrary " << this << "  " << d->libname;
     if ( d->timer && d->timer->isActive() )
 	d->timer->stop();
 
@@ -157,7 +134,7 @@ KLibrary::~KLibrary()
 	    while (!d->objs.isEmpty())
 		{
 		    QObject *obj = d->objs.takeFirst();
-		    kDebug(150) << "Factory still has object " << obj << " " << obj->objectName() << " Library = " << d->libname << endl;
+		    kDebug(150) << "Factory still has object" << obj << obj->objectName() << "Library = " << d->libname;
 		    disconnect( obj, SIGNAL( destroyed() ),
 				this, SLOT( slotObjectDestroyed() ) );
 		    delete obj;
@@ -179,7 +156,7 @@ QString KLibrary::fileName() const
     return d->filename;
 }
 
-KLibFactory* KLibraryPrivate::kde3Factory(const QByteArray &factoryname)
+KPluginFactory* KLibraryPrivate::kde3Factory(const QByteArray &factoryname)
 {
     QByteArray symname = "init_";
     if(!factoryname.isEmpty()) {
@@ -191,22 +168,26 @@ KLibFactory* KLibraryPrivate::kde3Factory(const QByteArray &factoryname)
     if ( factories.contains( symname ) )
         return factories[ symname ];
 
-    void* sym = q->symbol( symname );
+    KLibrary::void_function_ptr sym = q->resolveFunction( symname );
     if ( !sym )
     {
         kLibLoaderPrivate->errorMessage = i18n( "The library %1 does not offer an %2 function.", libname, QLatin1String("init_") + libname );
-        kWarning(150) << kLibLoaderPrivate->errorMessage << endl;
+        kDebug(150) << "The library" << libname << "does not offer an"
+                    << QLatin1String("init_") + libname << "function.";
         return 0;
     }
 
-    typedef KLibFactory* (*t_func)();
-    t_func func = (t_func)sym;
-    KLibFactory* factory = func();
+    typedef KPluginFactory* (*t_func)();
+    // Cast the void* to non-pointer type first - it's not legal to
+    // cast a pointer-to-object directly to a pointer-to-function.
+    ptrdiff_t tmp = reinterpret_cast<ptrdiff_t>(sym);
+    t_func func = reinterpret_cast<t_func>(tmp);
+    KPluginFactory* factory = func();
 
     if( !factory )
     {
         kLibLoaderPrivate->errorMessage = i18n("The library %1 does not offer a KDE compatible factory." , libname);
-        kWarning(150) << kLibLoaderPrivate->errorMessage << endl;
+        kDebug(150) << "The library" << libname << "does not offer a KDE compatible factory.";
         return 0;
     }
     factories.insert( symname, factory );
@@ -214,29 +195,32 @@ KLibFactory* KLibraryPrivate::kde3Factory(const QByteArray &factoryname)
     return factory;
 }
 
-KLibFactory *KLibraryPrivate::kde4Factory()
+KPluginFactory *KLibraryPrivate::kde4Factory()
 {
     const QByteArray symname("qt_plugin_instance");
     if ( factories.contains( symname ) )
         return factories[ symname ];
 
-    void* sym = q->symbol( symname );
+    KLibrary::void_function_ptr sym = q->resolveFunction( symname );
     if ( !sym )
     {
-//        KLibLoader::self()->d->errorMessage = i18n("The library %1 does not offer an qt_plugin_instance function.", libname);
-//        kWarning(150) << KLibLoader::self()->d->errorMessage << endl;
+        kLibLoaderPrivate->errorMessage = i18n("The library %1 does not offer a qt_plugin_instance function.", libname);
+        kDebug(150) << "The library" << libname << "does not offer a qt_plugin_instance function.";
         return 0;
     }
 
     typedef QObject* (*t_func)();
-    t_func func = (t_func)sym;
+    // Cast the void* to non-pointer type first - it's not legal to
+    // cast a pointer-to-object directly to a pointer-to-function.
+    ptrdiff_t tmp = reinterpret_cast<ptrdiff_t>(sym);
+    t_func func = reinterpret_cast<t_func>(tmp);
     QObject* instance = func();
-    KLibFactory *factory = qobject_cast<KLibFactory *>(instance);
+    KPluginFactory *factory = qobject_cast<KPluginFactory *>(instance);
 
     if( !factory )
     {
-//        KLibLoader::self()->d->errorMessage = i18n("The library %1 does not offer a KDE 4 compatible factory." , libname);
-//        kWarning(150) << KLibLoader::self()->d->errorMessage << endl;
+        kLibLoaderPrivate->errorMessage = i18n("The library %1 does not offer a KDE 4 compatible factory." , libname);
+        kDebug(150) << "The library" << libname << "does not offer a KDE 4 compatible factory.";
         return 0;
     }
     factories.insert( symname, factory );
@@ -245,9 +229,9 @@ KLibFactory *KLibraryPrivate::kde4Factory()
 
 }
 
-KLibFactory* KLibrary::factory(const char* factoryname)
+KPluginFactory* KLibrary::factory(const char* factoryname)
 {
-    KLibFactory *factory = d->kde4Factory();
+    KPluginFactory *factory = d->kde4Factory();
     if (!factory)
         factory = d->kde3Factory(factoryname);
 
@@ -260,23 +244,38 @@ KLibFactory* KLibrary::factory(const char* factoryname)
     return factory;
 }
 
-void* KLibrary::resolve( const char* symname ) const
+void *KLibrary::resolveSymbol( const char* symname ) const
 {
-    void* sym = d->handle->resolve( symname );
+    void *sym = d->handle->resolve( symname );
     if ( !d->handle->isLoaded() || !sym )
     {
         kLibLoaderPrivate->errorMessage = QLatin1String("KLibrary: ") + d->handle->errorString();
-        kWarning(150) << kLibLoaderPrivate->errorMessage << endl;
+        //kDebug(150) << kLibLoaderPrivate->errorMessage;
         return 0;
     }
 
     return sym;
 }
 
-bool KLibrary::hasSymbol( const char* symname ) const
+KLibrary::void_function_ptr KLibrary::resolveFunction( const char* symname ) const
 {
-    void* sym = d->handle->resolve(symname);
-    return (sym != 0L );
+    void *psym = d->handle->resolve( symname );
+    if (!psym)
+        return 0;
+
+    // Cast the void* to non-pointer type first - it's not legal to
+    // cast a pointer-to-object directly to a pointer-to-function.
+    ptrdiff_t tmp = reinterpret_cast<ptrdiff_t>(psym);
+    void_function_ptr sym = reinterpret_cast<void_function_ptr>(tmp);
+
+    if ( !d->handle->isLoaded() || !sym )
+    {
+        kLibLoaderPrivate->errorMessage = QLatin1String("KLibrary: ") + d->handle->errorString();
+        //kDebug(150) << kLibLoaderPrivate->errorMessage;
+        return 0;
+    }
+
+    return sym;
 }
 
 void KLibrary::unload() const
@@ -352,7 +351,7 @@ KLibWrapPrivate::KLibWrapPrivate(KLibrary *l, QLibrary* h)
 {
     unload_mode = KLibLoader_cpp::UNKNOWN;
     if (handle->resolve("__kde_do_not_unload") != 0) {
-//        kDebug(150) << "Will not unload " << name << endl;
+//        kDebug(150) << "Will not unload " << name;
         unload_mode = KLibLoader_cpp::DONT_UNLOAD;
     } else if (handle->resolve("__kde_do_unload") != 0) {
         unload_mode = KLibLoader_cpp::UNLOAD;
@@ -375,15 +374,14 @@ KLibLoader::~KLibLoader()
 {
 }
 
-static inline QByteArray makeLibName( const char* name )
+static inline QString makeLibName( const QString &libname )
 {
-    QByteArray libname(name);
     int pos = libname.lastIndexOf('/');
     if (pos < 0)
       pos = 0;
     if (libname.indexOf('.', pos) < 0) {
         const char* const extList[] = { ".so", ".dylib", ".bundle", ".dll", ".sl" };
-        for (int i = 0; i < sizeof(extList) / sizeof(*extList); ++i) {
+        for (uint i = 0; i < sizeof(extList) / sizeof(*extList); ++i) {
            if (QLibrary::isLibrary(libname + extList[i]))
                return libname + extList[i];
         }
@@ -391,80 +389,65 @@ static inline QByteArray makeLibName( const char* name )
     return libname;
 }
 
-static inline QString findLibraryInternal(const char *name, const KComponentData &cData)
+static inline QString findLibraryInternal(const QString &name, const KComponentData &cData)
 {
-    QByteArray libname = makeLibName( name );
+    QString libname = makeLibName( name );
 
     // only look up the file if it is not an absolute filename
     // (mhk, 20000228)
     QString libfile;
-    if (!QDir::isRelativePath(libname)) {
-      libfile = QFile::decodeName( libname );
-    }
-    else
-    {
+    if (QDir::isRelativePath(libname)) {
       libfile = cData.dirs()->findResource("module", libname);
       if ( libfile.isEmpty() )
       {
         libfile = cData.dirs()->findResource("lib", libname);
 #ifndef NDEBUG
         if ( !libfile.isEmpty() && libname.startsWith( "lib" ) ) // don't warn for kdeinit modules
-          kDebug(150) << "library " << libname << " not found under 'module' but under 'lib'" << endl;
+          kDebug(150) << "library" << libname << "not found under 'module' but under 'lib'";
 #endif
       }
+    } else {
+      libfile = libname;
     }
     return libfile;
 }
 
 //static
-QString KLibLoader::findLibrary(const char *_name, const KComponentData &cData)
+QString KLibLoader::findLibrary(const QString &_name, const KComponentData &cData)
 {
-#ifndef Q_OS_WIN
-    return findLibraryInternal(_name, cData);
-#else
-    QByteArray name( _name );
-    name = name.replace( '\\', '/' );
-
-    QString libname = findLibraryInternal(name, cData);
-
+    QString libname = findLibraryInternal(QDir::fromNativeSeparators(_name), cData);
+#ifdef Q_OS_WIN
     // we don't have 'lib' prefix on windows -> remove it and try again
     if( libname.isEmpty() )
     {
-      QByteArray ba( name );
-      QByteArray file, path;
+      libname = _name;
+      QString file, path;
 
-      int pos = ba.lastIndexOf( '/' );
+      int pos = libname.lastIndexOf( '/' );
       if ( pos >= 0 )
       {
-        file = ba.mid( pos + 1 );
-        path = ba.left( pos );
-        name = path + '/' + file.mid( 3 );
+        file = libname.mid( pos + 1 );
+        path = libname.left( pos );
+        libname = path + '/' + file.mid( 3 );
       }
       else
       {
-        file = ba;
-        name = file.mid( 3 );
+        file = libname;
+        libname = file.mid( 3 );
       }
       if( !file.startsWith( "lib" ) )
           return libname;
 
-      libname = findLibraryInternal(name, cData);
+      libname = findLibraryInternal(libname, cData);
     }
-
-    return libname;
 #endif
+    return libname;
 }
 
 
-KLibrary* KLibLoader::globalLibrary( const char *_name )
+KLibrary* KLibLoader::library( const QString &_name, QLibrary::LoadHints hint )
 {
-    return library(_name, QLibrary::ExportExternalSymbolsHint);
-}
-
-
-KLibrary* KLibLoader::library( const char *_name, QLibrary::LoadHints hint )
-{
-    if (!_name)
+    if (_name.isEmpty())
         return 0;
 
     KLIBLOADER_PRIVATE;
@@ -479,7 +462,7 @@ KLibrary* KLibLoader::library( const char *_name, QLibrary::LoadHints hint )
        unloaded meanwhile, whithout being dlclose()'ed.  */
     QStack<KLibWrapPrivate*>::Iterator it = d->loaded_stack.begin();
     for (; it != d->loaded_stack.end(); ++it) {
-      if ((*it)->name == QLatin1String(_name))
+      if ((*it)->name == _name)
         wrap = *it;
     }
 
@@ -487,18 +470,17 @@ KLibrary* KLibLoader::library( const char *_name, QLibrary::LoadHints hint )
       d->pending_close.removeAll(wrap);
       if (!wrap->lib) {
         /* This lib only was in loaded_stack, but not in d->m_libs.  */
-        wrap->lib = new KLibrary( QLatin1String(_name), wrap->filename, wrap->handle );
+        wrap->lib = new KLibrary( _name, wrap->filename, wrap->handle );
       }
       wrap->ref_count++;
     } else {
       QString libfile = findLibrary( _name );
       if ( libfile.isEmpty() )
       {
-        const QByteArray libname ( _name );
 #ifndef NDEBUG
-        kDebug(150) << "library=" << _name << ": No file named " << libname << " found in paths." << endl;
+        kDebug(150).nospace() << "library=" << _name << ": No file named " << _name << " found in paths.";
 #endif
-        d->errorMessage = i18n("Library files for \"%1\" not found in paths.",  QString(libname) );
+        d->errorMessage = i18n("Library files for \"%1\" not found in paths.", _name );
         return 0;
       }
 
@@ -512,7 +494,7 @@ KLibrary* KLibLoader::library( const char *_name, QLibrary::LoadHints hint )
       else
         d->errorMessage.clear();
 
-      KLibrary *lib = new KLibrary( QLatin1String(_name), libfile, handle);
+      KLibrary *lib = new KLibrary( _name, libfile, handle);
       wrap = new KLibWrapPrivate(lib, handle);
       d->loaded_stack.push(wrap);
     }
@@ -530,9 +512,9 @@ QString KLibLoader::lastErrorMessage() const
     return d->errorMessage;
 }
 
-void KLibLoader::unloadLibrary( const char *libname )
+void KLibLoader::unloadLibrary( const QString &libname )
 {
-    KLIBLOADER_PRIVATE;
+  KLIBLOADER_PRIVATE;
   if (!d->m_libs.contains(libname))
     return;
 
@@ -540,7 +522,7 @@ void KLibLoader::unloadLibrary( const char *libname )
   if (--wrap->ref_count)
     return;
 
-//  kDebug(150) << "closing library " << libname << endl;
+//  kDebug(150) << "closing library " << libname;
 
   d->m_libs.remove( libname );
 
@@ -549,9 +531,9 @@ void KLibLoader::unloadLibrary( const char *libname )
   d->close_pending( wrap );
 }
 
-KLibFactory* KLibLoader::factory( const char* _name )
+KPluginFactory* KLibLoader::factory( const QString &_name, QLibrary::LoadHints hint )
 {
-    KLibrary* lib = library( _name );
+    KLibrary* lib = library( _name, hint );
     if ( !lib )
         return 0;
 
@@ -560,7 +542,7 @@ KLibFactory* KLibLoader::factory( const char* _name )
 
 void KLibLoader::slotLibraryDestroyed()
 {
-    KLIBLOADER_PRIVATE;
+  KLIBLOADER_PRIVATE;
   const KLibrary *lib = static_cast<const KLibrary *>( sender() );
 
   for (QHash<QString, KLibWrapPrivate*>::Iterator it = d->m_libs.begin(); it != d->m_libs.end(); ++it)
@@ -615,11 +597,11 @@ void KLibLoaderPrivate::close_pending(KLibWrapPrivate *wrap)
     if (!pending_close.contains( wrap )) {
       if (!deleted_one)
         /* Only diagnose, if we really haven't deleted anything. */
-//        kDebug(150) << "try to dlclose " << wrap->name << ": not yet" << endl;
+//      kDebug(150) << "try to dlclose " << wrap->name << ": not yet";
       break;
     }
 
-//    kDebug(150) << "try to dlclose " << wrap->name << ": yes, done." << endl;
+//  kDebug(150) << "try to dlclose " << wrap->name << ": yes, done.";
 
     if ( !deleted_one ) {
       /* Only do the hack once in this loop.
@@ -631,14 +613,8 @@ void KLibLoaderPrivate::close_pending(KLibWrapPrivate *wrap)
 
       /* Well.. let's do something more subtle... convert the clipboard context
          to text. That should be safe as it only uses objects defined by Qt. */
-      if( qApp->clipboard()->ownsSelection()) {
-	qApp->clipboard()->setText(
-            qApp->clipboard()->text( QClipboard::Selection ), QClipboard::Selection );
-      }
-      if( qApp->clipboard()->ownsClipboard()) {
-	qApp->clipboard()->setText(
-            qApp->clipboard()->text( QClipboard::Clipboard ), QClipboard::Clipboard );
-      }
+
+      emit instance.kapplication_hook_clearClipboard();
     }
 
     deleted_one = true;
