@@ -18,26 +18,26 @@
  *  Boston, MA 02110-1301, USA.
  **/
 
-#include <qdir.h>
-#include <qeventloop.h>
-#include <config.h>
-
 #include "kbuildsycoca.h"
 #include "kresourcelist.h"
 #include "vfolder_menu.h"
 
+#include <config.h>
+
 #include <kservice.h>
 #include <kmimetype.h>
-#include <kbuildservicetypefactory.h>
-#include <kbuildmimetypefactory.h>
-#include <kbuildservicefactory.h>
-#include <kbuildservicegroupfactory.h>
-#include <kbuildprotocolinfofactory.h>
-#include <kctimefactory.h>
+#include "kbuildservicetypefactory.h"
+#include "kbuildmimetypefactory.h"
+#include "kbuildservicefactory.h"
+#include "kbuildservicegroupfactory.h"
+#include "kbuildprotocolinfofactory.h"
+#include "kctimefactory.h"
 #include <ktemporaryfile.h>
-#include <qdatastream.h>
-#include <qfile.h>
-#include <qtimer.h>
+#include <QtCore/QDataStream>
+#include <QtCore/QDir>
+#include <QtCore/QEventLoop>
+#include <QtCore/QFile>
+#include <QtCore/QTimer>
 #include <QtDBus/QtDBus>
 #include <errno.h>
 
@@ -134,7 +134,7 @@ void KBuildSycoca::processGnomeVfs()
    QString file = KStandardDirs::locate("app-reg", "gnome-vfs.applications");
    if (file.isEmpty())
    {
-//      kDebug(7021) << "gnome-vfs.applications not found." << endl;
+//      kDebug(7021) << "gnome-vfs.applications not found.";
       return;
    }
 
@@ -169,7 +169,7 @@ void KBuildSycoca::processGnomeVfs()
           {
              serviceTypes += mimetypes.split( ',', QString::SkipEmptyParts );
 //             kDebug(7021) << "Adding gnome mimetypes for '" << app << "'.\n";
-//             kDebug(7021) << "ServiceTypes=" << s->serviceTypes().join(":") << endl;
+//             kDebug(7021) << "ServiceTypes=" << s->serviceTypes().join(":");
           }
       }
    }
@@ -213,12 +213,12 @@ KSycocaEntry::Ptr KBuildSycoca::createEntry(const QString &file, bool addToFacto
       else if (oldTimestamp)
       {
          g_changed = true;
-         kDebug(7021) << "modified: " << file << endl;
+         kDebug(7021) << "modified:" << file;
       }
       else
       {
          g_changed = true;
-         kDebug(7021) << "new: " << file << endl;
+         kDebug(7021) << "new:" << file;
       }
    }
    g_ctimeInfo->addCTime(file, timeStamp );
@@ -255,8 +255,8 @@ bool KBuildSycoca::build()
   // Convert for each factory the entryList to a Dict.
   int i = 0;
   // For each factory
-  for (KSycocaFactoryList::Iterator factory = m_lstFactories->begin();
-       factory != m_lstFactories->end();
+  for (KSycocaFactoryList::Iterator factory = factories()->begin();
+       factory != factories()->end();
        ++factory)
   {
      KBSEntryDict *entryDict = new KBSEntryDict;
@@ -279,8 +279,8 @@ bool KBuildSycoca::build()
 
   QStringList allResources; // we could use QSet<QString> - does order matter?
   // For each factory
-  for (KSycocaFactoryList::Iterator factory = m_lstFactories->begin();
-       factory != m_lstFactories->end();
+  for (KSycocaFactoryList::Iterator factory = factories()->begin();
+       factory != factories()->end();
        ++factory)
   {
     // For each resource the factory deals with
@@ -320,8 +320,8 @@ bool KBuildSycoca::build()
      // For each factory
      KBSEntryDictList::const_iterator ed_it = entryDictList.begin();
      const KBSEntryDictList::const_iterator ed_end = entryDictList.end();
-     KSycocaFactoryList::const_iterator it = m_lstFactories->begin();
-     const KSycocaFactoryList::const_iterator end = m_lstFactories->end();
+     KSycocaFactoryList::const_iterator it = factories()->begin();
+     const KSycocaFactoryList::const_iterator end = factories()->end();
      for ( ; it != end; ++it, ++ed_it )
      {
         g_factory = (*it);
@@ -380,8 +380,6 @@ bool KBuildSycoca::build()
      entry->setLayoutInfo(kdeMenu->layoutList);
      createMenu(QString(), QString(), kdeMenu);
 
-     createMenuAttribute( entry );
-
      (void) existingResourceDirs();
      *g_allResourceDirs += g_vfolder->allDirectories();
 
@@ -402,21 +400,10 @@ bool KBuildSycoca::build()
   return result;
 }
 
-void KBuildSycoca::createMenuAttribute( KServiceGroup::Ptr entry )
-{
-    KServiceGroup::List list = entry->entries(true, true);
-    KServiceGroup::List::ConstIterator it = list.begin();
-    for (; it != list.end(); ++it) {
-        if ((*it)->isType(KST_KServiceGroup)) {
-            KServiceGroup::Ptr g = KServiceGroup::Ptr::staticCast( *it );
-            createMenuAttribute( g );
-        }
-    }
-}
-
-
-void KBuildSycoca::createMenu(QString caption, QString name, VFolderMenu::SubMenu *menu)
+void KBuildSycoca::createMenu(const QString &caption_, const QString &name_, VFolderMenu::SubMenu *menu)
 {
+  QString caption = caption_;
+  QString name = name_;
   foreach (VFolderMenu::SubMenu *subMenu, menu->subMenus)
   {
      QString subName = name+subMenu->name+'/';
@@ -488,7 +475,7 @@ bool KBuildSycoca::recreate()
   }
   if (!openedOK)
   {
-    fprintf(stderr, "kbuildsycoca: ERROR creating database '%s'! %s\n",
+    fprintf(stderr, "kbuildsycoca4: ERROR creating database '%s'! %s\n",
       path.toLocal8Bit().data(), database.errorString().toLocal8Bit().data());
 #ifdef KBUILDSYCOCA_GUI // KBUILDSYCOCA_GUI is used on win32 to build
                         // GUI version of kbuildsycoca, so-called "kbuildsycocaw".
@@ -501,7 +488,7 @@ bool KBuildSycoca::recreate()
   m_str = new QDataStream ( &database );
   m_str->setVersion(QDataStream::Qt_3_1);
 
-  kDebug(7021) << "Recreating ksycoca file (" << path << ", version " << KSycoca::version() << ")" << endl;
+  kDebug(7021).nospace() << "Recreating ksycoca file (" << path << ", version " << KSycoca::version() << ")";
 
   // It is very important to build the servicetype one first
   // Both are registered in KSycoca, no need to keep the pointers
@@ -520,8 +507,8 @@ bool KBuildSycoca::recreate()
     m_str = 0L;
     if (!database.finalize())
     {
-      fprintf(stderr, "kbuildsycoca: ERROR writing database '%s'!\n", database.fileName().toLocal8Bit().data());
-      fprintf(stderr, "kbuildsycoca: Disk full?\n");
+      fprintf(stderr, "kbuildsycoca4: ERROR writing database '%s'!\n", database.fileName().toLocal8Bit().data());
+      fprintf(stderr, "kbuildsycoca4: Disk full?\n");
 #ifdef KBUILDSYCOCA_GUI
       if (!silent)
         KMessageBox::error(0, i18n("Error writing database '%1'.\nCheck that the permissions are correct on the directory and the disk is not full.\n", path.toLocal8Bit().data()), i18n("KBuildSycoca"));
@@ -536,7 +523,7 @@ bool KBuildSycoca::recreate()
     database.abort();
     if (bMenuTest)
        return true;
-    kDebug(7021) << "Database is up to date" << endl;
+    kDebug(7021) << "Database is up to date";
   }
 
   if (!bGlobalDatabase)
@@ -560,11 +547,11 @@ void KBuildSycoca::save()
    m_str->device()->seek(0);
 
    (*m_str) << (qint32) KSycoca::version();
-   KSycocaFactory * servicetypeFactory = 0L;
-   KSycocaFactory * mimeTypeFactory = 0L;
-   KBuildServiceFactory * serviceFactory = 0L;
-   for(KSycocaFactoryList::Iterator factory = m_lstFactories->begin();
-       factory != m_lstFactories->end();
+   KSycocaFactory * servicetypeFactory = 0;
+   KBuildMimeTypeFactory * mimeTypeFactory = 0;
+   KBuildServiceFactory * serviceFactory = 0;
+   for(KSycocaFactoryList::Iterator factory = factories()->begin();
+       factory != factories()->end();
        ++factory)
    {
       qint32 aId;
@@ -573,7 +560,7 @@ void KBuildSycoca::save()
       if ( aId == KST_KServiceTypeFactory )
          servicetypeFactory = *factory;
       else if ( aId == KST_KMimeTypeFactory )
-         mimeTypeFactory = *factory;
+         mimeTypeFactory = static_cast<KBuildMimeTypeFactory *>( *factory );
       else if ( aId == KST_KServiceFactory )
          serviceFactory = static_cast<KBuildServiceFactory *>( *factory );
       aOffset = (*factory)->offset();
@@ -590,11 +577,12 @@ void KBuildSycoca::save()
    (*m_str) << (*g_allResourceDirs);
 
    // Calculate per-servicetype/mimetype data
+   mimeTypeFactory->parseSubclasses();
    serviceFactory->populateServiceTypes();
 
    // Write factory data....
-   for(KSycocaFactoryList::Iterator factory = m_lstFactories->begin();
-       factory != m_lstFactories->end();
+   for(KSycocaFactoryList::Iterator factory = factories()->begin();
+       factory != factories()->end();
        ++factory)
    {
       (*factory)->save(*m_str);
@@ -608,8 +596,8 @@ void KBuildSycoca::save()
    m_str->device()->seek(0);
 
    (*m_str) << (qint32) KSycoca::version();
-   for(KSycocaFactoryList::Iterator factory = m_lstFactories->begin();
-       factory != m_lstFactories->end(); ++factory)
+   for(KSycocaFactoryList::Iterator factory = factories()->begin();
+       factory != factories()->end(); ++factory)
    {
       qint32 aId;
       qint32 aOffset;
@@ -629,23 +617,22 @@ bool KBuildSycoca::checkDirTimestamps( const QString& dirname, const QDateTime&
    if( top )
    {
       QFileInfo inf( dirname );
-      if( inf.lastModified() > stamp )
-         {
-         kDebug( 7021 ) << "timestamp changed:" << dirname << endl;
+      if( inf.lastModified() > stamp ) {
+         kDebug( 7021 ) << "timestamp changed:" << dirname;
          return false;
-         }
+      }
    }
    QDir dir( dirname );
-   QFileInfoList list = dir.entryInfoList( QDir::NoFilter, QDir::Unsorted );
-   if (list.count() == 0)
+   const QFileInfoList list = dir.entryInfoList( QDir::NoFilter, QDir::Unsorted );
+   if (list.isEmpty())
       return true;
 
-   foreach ( QFileInfo fi, list ) {
+   foreach ( const QFileInfo& fi, list ) {
       if( fi.fileName() == "." || fi.fileName() == ".." )
          continue;
       if( fi.lastModified() > stamp )
       {
-         kDebug( 7201 ) << "timestamp changed:" << fi.filePath() << endl;
+         kDebug( 7201 ) << "timestamp changed:" << fi.filePath();
          return false;
       }
       if( fi.isDir() && !checkDirTimestamps( fi.filePath(), stamp, false ))
@@ -660,7 +647,7 @@ bool KBuildSycoca::checkDirTimestamps( const QString& dirname, const QDateTime&
 // means that there's no need to rebuild ksycoca
 bool KBuildSycoca::checkTimestamps( quint32 timestamp, const QStringList &dirs )
 {
-   kDebug( 7021 ) << "checking file timestamps" << endl;
+   kDebug( 7021 ) << "checking file timestamps";
    QDateTime stamp;
    stamp.setTime_t( timestamp );
    for( QStringList::ConstIterator it = dirs.begin();
@@ -670,7 +657,7 @@ bool KBuildSycoca::checkTimestamps( quint32 timestamp, const QStringList &dirs )
       if( !checkDirTimestamps( *it, stamp, true ))
             return false;
    }
-   kDebug( 7021 ) << "timestamps check ok" << endl;
+   kDebug( 7021 ) << "timestamps check ok";
    return true;
 }
 
@@ -709,33 +696,30 @@ QStringList KBuildSycoca::existingResourceDirs()
    return *dirs;
 }
 
-static KCmdLineOptions options[] = {
-   { "nosignal", I18N_NOOP("Do not signal applications to update"), 0 },
-   { "noincremental", I18N_NOOP("Disable incremental update, re-read everything"), 0 },
-   { "checkstamps", I18N_NOOP("Check file timestamps"), 0 },
-   { "nocheckfiles", I18N_NOOP("Disable checking files (dangerous)"), 0 },
-   { "global", I18N_NOOP("Create global database"), 0 },
-   { "menutest", I18N_NOOP("Perform menu generation test run only"), 0 },
-   { "track <menu-id>", I18N_NOOP("Track menu id for debug purposes"), 0 },
-#ifdef KBUILDSYCOCA_GUI
-   { "silent", I18N_NOOP("Silent - work without windows and stderr"), 0 },
-   { "showprogress", I18N_NOOP("Show progress information (even if 'silent' mode is on)"), 0 },
-#endif
-   KCmdLineLastOption
-};
-
 static const char appFullName[] = "org.kde.kbuildsycoca";
-static const char appName[] = "kbuildsycoca";
+static const char appName[] = "kbuildsycoca4";
 static const char appVersion[] = "1.1";
 
 extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
 {
-   KLocale::setMainCatalog("kdelibs");
-   KAboutData d(appName, I18N_NOOP("KBuildSycoca"), appVersion,
-                I18N_NOOP("Rebuilds the system configuration cache."),
-                KAboutData::License_GPL, "(c) 1999-2002 KDE Developers");
-   d.addAuthor("David Faure", I18N_NOOP("Author"), "faure@kde.org");
-   d.addAuthor("Waldo Bastian", I18N_NOOP("Author"), "bastian@kde.org");
+   KAboutData d(appName, "kdelibs4", ki18n("KBuildSycoca"), appVersion,
+                ki18n("Rebuilds the system configuration cache."),
+                KAboutData::License_GPL, ki18n("(c) 1999-2002 KDE Developers"));
+   d.addAuthor(ki18n("David Faure"), ki18n("Author"), "faure@kde.org");
+   d.addAuthor(ki18n("Waldo Bastian"), ki18n("Author"), "bastian@kde.org");
+
+   KCmdLineOptions options;
+   options.add("nosignal", ki18n("Do not signal applications to update"));
+   options.add("noincremental", ki18n("Disable incremental update, re-read everything"));
+   options.add("checkstamps", ki18n("Check file timestamps"));
+   options.add("nocheckfiles", ki18n("Disable checking files (dangerous)"));
+   options.add("global", ki18n("Create global database"));
+   options.add("menutest", ki18n("Perform menu generation test run only"));
+   options.add("track <menu-id>", ki18n("Track menu id for debug purposes"));
+#ifdef KBUILDSYCOCA_GUI
+   options.add("silent", ki18n("Silent - work without windows and stderr"));
+   options.add("showprogress", ki18n("Show progress information (even if 'silent' mode is on)"));
+#endif
 
    KCmdLineArgs::init(argc, argv, &d);
    KCmdLineArgs::addCmdLineOptions(options);
@@ -749,7 +733,6 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
      setenv("KDEROOTHOME", "-", 1);
    }
 
-   //KApplication::disableAutoDcopRegistration();
 #ifdef KBUILDSYCOCA_GUI
    KApplication k;
 #else
@@ -763,7 +746,7 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
    QLabel progress( QString("<p><br><nobr>    %1    </nobr><br>").arg( i18n("Reloading KDE configuration, please wait...") ), 0, "", Qt::WType_Dialog | Qt::WStyle_DialogBorder  | Qt::WStyle_Customize| Qt::WStyle_Title );
    QString capt = i18n("KDE Configuration Manager");
    if (!silent) {
-     if (KMessageBox::No == KMessageBox::questionYesNo(0, i18n("Do you want to reload KDE configuration?"), capt, i18n("Reload"), i18n("Do Not Reload")))
+     if (KMessageBox::No == KMessageBox::questionYesNo(0, i18n("Do you want to reload KDE configuration?"), capt, i18nc("Reload KDE configuration messagebox", "Reload"), i18n("Do Not Reload")))
        return 0;
    }
    if (!silent || showprogress) {
@@ -776,25 +759,29 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
    KCrash::setEmergencySaveFunction(crashHandler);
    KCrash::setApplicationName(QString(appName));
 
-   // this program is in kdelibs so it uses kdelibs as catalog
-   KLocale::setMainCatalog("kdelibs");
    // force generating of KLocale object. if not, the database will get
    // be translated
    KGlobal::locale();
    KGlobal::dirs()->addResourceType("app-reg", "share/application-registry" );
 
+    if (!QDBusConnection::sessionBus().isConnected())
+    {
+        kError() << "kbuildsycoca4: Cannot find the D-Bus session server" << endl;
+        return 255;
+    }
+
    while(true)
    {
      // kapp registered already, but with the PID in the name.
      // We need to re-register without it, to detect already-running kbuildsycoca instances.
-     if (QDBusConnection::sessionBus().registerService(appFullName))
+     if (QDBusConnection::sessionBus().interface()->registerService(appFullName, QDBusConnectionInterface::QueueService))
      {
        break; // Go
      }
      fprintf(stderr, "Waiting for already running %s to finish.\n", appName);
 
      QEventLoop eventLoop;
-     QObject::connect(QDBusConnection::sessionBus().interface(), SIGNAL(serviceAcquired(QString)),
+     QObject::connect(QDBusConnection::sessionBus().interface(), SIGNAL(serviceRegistered(QString)),
                       &eventLoop, SLOT(quit()));
      eventLoop.exec( QEventLoop::ExcludeUserInputEvents );
    }
@@ -802,12 +789,7 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
 
    bool checkfiles = bGlobalDatabase || args->isSet("checkfiles");
 
-#ifdef Q_WS_WIN
-   // incremental does not work under win32 because of shared access violation 
-   bool incremental = 0;
-#else
    bool incremental = !bGlobalDatabase && args->isSet("incremental") && checkfiles;
-#endif
    if (incremental || !checkfiles)
    {
      KSycoca::self()->disableAutoRebuild(); // Prevent deadlock
@@ -878,7 +860,7 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
       g_ctimeDict = 0;
       if (incremental)
       {
-         kDebug() << "Reusing existing ksycoca" << endl;
+         kDebug() << "Reusing existing ksycoca";
          KSycoca *oldSycoca = KSycoca::self();
          KSycocaFactoryList *factories = new KSycocaFactoryList;
          g_allEntries = new KSycocaEntryListList;
@@ -907,7 +889,7 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
 
       KBuildSycoca *sycoca= new KBuildSycoca; // Build data base
       if (args->isSet("track"))
-         sycoca->setTrackId(QString::fromLocal8Bit(args->getOption("track")));
+         sycoca->setTrackId(args->getOption("track"));
       if (!sycoca->recreate()) {
 #ifdef KBUILDSYCOCA_GUI
         if (!silent || showprogress)
