@@ -16,6 +16,8 @@
  *  Boston, MA 02110-1301, USA.
  **/
 
+#include "vfolder_menu.h"
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -29,21 +31,19 @@
 #include <kservice.h>
 #include <kde_file.h>
 
-#include <qmap.h>
-#include <qfile.h>
-#include <qdir.h>
-#include <qregexp.h>
+#include <QtCore/QMap>
+#include <QtCore/QFile>
+#include <QtCore/QDir>
+#include <QtCore/QRegExp>
 
-#include "vfolder_menu.h"
-
-static void foldNode(QDomElement &docElem, QDomElement &e, QMap<QString,QDomElement> &dupeList, QString s=QString())
+static void foldNode(QDomElement &docElem, QDomElement &e, QMap<QString,QDomElement> &dupeList, QString s=QString()) //krazy:exclude=passbyvalue
 {
    if (s.isEmpty())
       s = e.text();
    QMap<QString,QDomElement>::iterator it = dupeList.find(s);
    if (it != dupeList.end())
    {
-      kDebug(7021) << e.tagName() << " and " << s << " requires combining!" << endl;
+      kDebug(7021) << e.tagName() << "and" << s << "requires combining!";
 
       docElem.removeChild(*it);
       dupeList.erase(it);
@@ -65,7 +65,7 @@ static void replaceNode(QDomElement &docElem, QDomNode &n, const QStringList &li
    QDomNode next = n.nextSibling();
    docElem.removeChild(n);
    n = next;
-//   kDebug(7021) << "Next tag = " << n.toElement().tagName() << endl;
+//   kDebug(7021) << "Next tag = " << n.toElement().tagName();
 }
 
 void VFolderMenu::registerFile(const QString &file)
@@ -133,7 +133,7 @@ VFolderMenu::matchItems(QHash<QString,KService::Ptr>& items1, const QHash<QStrin
 }
 
 void
-VFolderMenu::excludeItems(QHash<QString,KService::Ptr> items1, const QHash<QString,KService::Ptr>& items2)
+VFolderMenu::excludeItems(QHash<QString,KService::Ptr>& items1, const QHash<QString,KService::Ptr>& items2)
 {
    foreach (KService::Ptr p, items2)
        items1.remove(p->menuId());
@@ -431,7 +431,7 @@ VFolderMenu::absoluteDir(const QString &_dir, const QString &baseDir, bool keepR
    {
       dir = baseDir + dir;
    }
-   if (!dir.endsWith("/"))
+   if (!dir.endsWith('/'))
       dir += '/';
 
    if (QDir::isRelativePath(dir) && !keepRelativeToCfg)
@@ -477,14 +477,14 @@ VFolderMenu::loadDoc()
    QFile file( m_docInfo.path );
    if ( !file.open( QIODevice::ReadOnly ) )
    {
-      kWarning(7021) << "Could not open " << m_docInfo.path << endl;
+      kWarning(7021) << "Could not open " << m_docInfo.path;
       return doc;
    }
    QString errorMsg;
    int errorRow;
    int errorCol;
    if ( !doc.setContent( &file, &errorMsg, &errorRow, &errorCol ) ) {
-      kWarning(7021) << "Parse error in " << m_docInfo.path << ", line " << errorRow << ", col " << errorCol << ": " << errorMsg << endl;
+      kWarning(7021) << "Parse error in " << m_docInfo.path << ", line " << errorRow << ", col " << errorCol << ": " << errorMsg;
       file.close();
       return doc;
    }
@@ -504,7 +504,7 @@ VFolderMenu::loadDoc()
 void
 VFolderMenu::mergeFile(QDomElement &parent, const QDomNode &mergeHere)
 {
-kDebug(7021) << "VFolderMenu::mergeFile: " << m_docInfo.path << endl;
+kDebug(7021) << "VFolderMenu::mergeFile:" << m_docInfo.path;
    QDomDocument doc = loadDoc();
 
    QDomElement docElem = doc.documentElement();
@@ -547,7 +547,7 @@ VFolderMenu::mergeMenus(QDomElement &docElem, QString &name)
    while( !n.isNull() ) {
       QDomElement e = n.toElement(); // try to convert the node to an element.
       if( e.isNull() ) {
-// kDebug(7021) << "Empty node" << endl;
+// kDebug(7021) << "Empty node";
       }
       else if( e.tagName() == "DefaultAppDirs") {
          // Replace with m_defaultAppDirs
@@ -711,7 +711,7 @@ VFolderMenu::pushDocInfo(const QString &fileName, const QString &baseDir)
    {
       m_docInfo.baseDir.clear();
       m_docInfo.baseName.clear();
-      kDebug(7021) << "Menu " << fileName << " not found." << endl;
+      kDebug(7021) << "Menu" << fileName << "not found.";
       return;
    }
    int i;
@@ -780,7 +780,7 @@ VFolderMenu::locateMenuFile(const QString &fileName)
          fileNameOnly = xdgMenuPrefix + fileNameOnly;
 
       QString baseName = QDir::cleanPath(m_docInfo.baseDir +
-                                         fileInfo.path() + "/" + fileNameOnly);
+                                         fileInfo.path() + '/' + fileNameOnly);
       result = KStandardDirs::locate("xdgconf-menu", baseName);
    }
 
@@ -850,7 +850,7 @@ VFolderMenu::loadMenu(const QString &fileName)
       if (m_docInfo.path.isEmpty())
          kError(7021) << fileName << " not found in " << m_allDirectories << endl;
       else
-         kWarning(7021) << "Load error (" << m_docInfo.path << ")" << endl;
+         kWarning(7021) << "Load error (" << m_docInfo.path << ")";
       return;
    }
 
@@ -967,7 +967,7 @@ VFolderMenu::processCondition(QDomElement &domElem, QHash<QString,KService::Ptr>
    else if (domElem.tagName() == "Filename")
    {
       QString filename = domElem.text();
-kDebug(7021) << "Adding file " << filename << endl;
+kDebug(7021) << "Adding file" << filename;
       KService::Ptr s = findApplication(filename);
       if (s)
          items.insert(filename, s);
@@ -977,7 +977,7 @@ kDebug(7021) << "Adding file " << filename << endl;
 void
 VFolderMenu::loadApplications(const QString &dir, const QString &prefix)
 {
-   kDebug(7021) << "Looking up applications under " << dir << endl;
+   kDebug(7021) << "Looking up applications under" << dir;
 
    // We look for a set of files.
    DIR *dp = opendir( QFile::encodeName(dir));
@@ -1032,10 +1032,10 @@ VFolderMenu::loadApplications(const QString &dir, const QString &prefix)
 void
 VFolderMenu::processKDELegacyDirs()
 {
-kDebug(7021) << "processKDELegacyDirs()" << endl;
+kDebug(7021) << "processKDELegacyDirs()";
 
    QHash<QString,KService::Ptr> items;
-   QString prefix = "kde-";
+   QString prefix = "kde4-";
 
    QStringList relFiles;
 
@@ -1094,7 +1094,7 @@ kDebug(7021) << "processKDELegacyDirs()" << endl;
 void
 VFolderMenu::processLegacyDir(const QString &dir, const QString &relDir, const QString &prefix)
 {
-kDebug(7021) << "processLegacyDir(" << dir << ", " << relDir << ", " << prefix << ")" << endl;
+kDebug(7021).nospace() << "processLegacyDir(" << dir << ", " << relDir << ", " << prefix << ")";
 
    QHash<QString,KService::Ptr> items;
    // We look for a set of files.
@@ -1257,7 +1257,7 @@ VFolderMenu::processMenu(QDomElement &docElem, int pass)
       }
       if (directoryFile.isEmpty())
       {
-         kDebug(7021) << "Menu " << name << " does not specify a directory file." << endl;
+         kDebug(7021) << "Menu" << name << "does not specify a directory file.";
       }
 
       // Override previous directoryFile iff available
@@ -1310,7 +1310,7 @@ VFolderMenu::processMenu(QDomElement &docElem, int pass)
             createAppsInfo();
             if (!kdeLegacyDirsDone)
             {
-kDebug(7021) << "Processing KDE Legacy dirs for <KDE>" << endl;
+kDebug(7021) << "Processing KDE Legacy dirs for <KDE>";
                SubMenu *oldMenu = m_currentMenu;
                m_currentMenu = new SubMenu;
 
@@ -1333,7 +1333,7 @@ kDebug(7021) << "Processing KDE Legacy dirs for <KDE>" << endl;
             {
                if (!kdeLegacyDirsDone)
                {
-kDebug(7021) << "Processing KDE Legacy dirs for " << dir << endl;
+kDebug(7021) << "Processing KDE Legacy dirs for" << dir;
                   SubMenu *oldMenu = m_currentMenu;
                   m_currentMenu = new SubMenu;
 
@@ -1471,7 +1471,7 @@ kDebug(7021) << "Processing KDE Legacy dirs for " << dir << endl;
                   dest = e2.text();
                n2 = n2.nextSibling();
             }
-            kDebug(7021) << "Moving " << orig << " to " << dest << endl;
+            kDebug(7021) << "Moving" << orig << "to" << dest;
             if (!orig.isEmpty() && !dest.isEmpty())
             {
               SubMenu *menu = takeSubMenu(m_currentMenu, orig);
@@ -1507,7 +1507,7 @@ static QString parseAttribute( const QDomElement &e)
         else if ( str=="false" )
             option= "NME ";
         else
-            kDebug()<<" Error in parsing show_empty attribute :"<<str<<endl;
+            kDebug()<<" Error in parsing show_empty attribute :"<<str;
     }
     if ( e.hasAttribute( "inline" ) )
     {
@@ -1517,7 +1517,7 @@ static QString parseAttribute( const QDomElement &e)
         else if ( str=="false" )
             option+="NI ";
         else
-            kDebug()<<" Error in parsing inlibe attribute :"<<str<<endl;
+            kDebug()<<" Error in parsing inlibe attribute :"<<str;
     }
     if ( e.hasAttribute( "inline_limit" ) )
     {
@@ -1534,7 +1534,7 @@ static QString parseAttribute( const QDomElement &e)
         else if ( str == "false" )
             option+="NIH ";
         else
-            kDebug()<<" Error in parsing of inline_header attribute :"<<str<<endl;
+            kDebug()<<" Error in parsing of inline_header attribute :"<<str;
 
     }
     if ( e.hasAttribute( "inline_alias" ) && e.attribute( "inline_alias" )=="true")
@@ -1545,7 +1545,7 @@ static QString parseAttribute( const QDomElement &e)
         else if ( str=="false" )
             option+="NIA";
         else
-            kDebug()<<" Error in parsing inline_alias attribute :"<<str<<endl;
+            kDebug()<<" Error in parsing inline_alias attribute :"<<str;
     }
     if( !option.isEmpty())
     {
@@ -1600,7 +1600,7 @@ static QStringList parseLayoutNode(const QDomElement &docElem)
 }
 
 void
-VFolderMenu::layoutMenu(VFolderMenu::SubMenu *menu, QStringList defaultLayout)
+VFolderMenu::layoutMenu(VFolderMenu::SubMenu *menu, QStringList defaultLayout) //krazy:exclude=passbyvalue
 {
    if (!menu->defaultLayoutNode.isNull())
    {
@@ -1659,11 +1659,11 @@ VFolderMenu::parseMenu(const QString &file, bool forceLegacyLoad)
       if (pass == 0)
       {
          buildApplicationIndex(false);
-      }
+      } else
       if (pass == 1)
       {
          buildApplicationIndex(true);
-      }
+      } else
       if (pass == 2)
       {
          QStringList defaultLayout;
