@@ -1,19 +1,32 @@
 /* This file is part of the KDE libraries
-    Copyright (C) 1998, 1999 Christian Tibirna <ctibirna@total.net>
-              (C) 1998, 1999 Daniel M. Duley <mosfet@kde.org>
-              (C) 1998, 1999 Dirk A. Mueller <mueller@kde.org>
-
-*/
-
-#include <QApplication>
-#include <QImage>
-#include <QPainter>
-#include <QPaintEngine>
-#include <QDesktopWidget>
+ *  Copyright (C) 1998, 1999 Christian Tibirna <ctibirna@total.net>
+ *            (C) 1998, 1999 Daniel M. Duley <daniel.duley@verizon.net>
+ *            (C) 1998, 1999 Dirk A. Mueller <mueller@kde.org>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License version 2 as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public License
+ * along with this library; see the file COPYING.LIB.  If not, write to
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 #include "kpixmapeffect.h"
 #include "kimageeffect.h"
 
+#include <QtGui/QApplication>
+#include <QtGui/QImage>
+#include <QtGui/QPainter>
+#include <QtGui/QTextItem>
+#include <QtGui/QDesktopWidget>
+
 //======================================================================
 //
 // Gradient effects
@@ -220,7 +233,7 @@ void KPixmapEffect::pattern(QPixmap &pixmap, const QColor &ca,
 
 // -----------------------------------------------------------------------------
 
-QPixmap KPixmapEffect::pattern(const QPixmap& pmtile, QSize size,
+QPixmap KPixmapEffect::pattern(const QPixmap& pmtile, const QSize &size,
                        const QColor &ca, const QColor &cb, int ncols)
 {
     if (pmtile.depth() > 8)
@@ -237,7 +250,7 @@ QPixmap KPixmapEffect::pattern(const QPixmap& pmtile, QSize size,
 
 // -----------------------------------------------------------------------------
 
-QPixmap KPixmapEffect::createTiled(const QPixmap& pixmap, QSize size)
+QPixmap KPixmapEffect::createTiled(const QPixmap& pixmap, const QSize &size)
 {
     QPixmap pix(size);
 
