@@ -21,15 +21,15 @@
 #include "cupsinfos.h"
 #include "sidepixmap.h"
 
-#include <qtimer.h>
-#include <qprogressbar.h>
-#include <qlabel.h>
-#include <qlayout.h>
+#include <QtCore/QTimer>
+#include <QtGui/QProgressBar>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
 #include <klineedit.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <qmessagebox.h>
-#include <qfile.h>
+#include <QtGui/QMessageBox>
+#include <QtCore/QFile>
 #include <kdebug.h>
 #include <kseparator.h>
 #include <kpushbutton.h>
@@ -45,9 +45,10 @@ CupsAddSmb::CupsAddSmb(QWidget *parent, const char *name)
 	m_state = None;
 	m_status = false;
 	m_actionindex = 0;
-	connect(&m_proc, SIGNAL(receivedStdout(KProcess*,char*,int)), SLOT(slotReceived(KProcess*,char*,int)));
-	connect(&m_proc, SIGNAL(receivedStderr(KProcess*,char*,int)), SLOT(slotReceived(KProcess*,char*,int)));
-	connect(&m_proc, SIGNAL(processExited(KProcess*)), SLOT(slotProcessExited(KProcess*)));
+        m_proc.setOutputChannelMode(KProcess::MergedChannels);
+	connect(&m_proc, SIGNAL(readyReadStandardOutput()), SLOT(slotReceived()));
+	connect(&m_proc, SIGNAL(finished(int,KProcess::ExitStatus)),
+                SLOT(slotProcessExited(int,KProcess::ExitStatus)));
 
 	m_side = new SidePixmap(this);
 	m_doit = new QPushButton(i18n("&Export"), this);
@@ -149,42 +150,45 @@ void CupsAddSmb::slotActionClicked()
 {
 	if (m_state == None)
 		doExport();
-	else if (m_proc.isRunning())
+	else if (m_proc.state() != KProcess::NotRunning)
 		m_proc.kill();
 }
 
-void CupsAddSmb::slotReceived(KProcess*, char *buf, int buflen)
+void CupsAddSmb::slotReceived()
 {
 	QString	line;
-	int		index(0);
 	bool	partial(false);
 	static bool incomplete(false);
 
-	kDebug(500) << "slotReceived()" << endl;
+	kDebug(500) << "slotReceived()";
 	while (1)
 	{
 		// read a line
 		line = QLatin1String("");
 		partial = true;
-		while (index < buflen)
+		char c;
+		while (m_proc.getChar(&c))
 		{
-			QChar	c(buf[index++]);
 			if (c == '\n')
 			{
 				partial = false;
 				break;
 			}
-			else if (c.isPrint())
-				line += c;
+			else
+			{
+				QChar qc(c);
+				if (qc.isPrint())
+					line += qc;
+			}
 		}
 
 		if (line.isEmpty())
 		{
-			kDebug(500) << "NOTHING TO READ" << endl;
+			kDebug(500) << "NOTHING TO READ";
 			return;
 		}
 
-		kDebug(500) << "ANSWER = " << line << " (END = " << line.length() << ")" << endl;
+		kDebug(500) << "ANSWER = " << line << " (END = " << line.length() << ")";
 		if (!partial)
 		{
 			if (incomplete && m_buffer.count() > 0)
@@ -192,22 +196,22 @@ void CupsAddSmb::slotReceived(KProcess*, char *buf, int buflen)
 			else
 				m_buffer << line;
 			incomplete = false;
-			kDebug(500) << "COMPLETE LINE READ (" << m_buffer.count() << ")" << endl;
+			kDebug(500) << "COMPLETE LINE READ (" << m_buffer.count() << ")";
 		}
 		else
 		{
 			if (line.startsWith("smb:") || line.startsWith("rpcclient $"))
 			{
-				kDebug(500) << "END OF ACTION" << endl;
+				kDebug(500) << "END OF ACTION";
 				checkActionStatus();
 				if (m_status)
 					nextAction();
 				else
 				{
 					// quit program
-					kDebug(500) << "EXITING PROGRAM..." << endl;
-					m_proc.writeStdin("quit\n", 5);
-					kDebug(500) << "SENT" << endl;
+					kDebug(500) << "EXITING PROGRAM...";
+					m_proc.write("quit\n", 5);
+					kDebug(500) << "SENT";
 				}
 				return;
 			}
@@ -218,7 +222,7 @@ void CupsAddSmb::slotReceived(KProcess*, char *buf, int buflen)
 				else
 					m_buffer << line;
 				incomplete = true;
-				kDebug(500) << "INCOMPLETE LINE READ (" << m_buffer.count() << ")" << endl;
+				kDebug(500) << "INCOMPLETE LINE READ (" << m_buffer.count() << ")";
 			}
 		}
 	}
@@ -246,7 +250,7 @@ void CupsAddSmb::checkActionStatus()
 			m_status = (m_buffer.count() == 1 || !m_buffer[1].startsWith("result"));
 			break;
 	}
-	kDebug(500) << "ACTION STATUS = " << m_status << endl;
+	kDebug(500) << "ACTION STATUS = " << m_status;
 }
 
 void CupsAddSmb::nextAction()
@@ -259,11 +263,11 @@ void CupsAddSmb::doNextAction()
 {
 	m_buffer.clear();
 	m_state = None;
-	if (m_proc.isRunning())
+	if (m_proc.state() == KProcess::Running)
 	{
 		QByteArray	s = m_actions[m_actionindex++].toLatin1();
 		m_bar->setValue(m_bar->value()+1);
-		kDebug(500) << "NEXT ACTION = " << s << endl;
+		kDebug(500) << "NEXT ACTION = " << s;
 		if (s == "quit")
 		{
 			// do nothing
@@ -306,24 +310,24 @@ void CupsAddSmb::doNextAction()
 		}
 		else
 		{
-			kDebug(500) << "ACTION = unknown action" << endl;
+			kDebug(500) << "ACTION = unknown action";
 			m_proc.kill();
 			return;
 		}
 		// send action
-		kDebug(500) << "ACTION = " << s << endl;
+		kDebug(500) << "ACTION = " << s;
 		s.append("\n");
-		m_proc.writeStdin(s.data(), s.length());
+		m_proc.write(s);
 	}
 }
 
-void CupsAddSmb::slotProcessExited(KProcess*)
+void CupsAddSmb::slotProcessExited(int, KProcess::ExitStatus exitStatus)
 {
-	kDebug(500) << "PROCESS EXITED (" << m_state << ")" << endl;
-	if (m_proc.normalExit() && m_state != Start && m_status)
+	kDebug(500) << "PROCESS EXITED (" << m_state << ")";
+	if (exitStatus == KProcess::NormalExit && m_state != Start && m_status)
 	{
 		// last process went OK. If it was smbclient, then switch to rpcclient
-		if (qstrncmp(m_proc.args().first(), "smbclient", 9) == 0)
+		if (m_procname == "smbclient")
 		{
 			doInstall();
 			return;
@@ -345,7 +349,7 @@ void CupsAddSmb::slotProcessExited(KProcess*)
 		}
 	}
 
-	if (m_proc.normalExit())
+	if (exitStatus == KProcess::NormalExit)
 	{
 		showError(
 				i18n("Operation failed. Possible reasons are: permission denied "
@@ -440,8 +444,9 @@ bool CupsAddSmb::doExport()
 	m_actions << "put" << m_datadir+"/drivers/PSMON.DLL" << "WIN40/PSMON.DLL";
 	m_actions << "quit";
 
-	m_proc.clearArguments();
-	m_proc << "smbclient" << QLatin1String("//")+m_servered->text()+"/print$";
+	m_proc.clearProgram();
+	m_procname = "smbclient";
+	m_proc << m_procname << QLatin1String("//")+m_servered->text()+"/print$";
 	return startProcess();
 }
 
@@ -462,8 +467,9 @@ bool CupsAddSmb::doInstall()
 	//m_text->setText(i18n("Preparing to install driver on host <b>%1</b>").arg(m_servered->text()));
 	m_textinfo->setText(i18n("Preparing to install driver on host %1", m_servered->text()));
 
-	m_proc.clearArguments();
-	m_proc << "rpcclient" << m_servered->text();
+	m_proc.clearProgram();
+	m_procname = "rpcclient";
+	m_proc << m_procname << m_servered->text();
 	return startProcess();
 }
 
@@ -477,8 +483,9 @@ bool CupsAddSmb::startProcess()
 	m_state = Start;
 	m_actionindex = 0;
 	m_buffer.clear();
-	kDebug(500) << "PROCESS STARTED = " << m_proc.args()[0] << endl;
-	return m_proc.start(KProcess::NotifyOnExit, KProcess::All);
+	kDebug(500) << "PROCESS STARTED = " << m_procname;
+	m_proc.start();
+	return m_proc.waitForStarted(5000); // don't wait more than 5 seconds
 }
 
 #include "cupsaddsmb2.moc"
