@@ -20,8 +20,8 @@
 #ifndef CUPSADDSMB_H
 #define CUPSADDSMB_H
 
-#include <qobject.h>
-#include <qstringlist.h>
+#include <QtCore/QObject>
+#include <QtCore/QStringList>
 #include <kprocess.h>
 #include <kdialog.h>
 
@@ -37,15 +37,15 @@ class CupsAddSmb : public KDialog
 
 public:
 	enum State { None, Start, MkDir, Copy, AddDriver, AddPrinter };
-	CupsAddSmb(QWidget *parent = 0, const char *name = 0);
+	explicit CupsAddSmb(QWidget *parent = 0, const char *name = 0);
 	~CupsAddSmb();
 
 	static bool exportDest(const QString& dest, const QString& datadir);
 
 protected Q_SLOTS:
-	void slotReceived(KProcess*, char*, int);
+	void slotReceived();
 	void doNextAction();
-	void slotProcessExited(KProcess*);
+	void slotProcessExited(int exitCode, KProcess::ExitStatus exitStatus);
 	void slotActionClicked();
 
 protected:
@@ -58,6 +58,7 @@ protected:
 
 private:
 	KProcess	m_proc;
+	QString		m_procname;
 	QStringList	m_buffer;
 	int		m_state;
 	QStringList	m_actions;
