@@ -20,8 +20,8 @@
 #ifndef CUPSDCOMMENT_H
 #define	CUPSDCOMMENT_H
 
-#include <qstringlist.h>
-#include <QHash>
+#include <QtCore/QStringList>
+#include <QtCore/QHash>
 
 class QFile;
 
