@@ -17,11 +17,12 @@
  *  Boston, MA 02110-1301, USA.
  **/
 
-#include <config.h>
 #include "cupsdconf.h"
 
-#include <qfile.h>
-#include <qregexp.h>
+#include <config.h>
+
+#include <QtCore/QFile>
+#include <QtCore/QRegExp>
 #include <klocale.h>
 #include <kdebug.h>
 #include <kconfig.h>
@@ -450,7 +451,7 @@ bool CupsdConf::saveToFile(const QString& filename)
 
 		t << endl << comments_["browseshortnames"] << endl;
 		if (browsing_) t << "BrowseShortNames " << (useshortnames_ ? "Yes" : "No") << endl;
-		
+
 		t << endl << "# Unknown" << endl;
 		for (QList< QPair<QString,QString> >::ConstIterator it=unknown_.begin(); it!=unknown_.end(); ++it)
 			t << (*it).first << " " << (*it).second << endl;
@@ -498,7 +499,7 @@ bool CupsdConf::parseOption(const QString& line)
 		keyword = l.toLower();
 	}
 
-	//kDebug() << "cupsd.conf keyword=" << keyword << endl;
+	//kDebug() << "cupsd.conf keyword=" << keyword;
 	if (keyword == "accesslog") accesslog_ = value;
 	else if (keyword == "autopurgejobs") autopurgejobs_ = (value.toLower() == "yes");
 	else if (keyword == "browseaddress") browseaddresses_.append("Send "+value);
@@ -611,8 +612,7 @@ bool CupsdConf::parseOption(const QString& line)
 
 bool CupsdConf::loadAvailableResources()
 {
-	KConfig	conf("kdeprintrc");
-	conf.setGroup("CUPS");
+	KConfigGroup	conf = KSharedConfig::openConfig("kdeprintrc")->group( "CUPS" );
 	QString	host = conf.readEntry("Host",cupsServer());
 	int 	port = conf.readEntry("Port",ippPort());
 	http_t	*http_ = httpConnect(host.toLocal8Bit(),port);
@@ -880,9 +880,9 @@ QString CupsResource::typeToIconName(int type)
 	   case RESOURCE_GLOBAL:
 	   	return QString("folder");
 	   case RESOURCE_PRINTER:
-	   	return QString("kdeprint_printer");
+	   	return QString("kdeprint-printer");
 	   case RESOURCE_CLASS:
-	   	return QString("kdeprint_printer_class");
+	   	return QString("kdeprint-printer-class");
 	}
 	return QString("folder");
 }
