@@ -17,11 +17,12 @@
  *  Boston, MA 02110-1301, USA.
  **/
 
-#include "config.h"
-
-
 #include "cupsddialog.h"
 
+#include <config.h>
+
+#include <kdeprint_export.h>
+
 #include "cupsdpage.h"
 #include "cupsdconf.h"
 #include "cupsdsplash.h"
@@ -34,24 +35,24 @@
 #include "cupsdbrowsingpage.h"
 #include "cupsdsecuritypage.h"
 
-#include <qdir.h>
-#include <QWhatsThis>
+#include <QtCore/QDir>
+#include <QtGui/QWhatsThis>
 #include <kvbox.h>
 #include <kmessagebox.h>
 #include <klocale.h>
-#include <qfile.h>
-#include <qfileinfo.h>
-#include <qicon.h>
-#include <qpixmap.h>
+#include <QtCore/QFile>
+#include <QtCore/QFileInfo>
+#include <QtGui/QIcon>
+#include <QtGui/QPixmap>
 #include <kglobal.h>
 #include <kicon.h>
 #include <kiconloader.h>
 #include <kcomponentdata.h>
 #include <kpagewidgetmodel.h>
-#include <qstringlist.h>
+#include <QtCore/QStringList>
 #include <kpassworddialog.h>
 #include <kguiitem.h>
-#include <qprocess.h>
+#include <QtCore/Q_PID>
 
 #include <signal.h>
 #include <cups/cups.h>
@@ -116,14 +117,14 @@ CupsdDialog::CupsdDialog(QWidget *parent, const char *name)
   setFaceType( List );
   setCaption(i18n("CUPS Server Configuration"));
   setButtons( Ok | Cancel | User1 );
-  setButtonGuiItem( User1, KGuiItem(i18n("Short Help"), "help") );
+  setButtonGuiItem( User1, KGuiItem(i18n("Short Help"), "help-contents") );
   setDefaultButton( Ok );
   setObjectName( name );
   setModal( true );
   showButtonSeparator( true );
 
-	KIconLoader::global()->addAppDir("kdeprint");
-	KGlobal::locale()->insertCatalog("cupsdconf");
+	KIconLoader::global()->addAppDir("kdeprint4");
+	KGlobal::locale()->insertCatalog("cupsdconf4");
 
 	filename_ = "";
 	conf_ = 0;
@@ -267,7 +268,7 @@ bool CupsdDialog::configure(const QString& filename, QWidget *parent, QString *m
 	}
 	else
 	{
-		KGlobal::locale()->insertCatalog("cupsdconf"); // Must be before dialog is created to translate "Short Help"
+		KGlobal::locale()->insertCatalog("cupsdconf4"); // Must be before dialog is created to translate "Short Help"
 		CupsdDialog	dlg(parent);
 		if (dlg.setConfigFile(fn) && dlg.exec())
 		{
