@@ -22,8 +22,8 @@
 #include "qdirlineedit.h"
 #include "qdirmultilineedit.h"
 
-#include <qlabel.h>
-#include <qlayout.h>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
 
 #include <klocale.h>
 
