@@ -22,9 +22,9 @@
 #include "qdirlineedit.h"
 #include "sizewidget.h"
 
-#include <qlabel.h>
-#include <qcombobox.h>
-#include <qlayout.h>
+#include <QtGui/QLabel>
+#include <QtGui/QComboBox>
+#include <QtGui/QLayout>
 
 #include <klocale.h>
 #include <kfiledialog.h>
@@ -34,7 +34,7 @@ CupsdLogPage::CupsdLogPage(QWidget *parent)
 {
 	setPageLabel(i18n("Log"));
 	setHeader(i18n("Log Settings"));
-	setPixmap("contents");
+	setPixmap("help-contents");
 
 	accesslog_ = new QDirLineEdit(true, this);
 	errorlog_ = new QDirLineEdit(true, this);
