@@ -23,9 +23,9 @@
 #include "editlist.h"
 #include "locationdialog.h"
 
-#include <qlabel.h>
-#include <qlineedit.h>
-#include <qlayout.h>
+#include <QtGui/QLabel>
+#include <QtGui/QLineEdit>
+#include <QtGui/QLayout>
 
 #include <klocale.h>
 #include <kiconloader.h>
