@@ -20,8 +20,8 @@
 #ifndef EDITLIST_H
 #define EDITLIST_H
 
-#include <qwidget.h>
-#include <qpixmap.h>
+#include <QtGui/QWidget>
+#include <QtGui/QPixmap>
 
 class KListWidget;
 class QPushButton;
