@@ -29,7 +29,7 @@ class IppReportDlg : public KDialog
 {
 	Q_OBJECT
 public:
-	IppReportDlg(QWidget *parent = 0, const char *name = 0);
+	explicit IppReportDlg(QWidget *parent = 0, const char *name = 0);
 	static void report(IppRequest *req, int group, const QString& caption = QString());
 
 protected Q_SLOTS:
