@@ -25,14 +25,12 @@
 #include <kdebug.h>
 #include <kglobal.h>
 #include <klocale.h>
-#include <qdatetime.h>
-#include <qregexp.h>
+#include <QtCore/QDate>
+#include <QtCore/QRegExp>
 
 #include <cups/cups.h>
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
 #ifdef HAVE_CUPS_NO_PWD_CACHE
 static QByteArray cups_authstring = "";
@@ -40,28 +38,28 @@ static QByteArray cups_authstring = "";
 
 void dumpRequest(ipp_t *req, bool answer = false, const QString& s = QString())
 {
-	kDebug(500) << "==========" << endl;
+	kDebug(500) << "==========";
 	if (s.isEmpty())
-		kDebug(500) << (answer ? "Answer" : "Request") << endl;
+		kDebug(500) << (answer ? "Answer" : "Request");
 	else
-		kDebug(500) << s << endl;
-	kDebug(500) << "==========" << endl;
+		kDebug(500) << s;
+	kDebug(500) << "==========";
 	if (!req)
 	{
-		kDebug(500) << "Null request" << endl;
+		kDebug(500) << "Null request";
 		return;
 	}
-	kDebug(500) << "State = 0x" << QString::number(req->state, 16) << endl;
-	kDebug(500) << "ID = 0x" << QString::number(req->request.status.request_id, 16) << endl;
+	kDebug(500) << "State = 0x" << QString::number(req->state, 16);
+	kDebug(500) << "ID = 0x" << QString::number(req->request.status.request_id, 16);
 	if (answer)
 	{
-		kDebug(500) << "Status = 0x" << QString::number(req->request.status.status_code, 16) << endl;
-		kDebug(500) << "Status message = " << ippErrorString(req->request.status.status_code) << endl;
+		kDebug(500) << "Status = 0x" << QString::number(req->request.status.status_code, 16);
+		kDebug(500) << "Status message = " << ippErrorString(req->request.status.status_code);
 	}
 	else
-		kDebug(500) << "Operation = 0x" << QString::number(req->request.op.operation_id, 16) << endl;
-	kDebug(500) << "Version = " << (int)(req->request.status.version[0]) << "." << (int)(req->request.status.version[1]) << endl;
-	kDebug(500) << endl;
+		kDebug(500) << "Operation = 0x" << QString::number(req->request.op.operation_id, 16);
+	kDebug(500) << "Version = " << (int)(req->request.status.version[0]) << "." << (int)(req->request.status.version[1]);
+	kDebug(500);
 
 	ipp_attribute_t *attr = req->attrs;
 	while (attr)
@@ -96,7 +94,7 @@ void dumpRequest(ipp_t *req, bool answer = false, const QString& s = QString())
 			if (i != (attr->num_values-1))
 				s += ", ";
 		}
-		kDebug(500) << s << endl;
+		kDebug(500) << s;
 		attr = attr->next;
 	}
 }
@@ -154,7 +152,7 @@ void IppRequest::init()
 		request_ = 0;
 	}
 	request_ = ippNew();
-	//kDebug(500) << "kdeprint: IPP request, lang=" << KGlobal::locale()->language() << endl;
+	//kDebug(500) << "kdeprint: IPP request, lang=" << KGlobal::locale()->language();
         QByteArray langstr = qPrintable(KGlobal::locale()->language());
 	cups_lang_t*	lang = cupsLangGet(langstr.data());
 	// default charset to UTF-8 (ugly hack)
@@ -310,7 +308,11 @@ bool IppRequest::doFileRequest(const QString& res, const QString& filename)
 	}
 
 #ifdef HAVE_CUPS_NO_PWD_CACHE
-	strncpy( HTTP->authstring, cups_authstring.data(), HTTP_MAX_VALUE );
+#if CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR <= 2
+    strncpy(  HTTP->authstring, cups_authstring.data(), HTTP_MAX_VALUE );
+#else
+    httpSetAuthString( HTTP, NULL, cups_authstring.data() );
+#endif
 #endif
 
 	if (dump_ > 0)
@@ -320,7 +322,11 @@ bool IppRequest::doFileRequest(const QString& res, const QString& filename)
 
 	request_ = cupsDoFileRequest(HTTP, request_, (res.isEmpty() ? "/" : qPrintable(res)), (filename.isEmpty() ? NULL : qPrintable(filename)));
 #ifdef HAVE_CUPS_NO_PWD_CACHE
-	cups_authstring = HTTP->authstring;
+#if CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR <= 2
+    cups_authstring = HTTP->authstring;
+#else
+	cups_authstring = httpGetAuthString( HTTP );
+#endif
 #endif
 	httpClose(HTTP);
 
@@ -515,22 +521,6 @@ void IppRequest::setMap(const QMap<QString,QString>& opts)
 	cupsFreeOptions(n, options);
 
 	// find an remove that annoying "document-format" attribute
-#if CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR >= 2
 	ipp_attribute_t *attr = ippFindAttribute(request_, "document-format", IPP_TAG_NAME);
 	ippDeleteAttribute(request_, attr);
-#else
-	// (can't use IppDeleteAttribute as older cups doesn't have that)
-	ipp_attribute_t *attr = request_->attrs;
-	while (attr)
-	{
-		if (attr->next && strcmp(attr->next->name, "document-format") == 0)
-		{
-			ipp_attribute_t	*attr2 = attr->next;
-			attr->next = attr2->next;
-			_ipp_free_attr(attr2);
-			break;
-		}
-		attr = attr->next;
-	}
-#endif
 }
