@@ -19,13 +19,13 @@
 
 #include "kmconfigcupsdir.h"
 
-#include <qcheckbox.h>
+#include <QtGui/QCheckBox>
 #include <kurlrequester.h>
 #include <klocale.h>
 #include <kdialog.h>
 #include <kconfig.h>
-#include <QGroupBox>
-#include <qlayout.h>
+#include <QtGui/QGroupBox>
+#include <QtGui/QLayout>
 #include <kcursor.h>
 
 KMConfigCupsDir::KMConfigCupsDir(QWidget *parent)
@@ -41,7 +41,7 @@ KMConfigCupsDir::KMConfigCupsDir(QWidget *parent)
 	m_installdir = new KUrlRequester(m_dirbox);
 	m_installdir->setMode(KFile::Directory|KFile::ExistingOnly|KFile::LocalOnly);
 	m_stddir = new QCheckBox(i18n("Standard installation (/)"), m_dirbox);
-	m_stddir->setCursor(KCursor::handCursor());
+	m_stddir->setCursor(QCursor(Qt::PointingHandCursor));
 
 	QVBoxLayout *lay0 = new QVBoxLayout(this);
 	lay0->setMargin(0);
@@ -60,14 +60,12 @@ KMConfigCupsDir::KMConfigCupsDir(QWidget *parent)
 
 void KMConfigCupsDir::loadConfig(KConfig *conf)
 {
-	conf->setGroup("CUPS");
-	QString	dir = conf->readPathEntry("InstallDir");
+	QString	dir = conf->group( "CUPS" ).readPathEntry("InstallDir");
 	m_stddir->setChecked(dir.isEmpty());
 	m_installdir->setUrl(KUrl::fromPath(dir));
 }
 
 void KMConfigCupsDir::saveConfig(KConfig *conf)
 {
-	conf->setGroup("CUPS");
-	conf->writePathEntry("InstallDir",(m_stddir->isChecked() ? QString() : m_installdir->url().url()));
+	conf->group( "CUPS" ).writePathEntry("InstallDir",(m_stddir->isChecked() ? QString() : m_installdir->url().url()));
 }
