@@ -17,8 +17,6 @@
  *  Boston, MA 02110-1301, USA.
  **/
 
-#include <config.h>
-
 #include "kmcupsmanager.h"
 #include "kmprinter.h"
 #include "ipprequest.h"
@@ -28,39 +26,41 @@
 #include "kmdbentry.h"
 #include "cupsaddsmb2.h"
 #include "ippreportdlg.h"
-#include "kpipeprocess.h"
 #include "util.h"
 #include "foomatic2loader.h"
 #include "ppdloader.h"
 
-#include <qfile.h>
-#include <qtextstream.h>
-#include <qregexp.h>
-#include <qtimer.h>
-#include <qdatetime.h>
+#include <config.h>
 
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
+#include <QtCore/QRegExp>
+#include <QtCore/QTimer>
+#include <QtCore/QDate>
+#include <QtNetwork/QTcpSocket>
+
+#include <kprocess.h>
 #include <kdebug.h>
 #include <krandom.h>
 #include <kicon.h>
 #include <klocale.h>
 #include <kconfig.h>
 #include <kstandarddirs.h>
-#include <kbufferedsocket.h>
+#include <ksocketfactory.h>
+#include <klocalsocket.h>
 #include <klibloader.h>
 #include <kactioncollection.h>
 #include <kmessagebox.h>
 #include <kaction.h>
-#include <kprocess.h>
+#include <kshell.h>
 #include <kfilterdev.h>
 #include <cups/cups.h>
 #include <cups/ppd.h>
 #include <math.h>
 
-using namespace KNetwork;
-
 #define ppdi18n(s)	i18n(QString::fromLocal8Bit(s).toUtf8())
 
-static void extractMaticData(QString& buf, const QString& filename);
+//static void extractMaticData(QString& buf, const QString& filename);
 static QString printerURI(KMPrinter *p, bool useExistingURI);
 static QString downloadDriver(KMPrinter *p);
 
@@ -76,6 +76,7 @@ KMCupsManager::KMCupsManager(QObject *parent, const QStringList & /*args*/)
 	CupsInfos::self();
 	m_cupsdconf = 0;
 	m_currentprinter = 0;
+	m_socket = 0;
 
 	setHasManagement(true);
 	setPrinterOperationMask(KMManager::PrinterAll);
@@ -110,10 +111,9 @@ QString KMCupsManager::driverDirectory()
 
 QString KMCupsManager::cupsInstallDir()
 {
-	KConfig	*conf=  KMFactory::self()->printConfig();
-	conf->setGroup("CUPS");
-	QString	dir = conf->readPathEntry("InstallDir");
-	return dir;
+	KConfig *cf = KMFactory::self()->printConfig();
+	KConfigGroup group = cf->group("CUPS");
+	return group.readPathEntry("InstallDir");
 }
 
 void KMCupsManager::reportIppError(IppRequest *req)
@@ -546,25 +546,11 @@ DrMain* KMCupsManager::loadMaticDriver(const QString& drname)
 		return NULL;
 	}
 
-	KPipeProcess	in;
-	QFile		out(tmpFile);
-	QString cmd = KProcess::quote(exe);
-	cmd += " -t cups -d ";
-	cmd += KProcess::quote(comps[2]);
-	cmd += " -p ";
-	cmd += KProcess::quote(comps[1]);
-	if (in.open(cmd) && out.open(QIODevice::WriteOnly))
+	KProcess	proc;
+	proc << exe << "-t" << "cups" << "-d" << comps[2] << "-p" << comps[1];
+	proc.setStandardOutputFile(tmpFile);
+	if (!proc.execute())
 	{
-		QTextStream	tin(&in), tout(&out);
-		QString	line;
-		while (!tin.atEnd())
-		{
-			line = tin.readLine();
-			tout << line << endl;
-		}
-		in.close();
-		out.close();
-
 		DrMain	*driver = loadDriverFile(tmpFile);
 		if (driver)
 		{
@@ -600,7 +586,7 @@ DrMain* KMCupsManager::loadDriverFile(const QString& fname)
 
 void KMCupsManager::saveDriverFile(DrMain *driver, const QString& filename)
 {
-	kDebug( 500 ) << "Saving PPD file with template=" << driver->get( "template" ) << endl;
+	kDebug( 500 ) << "Saving PPD file with template=" << driver->get( "template" );
 	QIODevice *in = KFilterDev::deviceForFile( driver->get( "template" ) );
 	QFile	out(filename);
 	if (in && in->open(QIODevice::ReadOnly) && out.open(QIODevice::WriteOnly))
@@ -719,18 +705,18 @@ bool KMCupsManager::savePrinterDriver(KMPrinter *p, DrMain *d)
 	return result;
 }
 
-void* KMCupsManager::loadCupsdConfFunction(const char *name)
+KLibrary::void_function_ptr KMCupsManager::loadCupsdConfFunction(const char *name)
 {
 	if (!m_cupsdconf)
 	{
-		m_cupsdconf = KLibLoader::self()->library("cupsdconf");
+		m_cupsdconf = KLibLoader::self()->library(QLatin1String("cupsdconf"));
 		if (!m_cupsdconf)
 		{
 			setErrorMsg(i18n("Library cupsdconf not found. Check your installation."));
 			return NULL;
 		}
 	}
-	void*	func = m_cupsdconf->symbol(name);
+	KLibrary::void_function_ptr	func = m_cupsdconf->resolveFunction(name);
 	if (!func)
 		setErrorMsg(i18n("Symbol %1 not found in cupsdconf library.", name));
 	return func;
@@ -740,7 +726,7 @@ void KMCupsManager::unloadCupsdConf()
 {
 	if (m_cupsdconf)
 	{
-		KLibLoader::self()->unloadLibrary("libcupsdconf");
+		KLibLoader::self()->unloadLibrary(QLatin1String("libcupsdconf"));
 		m_cupsdconf = 0;
 	}
 }
@@ -809,13 +795,13 @@ void KMCupsManager::createPluginActions(KActionCollection *coll)
 {
 	KAction	*act = new KAction(i18n("&Export Driver..."), this);
 	coll->addAction( "plugin_export_driver", act );
-	act->setIcon( KIcon( "kdeprint_uploadsmb" ) );
+	act->setIcon( KIcon( "kdeprint-uploadsmb" ) );
 	act->setActionGroup(pluginGroup());
 	connect( act, SIGNAL( triggered( bool ) ), this, SLOT(exportDriver()) );
 
 	act = new KAction(i18n("&Printer IPP Report"), this);
 	coll->addAction( "plugin_printer_ipp_report", act );
-	act->setIcon( KIcon( "kdeprint_report" ) );
+	act->setIcon( KIcon( "kdeprint-report" ) );
 	act->setActionGroup(pluginGroup());
 	connect( act, SIGNAL( triggered( bool ) ), this, SLOT(printerIppReport()) );
 }
@@ -890,19 +876,14 @@ QString KMCupsManager::testPage()
 
 void KMCupsManager::checkUpdatePossibleInternal()
 {
-	kDebug(500) << "Checking for update possible" << endl;
-	m_socket = new KNetwork::KBufferedSocket;
-	m_socket->setTimeout( 1500 );
-	connect( m_socket, SIGNAL( connected(const KNetwork::KResolverEntry&) ),
-                SLOT( slotConnectionSuccess() ) );
-	connect( m_socket, SIGNAL( gotError( int ) ), SLOT( slotConnectionFailed( int ) ) );
+	kDebug(500) << "Checking for update possible";
 	trials = 5;
-	QTimer::singleShot( 1, this, SLOT( slotAsyncConnect() ) );
+	QMetaObject::invokeMethod( this, "slotAsyncConnect", Qt::QueuedConnection );
 }
 
 void KMCupsManager::slotConnectionSuccess()
 {
-	kDebug(500) << "Connection success, trying to send a request..." << endl;
+	kDebug(500) << "Connection success, trying to send a request...";
 
 	IppRequest req;
 	req.setOperation( CUPS_GET_PRINTERS );
@@ -911,7 +892,7 @@ void KMCupsManager::slotConnectionSuccess()
 		setUpdatePossible( true );
 	else
 	{
-		kDebug(500) << "Unable to get printer list" << endl;
+		kDebug(500) << "Unable to get printer list";
 		if ( trials > 0 )
 		{
 			trials--;
@@ -928,16 +909,27 @@ void KMCupsManager::slotConnectionSuccess()
 
 void KMCupsManager::slotAsyncConnect()
 {
-	kDebug(500) << "Starting async connect " << CupsInfos::self()->hostaddr() << endl;
-        if (CupsInfos::self()->host().startsWith("/"))
-            m_socket->connect( QString(), CupsInfos::self()->host());
+	kDebug(500) << "Starting async connect " << CupsInfos::self()->hostaddr();
+	if (CupsInfos::self()->host().startsWith('/'))
+	{
+		KLocalSocket *ls = new KLocalSocket;
+		m_socket = ls;
+		ls->connectToPath( CupsInfos::self()->host() );
+		if ( ls->isOpen() )
+			// fake it
+			QMetaObject::invokeMethod( this, "slotConnectionSuccess", Qt::QueuedConnection );
+	}
         else
-            m_socket->connect( CupsInfos::self()->host(), QString::number(CupsInfos::self()->port()) );
+		m_socket = KSocketFactory::connectToHost( "ipp", CupsInfos::self()->host(), CupsInfos::self()->port() );
+
+	connect( m_socket, SIGNAL( connected() ),
+                SLOT( slotConnectionSuccess() ) );
+	connect( m_socket, SIGNAL( error( QAbstractSocket::SocketError ) ), SLOT( slotConnectionFailed(QAbstractSocket::SocketError ) ) );
 }
 
-void KMCupsManager::slotConnectionFailed( int errcode )
+void KMCupsManager::slotConnectionFailed( QAbstractSocket::SocketError errcode )
 {
-	kDebug(500) << "Connection failed trials=" << trials << endl;
+	kDebug(500) << "Connection failed trials=" << trials;
 	if ( trials > 0 )
 	{
 		trials--;
@@ -947,14 +939,13 @@ void KMCupsManager::slotConnectionFailed( int errcode )
 
 	QString einfo;
 	switch (errcode) {
-	    case KNetwork::KSocketBase::ConnectionRefused:
-	    case KNetwork::KSocketBase::ConnectionTimedOut:
+	    case QAbstractSocket::ConnectionRefusedError:
+	    case QAbstractSocket::SocketTimeoutError:
 		einfo = i18n("connection refused") + QString(" (%1)").arg(errcode);
 		break;
-	    case KNetwork::KSocketBase::LookupFailure:
+	    case QAbstractSocket::HostNotFoundError:
 		einfo = i18n("host not found") + QString(" (%1)").arg(errcode);
 		break;
-	    case KNetwork::KSocketBase::WouldBlock:
 	    default:
 		einfo = i18n("read failed (%1)", errcode);
 		break;
@@ -977,6 +968,7 @@ void KMCupsManager::hostPingFailedSlot() {
 
 //*****************************************************************************************************
 
+#if 0 // currently unused
 static void extractMaticData(QString& buf, const QString& filename)
 {
 	QFile	f(filename);
@@ -992,6 +984,7 @@ static void extractMaticData(QString& buf, const QString& filename)
 		}
 	}
 }
+#endif
 
 static QString printerURI(KMPrinter *p, bool use)
 {
