@@ -20,15 +20,14 @@
 #ifndef KMCUPSMANAGER_H
 #define KMCUPSMANAGER_H
 
-#include <kbufferedsocket.h>
+#include <QtNetwork/QAbstractSocket>
 #include "kmmanager.h"
+#include <klibloader.h>
 
 class IppRequest;
 class KLibrary;
 
-namespace KNetwork {
-    class KStreamSocket;
-}
+class QIODevice;
 
 class KMCupsManager : public KMManager
 {
@@ -72,7 +71,7 @@ public Q_SLOTS:
 	void printerIppReport();
 
 protected Q_SLOTS:
-	void slotConnectionFailed( int );
+	void slotConnectionFailed( QAbstractSocket::SocketError );
 	void slotConnectionSuccess();
 	void slotAsyncConnect();
 
@@ -89,7 +88,7 @@ protected:
 	DrMain* loadMaticDriver(const QString& drname);
 	void saveDriverFile(DrMain *driver, const QString& filename);
 	void reportIppError(IppRequest*);
-	void* loadCupsdConfFunction(const char*);
+	KLibrary::void_function_ptr loadCupsdConfFunction(const char*);
 	void unloadCupsdConf();
 	QString cupsInstallDir();
 	void ippReport(IppRequest&, int, const QString&);
@@ -99,7 +98,7 @@ protected:
 private:
 	KLibrary	*m_cupsdconf;
 	KMPrinter	*m_currentprinter;
-        KNetwork::KStreamSocket   *m_socket;
+	QIODevice	*m_socket;
 	bool m_hostSuccess;
 	bool m_lookupDone;
 };
