@@ -24,7 +24,7 @@
 #include "ipprequest.h"
 
 #include <klistwidget.h>
-#include <qlayout.h>
+#include <QtGui/QLayout>
 #include <klocale.h>
 #include <kdebug.h>
 #include <kiconloader.h>
@@ -87,7 +87,7 @@ void KMWIppSelect::initPrinter(KMPrinter *p)
 		{
 			if (attr->name && strcmp(attr->name,"printer-name") == 0) {
 				QListWidgetItem* item = new QListWidgetItem();
-                item->setIcon(SmallIcon("kdeprint_printer"));
+                item->setIcon(SmallIcon("kdeprint-printer"));
                 item->setText(QLatin1String(attr->values[0].string.text)); 
                 m_list->addItem(item);
             }
@@ -110,5 +110,5 @@ void KMWIppSelect::updatePrinter(KMPrinter *p)
 	path.prepend("/printers/");
 	url.setPath(path);
 	p->setDevice(url.url());
-kDebug(500) << url.url() << endl;
+kDebug(500) << url.url();
 }
