@@ -23,11 +23,11 @@
 #include "kmmanager.h"
 #include "cupsinfos.h"
 
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qlineedit.h>
-#include <q3header.h>
-#include <QHash>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtGui/QLineEdit>
+#include <Qt3Support/Q3Header>
+#include <QtCore/QHash>
 
 #include <klocale.h>
 #include <k3listview.h>
@@ -98,7 +98,7 @@ void KMWOther::initPrinter(KMPrinter *p)
 				parent = new Q3ListViewItem( root, lastparent, cl );
 				parent->setOpen( true );
 				if ( cl == "network" )
-					parent->setPixmap( 0, SmallIcon( "network" ) );
+					parent->setPixmap( 0, SmallIcon( "network-wired" ) );
 				else if ( cl == "direct" )
 					parent->setPixmap( 0, SmallIcon( "kdeprint_computer" ) );
 				else if ( cl == "serial" )
