@@ -22,15 +22,15 @@
 #include "imagepreview.h"
 #include "driver.h"
 
-#include <qcombobox.h>
-#include <QButtonGroup>
-#include <qradiobutton.h>
-#include <QGroupBox>
-#include <qpushbutton.h>
-#include <qapplication.h>
-#include <qimage.h>
-#include <qlabel.h>
-#include <qlayout.h>
+#include <QtGui/QComboBox>
+#include <QtGui/QButtonGroup>
+#include <QtGui/QRadioButton>
+#include <QtGui/QGroupBox>
+#include <QtGui/QPushButton>
+#include <QtGui/QApplication>
+#include <QtGui/QImage>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
 #include <klocale.h>
 #include <knuminput.h>
 #include <kseparator.h>
@@ -44,8 +44,8 @@ KPImagePage::KPImagePage(DrMain *driver, QWidget *parent)
 			" <p><b>Brightness:</b> Slider to control the brightness value of all colors used.</p>"
 			" <p> The brightness value can range from 0 to 200. Values greater than 100 will"
 			" lighten the print. Values less than 100 will darken the print. </p>"
-			" <br>"
-			" <hr>"
+			" <br />"
+			" <hr />"
 			" <p><em><b>Additional hint for power users:</b> This KDEPrint GUI element matches"
 			" with the CUPS commandline job option parameter:</em>"
 			" <pre>"
@@ -57,7 +57,7 @@ KPImagePage::KPImagePage(DrMain *driver, QWidget *parent)
 	QString whatsThisHueImagePage = i18n( " <qt>"
 			" <p><b>Hue (Tint):</b> Slider to control the hue value for color rotation.</p>"
 			" <p> The hue value is a number from -360 to 360 and represents the color hue rotation."
-			" The following table summarizes the change you will see for the base colors:"
+			" The following table summarizes the change you will see for the base colors:</p>"
 			" <center>"
 			" <table border=\"1\" width=\"70%\">"
 			" <tr><th><b>Original</b></th> <th><b>hue=-45</b></th> <th><b>hue=45</b></th>   </tr>"
@@ -69,8 +69,8 @@ KPImagePage::KPImagePage(DrMain *driver, QWidget *parent)
 			" <tr><td>Cyan</td>            <td>Blue-green</td>     <td>Light-navy-blue</td> </tr>"
 			" </table>"
 			" </center>"
-			" <br>"
-			" <hr>"
+			" <br />"
+			" <hr />"
 			" <p><em><b>Additional hint for power users:</b> This KDEPrint GUI element matches"
 			" with the CUPS commandline job option parameter:</em>"
 			" <pre>"
@@ -87,8 +87,8 @@ KPImagePage::KPImagePage(DrMain *driver, QWidget *parent)
 			" higher saturation uses more toner."
 			" A color saturation of 0 produces a black-and-white print, while a value of 200 will"
 			" make the colors extremely intense. </p>"
-			" <br> "
-			" <hr> "
+			" <br /> "
+			" <hr /> "
 			" <p><em><b>Additional hint for power users:</b> This KDEPrint GUI element matches"
 			" with the CUPS commandline job option parameter:</em>"
 			" <pre>"
@@ -102,10 +102,10 @@ KPImagePage::KPImagePage(DrMain *driver, QWidget *parent)
 			" <p> The gamma value can range from 1 to 3000."
 			" A gamma value greater than 1000 lightens the print. A gamma value less than 1000"
 			" darkens the print. The default gamma is 1000. </p>"
-			" <p><b>Note:</b></p> the gamma value adjustment is not visible in the thumbnail"
+			" <p><b>Note:</b></p><p> the gamma value adjustment is not visible in the thumbnail"
 			" preview. </p>"
-			" <br>"
-			" <hr>"
+			" <br />"
+			" <hr />"
 			" <p><em><b>Additional hint for power users:</b> This KDEPrint GUI element matches"
 			" with the CUPS commandline job option parameter:</em>"
 			" <pre>"
@@ -165,24 +165,24 @@ KPImagePage::KPImagePage(DrMain *driver, QWidget *parent)
 			" in relation to the page (not the image). A scaling of 100 percent will fill the page as completely"
 			" as the image aspect ratio allows (doing auto-rotation of the image as needed)."
 			" A scaling of more than 100 will print the image across multiple"
-			" sheets. A scaling of 200 percent will print on up to 4 pages. </li>"
-			" Scaling in % of page size defaults to 100 %."
+			" sheets. A scaling of 200 percent will print on up to 4 pages. "
+			" Scaling in % of page size defaults to 100 %.</li>"
 			" <li> <b>% of Natural Image Size:</b> The percent value slider moves from 1 to 800. It specifies"
 			" the printout size in relation"
 			" to the natural image size. A scaling of 100 percent will print the image at its natural size, while a"
 			" scaling of 50 percent will print the image at half its natural size. If the specified scaling makes"
 			" the image larger than the page, multiple pages will be printed."
-			" Scaling in % of natural image size defaults to 100 %."
+			" Scaling in % of natural image size defaults to 100 %.</li>"
 			" </ul>"
-			" <br>"
-			" <hr>"
+			" <br />"
+			" <hr />"
 			" <p><em><b>Additional hint for power users:</b> This KDEPrint GUI element matches"
 			" with the CUPS commandline job option parameter:</em> "
 			" <pre>"
 			"     -o natural-scaling=...     # range in  %  is 1....800"
-			" <br> "
+			" <br /> "
 			"    -o scaling=...             # range in  %  is 1....800"
-			" <br> "
+			" <br /> "
 			"    -o ppi=...                 # range in ppi is 1...1200"
 			" </pre>"
 			" </p> "
@@ -190,7 +190,7 @@ KPImagePage::KPImagePage(DrMain *driver, QWidget *parent)
 
 	QString whatsThisPreviewPositionImagePage = i18n( " <qt>"
 			" <p><b>Position Preview Thumbnail</b></p>"
-			" <p>This position preview thumbnail indicates the position of the image on the paper sheet."
+			" <p>This position preview thumbnail indicates the position of the image on the paper sheet.</p>"
 			" <p>Click on horizontal and vertical radio buttons to move image alignment on paper around. Options are:"
 			" <ul>"
 			" <li> center      </li>"
@@ -223,8 +223,8 @@ KPImagePage::KPImagePage(DrMain *driver, QWidget *parent)
 			" <p>Select a pair of radiobuttons to "
 			" move image to the position you want on the paper printout. Default"
 			" is 'center'. </p>"
-			" <br>"
-			" <hr>"
+			" <br /> "
+			" <hr /> "
 			" <p><em><b>Additional hint for power users:</b> This KDEPrint GUI element matches"
 			" with the CUPS commandline job option parameter:</em>"
 			" <pre>"
@@ -250,17 +250,17 @@ KPImagePage::KPImagePage(DrMain *driver, QWidget *parent)
 	m_brightness->setRange(0, 200, 20, true);
 	  m_brightness->setWhatsThis(whatsThisBrightnessImagePage);
 
-	m_hue = new KIntNumInput(m_brightness, 0,colorbox);
+	m_hue = new KIntNumInput(0,colorbox);
 	m_hue->setLabel(i18n("&Hue (Color rotation):"));
 	m_hue->setRange(-360, 360, 36, true);
 	  m_hue->setWhatsThis(whatsThisHueImagePage);
 
-	m_saturation = new KIntNumInput(m_brightness, 100,colorbox);
+	m_saturation = new KIntNumInput(100,colorbox);
 	m_saturation->setLabel(i18n("&Saturation:"));
 	m_saturation->setRange(0, 200, 20, true);
 	  m_saturation->setWhatsThis(whatsThisSaturationImagePage);
 
-	m_gamma = new KIntNumInput(m_saturation, 1000,colorbox);
+	m_gamma = new KIntNumInput(1000,colorbox);
 	m_gamma->setLabel(i18n("&Gamma (Color correction):"));
 	m_gamma->setRange(1, 3000, 100, true);
 	  m_gamma->setWhatsThis(whatsThisGammaImagePage);
