@@ -27,7 +27,7 @@ class QTableWidget;
 class KPTagsPage : public KPrintDialogPage
 {
 public:
-	KPTagsPage(bool ro = false, QWidget *parent = 0);
+	explicit KPTagsPage(bool ro = false, QWidget *parent = 0);
 	~KPTagsPage();
 
 	void getOptions(QMap<QString,QString>& opts, bool incldef = false);
