@@ -22,10 +22,10 @@
 #include "driveritem.h"
 #include "driver.h"
 
-#include <QHeaderView>
-#include <QLayout>
-#include <QSplitter>
-#include <QTreeWidget>
+#include <QtGui/QHeaderView>
+#include <QtGui/QLayout>
+#include <QtGui/QSplitter>
+#include <QtGui/QTreeWidget>
 
 #include <kdialog.h>
 #include <klocale.h>
@@ -52,7 +52,7 @@ DriverView::DriverView( QWidget *parent )
 			" will forget your current settings when kprinter is closed again, and will start next time"
 			" with the previously saved defaults. </li>"
 			" <li><em>'Cancel'</em> will not change anything. If you proceed to print after clicking"
-			" <em>'Cancel'</em>, the job will print with the default settings of this queue."
+			" <em>'Cancel'</em>, the job will print with the default settings of this queue.</li>"
 			" </ul>"
 			" <p><b>Note.</b> The number of available job options depends strongly on the actual"
 			" driver used for your print queue. <em>'Raw'</em> queues do not have a driver or a"
@@ -76,7 +76,7 @@ DriverView::DriverView( QWidget *parent )
 			" will forget your current settings when kprinter is closed again, and will start next time"
 			" with your previous defaults. </li>"
 			" <li><em>'Cancel'</em> will not change anything. If you proceed to print after clicking"
-			" <em>'Cancel'</em>, the job will print with the default settings of this queue." 
+			" <em>'Cancel'</em>, the job will print with the default settings of this queue.</li>"
 			" </ul>"
 			" <p><b>Note.</b> The number of available job options depends strongly on the actual"
 			" driver used for your print queue. <em>'Raw'</em> queues do not have a driver or a"
