@@ -21,10 +21,10 @@
 #ifndef DRIVERVIEW_H
 #define DRIVERVIEW_H
 
-#include <QMap>
-#include <QWidget>
+#include <kdeprint_export.h>
 
-#include <kdelibs_export.h>
+#include <QtCore/QMap>
+#include <QtGui/QWidget>
 
 class QTreeWidget;
 class QTreeWidgetItem;
