@@ -22,15 +22,15 @@
 #include "driveritem.h"
 
 #include <math.h>
-#include <qlineedit.h>
-#include <qslider.h>
-#include <qlabel.h>
+#include <QtGui/QLineEdit>
+#include <QtGui/QSlider>
+#include <QtGui/QLabel>
 #include <klistwidget.h>
 #include <kbuttongroup.h>
-#include <qradiobutton.h>
-#include <QStackedWidget>
-#include <qlayout.h>
-#include <qapplication.h>
+#include <QtGui/QRadioButton>
+#include <QtGui/QStackedWidget>
+#include <QtGui/QLayout>
+#include <QtGui/QApplication>
 
 #include <kcursor.h>
 #include <kdialog.h>
@@ -208,7 +208,7 @@ OptionListView::OptionListView(QWidget *parent)
 	main_->setSpacing(10);
 	main_->addWidget(m_list);
 
-	connect(m_list,SIGNAL(selectionChanged()),SLOT(slotSelectionChanged()));
+	connect(m_list,SIGNAL(itemSelectionChanged()),SLOT(slotSelectionChanged()));
 }
 
 void OptionListView::setOption(DrBase *opt)
@@ -251,9 +251,9 @@ OptionBooleanView::OptionBooleanView(QWidget *parent)
 	//m_group->setFrameStyle(QFrame::NoFrame);
 
 	m_btn1 = new QRadioButton(m_group);
-	m_btn1->setCursor(KCursor::handCursor());
+	m_btn1->setCursor( QCursor( Qt::OpenHandCursor ) );
 	m_btn2 = new QRadioButton(m_group);
-	m_btn2->setCursor(KCursor::handCursor());
+	m_btn2->setCursor( QCursor( Qt::OpenHandCursor ) );
 	
 	layout->addWidget( m_btn1 );
 	layout->addWidget( m_btn2 );
