@@ -20,8 +20,8 @@
 #ifndef DROPTIONVIEW_H
 #define DROPTIONVIEW_H
 
-#include <qwidget.h>
-#include <qstringlist.h>
+#include <QtGui/QWidget>
+#include <QtCore/QStringList>
 
 class QLineEdit;
 class QSlider;
