@@ -40,8 +40,8 @@
 
 #include <kstandarddirs.h>
 #include <kdebug.h>
-#include <kbufferedsocket.h>
-#include <qfile.h>
+#include <klocalsocket.h>
+#include <QtCore/QFile>
 #include <unistd.h>
 
 static const char* const config_stddirs[] = {
@@ -53,11 +53,9 @@ static const char* const config_stddirs[] = {
 	0
 };
 
-bool KdeprintChecker::check(KConfig *conf, const QString& group)
+bool KdeprintChecker::check(const KConfigGroup &conf)
 {
-	if (!group.isEmpty())
-		conf->setGroup(group);
-	QStringList	uris = conf->readEntry("Require", QStringList());
+	QStringList	uris = conf.readEntry("Require", QStringList());
 	return check(uris);
 }
 
@@ -67,7 +65,7 @@ bool KdeprintChecker::check(const QStringList& uris)
 	for (QStringList::ConstIterator it=uris.begin(); it!=uris.end() && state; ++it)
 	{
 		state = (state && checkUrl(KUrl(*it)));
-		// kDebug( 500 ) << "auto-detection uri=" << *it << ", state=" << state << endl;
+		// kDebug( 500 ) << "auto-detection uri=" << *it << ", state=" << state;
 	}
 	return state;
 }
@@ -101,7 +99,7 @@ bool KdeprintChecker::checkConfig(const KUrl& url)
 		const char* const *p = config_stddirs;
 		while (*p)
 		{
-			// kDebug( 500 ) << "checkConfig() with " << QLatin1String( *p ) + f << endl;
+			// kDebug( 500 ) << "checkConfig() with " << QLatin1String( *p ) + f;
 			if ( QFile::exists( QLatin1String( *p ) + f ) )
 			{
 				state = true;
@@ -122,8 +120,13 @@ bool KdeprintChecker::checkExec(const KUrl& url)
 
 bool KdeprintChecker::checkService(const KUrl& url)
 {
+#ifdef __GNUC__
+# warning "This code doesn't make sense"
+#endif
 	QString	serv(url.path().mid(1));
-	KNetwork::KBufferedSocket	sock;
+        KLocalSocket sock;
+        sock.connectToPath(serv);
+        sock.waitForConnected();
 
-	return sock.connect("localhost", serv);
+	return sock.isOpen();
 }
