@@ -20,15 +20,18 @@
 #ifndef KDEPRINTCHECK_H
 #define KDEPRINTCHECK_H
 
-#include <qstring.h>
-#include <qstringlist.h>
-#include <kconfig.h>
+#include <kdeprint_export.h>
+
+#include <kconfiggroup.h>
 #include <kurl.h>
 
+#include <QtCore/QString>
+#include <QtCore/QStringList>
+
 class KDEPRINT_EXPORT KdeprintChecker
 {
 public:
-	static bool check(KConfig *conf, const QString& group = QString());
+	static bool check(const KConfigGroup &conf);
 	static bool check(const QStringList& uris);
 
 private:
