@@ -20,22 +20,23 @@
 #include "kdeprintd.h"
 #include "kprintprocess.h"
 
-#include <qfile.h>
+#include <QtCore/QFile>
 #include <klocale.h>
 #include <knotification.h>
 #include <kmessagebox.h>
 #include <kdebug.h>
 #include <kpassworddialog.h>
 #include <kio/authinfo.h>
-#include <qlabel.h>
+#include <QtGui/QLabel>
 #include <kpushbutton.h>
 #include <kiconloader.h>
 #include <kstandarddirs.h>
-#include <kwin.h>
+#include <kwindowsystem.h>
 #include <krandom.h>
-#include <qlayout.h>
-#include <qtimer.h>
-#include <qregexp.h>
+#include <kshell.h>
+#include <QtGui/QLayout>
+#include <QtCore/QTimer>
+#include <QtCore/QRegExp>
 #include <QtDBus/QtDBus>
 
 #include <unistd.h>
@@ -71,10 +72,10 @@ StatusWindow::StatusWindow(int pid)
 	m_label->setAlignment(Qt::AlignCenter);
 	m_button = new KPushButton(KStandardGuiItem::close(), this);
 	m_icon = new QLabel(this);
-	m_icon->setPixmap(DesktopIcon("fileprint"));
+	m_icon->setPixmap(DesktopIcon("document-print"));
 	m_icon->setAlignment(Qt::AlignCenter);
 #ifdef Q_WS_X11
-	KWin::setIcons(winId(), *(m_icon->pixmap()), SmallIcon("fileprint"));
+	KWindowSystem::setIcons(winId(), *(m_icon->pixmap()), SmallIcon("document-print"));
 #endif
 	QGridLayout	*l0 = new QGridLayout(this);
     l0->setMargin(10);
@@ -130,12 +131,12 @@ QString KDEPrintd::print(const QString& cmd, const QStringList& files, bool remf
 		if ( !url.isLocalFile() )
 		{
 			QString tmpFilename = KStandardDirs::locateLocal( "tmp", "kdeprint_" + KRandom::randomString( 8 ) );
-			command.replace( re, KProcess::quote( tmpFilename ) );
+			command.replace( re, KShell::quoteArg( tmpFilename ) );
 			proc->setOutput( re.cap( 1 ) );
 			proc->setTempOutput( tmpFilename );
 		}
 		else
-			command.replace( re, KProcess::quote( re.cap( 1 ) ) );
+			command.replace( re, KShell::quoteArg( re.cap( 1 ) ) );
 	}
 
 	if ( checkFiles( command, files ) )
@@ -161,7 +162,7 @@ void KDEPrintd::slotPrintTerminated( KPrintProcess *proc )
 
 void KDEPrintd::slotPrintError( KPrintProcess *proc, const QString& msg )
 {
-	KNotification::event("printerror",i18n("<p><nobr>A print error occurred. Error message received from system:</nobr></p><br>%1", msg));
+	KNotification::event("printerror",i18n("<p><nobr>A print error occurred. Error message received from system:</nobr></p><br />%1", msg));
 	m_processpool.removeAll( proc );
 }
 
@@ -187,10 +188,10 @@ bool KDEPrintd::checkFiles(QString& cmd, const QStringList& files)
 				     "as a different user to the one currently logged in. To continue "
 				     "printing, you need to provide root's password."),
 				QString(),
-				KGuiItem(i18n("Enter the root password")),
+				KGuiItem(i18n("Enter the root password")), KStandardGuiItem::cancel(),
 				"provideRootsPassword") == KMessageBox::Continue)
 			{
-				cmd = ("kdesu -c " + KProcess::quote(cmd));
+				cmd = ("kdesu -c " + KShell::quoteArg(cmd));
 				break;
 			}
 			else
@@ -287,13 +288,13 @@ void KDEPrintd::processRequest()
 			output >> result;
 
 			if ( result.isModified() )
-				authString = result.username + ":" + result.password + ":" + QString::number( seqNbr );
+				authString = result.username + ':' + result.password + ':' + QString::number( seqNbr );
 		}
 		else
-			kWarning( 500 ) << "D-BUS returned invalid reply" << endl;
+			kWarning( 500 ) << "D-BUS returned invalid reply";
 	}
 	else
-		kWarning( 500 ) << "Cannot communicate with kded_kpasswdserver" << endl;
+		kWarning( 500 ) << "Cannot communicate with kded_kpasswdserver";
 
         QDBusConnection::sessionBus().send(req->reply.createReply(authString));
 
@@ -318,7 +319,7 @@ void KDEPrintd::initPassword( const QString& user, const QString& passwd, const
 		QDBusInterface( "org.kde.kded", "/modules/kpasswdserver", "org.kde.KPasswdServer" ).
 		call("addAuthInfo", params, qlonglong(0));
 	if ( reply.type() != QDBusMessage::ReplyMessage )
-		kWarning( 500 ) << "Unable to initialize password, cannot communicate with kded_kpasswdserver" << endl;
+		kWarning( 500 ) << "Unable to initialize password, cannot communicate with kded_kpasswdserver";
 }
 
 #include "kdeprintd.moc"
