@@ -21,10 +21,10 @@
 #define KDEPRINTD_H
 
 #include <kdedmodule.h>
-#include <qlist.h>
-#include <qstringlist.h>
-#include <qpointer.h>
-#include <qhash.h>
+#include <QtCore/QList>
+#include <QtCore/QStringList>
+#include <QtCore/QPointer>
+#include <QtCore/QHash>
 #include <QtDBus/QtDBus>
 
 class KPrintProcess;
