@@ -19,11 +19,11 @@
 
 #include "kfilelist.h"
 
-#include <qtoolbutton.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <QDragEnterEvent>
-#include <QTreeWidget>
+#include <QtGui/QToolButton>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtGui/QKeyEvent>
+#include <QtGui/QTreeWidget>
 
 #include <kio/netaccess.h>
 #include <kfiledialog.h>
@@ -42,16 +42,16 @@ KFileList::KFileList(QWidget *parent)
 						" select a file for printing. Note, that "
 						" <ul><li>you can select ASCII or International Text, PDF,"
 						" PostScript, JPEG, TIFF, PNG, GIF and many other graphic"
-						" formats."
+						" formats.</li>"
 						" <li>you can select various files from different paths"
 						" and send them as one \"multi-file job\" to the printing"
-						" system."
-						" </ul>"
+						" system.</li>"
+						" </ul></p>"
 					        " </qt>" );
 
 	QString whatsThisRemoveFileButton = i18n(" <qt> <b>Remove File button</b>"
                                                 " <p>This button removes the highlighted file from the"
-						" list of to-be-printed files."
+						" list of to-be-printed files.</p>"
 					        " </qt>" );
 
 	QString whatsThisMoveFileUpButton = i18n(" <qt> <b>Move File Up button</b>"
@@ -103,34 +103,34 @@ KFileList::KFileList(QWidget *parent)
 	connect(m_files, SIGNAL(itemSelectionChanged()), SLOT(slotSelectionChanged()));
 
 	m_add = new QToolButton(this);
-	m_add->setIcon(KIcon("fileopen"));
+	m_add->setIcon(KIcon("document-open"));
 	connect(m_add, SIGNAL(clicked()), SLOT(slotAddFile()));
 	m_add->setToolTip(i18n("Add file"));
 	m_add->setWhatsThis(whatsThisAddFileButton);
 
 	m_remove = new QToolButton(this);
-	m_remove->setIcon(KIcon("remove"));
+	m_remove->setIcon(KIcon("list-remove"));
 	connect(m_remove, SIGNAL(clicked()), SLOT(slotRemoveFile()));
 	m_remove->setToolTip(i18n("Remove file"));
 	m_remove->setWhatsThis(whatsThisRemoveFileButton);
 	m_remove->setEnabled(false);
 
 	m_open = new QToolButton(this);
-	m_open->setIcon(KIcon("filefind"));
+	m_open->setIcon(KIcon("file-find"));
 	connect(m_open, SIGNAL(clicked()), SLOT(slotOpenFile()));
 	m_open->setToolTip(i18n("Open file"));
 	m_open->setWhatsThis(whatsThisOpenFileButton);
 	m_open->setEnabled(false);
 
 	m_up = new QToolButton(this);
-	m_up->setIcon(KIcon("up"));
+	m_up->setIcon(KIcon("go-up"));
 	connect(m_up, SIGNAL(clicked()), SLOT(slotUp()));
 	m_up->setToolTip(i18n("Move up"));
 	m_up->setWhatsThis(whatsThisMoveFileUpButton);
 	m_up->setEnabled(false);
 
 	m_down = new QToolButton(this);
-	m_down->setIcon(KIcon("down"));
+	m_down->setIcon(KIcon("go-down"));
 	connect(m_down, SIGNAL(clicked()), SLOT(slotDown()));
 	m_down->setToolTip(i18n("Move down"));
 	m_down->setWhatsThis(whatsThisMoveFileDownButton);
