@@ -27,9 +27,12 @@
 #include "kdeprintcheck.h"
 #include "kxmlcommand.h"
 
-#include <qdir.h>
-#include <qfile.h>
-#include <qsettings.h>
+#include <config.h>
+
+#include <QtCore/QCoreApplication>
+#include <QtCore/QDir>
+#include <QtCore/QFile>
+#include <QtCore/QSettings>
 
 #include <klibloader.h>
 #include <kconfig.h>
@@ -38,11 +41,11 @@
 #include <kdebug.h>
 #include <kmessagebox.h>
 #include <klocale.h>
-#include <ksimpleconfig.h>
-#include <kstaticdeleter.h>
 #include <kio/authinfo.h>
 
-#include <unistd.h>
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+#endif
 
 #include "kmfactoryadaptor.h"
 #include "kmfactoryinterface.h"
@@ -53,29 +56,31 @@
 extern void qt_generate_epsf( bool b );
 #endif
 
-KMFactory* KMFactory::m_self = 0;
-static KStaticDeleter<KMFactory> s_kmfactorysd;
+// FIXME: move to Private class
+static KMFactory *pSelf = 0;
+static void delete_kmfactory_self()
+{
+    delete pSelf;
+    pSelf = 0;
+}
 
 KMFactory* KMFactory::self()
 {
-	if (!m_self)
-		m_self = s_kmfactorysd.setObject(m_self, new KMFactory());
-	return m_self;
+    if(!pSelf) {
+        qAddPostRoutine(delete_kmfactory_self);
+        pSelf = new KMFactory();
+    }
+    return pSelf;
 }
 
 bool KMFactory::exists()
 {
-    return m_self != 0L;
+    return pSelf != 0;
 }
 
 void KMFactory::release()
 {
-	if (m_self)
-	{
-		KMFactory* p = m_self;
-		m_self = 0; // so that exists() says false
-		delete p;
-	}
+    delete_kmfactory_self();
 }
 
 KMFactory::KMFactory()
@@ -105,7 +110,7 @@ KMFactory::KMFactory()
 		settings.setValue( "/qt/embedFonts", true );
 
 	KIconLoader::global()->addAppDir("kdeprint");
-	KGlobal::locale()->insertCatalog("kdeprint");
+	KGlobal::locale()->insertCatalog("kdeprint4");
 
 	// create D-Bus signal connection
 	(void)new KMFactoryAdaptor(this);
@@ -120,7 +125,6 @@ KMFactory::~KMFactory()
 	// The only object to be destroyed is m_printconfig. All other objects have been
 	// created with "this" as parent, so we don't need to care about their destruction
 	UNLOAD_OBJECT(m_printconfig);
-	m_self = 0;
 }
 
 KMManager* KMFactory::manager()
@@ -230,30 +234,28 @@ void KMFactory::loadFactory(const QString& syst)
 	}
 }
 
-KConfig* KMFactory::printConfig(const QString& group)
+KConfig *KMFactory::printConfig()
 {
-	if (!m_printconfig)
-	{
-		m_printconfig = new KConfig("kdeprintrc");
-		Q_CHECK_PTR(m_printconfig);
+        if (!m_printconfig)
+        {
+                m_printconfig = new KConfig("kdeprintrc");
+                Q_CHECK_PTR(m_printconfig);
 	}
-	if (!group.isEmpty())
-		m_printconfig->setGroup(group);
 	return m_printconfig;
 }
 
 QString KMFactory::printSystem()
 {
-	KConfig	*conf = printConfig();
-	conf->setGroup("General");
-	QString	sys = conf->readEntry("PrintSystem");
+	KConfig *cf = printConfig();
+	KConfigGroup conf = cf->group("General");
+	QString	sys = conf.readEntry("PrintSystem");
 	if (sys.isEmpty())
 	{
 		// perform auto-detection (will at least return "lpdunix")
 		sys = autoDetect();
 		// save the result
-		conf->writeEntry("PrintSystem", sys);
-		conf->sync();
+		conf.writeEntry("PrintSystem", sys);
+		conf.sync();
 	}
 	else if ( sys.length()==1 && sys[0].isDigit() ) // discard old-style settings
         	sys = "lpdunix";
@@ -282,10 +284,10 @@ void KMFactory::reload(const QString& syst, bool saveSyst)
 	unload();
 	if (saveSyst)
 	{
-		KConfig	*conf = printConfig();
-		conf->setGroup("General");
-		conf->writeEntry("PrintSystem", syst);
-		conf->sync();
+		KConfig *cf = printConfig();
+		KConfigGroup conf = cf->group("General");
+		conf.writeEntry("PrintSystem", syst);
+		conf.sync();
 
 		// notify all other apps using DCOP signal
 		emit pluginChanged(getpid());
@@ -319,10 +321,10 @@ KMFactory::PluginInfo KMFactory::pluginInfo(const QString& name)
 	QString	path(name);
 	if (path[0] != '/')
 		path = KStandardDirs::locate("data", QString::fromLatin1("kdeprint/plugins/%1.print").arg(name));
-	KSimpleConfig	conf(path);
+	KConfig	_conf(path, KConfig::OnlyLocal);
 	PluginInfo	info;
 
-	conf.setGroup("KDE Print Entry");
+	KConfigGroup conf( &_conf, "KDE Print Entry");
 	info.name = conf.readEntry("PrintSystem");
 	info.comment = conf.readEntry("Comment");
 	if (info.comment.isEmpty())
@@ -346,7 +348,7 @@ void KMFactory::registerObject(KPReloadObject *obj, bool priority)
 			m_objects.prepend(obj);
 		else
 			m_objects.append(obj);
-		kDebug(500) << "kdeprint: registering " << (void*)obj << ", number of objects = " << m_objects.count() << endl;
+		kDebug(500) << "kdeprint: registering " << (void*)obj << ", number of objects = " << m_objects.count();
 	}
 }
 
@@ -354,7 +356,7 @@ void KMFactory::unregisterObject(KPReloadObject *obj)
 {
 	// remove object from list (not deleted as autoDelete is false)
 	m_objects.removeAll(obj);
-	kDebug(500) << "kdeprint: unregistering " << (void*)obj << ", number of objects = " << m_objects.count() << endl;
+	kDebug(500) << "kdeprint: unregistering " << (void*)obj << ", number of objects = " << m_objects.count();
 }
 
 QString KMFactory::autoDetect()
@@ -379,7 +381,7 @@ void KMFactory::slot_pluginChanged(int pid)
 	if (pid != getpid())
 	{
 		// Unload config object (avoid saving it)
-		printConfig()->rollback();
+		m_printconfig->rollback();
 		UNLOAD_OBJECT(m_printconfig);
 		// Then reload everything and notified registered objects.
 		// Do NOT re-save the new print system.
@@ -390,11 +392,11 @@ void KMFactory::slot_pluginChanged(int pid)
 
 void KMFactory::slot_configChanged()
 {
-	kDebug(500) << "KMFactory (" << getpid() << ") receiving DCOP signal configChanged()" << endl;
+	kDebug(500) << "KMFactory (" << getpid() << ") receiving DCOP signal configChanged()";
 	// unload/reload config object (make it non dirty to
 	// avoid saving it and overwriting the newly saved options
 	// in the other application)
-	printConfig()->rollback();
+	m_printconfig->rollback();
 	UNLOAD_OBJECT(m_printconfig);
 	printConfig();
 
@@ -410,9 +412,9 @@ void KMFactory::slot_configChanged()
 
 void KMFactory::saveConfig()
 {
-	KConfig	*conf = printConfig();
-	conf->sync();
-	kDebug(500) << "KMFactory (" << getpid() << ") emitting DCOP signal configChanged()" << endl;
+	KConfigGroup conf(printConfig(),"");
+	conf.sync();
+	kDebug(500) << "KMFactory (" << getpid() << ") emitting DCOP signal configChanged()";
 	emit configChanged();
 	// normally, the self application should also receive the signal,
 	// anyway the config object has been updated "locally", so ne real
