@@ -20,8 +20,8 @@
 #ifndef KMSPECIALMANAGER_H
 #define KMSPECIALMANAGER_H
 
-#include <qobject.h>
-#include <qmap.h>
+#include <QtCore/QObject>
+#include <QtCore/QMap>
 
 class KMPrinter;
 class KMManager;
@@ -30,6 +30,8 @@ class DrMain;
 
 class KMSpecialManager : public QObject
 {
+	Q_OBJECT
+
 public:
 	explicit KMSpecialManager(KMManager *parent);
 
