@@ -20,14 +20,16 @@
 #ifndef KMTHREADJOB_H
 #define KMTHREADJOB_H
 
-#include <QMultiHash>
-#include <qobject.h>
+#include <QtCore/QHash>
+#include <QtCore/QObject>
 
 class KMJob;
 class KMJobManager;
 
 class KMThreadJob : public QObject
 {
+	Q_OBJECT
+
 public:
 	KMThreadJob(QObject *parent = 0);
 	~KMThreadJob();
