@@ -24,10 +24,10 @@
 #include "kprinter.h"
 
 #include <stdlib.h>
-#include <qfile.h>
-#include <qtextstream.h>
-#include <qdir.h>
-#include <qfileinfo.h>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
+#include <QtCore/QDir>
+#include <QtCore/QFileInfo>
 #include <klocale.h>
 #include <kstandarddirs.h>
 #include <kurl.h>
@@ -40,7 +40,7 @@ static QString instanceName(const QString& prname, const QString& instname)
 {
 	QString	str(prname);
 	if (!instname.isEmpty())
-		str.append("/"+instname);
+		str.append('/'+instname);
 	return str;
 }
 
@@ -163,7 +163,7 @@ void KMVirtualManager::setAsDefault(KMPrinter *p, const QString& name, QWidget *
 						  "applications. Note that this will only make your personal default printer "
 						  "as undefined for non-KDE applications and should not prevent you from "
 						  "printing normally. Do you really want to set <b>%1</b> as your personal default?</qt>" ,  instname ),
-					QString(), KGuiItem(i18n("Set as Default")), "setSpecialAsDefault" ) == KMessageBox::No )
+					QString(), KGuiItem(i18n("Set as Default")), KStandardGuiItem::cancel(), "setSpecialAsDefault" ) == KMessageBox::No )
 			return;
 	}
 
@@ -238,7 +238,7 @@ void KMVirtualManager::virtualList(QList<KMPrinter*>& list, const QString& prnam
 
 	// then look for instances
 	list.clear();
-	kDebug(500) << "KMVirtualManager::virtualList() prname=" << prname << endl;
+	kDebug(500) << "KMVirtualManager::virtualList() prname=" << prname;
 	QListIterator<KMPrinter*>	it(m_manager->m_printers);
 	while (it.hasNext()) {
     KMPrinter *printer(it.next());
