@@ -21,10 +21,10 @@
 #include "kmfactory.h"
 #include "kxmlcommand.h"
 
-#include <QToolButton>
-#include <QLayout>
-#include <QTreeWidget>
-#include <QLabel>
+#include <QtGui/QToolButton>
+#include <QtGui/QLayout>
+#include <QtGui/QTreeWidget>
+#include <QtGui/QLabel>
 
 #include <klocale.h>
 #include <kiconloader.h>
@@ -46,12 +46,11 @@ KPFilterPage::KPFilterPage(QWidget *parent)
 						" <p><b>Note 2:</b> The filters you define here are applied to your jobfile "
 						" <em><b>before</b></em> it is handed downstream to your spooler and print "
 						" subsystem (e.g. CUPS, LPRng, LPD).</p>"
-						" </ul>"
 						" </qt>" );
 
 	QString whatsThisRemoveFilterButton = i18n(" <qt> <b>Remove Filter button</b>"
 						" <p>This button removes the highlighted filter from the"
-						" list of filters."
+						" list of filters.</p>"
 						" </qt>" );
 
 	QString whatsThisMoveFilterUpButton = i18n(" <qt> <b>Move Filter Up button</b>"
@@ -113,7 +112,7 @@ KPFilterPage::KPFilterPage(QWidget *parent)
 						" <li>a <em>Poster Printing filter</em></li> "
 						" <li>and some more...</li> "
 						" </ul> "
-						" To insert a filter into this list, simply click on the <em>funnel</em> icon (topmost on "
+						" <p>To insert a filter into this list, simply click on the <em>funnel</em> icon (topmost on "
 						" the right icon column group) and proceed. </p>"
 						" <p>Please click on the other elements of this dialog to learn more about the KDEPrint "
 						" pre-filters. "
@@ -131,22 +130,22 @@ KPFilterPage::KPFilterPage(QWidget *parent)
 
 	m_add = new QToolButton(this);
 	  m_add->setWhatsThis(whatsThisAddFilterButton);
-	m_add->setIcon(KIcon("filter"));
+	m_add->setIcon(KIcon("search-filter"));
 	m_add->setToolTip(i18n("Add filter"));
 
 	m_remove = new QToolButton(this);
 	  m_remove->setWhatsThis(whatsThisRemoveFilterButton);
-	m_remove->setIcon(KIcon("remove"));
+	m_remove->setIcon(KIcon("list-remove"));
 	m_remove->setToolTip(i18n("Remove filter"));
 
 	m_up = new QToolButton(this);
 	  m_up->setWhatsThis(whatsThisMoveFilterUpButton);
-	m_up->setIcon(KIcon("up"));
+	m_up->setIcon(KIcon("go-up"));
 	m_up->setToolTip(i18n("Move filter up"));
 
 	m_down = new QToolButton(this);
 	  m_down->setWhatsThis(whatsThisMoveFilterDownButton);
-	m_down->setIcon(KIcon("down"));
+	m_down->setIcon(KIcon("go-down"));
 	m_down->setToolTip(i18n("Move filter down"));
 
 	m_configure = new QToolButton(this);
@@ -221,7 +220,7 @@ void KPFilterPage::slotAddClicked()
     QStringList data;
     data << cmd->description() << cmd->name();
 		QTreeWidgetItem	*item = new QTreeWidgetItem(data);
-		item->setIcon(0, SmallIcon("filter"));
+		item->setIcon(0, SmallIcon("search-filter"));
     m_view->insertTopLevelItem(pos, item);
 		checkFilterChain();
 	}
@@ -251,7 +250,7 @@ void KPFilterPage::slotUpClicked()
       QStringList data;
       data << item->text(0) << item->text(1);
       QTreeWidgetItem	*clone = new QTreeWidgetItem(data);
-      clone->setIcon(0, SmallIcon("filter"));
+      clone->setIcon(0, SmallIcon("search-filter"));
       m_view->insertTopLevelItem(index, clone);
       delete item;
       m_view->setItemSelected(clone, true);
@@ -270,7 +269,7 @@ void KPFilterPage::slotDownClicked()
       QStringList data;
       data << item->text(0) << item->text(1);
       QTreeWidgetItem	*clone = new QTreeWidgetItem(data);
-      clone->setIcon(0, SmallIcon("filter"));
+      clone->setIcon(0, SmallIcon("search-filter"));
       m_view->insertTopLevelItem(index+1, clone);
       delete item;
       m_view->setItemSelected(clone, true);
@@ -376,7 +375,7 @@ void KPFilterPage::checkFilterChain()
   for (int i = 0; i < m_view->topLevelItemCount(); ++i )
 	{
     QTreeWidgetItem *item = m_view->topLevelItem(i);
-		item->setIcon(0, (ok ? SmallIcon("filter") : SmallIcon("filterstop")));
+		item->setIcon(0, (ok ? SmallIcon("search-filter") : SmallIcon("filterstop")));
 		KXmlCommand	*f1 = m_activefilters.value(item->text(1), 0);
 		if (f1 && i < (m_view->topLevelItemCount() - 1))
 		{
