@@ -22,13 +22,13 @@
 #include "kmprinter.h"
 #include "kprinter.h"
 
-#include <QGroupBox>
-#include <QVBoxLayout>
+#include <QtGui/QGroupBox>
+#include <QtGui/QBoxLayout>
 #include <kbuttongroup.h>
-#include <qcombobox.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qradiobutton.h>
+#include <QtGui/QComboBox>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtGui/QRadioButton>
 
 #include <kcursor.h>
 #include <kdebug.h>
@@ -124,16 +124,16 @@ KPGeneralPage::KPGeneralPage(KMPrinter *pr, DrMain *dr, QWidget *parent)
 			" <p><b>\"General\"</b> </p> "
 			" <p>This dialog page contains <em>general</em> print job settings."
 			" General settings are applicable to most printers, most jobs "
-			" and most job file types. "
+			" and most job file types.</p> "
                         " <p>To get more specific help, enable the \"WhatsThis\" cursor and click on any of the"
-                        " text labels or GUI elements of this dialog."
+                        " text labels or GUI elements of this dialog.</p>"
 			" </qt>" );
 	QString whatsThisGeneralPageSizeLabel = i18n( " <qt> "
 			" <p><b>Page size:</b> Select paper size to be printed on from"
 			" the drop-down menu. </p>"
 			" <p>The exact list of choices depends on the printer driver (\"PPD\") you have installed.</p>"
-                        " <br> "
-                        " <hr> "
+                        " <br /> "
+                        " <hr /> "
 			" <p><em><b>Additional hint for power users:</b> This KDEPrint GUI element matches"
 			" with the CUPS commandline job option parameter:</em>"
 			" <pre>"
@@ -145,8 +145,8 @@ KPGeneralPage::KPGeneralPage(KMPrinter *pr, DrMain *dr, QWidget *parent)
 			" <p><b>Paper type:</b> Select paper type to be printed on from "
 			" the drop-down menu. </p>"
 			" <p>The exact list of choices depends on the printer driver (\"PPD\") you have installed. </p>"
-                        " <br> "
-                        " <hr> "
+                        " <br /> "
+                        " <hr /> "
 			" <p><em><b>Additional hint for power users:</b> This KDEPrint GUI element matches"
 			" with the CUPS commandline job option parameter:</em>"
 			" <pre>"
@@ -156,10 +156,10 @@ KPGeneralPage::KPGeneralPage(KMPrinter *pr, DrMain *dr, QWidget *parent)
 			" </qt>" );
 	QString whatsThisGeneralPaperSourceLabel = i18n( " <qt> "
 			" <p><b>Paper source:</b> Select paper source tray for the paper"
-                        " to be printed on from the drop-down menu."
+                        " to be printed on from the drop-down menu.</p>"
 			" <p>The exact list of choices depends on the printer driver (\"PPD\") you have installed. </p>"
-                        " <br>"
-                        " <hr>"
+                        " <br />"
+                        " <hr />"
 			" <p><em><b>Additional hint for power users:</b> This KDEPrint GUI element matches"
 			" with the CUPS commandline job option parameter:</em> "
 			" <pre>"
@@ -170,7 +170,7 @@ KPGeneralPage::KPGeneralPage(KMPrinter *pr, DrMain *dr, QWidget *parent)
 	QString whatsThisGeneralOrientationLabel = i18n( " <qt>"
 			" <p><b>Image Orientation:</b> Orientation of the printed"
                         " page image on your paper is controlled by the radio buttons. By default,"
-                        " the orientation is <em>Portrait</em>"
+                        " the orientation is <em>Portrait</em></p>"
                         " <p>You can select from 4 alternatives:"
                         " <ul> "
                         " <li> <b>Portrait</b>. Portrait is the default setting. </li>"
@@ -179,8 +179,8 @@ KPGeneralPage::KPGeneralPage(KMPrinter *pr, DrMain *dr, QWidget *parent)
                         " <li> <b>Reverse Portrait</b>. Reverse Portrait prints the image upside down.</li>"
                         " </ul>"
                         " The icon changes according to your selection.</p>"
-                        " <br>"
-                        " <hr>"
+                        " <br />"
+                        " <hr />"
 			" <p><em><b>Additional hint for power users:</b> This KDEPrint GUI element matches"
 			" with the CUPS commandline job option parameter:</em>"
 			" <pre>"
@@ -191,9 +191,8 @@ KPGeneralPage::KPGeneralPage(KMPrinter *pr, DrMain *dr, QWidget *parent)
 	QString whatsThisGeneralDuplexLabel = i18n( "<qt>"
 			" <p><b>Duplex Printing:</b> These controls may be grayed out if your printer"
                         " does not support <em>duplex printing</em> (i.e. printing on both sides of the sheet)."
-                        " These controls are active if your printer supports duplex printing."
-                        " <p>"
-                        " You can choose from 3 alternatives: </p>"
+                        " These controls are active if your printer supports duplex printing.</p>"
+                        " <p>You can choose from 3 alternatives: </p>"
                         " <ul> "
                         " <li> <b>None.</b> This prints each page of the job on one side of the sheets only. </li>"
                         " <li> <b>Long Side.</b> This prints the job on both sides of the paper sheets."
@@ -206,7 +205,7 @@ KPGeneralPage::KPGeneralPage(KMPrinter *pr, DrMain *dr, QWidget *parent)
                         " the short edge. (Some printer drivers name this mode"
                         " <em>duplex-tumbled</em>).  </li>"
                         " </ul> "
-                        " <hr> "
+                        " <hr /> "
 			" <p><em><b>Additional hint for power users:</b> This KDEPrint GUI element matches"
 			" with the CUPS commandline job option parameter:</em>"
 			" <pre>"
@@ -221,14 +220,14 @@ KPGeneralPage::KPGeneralPage(KMPrinter *pr, DrMain *dr, QWidget *parent)
                         " title.</p>"
                         " <p>Banner pages are useful to separate different jobs more easily, especially in a multi-user"
                         " environment. </p>"
-                        " <p><em><b>Hint:</em></b> You can design your own banner pages. To make use of them, just put the banner"
+                        " <p><em><b>Hint:</b></em> You can design your own banner pages. To make use of them, just put the banner"
                         " file into the standard CUPS <em>banners</em> directory (this is usually <em>\"/usr/share/cups/banner/\"</em>."
 			" Your custom banner(s) must have one of the supported printable formats."
                         " Supported formats are ASCII text, PostScript, PDF and nearly any image format such as PNG, JPEG or"
                         " GIF. Your added banner pages will appear in the drop down menu CUPS is restarted.</p>"
                         " <p>CUPS comes with a selection of banner pages. </p>"
-                        " <br> "
-                        " <hr> "
+                        " <br /> "
+                        " <hr /> "
 			" <p><em><b>Additional hint for power users:</b> This KDEPrint GUI element matches"
 			" with the CUPS commandline job option parameter:</em> "
 			" <pre>"
@@ -241,13 +240,13 @@ KPGeneralPage::KPGeneralPage(KMPrinter *pr, DrMain *dr, QWidget *parent)
                         " You can choose to print more than one page onto each sheet of paper."
                         " This is sometimes useful to save paper.</p>"
                         " <p><b>Note 1:</b> the page images get scaled down accordingly to print 2 or 4 pages per sheet."
-                        " The page image does not get scaled if you print 1 page per sheet (the default setting)."
+                        " The page image does not get scaled if you print 1 page per sheet (the default setting).</p>"
                         " <p><b>Note 2:</b> If you select multiple pages per sheet here, the scaling and re-arranging is done"
                         " by your printing system. However, some printers are independently capable of printing multiple pages per sheet."
                         " In which case you find the option in the printer driver settings. Be careful: if you enable multiple" 
                         " pages per sheet in both places, your printout will not look as you intended. </p>"
-                        " <br> "
-                        " <hr> "
+                        " <br /> "
+                        " <hr /> "
 			" <p><em><b>Additional hint for power users:</b> This KDEPrint GUI element matches"
 			" with the CUPS commandline job option parameter:</em> "
 			" <pre>"
@@ -522,7 +521,7 @@ void KPGeneralPage::setOptions(const QMap<QString,QString>& opts)
 			}
 			else
 			{
-				kWarning() << "media option '" << value << "' not handled." << endl;
+				kWarning() << "media option '" << value << "' not handled.";
 			}
 		}
 		value = opts["PageSize"];
@@ -573,7 +572,7 @@ void KPGeneralPage::setOptions(const QMap<QString,QString>& opts)
 				else if ((index=findOption(default_source,DEFAULT_SOURCE,value)) >= 0)
 					m_inputslot->setCurrentIndex(index);
 				else
-					kWarning() << "media option '" << value << "' not handled." << endl;
+					kWarning() << "media option '" << value << "' not handled.";
 			}
 		}
 
@@ -623,8 +622,6 @@ void KPGeneralPage::setOptions(const QMap<QString,QString>& opts)
 
 	if ( m_orientbox->isEnabled() )
 		m_orientbox->setDisabled( opts[ "kde-orientation-fixed" ] == "1" );
-	if ( m_pagesize->isEnabled() )
-		m_pagesize->setDisabled( opts[ "kde-pagesize-fixed" ] == "1" );
 }
 
 void KPGeneralPage::getOptions(QMap<QString,QString>& opts, bool incldef)
