@@ -20,15 +20,14 @@
 #ifndef KPIPEPROCESS_H
 #define KPIPEPROCESS_H
 
-#include <qfile.h>
+#include <kdeprint_export.h>
+#include <QtCore/QFile>
 #include <stdio.h>
 
-#include <kdelibs_export.h>
-
 class KDEPRINT_EXPORT KPipeProcess : public QFile
 {
 public:
-	KPipeProcess(const QString& cmd = QString(), QIODevice::OpenModeFlag mode = QIODevice::ReadOnly);
+	explicit KPipeProcess(const QString& cmd = QString(), QIODevice::OpenModeFlag mode = QIODevice::ReadOnly);
 	~KPipeProcess();
 
 	bool open(const QString& cmd, QIODevice::OpenModeFlag mode = QIODevice::ReadOnly);
