@@ -18,8 +18,8 @@
  **/
 
 /*
- *  "WhatsThis" help items added by Kurt Pfeifle, August 2003,
- *  same copyright as above.
+ *  "WhatsThis" help items copyright August 2003 Kurt Pfeifle <kpfeifle@danka.de>
+ *  same license as above.
  **/
 
 #include "kprintdialog.h"
@@ -37,11 +37,11 @@
 #include "treecombobox.h"
 #include "messagewindow.h"
 
-#include <QGroupBox>
-#include <QVBoxLayout>
-#include <QCheckBox>
-#include <QLabel>
-#include <QLayout>
+#include <QtGui/QGroupBox>
+#include <QtGui/QBoxLayout>
+#include <QtGui/QCheckBox>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
 
 #include <klocale.h>
 #include <kiconloader.h>
@@ -113,7 +113,7 @@ KPrintDialog::KPrintDialog(QWidget *parent)
 						"  <em>KDE special printers</em> (which save"
 						" jobs to disk [as PostScript- or PDF-files], or deliver jobs via"
 						" email (as a PDF"
-						" attachment). If you are missing a real printer, you need to..."
+						" attachment). If you are missing a real printer, you need to...</p>"
 						" <ul>"
 						" <li>...either create a local printer with the help of the <em>KDE Add"
 						" Printer Wizard</em>. The Wizard is available for the CUPS and RLPR printing"
@@ -134,7 +134,7 @@ KPrintDialog::KPrintDialog(QWidget *parent)
 						" </qt>" );
 	QString whatsThisPrintJobProperties = i18n( " <qt><b>Print Job Properties:</b> "
 						" <p>This button opens a dialog where you can make decisions"
-						" regarding all supported print job options."
+						" regarding all supported print job options.</p>"
 						" </qt>" );
 	QString whatsThisPrinterFilter = i18n(  " <qt><b>Selective View on List of Printers:</b>"
 						" <p> This button reduces the list of visible printers"
@@ -164,17 +164,17 @@ KPrintDialog::KPrintDialog(QWidget *parent)
 						" <b>Example:</b> <pre>a2ps -P &lt;printername&gt; --medium=A3</pre>."
 						" </qt>" );
 	QString whatsThisOptions = i18n( " <qt><b>Additional Print Job Options</b>"
-						" <p>This button shows or hides additional printing options.</qt>" );
+						" <p>This button shows or hides additional printing options.</p></qt>" );
 	QString whatsThisSystemOptions = i18n(  " <qt><b>System Options:</b>"
 						" <p>This button starts a new dialog where you can adjust various"
   						" settings of your printing system. Amongst them:"
 						" <ul><li> Should KDE"
 						" applications embed all fonts into the PostScript they"
- 						" generate for printing?"
+ 						" generate for printing?</li>"
 						" <li> Should KDE use an external PostScript viewer"
-						" like <em>gv</em> for print page previews?"
-						" <li> Should KDEPrint use a local or a remote CUPS server?,"
-						" </ul> and many more.... "
+						" like <em>gv</em> for print page previews?</li>"
+						" <li> Should KDEPrint use a local or a remote CUPS server?,</li>"
+						" </ul> and many more....</p> "
 					        " </qt>" );
 
 	QString whatsThisHelpButton = i18n(     " <qt><b>Help:</b> This button takes you to the complete <em>KDEPrint"
@@ -214,7 +214,7 @@ KPrintDialog::KPrintDialog(QWidget *parent)
 						" (Button and Lineedit field are only available if you \"Print to File\")"
 					        " </qt>" );
 
-	QString whatsThisOutputFileButton = i18n(" <qt><b>Browse Directories button:<b> This button calls"
+	QString whatsThisOutputFileButton = i18n(" <qt><b>Browse Directories button:</b> This button calls"
 						" the \"File Open / Browse Directories\" dialog to let you"
 						" choose a directory and file name where your \"Print-to-File\""
 						" job should be saved."
@@ -222,13 +222,13 @@ KPrintDialog::KPrintDialog(QWidget *parent)
 
 	QString whatsThisAddFileButton = i18n(  " <qt><b>Add File to Job</b>"
 						" <p>This button calls the \"File Open / Browse Directories\" dialog to allow you"
-						" to select a file for printing. Note, that"
+						" to select a file for printing. Note, that</p>"
 						" <ul><li>you can select ASCII or International Text, PDF,"
 						" PostScript, JPEG, TIFF, PNG, GIF and many other graphical"
-						" formats."
+						" formats.</li>"
 						" <li>you can select various files from different paths"
 						" and send them as one \"multi-file job\" to the printing"
-						" system."
+						" system.</li>"
 						" </ul>"
 					        " </qt>" );
 
@@ -242,7 +242,7 @@ KPrintDialog::KPrintDialog(QWidget *parent)
 						" is only visible for printjobs created from inside KDE applications."
 						" If you start kprinter from the commandline, or if you use kprinter"
 						" as a print command for non-KDE applications (like Acrobat Reader,"
-                                                " Firefox or OpenOffice), print preview is not available here."
+                                                " Firefox or OpenOffice), print preview is not available here.</p>"
 					        " </qt>" );
 
 	QString whatsThisSetDefaultPrinter = i18n(" <qt><b>Set as Default Printer</b>"
@@ -251,13 +251,13 @@ KPrintDialog::KPrintDialog(QWidget *parent)
 						" <p><b>Note:</b> (Button is only visible if the checkbox for"
 						" <em>System Options</em>"
 						" --> <em>General</em> --> <em>Miscellaneous</em>: <em>\"Defaults"
-						" to the last printer used in the application\"</em> is disabled.)"
+						" to the last printer used in the application\"</em> is disabled.)</p>"
 					        " </qt>" );
 
 	d->m_printer = 0;
 	setCaption(i18n("Print"));
 	setButtons( KDialog::None );
-	
+
 	QWidget *main = new QWidget();
 
 	// widget creation
@@ -288,12 +288,12 @@ KPrintDialog::KPrintDialog(QWidget *parent)
 	m_printerlabel->setBuddy(d->m_printers);
 	d->m_properties = new KPushButton(KGuiItem(i18n("P&roperties"), "edit"), m_pbox);
 	d->m_properties->setWhatsThis(whatsThisPrintJobProperties);
-	d->m_options = new KPushButton(KGuiItem(i18n("System Op&tions"), "kdeprint_configmgr"), main);
+	d->m_options = new KPushButton(KGuiItem(i18n("System Op&tions"), "kdepring-configmgr"), main);
 	d->m_options->setWhatsThis(whatsThisSystemOptions);
-	d->m_default = new KPushButton(KGuiItem(i18n("Set as &Default"), "kdeprint_defaultsoft"), m_pbox);
+	d->m_default = new KPushButton(KGuiItem(i18n("Set as &Default"), "kdeprint-defaultsoft"), m_pbox);
 	d->m_default->setWhatsThis(whatsThisSetDefaultPrinter);
 	d->m_filter = new QPushButton(m_pbox);
-	d->m_filter->setIcon(KIcon("filter"));
+	d->m_filter->setIcon(KIcon("search-filter"));
 	d->m_filter->setMinimumSize(QSize(d->m_printers->minimumHeight(),d->m_printers->minimumHeight()));
 	d->m_filter->setCheckable(true);
 	d->m_filter->setDown(KMManager::self()->isFilterEnabled());
@@ -304,7 +304,7 @@ KPrintDialog::KPrintDialog(QWidget *parent)
 	d->m_wizard->setMinimumSize(QSize(d->m_printers->minimumHeight(),d->m_printers->minimumHeight()));
 	d->m_wizard->setToolTip(i18n("Add printer..."));
 	d->m_wizard->setWhatsThis(whatsThisAddPrinterWizard);
-	d->m_ok = new KPushButton(KGuiItem(i18n("&Print"), "fileprint"), main);
+	d->m_ok = new KPushButton(KGuiItem(i18n("&Print"), "document-print"), main);
         d->m_ok->setWhatsThis(whatsThisPrintButton);
 	d->m_ok->setDefault(true);
 	d->m_ok->setEnabled( false );
@@ -453,17 +453,16 @@ KPrintDialog::KPrintDialog(QWidget *parent)
 	}
 	else
 	{
-		KSharedConfig::Ptr config = KGlobal::config();
-		config->setGroup("KPrinter Settings");
-		expandDialog(!config->readEntry("DialogReduced", QVariant(KMFactory::self()->settings()->application != KPrinter::StandAlone)).toBool());
+		KConfigGroup config( KGlobal::config(), "KPrinter Settings");
+		expandDialog(!config.readEntry("DialogReduced",
+									   QVariant(KMFactory::self()->settings()->application != KPrinter::StandAlone)).toBool());
 	}
 }
 
 KPrintDialog::~KPrintDialog()
 {
-	KSharedConfig::Ptr config = KGlobal::config();
-	config->setGroup("KPrinter Settings");
-	config->writeEntry("DialogReduced", d->m_reduced);
+	KConfigGroup cg( KGlobal::config(), "KPrinter Settings");
+	cg.writeEntry("DialogReduced", d->m_reduced);
 
 	delete d;
 }
@@ -472,7 +471,9 @@ void KPrintDialog::setFlags(int f)
 {
 	SHOWHIDE(d->m_properties, (f & KMUiManager::Properties) && d->b_propertiesEnabled)
 	d->m_default->hide();
-	SHOWHIDE(d->m_default, ((f & KMUiManager::Default) && !KMFactory::self()->printConfig("General")->readEntry("UseLast", true)))
+	KConfig *cf = KMFactory::self()->printConfig();
+	KConfigGroup group = cf->group("General");
+	SHOWHIDE(d->m_default, ((f & KMUiManager::Default) && !group.readEntry("UseLast", true)))
 	SHOWHIDE(d->m_preview, (f & KMUiManager::Preview))
 	bool	on = (f & KMUiManager::OutputToFile);
 	SHOWHIDE(d->m_filelabel, on)
@@ -587,7 +588,13 @@ void KPrintDialog::initialize(KPrinter *printer)
 				sep = true;
 				d->m_printers->insertItem(QPixmap(), QLatin1String("--------"));
 			}
-			d->m_printers->insertItem(SmallIcon(printerIt->pixmap(),0,(printerIt->isValid() ? (int)K3Icon::DefaultState : (int)K3Icon::LockOverlay)),printerIt->name(),false/*sep*/);
+			
+			QStringList overlays;
+			if (!printerIt->isValid()) {
+				overlays.append("lock");
+                        }
+
+			d->m_printers->insertItem(SmallIcon(printerIt->pixmap(),0, K3Icon::DefaultState, overlays), printerIt->name(),false/*sep*/);
 			if (printerIt->isSoftDefault())
 				defsoft = d->m_printers->count()-1;
 			if (printerIt->isHardDefault())
@@ -606,7 +613,7 @@ void KPrintDialog::initialize(KPrinter *printer)
 	if (!d->m_printer->outputFileName().isEmpty())
 		d->m_file->setUrl( KUrl(d->m_printer->outputFileName()) );
 	else if (!d->m_printer->docFileName().isEmpty())
-		d->m_file->setUrl( KUrl(d->m_printer->docDirectory()+"/"+d->m_printer->docFileName()+".ps") );
+		d->m_file->setUrl( KUrl(d->m_printer->docDirectory()+'/'+d->m_printer->docFileName()+".ps") );
 
 	if ( d->m_printers->count() > 0 )
 		slotPrinterSelected( d->m_printers->currentIndex() );
@@ -831,7 +838,7 @@ void KPrintDialog::setOutputFileExtension(const QString& ext)
 		// change "file.ext"; don't change "file", "file." or ".file" but do change ".file.ext"
 		if ( p > 0 && p != int (f.length () - 1) )
 		{
-			url.setFileName( f.left( p ) + "." + ext );
+			url.setFileName( f.left( p ) + '.' + ext );
 			d->m_file->setUrl( url );
 		}
 	}
@@ -892,7 +899,7 @@ void KPrintDialog::expandDialog(bool on)
 			if (d->b_systemEnabled)
 				d->m_plugin->show();
 		}
-		d->m_extbtn->setIcon(KIcon("up"));
+		d->m_extbtn->setIcon(KIcon("go-up"));
 		d->m_extbtn->setText(i18n("&Options <<"));
 		d->m_reduced = false;
 	}
@@ -904,11 +911,11 @@ void KPrintDialog::expandDialog(bool on)
 			if (d->b_systemEnabled)
 				d->m_plugin->hide();
 		}
-		d->m_extbtn->setIcon(KIcon("down"));
+		d->m_extbtn->setIcon(KIcon("go-down"));
 		d->m_extbtn->setText(i18n("&Options >>"));
 		d->m_reduced = true;
 	}
-	
+
 	layout()->invalidate();
 	layout()->activate();
 	resize( width(), layout()->minimumSize().height() );
@@ -964,7 +971,7 @@ void KPrintDialog::enableDialogPage( int index, bool flag )
 {
 	if ( index < 0 || index >= ( int )d->m_pages.count() )
 	{
-		kWarning() << "KPrintDialog: page index out of bound" << endl;
+		kWarning() << "KPrintDialog: page index out of bound";
 		return;
 	}
 
