@@ -21,12 +21,14 @@
 #include "kprintdialogpage.h"
 
 KPrintDialogPage::KPrintDialogPage(QWidget *parent)
-    : QWidget(parent), m_printer(0), m_driver(0), m_ID(0), m_onlyreal(false)
+    : QWidget(parent), m_printer(0), m_driver(0), m_ID(0), m_onlyreal(false),
+      d(0)
 {
 }
 
 KPrintDialogPage::KPrintDialogPage(KMPrinter *pr, DrMain *dr, QWidget *parent)
-    : QWidget(parent), m_printer(pr), m_driver(dr), m_ID(0), m_onlyreal(false)
+    : QWidget(parent), m_printer(pr), m_driver(dr), m_ID(0), m_onlyreal(false),
+      d(0)
 {
 }
 
@@ -46,4 +48,45 @@ bool KPrintDialogPage::isValid(QString&)
 {
 	return true;
 }
+
+int KPrintDialogPage::id() const
+{
+    return m_ID;
+}
+
+void KPrintDialogPage::setId(int ID)
+{
+    m_ID = ID;
+}
+
+QString	KPrintDialogPage::title() const
+{
+    return m_title;
+}
+
+void KPrintDialogPage::setTitle(const QString& txt)
+{
+    m_title = txt;
+}
+
+bool KPrintDialogPage::onlyRealPrinters() const
+{
+    return m_onlyreal;
+}
+
+void KPrintDialogPage::setOnlyRealPrinters(bool on)
+{
+    m_onlyreal = on;
+}
+
+DrMain* KPrintDialogPage::driver()
+{
+    return m_driver;
+}
+
+KMPrinter* KPrintDialogPage::printer()
+{
+    return m_printer;
+}
+
 #include "kprintdialogpage.moc"
