@@ -1,6 +1,7 @@
 /*
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
+ *  Copyright (C) 2007 Thomas Zander <zander@kde.org>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -17,8 +18,6 @@
  *  Boston, MA 02110-1301, USA.
  **/
 
-#include <config.h>
-
 #include "kprinter.h"
 #include "kprinterimpl.h"
 #include "kprintdialog.h"
@@ -28,11 +27,13 @@
 #include "kmmanager.h"
 #include "driver.h"
 
-#include <qfile.h>
-#include <qdir.h>
-#include <qpaintengine.h>
-#include <qpointer.h>
-#include <qprintengine.h>
+#include <config.h>
+
+#include <QtCore/QFile>
+#include <QtCore/QDir>
+#include <QtGui/QTextItem>
+#include <QtCore/QPointer>
+#include <QtGui/QPrintEngine>
 #include <ktoolinvocation.h>
 #include <kauthorized.h>
 #include <kstandarddirs.h>
@@ -56,8 +57,8 @@ class KPrinterWrapper : public QPrinter
 {
 public:
 	KPrinterWrapper(PrinterMode mode = ScreenResolution)
-	: QPrinter(mode) {};
-	
+	: QPrinter(mode) {}
+
 	int metric(PaintDeviceMetric m) const { return QPrinter::metric(m); }
 	void setMargins( uint top, uint left, uint bottom, uint right );
 	void getMargins(uint *top, uint *left, uint *bottom, uint *right) const;
@@ -71,7 +72,7 @@ void KPrinterWrapper::setMargins( uint top, uint left, uint bottom, uint right )
 	// just ignore this value.
 	// QPainter::pageRect() is actually taken from e.g. CUPs or whether a full
 	// page is being used.
-	
+
 	QRect pageRect = paperRect().adjusted( left, top, 0U-right, 0U-bottom );
 	printEngine()->setProperty( QPrintEngine::PPK_PageRect, pageRect );
 }
@@ -139,9 +140,9 @@ class KPrinterEngine : public QPaintEngine
 public:
 	KPrinterEngine(KPrinter * kPrinter, QPaintEngine::PaintEngineFeatures features);
 	~KPrinterEngine();
-	
+
 	QPaintEngine * paintEngine() const { return m_kPrinter->d->m_printer->paintEngine(); }
-	
+
     bool begin(QPaintDevice *pdev);
     bool end();
 
@@ -179,7 +180,7 @@ public:
 
     Type type() const { return paintEngine()->type(); }
 
-	
+
 private:
 	KPrinter * m_kPrinter;
 };
@@ -188,7 +189,7 @@ KPrinterEngine::KPrinterEngine(KPrinter * kPrinter, QPaintEngine::PaintEngineFea
 	: QPaintEngine(features)
 {
 	m_kPrinter = kPrinter;
-	
+
 	setPaintDevice(m_kPrinter);
 }
 
@@ -202,10 +203,10 @@ bool KPrinterEngine::begin(QPaintDevice *pdev)
 	m_kPrinter->d->m_pagenumber = 1;
 	m_kPrinter->preparePrinting();
 	m_kPrinter->d->m_impl->statusMessage(i18n("Generating print data: page %1", m_kPrinter->d->m_pagenumber), m_kPrinter);
-	
+
 	bool value = paintEngine()->begin(pdev);
 	active = paintEngine()->isActive();
-	
+
 	return value;
 }
 
@@ -214,12 +215,12 @@ bool KPrinterEngine::end()
 {
 	bool value = paintEngine()->end();
 	active = paintEngine()->isActive();
-	
+
 	// this call should take care of everything (preview, output-to-file, filtering, ...)
 	value = value && m_kPrinter->printFiles(QStringList(m_kPrinter->d->m_printer->outputFileName()),true);
 	// reset "ready" state
 	m_kPrinter->finishPrinting();
-	
+
 	return value;
 }
 
@@ -260,17 +261,17 @@ void KPrinter::init(bool restore, QPrinter::PrinterMode m)
 
 	// initialize QPrinter wrapper
 	d->m_printer = new KPrinterWrapper(m);
-	
+
 	// get paint engine features
 	QPaintEngine::PaintEngineFeatures features = 0;
 	for ( uint i=0; i<32; ++i )
 	{
 		QPaintEngine::PaintEngineFeature feature = (QPaintEngine::PaintEngineFeature)(1<<i);
-		
+
 		if ( d->m_printer->paintEngine()->hasFeature( feature ) )
 			features |= feature;
 	}
-	
+
 	d->m_engine = new KPrinterEngine(this, features);
 
 	// other initialization
@@ -294,20 +295,19 @@ void KPrinter::loadSettings()
 	setSearchName(option("kde-searchname"));
 	d->m_options.remove("kde-searchname");
 
-    KSharedConfig::Ptr conf = KGlobal::config();
-    KConfig *pconf = KMFactory::self()->printConfig();
-	conf->setGroup("KPrinter Settings");
-	pconf->setGroup("General");
+    KConfigGroup conf = KConfigGroup( KGlobal::config(), "KPrinter Settings");
 
+    KConfig *cf = KMFactory::self()->printConfig();
+    KConfigGroup pconf = cf->group("General");
 	// load latest used printer from config file, if required in the options
-	if (searchName().isEmpty() && pconf->readEntry("UseLast", true))
-		setSearchName(conf->readEntry("Printer"));
+	if (searchName().isEmpty() && pconf.readEntry("UseLast", true))
+		setSearchName(conf.readEntry("Printer"));
 
 	// latest used print command
-	setOption("kde-printcommand",conf->readPathEntry("PrintCommand"));
+	setOption("kde-printcommand",conf.readPathEntry("PrintCommand"));
 
 	// latest used document directory
-	setDocDirectory( conf->readPathEntry( "DocDirectory" ) );
+	setDocDirectory( conf.readPathEntry( "DocDirectory" ) );
 	setDocFileName( "print" );
 }
 
@@ -320,21 +320,20 @@ void KPrinter::saveSettings()
 	}
 
 	// save latest used printer to config file
-	KSharedConfig::Ptr conf = KGlobal::config();
-	conf->setGroup("KPrinter Settings");
-	conf->writeEntry("Printer",searchName());
+	KConfigGroup conf( KGlobal::config(), "KPrinter Settings");
+	conf.writeEntry("Printer",searchName());
 	// latest used print command
-	conf->writePathEntry("PrintCommand",option("kde-printcommand"));
+	conf.writePathEntry("PrintCommand",option("kde-printcommand"));
 
 	// latest used document directory
 	if ( d->m_docdirectory.isEmpty() )
 	{
 		KUrl url( outputFileName() );
 		if ( url.isValid() )
-			conf->writePathEntry( "DocDirectory", url.directory() );
+			conf.writePathEntry( "DocDirectory", url.directory() );
 	}
 	else
-		conf->writePathEntry( "DocDirectory", d->m_docdirectory );
+		conf.writePathEntry( "DocDirectory", d->m_docdirectory );
 }
 
 bool KPrinter::setup(QWidget *parent, const QString& caption, bool forceExpand)
@@ -443,7 +442,7 @@ void KPrinter::translateQtOptions()
 			// But that doesn't mean it looks good. Apps which use setFullPage(false) assume that
 			// KPrinter will give them reasonable margins, so let's qMax with defaults from Qt in that case.
 			// Keep this in sync with KPMarginPage::initPageSize
-			
+
 			unsigned int it, il, ib, ir;
 			d->m_printer->getMargins( &it, &il, &ib, &ir );
 			top = qMax( top, (int)it );
@@ -735,7 +734,6 @@ void KPrinter::setPageSize(PageSize s)
 {
 	KMFactory::self()->settings()->pageSize = s;
 	setOption("kde-pagesize",QString::number((int)s),true);
-	d->m_impl->broadcastOption( "kde-pagesize-fixed", "1" );
 }
 
 void KPrinter::setOptions(const QMap<QString,QString>& opts)
@@ -806,13 +804,14 @@ bool KPrinter::autoConfigure(const QString& prname, QWidget *parent)
 
 void reportError(KPrinter *p)
 {
-	if (!KNotification::event("printerror",i18n("<p><nobr>A print error occurred. Error message received from system:</nobr></p><br>%1", p->errorMessage())))
-		kDebug(500) << "could not send notify event" << endl;
+	if (!KNotification::event("printerror",i18n("<p><nobr>A print error occurred. Error message received from system:</nobr></p><br />%1", p->errorMessage())))
+		kDebug(500) << "could not send notify event";
 }
 
-KPrinter::PageSize pageNameToPageSize(const QString& _name)
+KPrinter::PageSize pageNameToPageSize(const QString& _name, bool *ok)
 {
 	QString name = _name.toUpper();
+	if (ok) *ok = true;
 	if (name == "LETTER") return KPrinter::Letter;
 	else if (name == "LEGAL") return KPrinter::Legal;
 	else if (name == "A4") return KPrinter::A4;
@@ -843,7 +842,11 @@ KPrinter::PageSize pageNameToPageSize(const QString& _name)
 	else if (name == "C5" || name == "C5E" || name == "ENVC5") return KPrinter::C5E;
 	else if (name == "DL" || name == "DLE" || name == "ENVDL") return KPrinter::DLE;
 	else if (name == "COMM10" || name == "COM10" || name == "ENV10") return KPrinter::Comm10E;
-	else return KPrinter::A4;
+	else
+	{
+		if (ok) *ok = false;
+		return KPrinter::A4;
+	}
 }
 
 const char* pageSizeToPageName(KPrinter::PageSize s)
@@ -884,18 +887,11 @@ const char* pageSizeToPageName(KPrinter::PageSize s)
 	}
 }
 
-// FIXME: remove for 4.0
-QSize rangeToSize( const QString& )
-{
-	kWarning( 500 ) << "rangeToSize(QString) is obsolete, do not use (no effect)" << endl;
-	return QSize();
-}
-
 static void dumpOptions(const QMap<QString,QString>& opts)
 {
-	kDebug(500) << "********************" << endl;
+	kDebug(500) << "********************";
 	for (QMap<QString,QString>::ConstIterator it=opts.begin(); it!=opts.end(); ++it)
-		kDebug(500) << it.key() << " = " << it.value() << endl;
+		kDebug(500) << it.key() << " = " << it.value();
 }
 
 KPrinterImpl* KPrinter::implementation() const
@@ -1013,7 +1009,7 @@ QString KPrinter::printerSelectionOption() const
 void KPrinter::setPrinterSelectionOption(const QString&)
 {}
 
-const QMap<QString,QString>& KPrinter::options() const
+QMap<QString,QString> KPrinter::options() const
 { return d->m_options; }
 
 QString KPrinter::searchName() const
@@ -1071,7 +1067,7 @@ void KPrinter::setMargins( uint top, uint left, uint bottom, uint right )
 // FIXME: remove for 4.0
 QSize KPrinter::realPageSize() const
 {
-	kWarning( 500 ) << "KPrinter::realPageSize() is obsolete, do not use" << endl;
+	kWarning( 500 ) << "KPrinter::realPageSize() is obsolete, do not use";
 	if ( d->m_pagesize )
 		return d->m_pagesize->pageSize();
 	else
@@ -1082,15 +1078,15 @@ void KPrinter::setRealPageSize(DrPageSize *p)
 {
 	if ( p )
 	{
-		kDebug( 500 ) << "Page size:  width =" << p->pageWidth() << endl;
-		kDebug( 500 ) << "Page size: height =" << p->pageHeight() << endl;
-		kDebug( 500 ) << "Page size:   left =" << p->leftMargin() << endl;
-		kDebug( 500 ) << "Page size:    top =" << p->topMargin() << endl;
-		kDebug( 500 ) << "Page size:  right =" << p->rightMargin() << endl;
-		kDebug( 500 ) << "Page size: bottom =" << p->bottomMargin() << endl;
+		kDebug( 500 ) << "Page size:  width =" << p->pageWidth();
+		kDebug( 500 ) << "Page size: height =" << p->pageHeight();
+		kDebug( 500 ) << "Page size:   left =" << p->leftMargin();
+		kDebug( 500 ) << "Page size:    top =" << p->topMargin();
+		kDebug( 500 ) << "Page size:  right =" << p->rightMargin();
+		kDebug( 500 ) << "Page size: bottom =" << p->bottomMargin();
 	}
 	else
-		kDebug( 500 ) << "Resetting page size" << endl;
+		kDebug( 500 ) << "Resetting page size";
 
 	/* we copy the page size structure internally
 	 * as the original object is owned by the driver
@@ -1102,21 +1098,21 @@ void KPrinter::setRealPageSize(DrPageSize *p)
 }
 
 // FIXME: remove for 4.0
-void KPrinter::setRealPageSize( QSize )
+void KPrinter::setRealPageSize( const QSize& )
 {
-	kWarning( 500 ) << "KPrinter::setRealPageSize(QSize) is obsolete, do not use (no effect)" << endl;
+	kWarning( 500 ) << "KPrinter::setRealPageSize(QSize) is obsolete, do not use (no effect)";
 }
 
 // FIXME: remove for 4.0
 void KPrinter::setRealDrawableArea( const QRect& )
 {
-	kWarning( 500 ) << "KPrinter::setRealDrawableArea(QRect) is obsolete, do not use (no effect)" << endl;
+	kWarning( 500 ) << "KPrinter::setRealDrawableArea(QRect) is obsolete, do not use (no effect)";
 }
 
 // FIXME: remove for 4.0
 QRect KPrinter::realDrawableArea() const
 {
-	kWarning( 500 ) << "KPrinter::realDrawableArea() is obsolete, do not use" << endl;
+	kWarning( 500 ) << "KPrinter::realDrawableArea() is obsolete, do not use";
 	if ( d->m_pagesize )
 		return d->m_pagesize->pageRect();
 	else
@@ -1162,3 +1158,65 @@ int KPrinter::resolution() const
 
 void KPrinter::setUsePrinterResolution( bool on )
 { d->m_useprinterres = on; }
+
+
+void KPrinter::setOutputFormat(QPrinter::OutputFormat format)
+{
+    d->m_printer->setOutputFormat(format);
+}
+
+QPrinter::OutputFormat KPrinter::outputFormat () const
+{
+    return d->m_printer->outputFormat();
+}
+
+void KPrinter::setPaperSource(QPrinter::PaperSource papersource)
+{
+    d->m_printer->setPaperSource(papersource);
+}
+
+QPrinter::PaperSource KPrinter::paperSource () const
+{
+    return d->m_printer->paperSource();
+}
+
+QList< int > KPrinter::supportedResolutions() const
+{
+    return d->m_printer->supportedResolutions();
+}
+
+void KPrinter::setFontEmbeddingEnabled(bool enable)
+{
+    d->m_printer->setFontEmbeddingEnabled(enable);
+}
+
+bool KPrinter::fontEmbeddingEnabled() const
+{
+    return d->m_printer->fontEmbeddingEnabled();
+}
+
+void KPrinter::setDoubleSidedPrinting(bool enable)
+{
+    d->m_printer->setDoubleSidedPrinting(enable);
+}
+
+bool KPrinter::doubleSidedPrinting() const
+{
+    return d->m_printer->doubleSidedPrinting();
+}
+
+QRect KPrinter::paperRect() const
+{
+    return d->m_printer->paperRect();
+}
+
+QRect KPrinter::pageRect () const
+{
+    return d->m_printer->pageRect();
+}
+
+QPrinter::PrinterState KPrinter::printerState () const
+{
+    return d->m_printer->printerState();
+}
+
