@@ -1,7 +1,7 @@
 /*
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
- *
+ *  Copyright (C) 2007 Thomas Zander <zander@kde.org>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -21,17 +21,15 @@
 #ifndef KPRINTER_H
 #define KPRINTER_H
 
-#include <qpaintdevice.h>
-#include <qprinter.h>
-#include <qmap.h>
-#include <qstring.h>
-#include <qstringlist.h>
-
-#include <kdemacros.h>
-#include <kdelibs_export.h>
-
+#include <kdeprint_export.h>
 #include <kdeprint/kpreloadobject.h>
 
+#include <QtGui/QPaintDevice>
+#include <QtGui/QPrinter>
+#include <QtCore/QMap>
+#include <QtCore/QString>
+#include <QtCore/QStringList>
+
 class KPrinterImpl;
 class KPrintDialogPage;
 class KPrinterPrivate;
@@ -87,8 +85,6 @@ class DrPageSize;
  */
 class KDEPRINT_EXPORT KPrinter : public QPaintDevice, public KPReloadObject
 {
-//friend class KPrinterWrapper;
-friend class KPrinterImpl;
 public:
 	// Print global settings (set via static functions)
 	/**
@@ -99,7 +95,7 @@ public:
 	 *
 	 * @see addStandardPage(), removeStandardPage()
 	 */
-	enum StandardPageType { CopiesPage = 0x01, FilesPage = 0x02, Custom = 0x10 };
+	enum StandardPageType { CopiesPage = 0x01, FilesPage = 0x02, CustomPage = 0x10 };
 	/**
 	 * Defines whether the application can perform page selection itself or not.
 	 * Some print systems (like CUPS) can do page selection, in this case the
@@ -196,7 +192,8 @@ public:
 		Folio = QPrinter::Folio,
 		Ledger = QPrinter::Ledger,
 		Tabloid = QPrinter::Tabloid,
-		NPageSize = QPrinter::NPageSize
+		NPageSize = QPrinter::NPageSize,
+        CustomSize = QPrinter::Custom
 	};
 
 	// constructors / destructor
@@ -207,7 +204,7 @@ public:
 	 * @param restore if true, options will be restored/saved between successive KPrinter objects
 	 * @param m the mode to establish the KPrinter in (see QPrinter::PrinterMode)
 	 */
-	KPrinter(bool restore = true, QPrinter::PrinterMode m = QPrinter::ScreenResolution );
+	explicit KPrinter(bool restore = true, QPrinter::PrinterMode m = QPrinter::ScreenResolution );
 	/**
 	 * Destructor. This also saves the current KPrinter state for future printing.
 	 */
@@ -317,7 +314,7 @@ public:
 	/**
 	 * See QPrinter::setMinMax().
 	 */
-	void setMinMax(int, int);
+	void setMinMax(int min, int max);
 	/**
 	 * Returns the first page to be printed.
          * @deprecated Applications
@@ -462,22 +459,22 @@ public:
 	 * @see setRealPageSize
 	 * @obsolete
 	 */
-	QSize realPageSize() const;
+	KDE_DEPRECATED QSize realPageSize() const;
 	/**
 	 * DO NOT USE, WILL BE REMOVED.
 	 * @obsolete
 	 */
-	void setRealPageSize( QSize p );
+	KDE_DEPRECATED void setRealPageSize( const QSize &p );
 	/**
 	 * DO NOT USE, WILL BE REMOVED.
 	 * @obsolete
 	 */
-	void setRealDrawableArea( const QRect& r );
+	KDE_DEPRECATED void setRealDrawableArea( const QRect& r );
 	/**
 	 * DO NOT USE, WILL BE REMOVED.
 	 * @obsolete
 	 */
-	QRect realDrawableArea() const;
+	KDE_DEPRECATED QRect realDrawableArea() const;
 
 	void margins( uint *top, uint *left, uint *bottom, uint *right ) const;
 	void setMargins( uint top, uint left, uint bottom, uint right );
@@ -658,7 +655,7 @@ public:
 	 * Returns the complete set of print options from the KPrinter object. For internal use.
 	 * @returns the option set as a QMap object
 	 */
-	const QMap<QString,QString>& options() const;
+	QMap<QString,QString> options() const;
 	/**
 	 * Sets the option set in one operation. This method has some side effects like merging
 	 * the internal map with the one given in argument, but only for option in the form
@@ -747,6 +744,36 @@ public:
 	 */
 	QString docDirectory() const;
 
+    /// wrapped method from QPrinter
+    void setOutputFormat(QPrinter::OutputFormat format);
+    /// wrapped method from QPrinter
+    QPrinter::OutputFormat outputFormat () const;
+
+    /// wrapped method from QPrinter
+    void setPaperSource(QPrinter::PaperSource papersource);
+    /// wrapped method from QPrinter
+    QPrinter::PaperSource paperSource () const;
+
+    /// wrapped method from QPrinter
+    QList< int > supportedResolutions() const;
+
+    /// wrapped method from QPrinter
+    void setFontEmbeddingEnabled(bool enable);
+    /// wrapped method from QPrinter
+    bool fontEmbeddingEnabled() const;
+
+    /// wrapped method from QPrinter
+    void setDoubleSidedPrinting(bool enable);
+    /// wrapped method from QPrinter
+    bool doubleSidedPrinting() const;
+
+    /// wrapped method from QPrinter
+    QRect paperRect() const;
+    /// wrapped method from QPrinter
+    QRect pageRect () const;
+    /// wrapped method from QPrinter
+    QPrinter::PrinterState printerState () const;
+
 protected:
 	virtual int devType() const;
 	virtual QPaintEngine * paintEngine () const;
@@ -765,18 +792,14 @@ protected:
 private:
 	KPrinterPrivate* const d;
 	friend class KPrinterEngine;
+    friend class KPrinterImpl;
 };
 
 //**************************************************************************************
 
 // Utility functions
 
-KDEPRINT_EXPORT KPrinter::PageSize pageNameToPageSize(const QString& name);
+KDEPRINT_EXPORT KPrinter::PageSize pageNameToPageSize(const QString& name, bool *ok = 0);
 KDEPRINT_EXPORT const char* pageSizeToPageName(KPrinter::PageSize s);
-/**
- * DO NOT USE, WILL BE REMOVED.
- * @obsolete
- */
-QSize rangeToSize( const QString& );
 
 #endif
