@@ -29,8 +29,8 @@
 #include "kmprinter.h"
 #include "driver.h"
 
-#include <qfile.h>
-#include <qregexp.h>
+#include <QtCore/QFile>
+#include <QtCore/QRegExp>
 #include <QtDBus/QtDBus>
 #include <kinputdialog.h>
 #include <klocale.h>
@@ -39,12 +39,18 @@
 #include <kdebug.h>
 #include <kmimetype.h>
 #include <kmessagebox.h>
-#include <kprocess.h>
-#include <qprocess.h>
+#include <kshell.h>
+#include <QtCore/Q_PID>
 #include <kconfig.h>
 #include <kapplication.h>
 
 #include <stdlib.h>
+#include <unistd.h>
+#include <sys/wait.h>
+
+#ifndef WEXITSTATUS
+#define WEXITSTATUS(status) (((status) & 0xff00) >> 8)
+#endif
 
 void dumpOptions(const QMap<QString,QString>&);
 void initEditPrinter(KMPrinter *p)
@@ -148,7 +154,7 @@ bool KPrinterImpl::printFiles(KPrinter *p, const QStringList& f, bool flag)
 			KUrl url( p->outputFileName() );
 			if ( !url.isLocalFile() )
 			{
-				cmd = ( flag ? "mv" : "cp" ) + ( " %in $out{" + p->outputFileName() + "}" );
+				cmd = ( flag ? "mv" : "cp" ) + ( " %in $out{" + p->outputFileName() + '}' );
 			}
 			else
 			{
@@ -191,7 +197,7 @@ void KPrinterImpl::broadcastOption(const QString& key, const QString& value)
 
 int KPrinterImpl::dcopPrint(const QString& cmd, const QStringList& files, bool removeflag)
 {
-	kDebug(500) << "kdeprint: print command: " << cmd << endl;
+	kDebug(500) << "kdeprint: print command: " << cmd;
 
 	QDBusInterface kdeprintd( "org.kde.kded", "/modules/kdeprintd", "org.kde.KDEPrintd" );
 	QDBusReply<QString> reply = kdeprintd.call( "print", cmd, files, removeflag );
@@ -200,15 +206,16 @@ int KPrinterImpl::dcopPrint(const QString& cmd, const QStringList& files, bool r
 
 void KPrinterImpl::statusMessage(const QString& msg, KPrinter *printer)
 {
-	kDebug(500) << "kdeprint: status message: " << msg << endl;
-	KConfig	*conf = KMFactory::self()->printConfig();
-	conf->setGroup("General");
-	if (!conf->readEntry("ShowStatusMsg", true))
+	kDebug(500) << "kdeprint: status message: " << msg;
+	KConfig *cf = KMFactory::self()->printConfig();
+	
+	KConfigGroup conf = cf->group("General");
+	if (!conf.readEntry("ShowStatusMsg", true))
 		return;
 
 	QString	message(msg);
 	if (printer && !msg.isEmpty())
-		message.prepend(i18n("Printing document: %1", printer->docName())+"\n");
+		message.prepend(i18n("Printing document: %1", printer->docName())+'\n');
 
         QDBusInterface kdeprintd( "org.kde.kded", "/modules/kdeprintd", "org.kde.KDEPrintd" );
         (void)kdeprintd.call( "statusMessage", msg, int(getpid()), KGlobal::caption() );
@@ -230,7 +237,7 @@ bool KPrinterImpl::startPrinting(const QString& cmd, KPrinter *printer, const QS
 			printfiles.append(*it);
 		}
 		else
-			kDebug(500) << "File not found: " << (*it) << endl;
+			kDebug(500) << "File not found: " << (*it);
 
 	if (printfiles.count() > 0)
 	{
@@ -340,7 +347,7 @@ int KPrinterImpl::doFilterFiles(KPrinter *printer, QStringList& files, const QSt
 			return -1;
 		}
 	}
-	kDebug(500) << "kdeprint: filter command: " << filtercmd << endl;
+	kDebug(500) << "kdeprint: filter command: " << filtercmd;
 
 	QString	rin("%in"), rout("%out"), rpsl("%psl"), rpsu("%psu");
 	QString	ps = pageSizeToPageName( printer->option( "kde-printsize" ).isEmpty() ? printer->pageSize() : ( KPrinter::PageSize )printer->option( "kde-printsize" ).toInt() );
@@ -388,7 +395,7 @@ int KPrinterImpl::doFilterFiles(KPrinter *printer, QStringList& files, const QSt
 						else
 						{
 							KMessageBox::error(0,
-								i18n("<qt>Operation failed with message:<br>%1<br>Select another target format.</qt>", printer->errorMessage()));
+								i18n("<qt>Operation failed with message:<br />%1<br />Select another target format.</qt>", printer->errorMessage()));
 						}
 					}
 				}
@@ -475,7 +482,7 @@ int KPrinterImpl::autoConvertFiles(KPrinter *printer, QStringList& files, bool f
 						    "Do you want KDE to attempt and convert this file to %2?</qt>", mime, primaryMimeType),
 					       QString(),
 					       KGuiItem(i18n("Convert")),
-					       KGuiItem(i18n("Keep")),
+					       KGuiItem(i18n("Keep")), KStandardGuiItem::cancel(),
 					       QLatin1String("kdeprintAutoConvert"))) == KMessageBox::Yes)
 			{
 				// find the filter chain
@@ -483,7 +490,7 @@ int KPrinterImpl::autoConvertFiles(KPrinter *printer, QStringList& files, bool f
 				if (flist.count() == 0)
 				{
 					KMessageBox::error(NULL,
-							i18n("<qt>No appropriate filter was found to convert the file format %1 into %2.<br>"
+							i18n("<qt>No appropriate filter was found to convert the file format %1 into %2.<br />"
 							     "<ul>"
 							     "<li>Go to <i>System Options -> Commands</i> to look through the list of "
 							     "possible filters. Each filter executes an external program.</li>"
@@ -536,13 +543,13 @@ bool KPrinterImpl::setupSpecialCommand(QString& cmd, KPrinter *p, const QStringL
 	// XXX use KMacroExpander
 	s.replace("%psl", ps.toLower());
 	s.replace("%psu", ps);
-	s.replace("%out", "$out{" + p->outputFileName() + "}"); // Replace as last
+	s.replace("%out", "$out{" + p->outputFileName() + '}'); // Replace as last
 	cmd = s;
 	return true;
 }
 
 QString KPrinterImpl::quote(const QString& s)
-{ return KProcess::quote(s); }
+{ return KShell::quoteArg(s); }
 
 void KPrinterImpl::saveOptions(const QMap<QString,QString>& opts)
 {
@@ -552,9 +559,8 @@ void KPrinterImpl::saveOptions(const QMap<QString,QString>& opts)
 
 void KPrinterImpl::loadAppOptions()
 {
-	KSharedConfig::Ptr conf = KGlobal::config();
-	conf->setGroup("KPrinter Settings");
-	QStringList	opts = conf->readEntry("ApplicationOptions", QStringList());
+	KConfigGroup conf( KGlobal::config(), "KPrinter Settings");
+	QStringList	opts = conf.readEntry("ApplicationOptions", QStringList());
 	for (int i=0; i<opts.count(); i+=2)
 		if (opts[i].startsWith("app-"))
 			m_options[opts[i]] = opts[i+1];
@@ -567,9 +573,8 @@ void KPrinterImpl::saveAppOptions()
 		if (it.key().startsWith("app-"))
 			optlist << it.key() << it.value();
 
-	KSharedConfig::Ptr conf = KGlobal::config();
-	conf->setGroup("KPrinter Settings");
-	conf->writeEntry("ApplicationOptions", optlist);
+	KConfigGroup cg( KGlobal::config(), "KPrinter Settings");
+	cg.writeEntry("ApplicationOptions", optlist);
 }
 
 #include "kprinterimpl.moc"
