@@ -21,8 +21,8 @@
 #include "kprintpreview.h"
 #include "kmfactory.h"
 
-#include <qfile.h>
-#include <qlayout.h>
+#include <QtCore/QFile>
+#include <QtGui/QLayout>
 
 #include <kparts/part.h>
 #include <kaction.h>
@@ -45,7 +45,7 @@ KPreviewProc::KPreviewProc()
 : KProcess()
 {
 	m_bOk = false;
-	connect(this, SIGNAL(processExited(KProcess*)), SLOT(slotProcessExited(KProcess*)));
+	connect(this, SIGNAL(finished(int, QProcess::ExitStatus)), SLOT(slotProcessExited()));
 }
 
 KPreviewProc::~KPreviewProc()
@@ -54,7 +54,8 @@ KPreviewProc::~KPreviewProc()
 
 bool KPreviewProc::startPreview()
 {
-	if (start())
+	start();
+	if (waitForStarted())
 	{
 		QEventLoop eventLoop;
 		connect(this, SIGNAL(finished()), &eventLoop, SLOT(quit()));
@@ -65,14 +66,14 @@ bool KPreviewProc::startPreview()
 		return false;
 }
 
-void KPreviewProc::slotProcessExited(KProcess* proc)
+void KPreviewProc::slotProcessExited()
 {
 	emit finished();
-	if ( proc->normalExit() && proc->exitStatus() == 0 )
+	if ( exitStatus() == NormalExit && exitCode() == 0 )
 		m_bOk = true;
 	else
-		kDebug(500) << "KPreviewProc::slotProcessExited: normalExit=" << proc->normalExit()
-			<< " exitStatus=" << proc->exitStatus() << endl;
+		kDebug(500) << "KPreviewProc::slotProcessExited: exitStatus=" << exitStatus()
+			<< " exitCode=" << exitCode() << endl;
 }
 
 //*******************************************************************************************
@@ -106,7 +107,7 @@ public:
 
 static KLibFactory* componentFactory()
 {
-	kDebug(500) << "kdeprint: querying trader for 'application/postscript' service" << endl;
+	kDebug(500) << "kdeprint: querying trader for 'application/postscript' service";
 	KLibFactory	*factory(0);
 	KService::List offers = KMimeTypeTrader::self()->query(QLatin1String("application/postscript"), QString::fromLatin1("KParts/ReadOnlyPart"));
 	for (KService::List::ConstIterator it = offers.begin(); it != offers.end(); ++it)
@@ -135,7 +136,7 @@ static bool continuePrint(const QString& msg_, QWidget *parent, bool previewOnly
 	else
 	{
 		msg.append(" ").append(i18n("Do you want to continue printing anyway?"));
-		return (KMessageBox::warningContinueCancel(parent, msg, QString(), KGuiItem(i18n("Print"),"fileprint")) == KMessageBox::Continue);
+		return (KMessageBox::warningContinueCancel(parent, msg, QString(), KGuiItem(i18n("Print"),"document-print")) == KMessageBox::Continue);
 	}
 }
 
@@ -147,7 +148,7 @@ KPrintPreview::KPrintPreview(QWidget *parent, bool previewOnly)
 {
   setCaption( i18n("Print Preview") );
 
-	kDebug(500) << "kdeprint: creating preview dialog" << endl;
+	kDebug(500) << "kdeprint: creating preview dialog";
 	d->previewonly_ = previewOnly;
 
 	// create main view and actions
@@ -159,19 +160,19 @@ KPrintPreview::KPrintPreview(QWidget *parent, bool previewOnly)
     KAction *action = 0;
     action = new KAction(i18n("Print"), this);
 	d->actions_->addAction( "continue_print", action );
-    action->setIcon( KIcon( "fileprint" ) );
+    action->setIcon( KIcon( "document-print" ) );
     action->setShortcut( QKeySequence(Qt::Key_Return) );
     connect( action, SIGNAL( triggered( bool ) ), this, SLOT(accept()) );
 
     action = new KAction(i18n("Print"), this);
 	d->actions_->addAction( "continue_print", action );
-    action->setIcon( KIcon( "fileprint" ) );
+    action->setIcon( KIcon( "document-print" ) );
     action->setShortcut( QKeySequence(Qt::Key_Return) );
     connect( action, SIGNAL( triggered( bool ) ), this, SLOT(accept()) );
 
     action = new KAction(i18n("Cancel"), this);
 	d->actions_->addAction( "stop_print", action );
-    action->setIcon( KIcon( "stop" ) );
+    action->setIcon( KIcon( "process-stop" ) );
     action->setShortcut( QKeySequence(Qt::Key_Escape) );
     connect( action, SIGNAL( triggered( bool ) ), this, SLOT(reject()) );
 	}
@@ -186,7 +187,9 @@ KPrintPreview::~KPrintPreview()
 void KPrintPreview::initView(KLibFactory *factory)
 {
 	// load the component
-	d->gvpart_ = (KParts::ReadOnlyPart*)factory->create(d->mainwidget_, "KParts::ReadOnlyPart");
+	QStringList args;
+	args << "Print/Preview";
+	d->gvpart_ = (KParts::ReadOnlyPart*)factory->create(d->mainwidget_, "KParts::ReadOnlyPart", args);
 
 	// populate the toolbar
 	if (d->previewonly_)
@@ -258,12 +261,12 @@ bool KPrintPreview::preview(const QString& file, bool previewOnly, WId parentId)
 	KMimeType::Ptr mime = KMimeType::findByPath( file );
 	bool isPS = ( mime->name() == "application/postscript" );
 	if ( !isPS )
-		kDebug( 500 ) << "Previewing a non PostScript file, built-in preview disabled" << endl;
+		kDebug( 500 ) << "Previewing a non PostScript file, built-in preview disabled";
 
-	KConfig	*conf = KMFactory::self()->printConfig();
-	conf->setGroup("General");
+	KConfig *cf = KMFactory::self()->printConfig();
+	KConfigGroup conf = cf->group("General");
 	KLibFactory	*factory(0);
-	bool	externalPreview = conf->readEntry("ExternalPreview", false);
+	bool	externalPreview = conf.readEntry("ExternalPreview", false);
 	QWidget	*parentW = QWidget::find(parentId);
 	QString	exe;
 	if (!externalPreview && isPS && (factory = componentFactory()) != 0)
@@ -287,7 +290,7 @@ bool KPrintPreview::preview(const QString& file, bool previewOnly, WId parentId)
 	KPreviewProc	proc;
 	if (externalPreview && isPS )
 	{
-		exe = conf->readPathEntry("PreviewCommand", "gv");
+		exe = conf.readPathEntry("PreviewCommand", "gv");
 		if (KStandardDirs::findExe(exe).isEmpty())
 		{
 			QString	msg = i18n("The preview program %1 cannot be found. "
@@ -334,7 +337,7 @@ bool KPrintPreview::preview(const QString& file, bool previewOnly, WId parentId)
 	}
 	else if (!previewOnly)
 	{
-		return (KMessageBox::questionYesNo(parentW, i18n("Do you want to continue printing?"), QString(), KGuiItem(i18n("Print"),"fileprint"), KStandardGuiItem::cancel(), "continuePrinting") == KMessageBox::Yes);
+		return (KMessageBox::questionYesNo(parentW, i18n("Do you want to continue printing?"), QString(), KGuiItem(i18n("Print"),"document-print"), KStandardGuiItem::cancel(), "continuePrinting") == KMessageBox::Yes);
 	}
 	else
 		return false;
