@@ -22,16 +22,16 @@
 #define KPRINTPREVIEW_H
 
 #include <kdialog.h>
-#include <qstring.h>
+#include <QtCore/QString>
 #include <kprocess.h>
 
-class KLibFactory;
+class KPluginFactory;
 
 class KPrintPreview : public KDialog
 {
 	Q_OBJECT
 public:
-	KPrintPreview(QWidget *parent = 0, bool previewOnly = false);
+	explicit KPrintPreview(QWidget *parent = 0, bool previewOnly = false);
 	~KPrintPreview();
 
 	void openFile(const QString& file);
@@ -40,7 +40,7 @@ public:
 	static bool preview(const QString& file, bool previewOnly = false, WId parentId = 0);
 
 private:
-	void initView(KLibFactory*);
+	void initView(KPluginFactory*);
 
 private:
 	class KPrintPreviewPrivate;
@@ -60,7 +60,7 @@ Q_SIGNALS:
   void finished();
 
 protected Q_SLOTS:
-	void slotProcessExited(KProcess*);
+	void slotProcessExited();
 private:
 	bool m_bOk;
 };
