@@ -23,21 +23,21 @@
 #include "kdeprintcheck.h"
 #include "driverview.h"
 
-#include <qfile.h>
-#include <qregexp.h>
-#include <qdir.h>
-#include <qinputdialog.h>
-#include <qmap.h>
-#include <QTextStream>
+#include <QtCore/QFile>
+#include <QtCore/QRegExp>
+#include <QtCore/QDir>
+#include <QtGui/QInputDialog>
+#include <QtCore/QMap>
+#include <QtCore/QTextStream>
 
 
 
 #include <kstandarddirs.h>
 #include <klocale.h>
-#include <ksimpleconfig.h>
+#include <kconfig.h>
 #include <kdialog.h>
 #include <kdebug.h>
-#include <kprocess.h>
+#include <kshell.h>
 #include <klibloader.h>
 #include <kmessagebox.h>
 
@@ -77,11 +77,11 @@ KXmlCommand::KXmlCommand(const QString& xmlId)
 
 KXmlCommand::~KXmlCommand()
 {
-	//kDebug(500) << "deleting driver" << endl;
+	//kDebug(500) << "deleting driver";
 	delete d->m_driver;
-	//kDebug(500) << "deleting private data" << endl;
+	//kDebug(500) << "deleting private data";
 	delete d;
-	//kDebug(500) << "finished" << endl;
+	//kDebug(500) << "finished";
 }
 
 void KXmlCommand::init()
@@ -221,8 +221,8 @@ void KXmlCommand::check(bool use_xml)
 
 void KXmlCommand::loadDesktop()
 {
-	KSimpleConfig	conf(KStandardDirs::locate("data", "kdeprint/filters/"+name()+".desktop"));
-	conf.setGroup("KDE Print Filter Entry");
+	KConfig	_conf(KStandardDirs::locate("data", "kdeprint/filters/"+name()+".desktop"));
+	KConfigGroup conf( &_conf, "KDE Print Filter Entry");
 	d->m_description = conf.readEntry("Comment");
 	d->m_outputMime = conf.readEntry("MimeTypeOut");
 	d->m_inputMime = conf.readEntry("MimeTypeIn", QStringList());
@@ -232,8 +232,8 @@ void KXmlCommand::loadDesktop()
 
 void KXmlCommand::saveDesktop()
 {
-	KSimpleConfig	conf(KStandardDirs::locateLocal("data", "kdeprint/filters/"+name()+".desktop"));
-	conf.setGroup("KDE Print Filter Entry");
+	KConfig _conf(KStandardDirs::locateLocal("data", "kdeprint/filters/"+name()+".desktop"));
+	KConfigGroup conf( &_conf, "KDE Print Filter Entry");
 	conf.writeEntry("Comment", d->m_description);
 	conf.writeEntry("MimeTypeIn", d->m_inputMime);
 	conf.writeEntry("MimeTypeOut", d->m_outputMime);
@@ -356,7 +356,7 @@ DrBase* KXmlCommand::parseArgument(const QDomElement& e)
 	else
 		return 0;
 
-	opt->setName("_kde-" + d->m_name + "-" + e.attribute("name"));
+	opt->setName("_kde-" + d->m_name + '-' + e.attribute("name"));
 	setOptionText(opt, e.attribute("description"));
 	opt->set("format", e.attribute("format"));
 	opt->set("default", e.attribute("default"));
@@ -396,7 +396,7 @@ QString KXmlCommand::buildCommand(const QMap<QString,QString>& opts, bool pipein
 				}
 				else
 				{
-					format.replace( re, KProcess::quote( dopt->valueText() ) );
+					format.replace( re, KShell::quoteArg( dopt->valueText() ) );
 				}
 				str.append(format).append(" ");
 			}
@@ -466,7 +466,7 @@ void KXmlCommand::saveXml()
 QDomElement KXmlCommand::createIO(QDomDocument& doc, int n, const QString& tag)
 {
 	QDomElement	elem = doc.createElement(tag);
-	if (d->m_command.indexOf("%"+tag) != -1)
+	if (d->m_command.indexOf('%'+tag) != -1)
 	{
 		for (int i=0; i<2; i++)
 		{
@@ -655,7 +655,7 @@ QStringList KXmlCommandManager::commandListWithDescription()
 
 QString KXmlCommandManager::selectCommand(QWidget *parent)
 {
-	KLibrary *lib = KLibLoader::self()->library( "libkdeprint_management_module" );
+	KLibrary *lib = KLibLoader::self()->library( QLatin1String( "libkdeprint_management_module" ) );
 	if ( !lib )
 	{
 		KMessageBox::error( parent, i18n( "Unable to load KDE print management library: %1" ,  KLibLoader::self()->lastErrorMessage() ) );
@@ -663,7 +663,7 @@ QString KXmlCommandManager::selectCommand(QWidget *parent)
 	}
 	else
 	{
-		QString ( *func )( QWidget* ) = ( QString( * )( QWidget* ) )lib->symbol( "select_command" );
+		QString ( *func )( QWidget* ) = ( QString( * )( QWidget* ) )lib->resolveFunction( "select_command" );
 		if ( !func )
 		{
 			KMessageBox::error( parent, i18n( "Unable to find wizard object in management library." ) );
@@ -774,7 +774,7 @@ bool KXmlCommandManager::checkCommand(const QString& xmlId, int inputCheck, int
 	KXmlCommand	*xmlCmd = command(xmlId);
 	QString	errmsg;
 	bool	needDestroy(false);
-	//kDebug(500) << "checking command: " << xmlId << " (" << (xmlCmd != NULL) << ")" << endl;
+	//kDebug(500) << "checking command: " << xmlId << " (" << (xmlCmd != NULL) << ")";
 	if (!xmlCmd)
 	{
 		xmlCmd = loadCommand(xmlId, true);
