@@ -26,10 +26,10 @@
 #include "util.h"
 #include "kprinter.h"
 
-#include <qfile.h>
-#include <qdir.h>
-#include <qtextstream.h>
-#include <QStack>
+#include <QtCore/QFile>
+#include <QtCore/QDir>
+#include <QtCore/QTextStream>
+#include <QtCore/QStack>
 #include <kstandarddirs.h>
 #include <klocale.h>
 #include <kdebug.h>
