@@ -28,13 +28,13 @@
 #include "driver.h"
 #include "editentrydialog.h"
 
-#include <qfileinfo.h>
+#include <QtCore/QFileInfo>
 #include <kicon.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
 #include <kdebug.h>
 #include <kprinter.h>
-#include <qprocess.h>
+#include <QtCore/Q_PID>
 #include <kaction.h>
 #include <kmessagebox.h>
 #include <klibloader.h>
@@ -133,7 +133,7 @@ void KMLprManager::insertHandler(LprHandler *handler)
 {
     m_handlers.insert(handler->name(), handler);
     m_handlerlist.append(handler);
-    kDebug() << "Handler: " << handler->name() << endl;
+    kDebug() << "Handler: " << handler->name();
 }
 
 void KMLprManager::initHandlers()
@@ -151,15 +151,15 @@ void KMLprManager::initHandlers()
 	QStringList	l = KGlobal::dirs()->findAllResources("data", "kdeprint/lpr/*.la");
 	for (QStringList::ConstIterator it=l.begin(); it!=l.end(); ++it)
 	{
-		KLibrary	*library = KLibLoader::self()->library(QFile::encodeName(*it));
+		KLibrary	*library = KLibLoader::self()->library(*it);
 		if (library)
 		{
-			kDebug() << "loading external handler from " << *it << endl;
-			LprHandler*(*func)(KMManager*) = (LprHandler*(*)(KMManager*))(library->symbol("create_handler"));
+			kDebug() << "loading external handler from " << *it;
+			LprHandler*(*func)(KMManager*) = (LprHandler*(*)(KMManager*))(library->resolveFunction("create_handler"));
 			if (func)
 				insertHandler(func(this));
 			else
-				kDebug() << "couldn't find the symbol 'create_handler'" << endl;
+				kDebug() << "couldn't find the symbol 'create_handler'";
 		}
 	}
 
@@ -469,7 +469,7 @@ void KMLprManager::createPluginActions(KActionCollection *coll)
 {
 	KAction	*act = new KAction(i18n("&Edit printcap Entry..."), this);
 	coll->addAction( "plugin_editprintcap", act );
-	act->setIcon( KIcon( "kdeprint_report" ) );
+	act->setIcon( KIcon( "kdeprint-report" ) );
 	act->setActionGroup(pluginGroup());
 	connect( act, SIGNAL( triggered( bool ) ), this, SLOT(slotEditPrintcap() ) );
 }
@@ -489,7 +489,7 @@ void KMLprManager::slotEditPrintcap()
 		 "done by confirmed system administrator. This may "
 		 "prevent your printer from working. Do you want to "
 		 "continue?"), QString(), KStandardGuiItem::cont(),
-	    "editPrintcap") == KMessageBox::Cancel)
+	    KStandardGuiItem::cancel(), "editPrintcap") == KMessageBox::Cancel)
 		return;
 
 	PrintcapEntry	*entry = findEntry(m_currentprinter);
