@@ -20,13 +20,15 @@
 #ifndef LPQHELPER_H
 #define LPQHELPER_H
 
-#include <qlist.h>
-#include <qobject.h>
+#include <QtCore/QList>
+#include <QtCore/QObject>
 
 class KMJob;
 
 class LpqHelper : public QObject
 {
+	Q_OBJECT
+
 public:
 	LpqHelper(QObject *parent = 0);
 	~LpqHelper();
