@@ -24,9 +24,9 @@
 #include "lprsettings.h"
 #include "driver.h"
 
-#include <qfile.h>
-#include <qtextstream.h>
-#include <QStack>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
+#include <QtCore/QStack>
 #include <klocale.h>
 
 #include <unistd.h>
