@@ -26,8 +26,8 @@
 #include "kmmanager.h"
 #include "kprinter.h"
 
-#include <qfile.h>
-#include <qtextstream.h>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
 #include <klocale.h>
 #include <kdebug.h>
 #include <kstandarddirs.h>
