@@ -34,10 +34,10 @@
 #include <krandom.h>
 #include <kdebug.h>
 #include <kprocess.h>
-#include <qprocess.h>
-#include <qfile.h>
-#include <qtextstream.h>
-#include <qregexp.h>
+#include <QtCore/Q_PID>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
+#include <QtCore/QRegExp>
 
 #include <stdlib.h>
 #include <sys/wait.h>
@@ -257,25 +257,11 @@ DrMain* MaticHandler::loadDbDriver(const QString& path)
 		return NULL;
 	}
 
-	KPipeProcess	in;
-	QFile		out(tmpFile);
-	QString cmd = KProcess::quote(exe);
-	cmd += " -t lpd -d ";
-	cmd += KProcess::quote(comps[2]);
-	cmd += " -p ";
-	cmd += KProcess::quote(comps[1]);
-	if (in.open(cmd) && out.open(QIODevice::WriteOnly))
+	KProcess proc;
+	proc << exe << "-t" << "lpd" << "-d" << comps[2] << "-p" << comps[1];
+	proc.setStandardOutputFile(tmpFile);
+	if (!proc.execute())
 	{
-		QTextStream	tin(&in), tout(&out);
-		QString	line;
-		while (!tin.atEnd())
-		{
-			line = tin.readLine();
-			tout << line << endl;
-		}
-		in.close();
-		out.close();
-
 		DrMain	*driver = Foomatic2Loader::loadDriver(tmpFile);
 		if (driver)
 		{
@@ -330,10 +316,10 @@ bool MaticHandler::savePrinterDriver(KMPrinter *prt, PrintcapEntry *entry, DrMai
 		inFile.close();
 		tmpFile.close();
 
-		QString	cmd = "mv " + KProcess::quote(tmpFile.fileName()) + ' ' + KProcess::quote(outFile);
-		int	status = ::system(QFile::encodeName(cmd).data());
-		QFile::remove(tmpFile.fileName());
-		result = (status != -1 && WEXITSTATUS(status) == 0);
+		QFile::remove(outFile);
+		result = QFile::rename(tmpFile.fileName(), outFile);
+		if (!result)
+			QFile::remove(tmpFile.fileName());
 	}
 
 	if (!result)
