@@ -17,19 +17,19 @@
  *  Boston, MA 02110-1301, USA.
  **/
 
-#include <QEvent>
-#include <QLabel>
-#include <QLayout>
-#include <QPainter>
-#include <QScrollBar>
-#include <QStackedWidget>
-#include <QItemDelegate>
+#include "cjanuswidget.h"
+
+#include <QtCore/QEvent>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtGui/QPainter>
+#include <QtGui/QScrollBar>
+#include <QtGui/QStackedWidget>
+#include <QtGui/QItemDelegate>
 
 #include <klistwidget.h>
 #include <kseparator.h>
 
-#include "cjanuswidget.h"
-
 class CJanusWidget::CPage
 {
 public:
