@@ -31,11 +31,11 @@
 
 #include <kpagewidgetmodel.h>
 
-#include <qlayout.h>
+#include <QtGui/QLayout>
 #include <klocale.h>
 #include <kconfig.h>
 #include <kicon.h>
-#include <QFrame>
+#include <QtGui/QFrame>
 
 KMConfigDialog::KMConfigDialog(QWidget *parent, const char *name)
 : KPageDialog( parent )
@@ -57,7 +57,7 @@ KMConfigDialog::KMConfigDialog(QWidget *parent, const char *name)
 	KMFactory::self()->uiManager()->setupConfigDialog(this);
 
 	// initialize pages
-	KConfig	*conf = KMFactory::self()->printConfig();
+	KConfig *conf = KMFactory::self()->printConfig();
 	QListIterator<KMConfigPage*>	it(m_pages);
 	while(it.hasNext())
 		it.next()->loadConfig(conf);
@@ -89,10 +89,10 @@ void KMConfigDialog::addConfigPage(KMConfigPage *page)
 void KMConfigDialog::slotOk()
 {
 	// save configuration
-	KConfig	*conf = KMFactory::self()->printConfig();
+	KConfig *cf = KMFactory::self()->printConfig();
 	QListIterator<KMConfigPage*>	it(m_pages);
 	while(it.hasNext())
-		it.next()->saveConfig(conf);
+		it.next()->saveConfig(cf);
 	KMFactory::self()->saveConfig();
 
 	// close the dialog
