@@ -21,15 +21,16 @@
 #include "kmmanager.h"
 #include "kmfactory.h"
 
-#include <QGroupBox>
-#include <QVBoxLayout>
-#include <qlineedit.h>
-#include <qtoolbutton.h>
-#include <qlayout.h>
-#include <qlabel.h>
-#include <qapplication.h>
+#include <QtGui/QGroupBox>
+#include <QtGui/QBoxLayout>
+#include <QtGui/QLineEdit>
+#include <QtGui/QToolButton>
+#include <QtGui/QLayout>
+#include <QtGui/QLabel>
+#include <QtGui/QApplication>
 
 #include <klocale.h>
+#include <kconfiggroup.h>
 #include <kconfig.h>
 #include <kiconloader.h>
 #include <klistwidget.h>
@@ -40,7 +41,7 @@ KMConfigFilter::KMConfigFilter(QWidget *parent)
 {
 	setPageName(i18n("Filter"));
 	setPageHeader(i18n("Printer Filtering Settings"));
-	setPagePixmap("filter");
+	setPagePixmap("search-filter");
 
 	QGroupBox	*box = new QGroupBox(i18n("Printer Filter"), this);
 	box->setLayout( new QVBoxLayout );
@@ -50,9 +51,9 @@ KMConfigFilter::KMConfigFilter(QWidget *parent)
 	m_list2 = new KListWidget(box);
 	m_list2->setSelectionMode(KListWidget::ExtendedSelection);
 	m_add = new QToolButton( box );
-	m_add->setIcon(QApplication::isRightToLeft() ? KIcon( "back" ) : KIcon( "forward" ));
+	m_add->setIcon(QApplication::isRightToLeft() ? KIcon( "go-previous" ) : KIcon( "go-next" ));
 	m_remove = new QToolButton( box );
-	m_remove->setIcon(QApplication::isRightToLeft() ? KIcon( "forward" ) : KIcon( "back" ));
+	m_remove->setIcon(QApplication::isRightToLeft() ? KIcon( "go-next" ) : KIcon( "go-previous" ));
 	m_locationre = new QLineEdit(box);
 	QLabel	*lab = new QLabel(box);
 	lab->setText(i18n("The printer filtering allows you to view only a specific set of "
@@ -92,16 +93,16 @@ KMConfigFilter::KMConfigFilter(QWidget *parent)
 
 	connect(m_add, SIGNAL(clicked()), SLOT(slotAddClicked()));
 	connect(m_remove, SIGNAL(clicked()), SLOT(slotRemoveClicked()));
-	connect(m_list1, SIGNAL(selectionChanged()), SLOT(slotSelectionChanged()));
-	connect(m_list2, SIGNAL(selectionChanged()), SLOT(slotSelectionChanged()));
+	connect(m_list1, SIGNAL(itemSelectionChanged()), SLOT(slotSelectionChanged()));
+	connect(m_list2, SIGNAL(itemSelectionChanged()), SLOT(slotSelectionChanged()));
 	m_add->setEnabled(false);
 	m_remove->setEnabled(false);
 }
 
 void KMConfigFilter::loadConfig(KConfig *conf)
 {
-	conf->setGroup("Filter");
-	QStringList	m_plist = conf->readEntry("Printers", QStringList());
+	KConfigGroup cg( conf, "Filter");
+	QStringList	m_plist = cg.readEntry("Printers", QStringList());
 	QListIterator<KMPrinter*>	it(KMManager::self()->printerListComplete(false));
 	while (it.hasNext())
 	{
@@ -118,17 +119,17 @@ void KMConfigFilter::loadConfig(KConfig *conf)
 	}
 	m_list1->model()->sort(0);
 	m_list2->model()->sort(0);
-	m_locationre->setText(conf->readEntry("LocationRe"));
+	m_locationre->setText(cg.readEntry("LocationRe"));
 }
 
 void KMConfigFilter::saveConfig(KConfig *conf)
 {
-	conf->setGroup("Filter");
+	KConfigGroup cg( conf, "Filter");
 	QStringList	plist;
 	for (int i=0; i<m_list2->count(); i++)
 		plist << m_list2->item(i)->text();
-	conf->writeEntry("Printers", plist);
-	conf->writeEntry("LocationRe", m_locationre->text());
+	cg.writeEntry("Printers", plist);
+	cg.writeEntry("LocationRe", m_locationre->text());
 }
 
 void KMConfigFilter::transfer(KListWidget *from, KListWidget *to)
