@@ -19,14 +19,14 @@
 
 #include "kmconfigfonts.h"
 
-#include <QGroupBox>
-#include <QVBoxLayout>
+#include <QtGui/QGroupBox>
+#include <QtGui/QBoxLayout>
 #include <kpushbutton.h>
-#include <qlayout.h>
-#include <q3header.h>
-#include <qlabel.h>
-#include <qcheckbox.h>
-#include <qsettings.h>
+#include <QtGui/QLayout>
+#include <Qt3Support/Q3Header>
+#include <QtGui/QLabel>
+#include <QtGui/QCheckBox>
+#include <QtCore/QSettings>
 
 #include <klocale.h>
 #include <kconfig.h>
@@ -57,10 +57,10 @@ KMConfigFonts::KMConfigFonts(QWidget *parent)
 	m_fontpath->setSorting(-1);
 	m_addpath = new KUrlRequester(box2);
 	m_addpath->setMode(KFile::Directory|KFile::ExistingOnly|KFile::LocalOnly);
-	m_up = new KPushButton(KGuiItem(i18n("&Up"), "up"), box2);
-	m_down = new KPushButton(KGuiItem(i18n("&Down"), "down"), box2);
-	m_add = new KPushButton(KGuiItem(i18n("&Add"), "add"), box2);
-	m_remove = new KPushButton(KGuiItem(i18n("&Remove"), "editdelete"), box2);
+	m_up = new KPushButton(KGuiItem(i18n("&Up"), "go-up"), box2);
+	m_down = new KPushButton(KGuiItem(i18n("&Down"), "go-down"), box2);
+	m_add = new KPushButton(KGuiItem(i18n("&Add"), "list-add"), box2);
+	m_remove = new KPushButton(KGuiItem(i18n("&Remove"), "edit-delete"), box2);
 	QLabel	*lab0 = new QLabel(i18n("Additional director&y:"), box2);
 	lab0->setBuddy(m_addpath);
 
