@@ -19,11 +19,11 @@
 
 #include "kmconfiggeneral.h"
 
-#include <qlayout.h>
-#include <QGroupBox>
-#include <QVBoxLayout>
-#include <qcheckbox.h>
-#include <qlabel.h>
+#include <QtGui/QLayout>
+#include <QtGui/QGroupBox>
+#include <QtGui/QBoxLayout>
+#include <QtGui/QCheckBox>
+#include <QtGui/QLabel>
 
 #include <kpushbutton.h>
 #include <klocale.h>
@@ -44,7 +44,7 @@ KMConfigGeneral::KMConfigGeneral(QWidget *parent)
     setObjectName( "ConfigTimer" );
 	setPageName(i18n("General"));
 	setPageHeader(i18n("General Settings"));
-	setPagePixmap("fileprint");
+	setPagePixmap("document-print");
 
 	QGroupBox	*m_timerbox = new QGroupBox(i18n("Refresh Interval"), this);
 	m_timerbox->setLayout( new QVBoxLayout );
@@ -62,14 +62,14 @@ KMConfigGeneral::KMConfigGeneral(QWidget *parent)
 	m_defaulttestpage->setObjectName(QLatin1String("TestPageCheck"));
 	m_testpage = new KUrlRequester(m_testpagebox);
 	m_testpage->setMode(KFile::File|KFile::ExistingOnly|KFile::LocalOnly);
-	m_preview = new KPushButton(KGuiItem(i18n("Preview..."), "filefind"), m_testpagebox);
+	m_preview = new KPushButton(KGuiItem(i18n("Preview..."), "file-find"), m_testpagebox);
 	connect(m_defaulttestpage,SIGNAL(toggled(bool)),m_testpage,SLOT(setEnabled(bool)));
 	connect(m_defaulttestpage,SIGNAL(toggled(bool)),this,SLOT(setEnabledPreviewButton(bool)));
 	connect(m_preview,SIGNAL(clicked()),SLOT(slotTestPagePreview()));
         connect(m_testpage->lineEdit(),SIGNAL(textChanged ( const QString & )),this,SLOT(testPageChanged(const QString & )));
 	m_testpage->setDisabled(true);
 	m_preview->setDisabled(true);
-	m_defaulttestpage->setCursor(KCursor::handCursor());
+	m_defaulttestpage->setCursor(QCursor(Qt::PointingHandCursor));
 
 	QGroupBox	*m_statusbox = new QGroupBox(i18n("Miscellaneous"), this);
 	m_statusbox->setLayout( new QVBoxLayout );
@@ -117,31 +117,31 @@ void KMConfigGeneral::setEnabledPreviewButton(bool b)
     m_preview->setEnabled(!m_testpage->url().isEmpty() && b);
 }
 
-void KMConfigGeneral::loadConfig(KConfig *conf)
+void KMConfigGeneral::loadConfig(KConfig *_conf)
 {
-	conf->setGroup("General");
-	m_timer->setValue(conf->readEntry("TimerDelay", 5));
-	QString	tpage = conf->readPathEntry("TestPage");
+	KConfigGroup conf( _conf, "General");
+	m_timer->setValue(conf.readEntry("TimerDelay", 5));
+	QString	tpage = conf.readPathEntry("TestPage");
 	if (!tpage.isEmpty())
 	{
 		m_defaulttestpage->setChecked(true);
 		m_testpage->setUrl(KUrl(tpage));
 	}
-	m_statusmsg->setChecked(conf->readEntry("ShowStatusMsg", true));
-	m_uselast->setChecked(conf->readEntry("UseLast", true));
+	m_statusmsg->setChecked(conf.readEntry("ShowStatusMsg", true));
+	m_uselast->setChecked(conf.readEntry("UseLast", true));
 }
 
-void KMConfigGeneral::saveConfig(KConfig *conf)
+void KMConfigGeneral::saveConfig(KConfig *_conf)
 {
-	conf->setGroup("General");
-	conf->writeEntry("TimerDelay",m_timer->value());
-	conf->writePathEntry("TestPage",(m_defaulttestpage->isChecked() ? m_testpage->url().url() : QString()));
+	KConfigGroup conf( _conf, "General");
+	conf.writeEntry("TimerDelay",m_timer->value());
+	conf.writePathEntry("TestPage",(m_defaulttestpage->isChecked() ? m_testpage->url().url() : QString()));
 	if (m_defaulttestpage->isChecked() &&
 		KMimeType::findByFileContent(m_testpage->url().path())->name() != "application/postscript")
 		KMessageBox::sorry(this, i18n("The selected test page is not a PostScript file. You may not "
 		                              "be able to test your printer anymore."));
-	conf->writeEntry("ShowStatusMsg", m_statusmsg->isChecked());
-	conf->writeEntry("UseLast", m_uselast->isChecked());
+	conf.writeEntry("ShowStatusMsg", m_statusmsg->isChecked());
+	conf.writeEntry("UseLast", m_uselast->isChecked());
 }
 
 void KMConfigGeneral::slotTestPagePreview()
