@@ -20,7 +20,7 @@
 #include "kmiconview.h"
 #include "kmprinter.h"
 
-#include <qpainter.h>
+#include <QtGui/QPainter>
 #include <kiconloader.h>
 #include <kdebug.h>
 
@@ -64,14 +64,18 @@ void KMIconViewItem::updatePrinter(KMPrinter *p, int mode)
 	}
 	if (mode != m_mode || ((oldstate&0x4) != (m_state&0x4)) || (p && p->pixmap() != m_pixmap))
 	{
-		int	iconstate = (m_state&0x4 ? (int)K3Icon::DefaultState : (int)K3Icon::LockOverlay);
+		QStringList overlays;
+		if (m_state & 0x4) {
+			overlays.append("lock");
+                }
+
 		if (p)
 			m_pixmap = p->pixmap();
 		m_mode = mode;
 		if (m_mode == Qt::DockBottom)
-			setPixmap(DesktopIcon(m_pixmap, 0, iconstate));
+			setPixmap(DesktopIcon(m_pixmap, 0, K3Icon::DefaultState, overlays));
 		else
-			setPixmap(SmallIcon(m_pixmap, 0, iconstate));
+			setPixmap(SmallIcon(m_pixmap, 0, K3Icon::DefaultState, overlays));
 	}
 	//if (update)
 	//	repaint();
