@@ -20,9 +20,9 @@
 #include "kminfopage.h"
 #include "kmprinter.h"
 
-#include <qpixmap.h>
-#include <qlabel.h>
-#include <qlayout.h>
+#include <QtGui/QPixmap>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
 #include <kdialog.h>
 #include <klocale.h>
 #include <kiconloader.h>
