@@ -26,9 +26,9 @@
 #include "kprinter.h"
 #include "kmtimer.h"
 
-#include <qlayout.h>
-#include <qregexp.h>
-#include <qpushbutton.h>
+#include <QtGui/QLayout>
+#include <QtCore/QRegExp>
+#include <QtGui/QPushButton>
 #include <kmessagebox.h>
 #include <kinputdialog.h>
 #include <klistwidget.h>
@@ -86,21 +86,19 @@ void KMInstancePage::addButton(const QString& txt, const QString& pixmap, const
 
 void KMInstancePage::initActions()
 {
-	addButton(i18n("New..."), "filenew", SLOT(slotNew()));
-	addButton(i18n("Copy..."), "editcopy", SLOT(slotCopy()));
-	addButton(i18n("Remove"), "edittrash", SLOT(slotRemove()));
+	addButton(i18n("New..."), "document-new", SLOT(slotNew()));
+	addButton(i18n("Copy..."), "edit-copy", SLOT(slotCopy()));
+	addButton(i18n("Remove"), "edit-trash", SLOT(slotRemove()));
 	m_buttons.append(0);
 	addButton(i18n("Set as Default"), "exec", SLOT(slotDefault()));
 	addButton(i18n("Settings"), "configure", SLOT(slotSettings()));
 	m_buttons.append(0);
-	addButton(i18n("Test..."), "fileprint", SLOT(slotTest()));
+	addButton(i18n("Test..."), "document-print", SLOT(slotTest()));
 }
 
 void KMInstancePage::setPrinter(KMPrinter *p)
 {
-    Q_ASSERT( m_view->currentItem() );
-
-	QString	oldText = m_view->currentItem()->text();
+	QString	oldText = m_view->currentItem() ? m_view->currentItem()->text() : QString();
 
 	m_view->clear();
 	m_printer = p;
@@ -115,9 +113,9 @@ void KMInstancePage::setPrinter(KMPrinter *p)
 		{
       KMPrinter *printer(it.next());
 			QStringList	pair = printer->name().split('/', QString::SkipEmptyParts);
-			
+
             QListWidgetItem* item = new QListWidgetItem();
-            item->setIcon(SmallIcon((printer->isSoftDefault() ? "exec" : "fileprint")));
+            item->setIcon(SmallIcon((printer->isSoftDefault() ? "exec" : "document-print")));
             item->setText(pair.count() > 1 ? pair[1] : i18n("(Default)"));
             m_view->addItem(item);
 		}
@@ -163,10 +161,10 @@ void KMInstancePage::slotNew()
 
 void KMInstancePage::slotRemove()
 {
+	if(!m_view->currentItem()) return;
 	KMTimer::self()->hold();
 	bool	reload(false);
 
-    Q_ASSERT(m_view->currentItem());
 
 	QString	src = m_view->currentItem()->text();
 	if (!src.isEmpty())
@@ -187,9 +185,9 @@ void KMInstancePage::slotRemove()
 
 void KMInstancePage::slotCopy()
 {
+    if(!m_view->currentItem()) return;
 	KMTimer::self()->hold();
 
-    Q_ASSERT( m_view->currentItem() );
 
 	QString	src = m_view->currentItem()->text();
 	if (!src.isEmpty())
@@ -218,10 +216,10 @@ void KMInstancePage::slotCopy()
 
 void KMInstancePage::slotSettings()
 {
+    if(!m_view->currentItem())
+       return;
 	KMTimer::self()->hold();
 
-    Q_ASSERT( m_view->currentItem() );
-
 	QString	src = m_view->currentItem()->text();
 	if (!src.isEmpty())
 	{
@@ -254,10 +252,10 @@ void KMInstancePage::slotSettings()
 
 void KMInstancePage::slotDefault()
 {
+    if(!m_view->currentItem())
+       return;
 	KMTimer::self()->hold();
 
-    Q_ASSERT( m_view->currentItem() );
-
 	QString	src = m_view->currentItem()->text();
 	if (!src.isEmpty())
 	{
@@ -272,10 +270,10 @@ void KMInstancePage::slotDefault()
 
 void KMInstancePage::slotTest()
 {
+    if(!m_view->currentItem())
+      return;
 	KMTimer::self()->hold();
 
-    Q_ASSERT( m_view->currentItem() );
-
 	QString	src = m_view->currentItem()->text();
 	if (!src.isEmpty())
 	{
@@ -284,7 +282,7 @@ void KMInstancePage::slotTest()
 		KMPrinter	*mpr = KMFactory::self()->virtualManager()->findInstance(m_printer,src);
 		if (!mpr)
 			KMessageBox::error(this,i18n("Internal error: printer not found."));
-		else if (KMessageBox::warningContinueCancel(this, i18n("You are about to print a test page on %1. Do you want to continue?", mpr->printerName()), QString(), KGuiItem(i18n("Print Test Page")), "printTestPage") == KMessageBox::Continue)
+		else if (KMessageBox::warningContinueCancel(this, i18n("You are about to print a test page on %1. Do you want to continue?", mpr->printerName()), QString(), KGuiItem(i18n("Print Test Page")), KStandardGuiItem::cancel(), "printTestPage") == KMessageBox::Continue)
 		{
 			if (!KMFactory::self()->virtualManager()->testInstance(mpr))
 				KMessageBox::error(this, i18n("Unable to send test page to %1.", mpr->printerName()));
