@@ -45,17 +45,17 @@
 #include <kcursor.h>
 #include <kmenubar.h>
 #include <kdebug.h>
-#include <kwin.h>
+#include <kwindowsystem.h>
 #include <kio/netaccess.h>
-#include <qtimer.h>
-#include <qlayout.h>
+#include <QtCore/QTimer>
+#include <QtGui/QLayout>
 #include <stdlib.h>
-#include <qlineedit.h>
+#include <QtGui/QLineEdit>
 #include <kdialog.h>
-#include <qcheckbox.h>
+#include <QtGui/QCheckBox>
 #include <kconfig.h>
-#include <QDropEvent>
-#include <QMenuItem>
+#include <QtGui/QKeyEvent>
+#include <QtGui/QMenuItem>
 #include <kactionmenu.h>
 #include <ktoggleaction.h>
 
@@ -84,7 +84,7 @@ void KJobListView::dragEnterEvent( QDragEnterEvent *event )
 }
 
 KMJobViewer::KMJobViewer(QWidget *parent)
-: KMainWindow(parent)
+: KXmlGuiWindow(parent)
 {
 	m_view = 0;
 	m_pop = 0;
@@ -99,10 +99,10 @@ KMJobViewer::KMJobViewer(QWidget *parent)
 	if (m_standalone)
 	{
 		setCaption(i18n("No Printer"));
-		KConfig *conf = KMFactory::self()->printConfig();
+		KConfig *cf = KMFactory::self()->printConfig();
+		KConfigGroup conf = cf->group("Jobs");
 		QSize defSize( 550, 250 );
-		conf->setGroup( "Jobs" );
-		resize( conf->readEntry( "Size", defSize ) );
+		resize( conf.readEntry( "Size", defSize ) );
 	}
 }
 
@@ -110,10 +110,10 @@ KMJobViewer::~KMJobViewer()
 {
 	if (m_standalone)
 	{
-		kDebug( 500 ) << "Destroying stand-alone job viewer window" << endl;
-		KConfig *conf = KMFactory::self()->printConfig();
-		conf->setGroup( "Jobs" );
-		conf->writeEntry( "Size", size() );
+		kDebug( 500 ) << "Destroying stand-alone job viewer window";
+		KConfig *cf = KMFactory::self()->printConfig();
+		KConfigGroup conf = cf->group("Jobs" );
+		conf.writeEntry( "Size", size() );
 		emit viewerDestroyed(this);
 	}
 	removeFromManager();
@@ -145,7 +145,7 @@ void KMJobViewer::updateCaption()
 	if (!m_standalone)
 		return;
 
-	QString	pixname("fileprint");
+	QString	pixname("document-print");
 	if (!m_prname.isEmpty())
 	{
 		setCaption(i18n("Print Jobs for %1", m_prname));
@@ -157,8 +157,8 @@ void KMJobViewer::updateCaption()
 	{
 		setCaption(i18n("No Printer"));
 	}
-#ifndef Q_OS_WIN
-	KWin::setIcons(winId(), DesktopIcon(pixname), SmallIcon(pixname));
+#ifdef Q_WS_X11
+	KWindowSystem::setIcons(winId(), DesktopIcon(pixname), SmallIcon(pixname));
 #endif
 }
 
@@ -248,7 +248,7 @@ void KMJobViewer::init()
 		KMFactory::self()->uiManager()->setupJobViewer(m_view);
 		m_view->setFrameStyle(QFrame::WinPanel|QFrame::Sunken);
 		m_view->setLineWidth(1);
-		connect(m_view,SIGNAL(selectionChanged()),SLOT(slotSelectionChanged()));
+		connect(m_view,SIGNAL(itemSelectionChanged ()),SLOT(slotSelectionChanged()));
 		connect(m_view,SIGNAL(rightButtonPressed(QTreeWidgetItem*,const QPoint&,int)),SLOT(slotRightClicked(QTreeWidgetItem*,const QPoint&,int)));
 		setCentralWidget(m_view);
 	}
@@ -261,26 +261,26 @@ void KMJobViewer::initActions()
 	// job actions
 	KAction	*hact = new KAction(i18n("&Hold"), this);
 	actionCollection()->addAction( "job_hold", hact );
-	hact->setIcon( KIcon( "stop" ) );
+	hact->setIcon( KIcon( "process-stop" ) );
 	connect( hact, SIGNAL( triggered( bool ) ), this,SLOT(slotHold()) );
 
 	KAction	*ract = new KAction(i18n("&Resume"), this);
 	actionCollection()->addAction( "job_resume", ract );
-	ract->setIcon( KIcon( "run" ) );
+	ract->setIcon( KIcon( "system-run" ) );
 	connect( ract, SIGNAL( triggered( bool ) ), this,SLOT(slotResume()) );
 
 	KAction	*dact = new KAction(i18n("Remo&ve"), this);
 	actionCollection()->addAction( "job_remove", dact );
-	dact->setIcon( KIcon( "edittrash" ) );
+	dact->setIcon( KIcon( "edit-trash" ) );
 	dact->setShortcut( QKeySequence(Qt::Key_Delete) );
 	connect( dact, SIGNAL( triggered( bool ) ), this,SLOT(slotRemove()) );
 
 	KAction *sact = new KAction(i18n("Res&tart"), this);
 	actionCollection()->addAction( "job_restart", sact );
-	sact->setIcon( KIcon( "redo" ) );
+	sact->setIcon( KIcon( "edit-redo" ) );
 	connect( sact, SIGNAL( triggered( bool ) ), this, SLOT(slotRestart()) );
 
-	KActionMenu *mact = new KActionMenu(KIcon("fileprint"), i18n("&Move to Printer"), this);
+	KActionMenu *mact = new KActionMenu(KIcon("document-print"), i18n("&Move to Printer"), this);
 	actionCollection()->addAction( "job_move", mact );
 	mact->setDelayed(false);
 	connect(mact->menu(),SIGNAL(triggered(QAction*)),SLOT(slotMove(QAction*)));
@@ -297,7 +297,6 @@ void KMJobViewer::initActions()
 	KToggleAction *uact = new KToggleAction(i18n("Show Only User Jobs"), this);
 	actionCollection()->addAction( "view_user_jobs", uact );
 	uact->setIcon( KIcon( "personal" ) );
-	uact->setCheckedState(KGuiItem(i18n("Hide Only User Jobs"),"personal"));
 	connect(uact, SIGNAL(toggled(bool)), SLOT(slotUserOnly(bool)));
 
 	m_userfield = new QLineEdit(0);
@@ -326,7 +325,7 @@ void KMJobViewer::initActions()
 	}
 
 	// Filter actions
-	KActionMenu	*fact = new KActionMenu(KIcon("kdeprint_printer"), i18n("&Select Printer"), this);
+	KActionMenu	*fact = new KActionMenu(KIcon("kdeprint-printer"), i18n("&Select Printer"), this);
 	actionCollection()->addAction( "filter_modify", fact );
 	fact->setDelayed(false);
 	connect(fact->menu(),SIGNAL(triggered(QAction*)),SLOT(slotPrinterSelected(QAction*)));
@@ -359,7 +358,7 @@ void KMJobViewer::initActions()
 		// refresh action
 		KAction *action = new KAction(i18n("Refresh"), this );
 		actionCollection()->addAction( "refresh", action );
-		action->setIcon( KIcon( "reload" ) );
+		action->setIcon( KIcon( "view-refresh" ) );
 		connect( action, SIGNAL( triggered( bool ) ), this, SLOT(slotRefresh() ) );
 
 		// create status bar
@@ -386,7 +385,7 @@ void KMJobViewer::buildPrinterMenu(QMenu *menu, bool use_all, bool use_specials)
 	int	i(0);
 	if (use_all)
 	{
-		QAction *action = menu->addAction(QIcon(SmallIcon("fileprint")), i18n("All Printers"));
+		QAction *action = menu->addAction(QIcon(SmallIcon("document-print")), i18n("All Printers"));
 		action->setData(i++);
 		menu->addSeparator();
 	}
@@ -747,12 +746,12 @@ void KMJobViewer::slotConfigure()
 	KMTimer::self()->hold();
 
 	KDialog	dlg(this);
-  dlg.setCaption( i18n("Print Job Settings") );
-  dlg.setButtons( KDialog::Ok|KDialog::Cancel );
+	dlg.setCaption( i18n("Print Job Settings") );
+	dlg.setButtons( KDialog::Ok|KDialog::Cancel );
 	KMConfigJobs	*w = new KMConfigJobs(&dlg);
 	dlg.setMainWidget(w);
 	dlg.resize(300, 10);
-	KConfig	*conf = KMFactory::self()->printConfig();
+	KConfig *conf = KMFactory::self()->printConfig();
 	w->loadConfig(conf);
 	if (dlg.exec())
 	{
