@@ -36,10 +36,10 @@
 #include "messagewindow.h"
 
 #include <kmenubar.h>
-#include <qtimer.h>
-#include <qcombobox.h>
-#include <qlabel.h>
-#include <qlayout.h>
+#include <QtCore/QTimer>
+#include <QtGui/QComboBox>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
 #include <kmessagebox.h>
 #include <kaction.h>
 #include <kicon.h>
@@ -50,13 +50,13 @@
 #include <kmenu.h>
 #include <klibloader.h>
 #include <kdialog.h>
-#include <ksimpleconfig.h>
 #include <kstandarddirs.h>
 #include <kapplication.h>
 #include <ktoolinvocation.h>
 #include <kactioncollection.h>
 #include <ktoggleaction.h>
 #include <kactionmenu.h>
+#include <kdesktopfile.h>
 
 #undef m_manager
 #define	m_manager	KMFactory::self()->manager()
@@ -153,31 +153,32 @@ void KMMainView::loadParameters()
 
 void KMMainView::restoreSettings()
 {
-	KConfig	*conf = KMFactory::self()->printConfig();
-	conf->setGroup("General");
-	setViewType((KMPrinterView::ViewType)conf->readEntry("ViewType", int(KMPrinterView::Icons)));
-	setOrientation(conf->readEntry("Orientation", 1));
-	bool 	view = conf->readEntry("ViewToolBar", false);
+	KConfig *cf = KMFactory::self()->printConfig();
+	KConfigGroup conf = cf->group("General");
+	
+	setViewType((KMPrinterView::ViewType)conf.readEntry("ViewType", int(KMPrinterView::Icons)));
+	setOrientation(conf.readEntry("Orientation", 1));
+	bool 	view = conf.readEntry("ViewToolBar", false);
 	slotToggleToolBar(view);
 	((KToggleAction*)m_actions->action("view_toolbar"))->setChecked(view);
-	view = conf->readEntry("ViewMenuBar", true);
+	view = conf.readEntry("ViewMenuBar", true);
 	slotToggleMenuBar( view );
 	static_cast<KToggleAction*>( m_actions->action( "view_menubar" ) )->setChecked( view );
-	view = conf->readEntry("ViewPrinterInfos", true);
+	view = conf.readEntry("ViewPrinterInfos", true);
 	slotShowPrinterInfos(view);
 	((KToggleAction*)m_actions->action("view_printerinfos"))->setChecked(view);
 }
 
 void KMMainView::saveSettings()
 {
-	KConfig	*conf = KMFactory::self()->printConfig();
-	conf->setGroup("General");
-	conf->writeEntry("ViewType",(int)m_printerview->viewType());
-	conf->writeEntry("Orientation",orientation() == Qt::Horizontal ? 1 : 0);
-	conf->writeEntry("ViewToolBar",((KToggleAction*)m_actions->action("view_toolbar"))->isChecked());
-	conf->writeEntry("ViewMenuBar",static_cast<KToggleAction*>( m_actions->action("view_menubar") )->isChecked());
-	conf->writeEntry("ViewPrinterInfos",((KToggleAction*)m_actions->action("view_printerinfos"))->isChecked());
-	conf->sync();
+	KConfig *cf = KMFactory::self()->printConfig();
+	KConfigGroup conf = cf->group("General");
+	conf.writeEntry("ViewType",(int)m_printerview->viewType());
+	conf.writeEntry("Orientation",orientation() == Qt::Horizontal ? 1 : 0);
+	conf.writeEntry("ViewToolBar",((KToggleAction*)m_actions->action("view_toolbar"))->isChecked());
+	conf.writeEntry("ViewMenuBar",static_cast<KToggleAction*>( m_actions->action("view_menubar") )->isChecked());
+	conf.writeEntry("ViewPrinterInfos",((KToggleAction*)m_actions->action("view_printerinfos"))->isChecked());
+	conf.sync();
 }
 
 void KMMainView::initActions()
@@ -185,12 +186,12 @@ void KMMainView::initActions()
 	KIconSelectAction *vact = new KIconSelectAction(i18n("&View"), this);
 	m_actions->addAction( "view_change", vact );
 	QStringList	iconlst;
-	iconlst << "view_icon" << "view_detailed" << "view_tree";
+	iconlst << "view_icon" << "fileview-detailed" << "view_tree";
 	vact->setItems(i18n("&Icons,&List,&Tree").split(',', QString::SkipEmptyParts), iconlst);
 	vact->setCurrentItem(0);
 	connect(vact,SIGNAL(triggered(int)),SLOT(slotChangeView(int)));
 
-	KActionMenu	*stateAct = new KActionMenu(KIcon("kdeprint_printstate"), i18n("Start/Stop Printer"), this );
+	KActionMenu	*stateAct = new KActionMenu(KIcon("kdeprint-printstate"), i18n("Start/Stop Printer"), this );
 	m_actions->addAction( "printer_state_change", stateAct );
 	stateAct->setDelayed(false);
 	KAction *action = new KAction(i18n("&Start Printer"), this );
@@ -205,7 +206,7 @@ void KMMainView::initActions()
 	connect( action, SIGNAL( triggered( bool ) ),this,SLOT(slotChangePrinterState()) );
 	stateAct->addAction(action);
 
-	stateAct = new KActionMenu(KIcon("kdeprint_queuestate"), i18n("Enable/Disable Job Spooling"), this );
+	stateAct = new KActionMenu(KIcon("printer-queue-state"), i18n("Enable/Disable Job Spooling"), this );
 	m_actions->addAction( "printer_spool_change", stateAct );
 	stateAct->setDelayed(false);
 
@@ -223,7 +224,7 @@ void KMMainView::initActions()
 
 	action = new KAction(i18n("&Remove"), this );
 	m_actions->addAction( "printer_remove", action );
-	action->setIcon( KIcon( "edittrash" ) );
+	action->setIcon( KIcon( "edit-trash" ) );
 	connect( action, SIGNAL( triggered( bool ) ), this,SLOT(slotRemove()) );
 
 	action = new KAction(i18n("&Configure..."), this );
@@ -233,101 +234,98 @@ void KMMainView::initActions()
 
 	action = new KAction(i18n("Add &Printer/Class..."), this );
 	m_actions->addAction( "printer_add", action );
-	action->setIcon( KIcon( "kdeprint_addprinter" ) );
+	action->setIcon( KIcon( "kdeprint-addprinter" ) );
 	connect( action, SIGNAL( triggered( bool ) ), this,SLOT(slotAdd()) );
 
 	action = new KAction(i18n("Add &Special (pseudo) Printer..."), this );
 	m_actions->addAction( "printer_add_special", action );
-	action->setIcon( KIcon( "kdeprint_addpseudo" ) );
+	action->setIcon( KIcon( "kdeprint-addpseudo" ) );
 	connect( action, SIGNAL( triggered( bool ) ), this,SLOT(slotAddSpecial()) );
 
 	action = new KAction(i18n("Set as &Local Default"), this );
 	m_actions->addAction( "printer_hard_default", action );
-	action->setIcon( KIcon( "kdeprint_defaulthard" ) );
+	action->setIcon( KIcon( "kdeprint-defaulthard" ) );
 	connect( action, SIGNAL( triggered( bool ) ), this,SLOT(slotHardDefault()) );
 
 	action = new KAction(i18n("Set as &User Default"), this );
 	m_actions->addAction( "printer_soft_default", action );
-	action->setIcon( KIcon( "kdeprint_defaultsoft" ) );
+	action->setIcon( KIcon( "kdeprint-defaultsoft" ) );
 	connect( action, SIGNAL( triggered( bool ) ), this,SLOT(slotSoftDefault()) );
 
 	action = new KAction(i18n("&Test Printer..."), this );
 	m_actions->addAction( "printer_test", action );
-	action->setIcon( KIcon( "kdeprint_testprinter" ) );
+	action->setIcon( KIcon( "kdeprint-testprinter" ) );
 	connect( action, SIGNAL( triggered( bool ) ), this,SLOT(slotTest()) );
 
 	action = new KAction(i18n("Configure &Manager..."), this);
 	m_actions->addAction( "manager_configure", action );
-	action->setIcon( KIcon( "kdeprint_configmgr" ) );
+	action->setIcon( KIcon( "kdeprint-configmgr" ) );
 	connect( action, SIGNAL( triggered( bool ) ), this,SLOT(slotManagerConfigure()) );
 
 	action = new KAction(i18n("Initialize Manager/&View"), this);
 	m_actions->addAction( "view_refresh", action );
-	action->setIcon( KIcon( "reload" ) );
+	action->setIcon( KIcon( "view-refresh" ) );
 	connect( action, SIGNAL( triggered( bool ) ), this,SLOT(slotInit()) );
 
 	KIconSelectAction *dact = new KIconSelectAction(i18n("&Orientation"), this);
 	m_actions->addAction( "orientation_change", dact );
 	iconlst.clear();
-	iconlst << "view_top_bottom" << "view_left_right";
+	iconlst << "view-top-bottom" << "view-left-right";
 	dact->setItems(i18n("&Vertical,&Horizontal").split(',', QString::SkipEmptyParts), iconlst);
 	dact->setCurrentItem(0);
 	connect(dact,SIGNAL(triggered(int)),SLOT(slotChangeDirection(int)));
 
 	action = new KAction(i18n("R&estart Server"), this);
 	m_actions->addAction( "server_restart", action );
-	action->setIcon( KIcon( "kdeprint_restartsrv" ) );
+	action->setIcon( KIcon( "kdeprint-restartsrv" ) );
 	connect( action, SIGNAL( triggered( bool ) ), this,SLOT(slotServerRestart()) );
 
 	action = new KAction(i18n("Configure &Server..."), this);
 	m_actions->addAction( "server_configure", action );
-	action->setIcon( KIcon( "kdeprint_configsrv" ) );
+	action->setIcon( KIcon( "kdeprint-configsrv" ) );
 	connect( action, SIGNAL( triggered( bool ) ), this,SLOT(slotServerConfigure()) );
 
 
 	KToggleAction *tact = new KToggleAction(i18n("Show &Toolbar"), this);
 	m_actions->addAction( "view_toolbar", tact );
-	tact->setCheckedState(KGuiItem(i18n("Hide &Toolbar")));
 	connect(tact,SIGNAL(toggled(bool)),SLOT(slotToggleToolBar(bool)));
 	tact = new KToggleAction( i18n( "Show Me&nu Toolbar" ), this);
 	m_actions->addAction( "view_menubar", tact );
-	tact->setCheckedState(KGuiItem(i18n("Hide Me&nu Toolbar")));
 	connect( tact, SIGNAL( toggled( bool ) ), SLOT( slotToggleMenuBar( bool ) ) );
 	tact = new KToggleAction(i18n("Show Pr&inter Details"), this);
 	m_actions->addAction( "view_printerinfos", tact );
-	tact->setIcon( KIcon( "kdeprint_printer_infos" ) );
-	tact->setCheckedState(KGuiItem(i18n("Hide Pr&inter Details"),"kdeprint_printer_infos"));
+	tact->setIcon( KIcon( "kdeprint-printer-infos" ) );
 	tact->setChecked(true);
 	connect(tact,SIGNAL(toggled(bool)),SLOT(slotShowPrinterInfos(bool)));
 
 	tact = new KToggleAction(i18n("Toggle Printer &Filtering"), this);
 	m_actions->addAction( "view_pfilter", tact );
-	tact->setIcon( KIcon( "filter" ) );
+	tact->setIcon( KIcon( "search-filter" ) );
 	tact->setChecked(KMManager::self()->isFilterEnabled());
 	connect(tact, SIGNAL(toggled(bool)), SLOT(slotToggleFilter(bool)));
 
 	action = new KAction( i18n( "%1 &Handbook" , QString("KDEPrint") ), this );
 	m_actions->addAction( "invoke_help", action );
-	action->setIcon( KIcon( "contents" ) );
+	action->setIcon( KIcon( "help-contents" ) );
 	connect( action, SIGNAL( triggered( bool ) ), this, SLOT( slotHelp() ) );
 
 	action = new KAction( i18n( "%1 &Web Site" , QString("KDEPrint") ), this );
 	m_actions->addAction( "invoke_web", action );
-	action->setIcon( KIcon( "network" ) );
+	action->setIcon( KIcon( "network-wired" ) );
 	connect( action, SIGNAL( triggered( bool ) ), this, SLOT( slotHelp() ) );
 
-	KActionMenu	*mact = new KActionMenu(KIcon("package_utilities"), i18n("Pri&nter Tools"), this);
+	KActionMenu	*mact = new KActionMenu(KIcon("package-utilities"), i18n("Pri&nter Tools"), this);
 	m_actions->addAction( "printer_tool", mact );
 	mact->setDelayed(false);
 	connect(mact->menu(), SIGNAL(triggered(QAction*)), SLOT(slotToolSelected(QAction*)));
 	QStringList	files = KGlobal::dirs()->findAllResources("data", "kdeprint/tools/*.desktop");
 	for (QStringList::ConstIterator it=files.begin(); it!=files.end(); ++it)
 	{
-		KSimpleConfig	conf(*it);
-		conf.setGroup("Desktop Entry");
-		QAction *action = mact->menu()->addAction(conf.readEntry("Name", "Unnamed"));
+		const KDesktopFile conf(*it);
+		const KConfigGroup cg = conf.desktopGroup();
+		QAction *action = mact->menu()->addAction(cg.readEntry("Name", "Unnamed"));
 		action->setData(mact->menu()->actions().count());
-		m_toollist << conf.readEntry("X-KDE-Library");
+		m_toollist << cg.readEntry("X-KDE-Library");
 	}
 
 	// add actions to the toolbar
@@ -432,7 +430,7 @@ void KMMainView::slotRefresh()
 
 void KMMainView::slotTimer()
 {
-	kDebug() << "KMMainView::slotTimer" << endl;
+	kDebug() << "KMMainView::slotTimer";
 	QList<KMPrinter*> printerlist = m_manager->printerList();
 	bool ok = m_manager->errorMsg().isEmpty();
 	m_printerview->setPrinterList(&printerlist);
@@ -520,7 +518,7 @@ int KMMainView::viewType() const
 
 void KMMainView::slotChangeView(int ID)
 {
-	kDebug() << "KMMainView::slotChangeView" << endl;
+	kDebug() << "KMMainView::slotChangeView";
 	if (ID >= KMPrinterView::Icons && ID <= KMPrinterView::Tree)
 		m_printerview->setViewType((KMPrinterView::ViewType)ID);
 }
@@ -733,7 +731,7 @@ void KMMainView::slotTest()
 	if (m_current)
 	{
 		KMTimer::self()->hold();
-		if (KMessageBox::warningContinueCancel(this, i18n("You are about to print a test page on %1. Do you want to continue?", m_current->printerName()), QString(), KGuiItem(i18n("Print Test Page")), "printTestPage") == KMessageBox::Continue)
+		if (KMessageBox::warningContinueCancel(this, i18n("You are about to print a test page on %1. Do you want to continue?", m_current->printerName()), QString(), KGuiItem(i18n("Print Test Page")), KStandardGuiItem::cancel(), "printTestPage") == KMessageBox::Continue)
 		{
 			if (KMFactory::self()->manager()->testPrinter(m_current))
 				KMessageBox::information(this,i18n("Test page successfully sent to printer %1.", m_current->printerName()));
@@ -756,7 +754,7 @@ void KMMainView::showErrorMsg(const QString& msg, bool usemgr)
 			err = i18n("Internal error (no error message).");
 		else
 			err = m_manager->errorMsg();
-		s += i18n("Error message received from manager:</p><p>%1</p>", err);
+		s += i18n("<p>Error message received from manager:</p><p>%1</p>", err);
 		// clean up error message
 		m_manager->setErrorMsg(QString());
 	}
@@ -1006,7 +1004,7 @@ void KMMainView::slotHelp()
 		KToolInvocation::kdeinitExec( "kfmclient", args );
 	}
 	else
-		kDebug( 500 ) << "Unknown help invokator: " << s << endl;
+		kDebug( 500 ) << "Unknown help invokator: " << s;
 }
 
 #include "kmmainview.moc"
