@@ -20,27 +20,22 @@
 #ifndef KMMAINVIEW_H
 #define KMMAINVIEW_H
 
-#if !defined( _KDEPRINT_COMPILE ) && defined( __GNUC__ )
-#warning internal header, do not use except if you are a KDEPrint developer
-#endif
+#if defined( _KDEPRINT_COMPILE ) || defined(Q_MOC_RUN)
+/* internal header, do not use except if you are a KDEPrint developer */
 
 #include <kdeprint/kpreloadobject.h>
 #include <kmainwindow.h>
 
-class KMManager;
 class KMPrinterView;
 class KMPrinter;
 class KMPages;
 class KActionCollection;
 class QMenu;
-class QTimer;
-class QSplitter;
 class KToolBar;
 class QAction;
 class PluginComboBox;
 class QBoxLayout;
 class MessageWindow;
-class QMenuBar;
 
 /**
  * @internal
@@ -53,7 +48,7 @@ class KDEPRINT_MANAGEMENT_EXPORT KMMainView : public QWidget, public KPReloadObj
 {
 	Q_OBJECT
 public:
-	KMMainView(QWidget *parent = 0, KActionCollection *coll = 0);
+	explicit KMMainView(QWidget *parent = 0, KActionCollection *coll = 0);
 	~KMMainView();
 
 	void setOrientation(int);
@@ -129,3 +124,4 @@ private:
 KDEPRINT_MANAGEMENT_EXPORT int kdeprint_management_add_printer_wizard( QWidget* parent );
 
 #endif
+#endif
