@@ -20,9 +20,8 @@
 #ifndef KMPRINTERPAGE_H
 #define KMPRINTERPAGE_H
 
-#if !defined( _KDEPRINT_COMPILE ) && defined( __GNUC__ )
-#warning internal header, do not use except if you are a KDEPrint developer
-#endif
+#if defined( _KDEPRINT_COMPILE )
+/* internal header, do not use except if you are a KDEPrint developer */
 
 class KMPrinter;
 
@@ -41,3 +40,4 @@ public:
 };
 
 #endif
+#endif
