@@ -20,10 +20,9 @@
 #ifndef KMPROPBACKEND_H
 #define KMPROPBACKEND_H
 
+#include <kdeprint_export.h>
 #include "kmpropwidget.h"
 
-#include <kdelibs_export.h>
-
 class QLabel;
 
 class KDEPRINT_MANAGEMENT_EXPORT KMPropBackend : public KMPropWidget
