@@ -20,10 +20,9 @@
 #ifndef KMPROPDRIVER_H
 #define KMPROPDRIVER_H
 
+#include <kdeprint_export.h>
 #include "kmpropwidget.h"
 
-#include <kdelibs_export.h>
-
 class QLabel;
 
 class KDEPRINT_MANAGEMENT_EXPORT KMPropDriver : public KMPropWidget
