@@ -20,11 +20,11 @@
 #ifndef KMPROPERTYPAGE_H
 #define KMPROPERTYPAGE_H
 
-#include "cjanuswidget.h"
-#include "kmprinterpage.h"
+#include <kdeprint_export.h>
 #include <kdeprint/kpreloadobject.h>
-#include <kdelibs_export.h>
-#include <qlist.h>
+#include "kmprinterpage.h"
+#include "cjanuswidget.h"
+#include <QtCore/QList>
 
 class KMPropWidget;
 class KMPrinter;
