@@ -26,14 +26,14 @@
 #include "kxmlcommand.h"
 #include "driver.h"
 
-#include <qpushbutton.h>
-#include <qlineedit.h>
-#include <qcheckbox.h>
-#include <qcombobox.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <QGroupBox>
-#include <QVBoxLayout>
+#include <QtGui/QPushButton>
+#include <QtGui/QLineEdit>
+#include <QtGui/QCheckBox>
+#include <QtGui/QComboBox>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtGui/QGroupBox>
+#include <QtGui/QBoxLayout>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kicondialog.h>
@@ -95,7 +95,7 @@ KMSpecialPrinterDlg::KMSpecialPrinterDlg(QWidget *parent, const char *name)
 	m_extensionlabel->setBuddy(m_extension);
 
 	m_icon = new KIconButton(dummy);
-	m_icon->setIcon("fileprint");
+	m_icon->setIcon("document-print");
 	m_icon->setFixedSize(QSize(48,48));
 
 	connect( m_usefile, SIGNAL( toggled( bool ) ), m_mimetype, SLOT( setEnabled( bool ) ) );
