@@ -23,9 +23,9 @@
 #include "kmmanager.h"
 #include "kmprinter.h"
 
-#include <qlayout.h>
-#include <qlabel.h>
-#include <qtoolbutton.h>
+#include <QtGui/QLayout>
+#include <QtGui/QLabel>
+#include <QtGui/QToolButton>
 #include <klistwidget.h>
 #include <klocale.h>
 #include <kiconloader.h>
@@ -44,8 +44,8 @@ KMWClass::KMWClass(QWidget *parent)
 
 	QToolButton	*add = new QToolButton(this);
 	QToolButton	*remove = new QToolButton(this);
-	add->setIcon(BarIcon("forward"));
-	remove->setIcon(BarIcon("back"));
+	add->setIcon(BarIcon("go-next"));
+	remove->setIcon(BarIcon("go-previous"));
 	connect(add,SIGNAL(clicked()),SLOT(slotAdd()));
 	connect(remove,SIGNAL(clicked()),SLOT(slotRemove()));
 
