@@ -23,8 +23,8 @@
 #include "kmdbentry.h"
 #include "kmdriverdb.h"
 
-#include <qlabel.h>
-#include <qlayout.h>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
 #include <kpushbutton.h>
 #include <klistwidget.h>
 #include <klocale.h>
