@@ -21,8 +21,8 @@
 #include "kmwizard.h"
 #include "kmprinter.h"
 
-#include <qlabel.h>
-#include <qlayout.h>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
 
 #include <kurlrequester.h>
 #include <klocale.h>
