@@ -21,11 +21,11 @@
 #include "kmwizard.h"
 #include "kmprinter.h"
 
-#include <qlabel.h>
-#include <qlineedit.h>
+#include <QtGui/QLabel>
+#include <QtGui/QLineEdit>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <qregexp.h>
+#include <QtCore/QRegExp>
 
 KMWName::KMWName(QWidget *parent)
     : KMWInfoBase(3,parent)
@@ -78,11 +78,12 @@ void KMWName::initPrinter(KMPrinter *p)
 	setText(0,p->printerName());
 	setText(1,p->location());
 	setText(2,p->description());
-	if (text(2).isEmpty())
+	if (text(2).isEmpty()) {
 		if (p->option("kde-driver") == "raw")
 			setText(2,i18n("Raw printer"));
 		else
 			setText(2,p->manufacturer() + ' ' + p->model());
+        }
 
 	setCurrent(0);
 }
