@@ -20,8 +20,8 @@
 #ifndef	KMWSOCKETUTIL_H
 #define	KMWSOCKETUTIL_H
 
-#include <QList>
-#include <QString>
+#include <QtCore/QList>
+
 
 #include <kdialog.h>
 
