@@ -21,10 +21,10 @@
 #define KVISIBLEBUTTONGROUP_H
 
 
-#include <qgroupbox.h>
-#include <qbuttongroup.h>
-#include <qradiobutton.h>
-#include <qlayout.h>
+#include <QtGui/QGroupBox>
+#include <QtGui/QButtonGroup>
+#include <QtGui/QRadioButton>
+#include <QtGui/QLayout>
 
 
 class KVisibleButtonGroup : public QGroupBox, public QButtonGroup
@@ -48,7 +48,7 @@ private:
 class KRadioButtonWithHandOver : public QRadioButton
 {
 public:
-	KRadioButtonWithHandOver(const QString& txt, QWidget *parent = 0);
+	explicit KRadioButtonWithHandOver(const QString& txt, QWidget *parent = 0);
 };
 
 #endif
