@@ -20,21 +20,21 @@
 #include "kxmlcommanddlg.h"
 #include "driver.h"
 #include "kxmlcommand.h"
-#include <QStackedWidget>
+#include <QtGui/QStackedWidget>
 
-#include <qlayout.h>
-#include <q3header.h>
-#include <qlabel.h>
-#include <qlineedit.h>
-#include <qcombobox.h>
-#include <QGroupBox>
-#include <QVBoxLayout>
-#include <qtoolbutton.h>
+#include <QtGui/QLayout>
+#include <Qt3Support/Q3Header>
+#include <QtGui/QLabel>
+#include <QtGui/QLineEdit>
+#include <QtGui/QComboBox>
+#include <QtGui/QGroupBox>
+#include <QtGui/QBoxLayout>
+#include <QtGui/QToolButton>
 #include <kpushbutton.h>
-#include <qcheckbox.h>
+#include <QtGui/QCheckBox>
 #include <ktextedit.h>
-#include <qregexp.h>
-#include <qapplication.h>
+#include <QtCore/QRegExp>
+#include <QtGui/QApplication>
 
 #include <k3listview.h>
 #include <klocale.h>
@@ -88,17 +88,17 @@ KXmlCommandAdvancedDlg::KXmlCommandAdvancedDlg( QWidget *parent )
 	m_view->header()->hide();
 	m_view->setSorting(-1);
 	m_apply = new QToolButton(this);
-	m_apply->setIcon( QApplication::isRightToLeft()? KIcon( "forward" ) : KIcon("back"));
+	m_apply->setIcon( QApplication::isRightToLeft()? KIcon( "go-next" ) : KIcon("go-previous"));
 	m_addgrp = new QToolButton(this);
 	m_addgrp->setIcon(KIcon("folder"));
 	m_addopt = new QToolButton(this);
 	m_addopt->setIcon(KIcon("document"));
 	m_delopt = new QToolButton(this);
-	m_delopt->setIcon(KIcon("editdelete"));
+	m_delopt->setIcon(KIcon("edit-delete"));
 	m_up = new QToolButton(this);
-	m_up->setIcon(KIcon("up"));
+	m_up->setIcon(KIcon("go-up"));
 	m_down = new QToolButton(this);
-	m_down->setIcon(KIcon("down"));
+	m_down->setIcon(KIcon("go-down"));
 	m_dummy = new QWidget(this);
 	m_desc = new QLineEdit(m_dummy);
 	m_name = new QLineEdit(m_dummy);
@@ -144,9 +144,9 @@ KXmlCommandAdvancedDlg::KXmlCommandAdvancedDlg( QWidget *parent )
 	m_values->setSorting(-1);
 	m_values->setMaximumHeight(110);
 	m_addval = new QToolButton(w2);
-	m_addval->setIcon(KIcon("editcopy"));
+	m_addval->setIcon(KIcon("edit-copy"));
 	m_delval = new QToolButton(w2);
-	m_delval->setIcon(KIcon("editdelete"));
+	m_delval->setIcon(KIcon("edit-delete"));
 	m_addval->setToolTip(i18n("Add value"));
 	m_delval->setToolTip(i18n("Delete value"));
 
@@ -173,6 +173,7 @@ KXmlCommandAdvancedDlg::KXmlCommandAdvancedDlg( QWidget *parent )
 	m_outputpipe = new QLineEdit(gb_output);
 
 	m_comment = new KTextEdit( this );
+	m_comment->setReadOnly(true);
 	QLabel *m_commentlab = new QLabel( i18n( "Comment:" ), this );
 
 	QVBoxLayout	*l2 = new QVBoxLayout(this);
@@ -371,10 +372,10 @@ KXmlCommandAdvancedDlg::~KXmlCommandAdvancedDlg()
 {
 	if (m_opts.count() > 0)
 	{
-		kDebug() << "KXmlCommandAdvancedDlg: " << m_opts.count() << " items remaining" << endl;
+		kDebug() << "KXmlCommandAdvancedDlg: " << m_opts.count() << " items remaining";
 		for (QMap<QString,DrBase*>::ConstIterator it=m_opts.begin(); it!=m_opts.end(); ++it)
 		{
-			//kDebug() << "Item: name=" << (*it)->name() << endl;
+			//kDebug() << "Item: name=" << (*it)->name();
 			delete (*it);
 		}
 	}
@@ -393,7 +394,7 @@ void KXmlCommandAdvancedDlg::parseXmlCommand(KXmlCommand *xmlcmd)
 	Q3ListViewItem	*root = new Q3ListViewItem(m_view, xmlcmd->name(), xmlcmd->name());
 	DrMain	*driver = xmlcmd->driver();
 
-	root->setPixmap(0, SmallIcon("fileprint"));
+	root->setPixmap(0, SmallIcon("document-print"));
 	root->setOpen(true);
 	if (driver)
 	{
@@ -411,7 +412,8 @@ void KXmlCommandAdvancedDlg::parseXmlCommand(KXmlCommand *xmlcmd)
 	m_inputpipe->setText(xmlcmd->io(true, true));
 	m_outputfile->setText(xmlcmd->io(false, false));
 	m_outputpipe->setText(xmlcmd->io(false, true));
-	m_comment->setPlainText( xmlcmd->comment() );
+	m_comment->setHtml( xmlcmd->comment() );
+
 
 	viewItem(0);
 }
@@ -843,7 +845,7 @@ bool KXmlCommandAdvancedDlg::editCommand(KXmlCommand *xmlcmd, QWidget *parent)
 		DrMain	*driver = (xmldlg->m_opts.contains("__root__") ? static_cast<DrMain*>(xmldlg->m_opts["__root__"]) : 0);
 		if (!driver && xmldlg->m_opts.count() > 0)
 		{
-			kDebug() << "KXmlCommandAdvancedDlg: driver structure not found, creating one" << endl;
+			kDebug() << "KXmlCommandAdvancedDlg: driver structure not found, creating one";
 			driver = new DrMain;
 			driver->setName(xmlcmd->name());
 		}
@@ -888,17 +890,17 @@ KXmlCommandDlg::KXmlCommandDlg(QWidget *parent, const char *name)
 	m_requirements->addColumn("");
 	m_requirements->header()->hide();
 	m_addreq = new QToolButton(m_gb2);
-	m_addreq->setIcon(KIcon("filenew"));
+	m_addreq->setIcon(KIcon("document-new"));
 	m_removereq = new QToolButton(m_gb2);
-	m_removereq->setIcon(KIcon("editdelete"));
+	m_removereq->setIcon(KIcon("edit-delete"));
 	QPushButton	*m_edit = new KPushButton(KGuiItem(i18n("&Edit Command..."), "edit"), topmain);
 	m_mimetype = new QComboBox(dummy);
 	m_availablemime = new KListWidget(m_gb1);
 	m_selectedmime = new KListWidget(m_gb1);
 	m_addmime = new QToolButton(m_gb1);
-	m_addmime->setIcon(QApplication::isRightToLeft()? KIcon("forward") : KIcon("back"));
+	m_addmime->setIcon(QApplication::isRightToLeft()? KIcon("go-next") : KIcon("go-previous"));
 	m_removemime = new QToolButton(m_gb1);
-	m_removemime->setIcon(QApplication::isRightToLeft()? KIcon("back" ) : KIcon("forward"));
+	m_removemime->setIcon(QApplication::isRightToLeft()? KIcon("go-previous" ) : KIcon("go-next"));
 	m_gb2->setMinimumWidth(380);
 	m_gb1->setMinimumHeight(180);
 	m_requirements->setMaximumHeight(80);
@@ -973,8 +975,8 @@ KXmlCommandDlg::KXmlCommandDlg(QWidget *parent, const char *name)
 	connect(m_removemime, SIGNAL(clicked()), SLOT(slotRemoveMime()));
 	connect(m_edit, SIGNAL(clicked()), SLOT(slotEditCommand()));
 	connect(m_requirements, SIGNAL(selectionChanged(Q3ListViewItem*)), SLOT(slotReqSelected(Q3ListViewItem*)));
-	connect(m_availablemime, SIGNAL(selectionChanged(Q3ListBoxItem*)), SLOT(slotAvailableSelected(Q3ListBoxItem*)));
-	connect(m_selectedmime, SIGNAL(selectionChanged(Q3ListBoxItem*)), SLOT(slotSelectedSelected(Q3ListBoxItem*)));
+	connect(m_availablemime, SIGNAL(itemSelectionChanged ()), SLOT(slotAvailableSelected()));
+	connect(m_selectedmime, SIGNAL(itemSelectionChanged ()), SLOT(slotSelectedSelected()));
 	connect(m_addreq, SIGNAL(clicked()), SLOT(slotAddReq()));
 	connect(m_removereq, SIGNAL(clicked()), SLOT(slotRemoveReq()));
 
@@ -1111,14 +1113,14 @@ void KXmlCommandDlg::slotReqSelected(Q3ListViewItem *item)
 	m_removereq->setEnabled(item);
 }
 
-void KXmlCommandDlg::slotAvailableSelected(Q3ListBoxItem *item)
+void KXmlCommandDlg::slotAvailableSelected()
 {
-	m_addmime->setEnabled(item);
+	m_addmime->setEnabled(m_availablemime->currentItem());
 }
 
-void KXmlCommandDlg::slotSelectedSelected(Q3ListBoxItem *item)
+void KXmlCommandDlg::slotSelectedSelected()
 {
-	m_removemime->setEnabled(item);
+	m_removemime->setEnabled(m_selectedmime->currentItem());
 }
 
 #include "kxmlcommanddlg.moc"
