@@ -20,9 +20,9 @@
 #ifndef KXMLCOMMANDDLG_H
 #define KXMLCOMMANDDLG_H
 
-#include <qwidget.h>
-#include <qmap.h>
-#include <qstringlist.h>
+#include <QtGui/QImage>
+#include <QtCore/QMap>
+#include <QtCore/QStringList>
 #include <kdialog.h>
 
 class K3ListView;
@@ -32,7 +32,6 @@ class QLineEdit;
 class QComboBox;
 class QToolButton;
 class KListWidget;
-class Q3ListBoxItem;
 class QTextEdit;
 class QCheckBox;
 class QStackedWidget;
@@ -96,7 +95,7 @@ class KXmlCommandDlg : public KDialog
 {
 	Q_OBJECT
 public:
-	KXmlCommandDlg(QWidget *parent = 0, const char *name = 0);
+	explicit KXmlCommandDlg(QWidget *parent = 0, const char *name = 0);
 
 	void setCommand(KXmlCommand*);
 	static bool editCommand(KXmlCommand*, QWidget *parent = 0);
@@ -108,8 +107,8 @@ protected Q_SLOTS:
 	void slotAddReq();
 	void slotRemoveReq();
 	void slotReqSelected(Q3ListViewItem*);
-	void slotAvailableSelected(Q3ListBoxItem*);
-	void slotSelectedSelected(Q3ListBoxItem*);
+	void slotAvailableSelected();
+	void slotSelectedSelected();
 	void slotOk();
 
 private:
