@@ -20,10 +20,10 @@
 #ifndef SIDEPIXMAP_H
 #define SIDEPIXMAP_H
 
-#include <qframe.h>
-#include <qpixmap.h>
+#include <kdeprint_export.h>
 
-#include <kdelibs_export.h>
+#include <QtGui/QFrame>
+#include <QtGui/QPixmap>
 
 class KDEPRINT_MANAGEMENT_EXPORT SidePixmap : public QFrame
 {
