@@ -21,7 +21,7 @@
 #include "kmprinter.h"
 #include "kmfactory.h"
 
-#include <kconfig.h>
+#include <ksharedconfig.h>
 #include <kglobal.h>
 #include <kdebug.h>
 
@@ -38,23 +38,21 @@ PrinterFilter::~PrinterFilter()
 
 void PrinterFilter::update()
 {
-	KConfig	*conf = KMFactory::self()->printConfig();
-	conf->setGroup("Filter");
-	m_locationRe.setPattern(conf->readEntry("LocationRe"));
-	m_printers = conf->readEntry("Printers", QStringList());
+	KConfig *cf=KMFactory::self()->printConfig();
+	KConfigGroup conf = cf->group("Filter");
+	m_locationRe.setPattern(conf.readEntry("LocationRe"));
+	m_printers = conf.readEntry("Printers", QStringList());
 	// filter enable state is saved on a per application basis,
 	// so this option is retrieve from the application config file
-	conf = KGlobal::config().data();
-	conf->setGroup("KPrinter Settings");
-	m_enabled = conf->readEntry("FilterEnabled", false);
+	conf = KConfigGroup( KGlobal::config(), "KPrinter Settings");
+	m_enabled = conf.readEntry("FilterEnabled", false);
 }
 
 void PrinterFilter::setEnabled(bool on)
 {
 	m_enabled = on;
-	KSharedConfig::Ptr conf = KGlobal::config();
-	conf->setGroup("KPrinter Settings");
-	conf->writeEntry("FilterEnabled", m_enabled);
+	KConfigGroup cg( KGlobal::config(), "KPrinter Settings");
+	cg.writeEntry("FilterEnabled", m_enabled);
 }
 
 bool PrinterFilter::filter(KMPrinter *prt)
