@@ -9,13 +9,13 @@
 
 #include "helpwindow.h"
 #include <kapplication.h>
-#include <qwindowsstyle.h>
+#include <QtGui/QWindowsStyle>
 #include <stdlib.h>
-#include <QDesktopWidget>
+#include <QtGui/QDesktopWidget>
 #include <kcmdlineargs.h>
 int main( int argc, char ** argv )
 {
-    KCmdLineArgs::init( argc, argv, "helpviewer", 0, 0, 0, 0);
+    KCmdLineArgs::init( argc, argv, "helpviewer", 0, ki18n("helpviewer"), 0);
     KApplication a;
 
     QString home;
