@@ -19,12 +19,12 @@
 
 #include "escpwidget.h"
 
-#include <qpushbutton.h>
-#include <qlayout.h>
-#include <qlabel.h>
-#include <qcheckbox.h>
-#include <q3accel.h>
-#include <qbytearray.h>
+#include <QtGui/QPushButton>
+#include <QtGui/QLayout>
+#include <QtGui/QLabel>
+#include <QtGui/QCheckBox>
+#include <Qt3Support/Q3Accel>
+#include <QtCore/QByteRef>
 #include <kdemacros.h>
 #include <klocale.h>
 #include <kmessagebox.h>
@@ -71,9 +71,9 @@ EscpWidget::EscpWidget(QWidget *parent)
 {
 	m_hasoutput = false;
 
-	connect(&m_proc, SIGNAL(processExited(KProcess*)), SLOT(slotProcessExited(KProcess*)));
-	connect(&m_proc, SIGNAL(receivedStdout(KProcess*,char*,int)), SLOT(slotReceivedStdout(KProcess*,char*,int)));
-	connect(&m_proc, SIGNAL(receivedStderr(KProcess*,char*,int)), SLOT(slotReceivedStderr(KProcess*,char*,int)));
+	connect(&m_proc, SIGNAL(finished(int, QProcess::ExitStatus)), SLOT(slotProcessExited()));
+	connect(&m_proc, SIGNAL(readyReadStandardOutput()), SLOT(slotReceivedStdout()));
+	connect(&m_proc, SIGNAL(readyReadStandardError()), SLOT(slotReceivedStderr()));
 
 	QPushButton	*cleanbtn = new QPushButton(this);
 	cleanbtn->setObjectName(QLatin1String("-c"));
@@ -179,7 +179,7 @@ void EscpWidget::startCommand(const QString& arg)
 		}
 	}
 
-	if (m_proc.isRunning())
+	if (m_proc.state() == QProcess::Running)
 	{
 		KMessageBox::error(this, i18n("An escputil process is still running. "
 		                              "You must wait until its completion before continuing."));
@@ -195,7 +195,7 @@ void EscpWidget::startCommand(const QString& arg)
 		return;
 	}
 
-	m_proc.clearArguments();
+	m_proc.setProgram(QString(), QStringList());
 	m_proc << exestr;
 	if (m_useraw->isChecked() || arg == "-i")
 		m_proc << "-r" << m_deviceURL.path();
@@ -205,12 +205,14 @@ void EscpWidget::startCommand(const QString& arg)
 		m_proc << "-u";
 
 	m_proc << arg << "-q";
-	m_errorbuffer = m_outbuffer = QString();
+	m_errorbuffer = m_outbuffer = QByteArray();
 	m_hasoutput = ( arg == "-i" || arg == "-d" );
-	foreach ( QByteArray arg, m_proc.args() )
-		kDebug() << "ARG: " << arg << endl;
+//	foreach ( QByteArray arg, m_proc.args() )
+//		kDebug() << "ARG: " << arg;
 
-	if (m_proc.start(KProcess::NotifyOnExit, KProcess::AllOutput))
+	m_proc.setOutputChannelMode(KProcess::SeparateChannels);
+	m_proc.start();
+	if (m_proc.waitForFinished())
 		setEnabled(false);
 	else
 	{
@@ -220,17 +222,17 @@ void EscpWidget::startCommand(const QString& arg)
 	}
 }
 
-void EscpWidget::slotProcessExited(KProcess*)
+void EscpWidget::slotProcessExited()
 {
 	setEnabled(true);
-	if (!m_proc.normalExit() || m_proc.exitStatus() != 0)
+	if (m_proc.exitStatus() != QProcess::NormalExit || m_proc.exitCode() != 0)
 	{
 		QString	msg1 = "<qt>"+i18n("Operation terminated with errors.")+"</qt>";
 		QString	msg2;
 		if (!m_outbuffer.isEmpty())
-			msg2 += "<p><b><u>"+i18n("Output")+"</u></b></p><p>"+m_outbuffer+"</p>";
+			msg2 += "<p><b><u>"+i18n("Output")+"</u></b></p><p>"+QString::fromLocal8Bit(m_outbuffer)+"</p>";
 		if (!m_errorbuffer.isEmpty())
-			msg2 += "<p><b><u>"+i18n("Error")+"</u></b></p><p>"+m_errorbuffer+"</p>";
+			msg2 += "<p><b><u>"+i18n("Error")+"</u></b></p><p>"+QString::fromLocal8Bit(m_errorbuffer)+"</p>";
 		if (!msg2.isEmpty())
 			KMessageBox::detailedError(this, msg1, msg2);
 		else
@@ -238,21 +240,19 @@ void EscpWidget::slotProcessExited(KProcess*)
 	}
 	else if ( !m_outbuffer.isEmpty() && m_hasoutput )
 	{
-		KMessageBox::information( this, m_outbuffer );
+		KMessageBox::information( this, QString::fromLocal8Bit(m_outbuffer) );
 	}
 	m_hasoutput = false;
 }
 
-void EscpWidget::slotReceivedStdout(KProcess*, char *buf, int len)
+void EscpWidget::slotReceivedStdout()
 {
-	QString	bufstr = QByteArray(buf, len);
-	m_outbuffer.append(bufstr);
+	m_outbuffer.append( m_proc.readAllStandardOutput() );
 }
 
-void EscpWidget::slotReceivedStderr(KProcess*, char *buf, int len)
+void EscpWidget::slotReceivedStderr()
 {
-	QString	bufstr = QByteArray(buf, len);
-	m_errorbuffer.append(bufstr);
+	m_errorbuffer.append( m_proc.readAllStandardError() );
 }
 
 void EscpWidget::slotButtonClicked()
