@@ -10,38 +10,67 @@
  * kcookie.cpp: KDE authentication cookies.
  */
 
+#include "kcookie.h"
+
 #include <stdlib.h>
 
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qglobal.h>
-#include <qprocess.h>
+#include <QtCore/QString>
+#include <QtCore/QStringList>
+#include <QtCore/QBool>
+#include <QtCore/Q_PID>
 
 #include <kdebug.h>
-#include "kcookie.h"
+
+class KCookie::KCookiePrivate
+{
+public:
+    QByteArray m_Display;
+#ifdef Q_WS_X11
+    QByteArray m_DisplayAuth;
+#endif
+};
+
 
 
 KCookie::KCookie()
+    : d( new KCookiePrivate )
 {
 #ifdef Q_WS_X11
     getXCookie();
 #endif
 }
 
+KCookie::~KCookie()
+{
+    delete d;
+}
+
+QByteArray KCookie::display() const
+{
+    return d->m_Display;
+}
+
+#ifdef Q_WS_X11
+QByteArray KCookie::displayAuth() const
+{
+    return d->m_DisplayAuth;
+}
+#endif
+
 void KCookie::getXCookie()
 {
 #ifdef Q_WS_X11
-    m_Display = getenv("DISPLAY");
+    d->m_Display = getenv("DISPLAY");
 #else
-    m_Display = getenv("QWS_DISPLAY");
+    d->m_Display = getenv("QWS_DISPLAY");
 #endif
-    if (m_Display.isEmpty())
+    if (d->m_Display.isEmpty())
     {
 	kError(900) << k_lineinfo << "$DISPLAY is not set.\n";
 	return;
     }
 #ifdef Q_WS_X11 // No need to mess with X Auth stuff
-    QByteArray disp = m_Display;
+    QByteArray disp = d->m_Display;
     if (disp.startsWith("localhost:"))
        disp.remove(0, 9);
 
@@ -56,7 +85,7 @@ void KCookie::getXCookie()
     if (output.isEmpty())
     {
        kWarning(900) << "No X authentication info set for display " <<
-       m_Display << endl; return;
+       d->m_Display << endl; return;
     }
     QList<QByteArray> lst = output.split(' ');
     if (lst.count() != 3)
@@ -64,6 +93,6 @@ void KCookie::getXCookie()
 	kError(900) << k_lineinfo << "parse error.\n";
 	return;
     }
-    m_DisplayAuth = (lst[1] + ' ' + lst[2]);
+    d->m_DisplayAuth = (lst[1] + ' ' + lst[2]);
 #endif
 }
