@@ -14,7 +14,11 @@
  *  terminal programs.
  */
 
+#include "process.h"
+#include "kcookie.h"
+
 #include <config.h>
+#include <config-pty.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -41,22 +45,19 @@
 #include <sys/select.h>                // Needed on some systems.
 #endif
 
-#include <qglobal.h>
-#include <qfile.h>
+#include <QtCore/QBool>
+#include <QtCore/QFile>
 
-#include <kconfig.h>
+#include <ksharedconfig.h>
+#include <kconfiggroup.h>
 #include <kdebug.h>
 #include <kstandarddirs.h>
 
-#include "process.h"
-#include "kdesu_pty.h"
-#include "kcookie.h"
-
 /*
-** Wait for @p ms miliseconds 
+** Wait for @p ms miliseconds
 ** @param fd file descriptor
 ** @param ms time to wait in miliseconds
-** @return 
+** @return
 */
 int PtyProcess::waitMS(int fd,int ms)
 {
@@ -70,6 +71,9 @@ int PtyProcess::waitMS(int fd,int ms)
 	return select(fd+1, &fds, 0L, 0L, &tv);
 }
 
+// XXX this function is nonsense:
+// - for our child, we could use waitpid().
+// - the configurability at this place it *complete* braindamage
 /*
 ** Basic check for the existence of @p pid.
 ** Returns true iff @p pid is an extant process.
@@ -77,14 +81,14 @@ int PtyProcess::waitMS(int fd,int ms)
 bool PtyProcess::checkPid(pid_t pid)
 {
     KSharedConfig::Ptr config = KGlobal::config();
-	config->setGroup("super-user-command");
-	QString superUserCommand = config->readEntry("super-user-command", "sudo");
-	//sudo does not accept signals from user so we except it
-	if (superUserCommand == "sudo") {
-		return true;
-	} else {
-	return kill(pid,0) == 0;
-	}
+    KConfigGroup cg(config, "super-user-command");
+    QString superUserCommand = cg.readEntry("super-user-command", "sudo");
+    //sudo does not accept signals from user so we except it
+    if (superUserCommand == "sudo") {
+        return true;
+    } else {
+        return kill(pid, 0) == 0;
+    }
 }
 
 /*
@@ -119,7 +123,14 @@ int PtyProcess::checkPidExited(pid_t pid)
 class PtyProcess::PtyProcessPrivate
 {
 public:
+    PtyProcessPrivate() : m_pPTY(0L) {}
+    ~PtyProcessPrivate()
+    {
+        delete m_pPTY;
+    }
     QList<QByteArray> env;
+    KPty *m_pPTY;
+    QByteArray m_Inbuf;
 };
 
 
@@ -128,32 +139,25 @@ PtyProcess::PtyProcess()
 {
     m_bTerminal = false;
     m_bErase = false;
-    m_pPTY = 0L;
 }
 
 
 int PtyProcess::init()
 {
-    delete m_pPTY;
-    m_pPTY = new PTY();
-    m_Fd = m_pPTY->getpt();
-    if (m_Fd < 0)
-        return -1;
-    if ((m_pPTY->grantpt() < 0) || (m_pPTY->unlockpt() < 0))
+    delete d->m_pPTY;
+    d->m_pPTY = new KPty();
+    if (!d->m_pPTY->open())
     {
-        kError(900) << k_lineinfo << "Master setup failed.\n";
-        m_Fd = -1;
+        kError(900) << k_lineinfo << "Failed to open PTY.\n";
         return -1;
     }
-    m_TTY = m_pPTY->ptsname();
-    m_Inbuf.resize(0);
+    d->m_Inbuf.resize(0);
     return 0;
 }
 
 
 PtyProcess::~PtyProcess()
 {
-    delete m_pPTY;
     delete d;
 }
 
@@ -163,6 +167,16 @@ void PtyProcess::setEnvironment( const QList<QByteArray> &env )
     d->env = env;
 }
 
+int PtyProcess::fd() const
+{
+    return d->m_pPTY ? d->m_pPTY->masterFd() : -1;
+}
+
+int PtyProcess::pid() const
+{
+    return m_Pid;
+}
+
 /** Returns the additional environment variables set by setEnvironment() */
 QList<QByteArray> PtyProcess::environment() const
 {
@@ -180,22 +194,22 @@ QByteArray PtyProcess::readLine(bool block)
     int pos;
     QByteArray ret;
 
-    if (!m_Inbuf.isEmpty())
+    if (!d->m_Inbuf.isEmpty())
     {
-        pos = m_Inbuf.indexOf('\n');
+        pos = d->m_Inbuf.indexOf('\n');
         if (pos == -1)
         {
-            ret = m_Inbuf;
-            m_Inbuf.resize(0);
+            ret = d->m_Inbuf;
+            d->m_Inbuf.resize(0);
         } else
         {
-            ret = m_Inbuf.left(pos);
-            m_Inbuf = m_Inbuf.mid(pos+1);
+            ret = d->m_Inbuf.left(pos);
+            d->m_Inbuf = d->m_Inbuf.mid(pos+1);
         }
         return ret;
     }
 
-    int flags = fcntl(m_Fd, F_GETFL);
+    int flags = fcntl(fd(), F_GETFL);
     if (flags < 0)
     {
         kError(900) << k_lineinfo << "fcntl(F_GETFL): " << perror << "\n";
@@ -207,9 +221,9 @@ QByteArray PtyProcess::readLine(bool block)
     else
         flags |= O_NONBLOCK;
 
-    if ((flags != oflags) && (fcntl(m_Fd, F_SETFL, flags) < 0))
+    if ((flags != oflags) && (fcntl(fd(), F_SETFL, flags) < 0))
     {
-       // We get an error here when the child process has closed 
+       // We get an error here when the child process has closed
        // the file descriptor already.
        return ret;
     }
@@ -218,7 +232,7 @@ QByteArray PtyProcess::readLine(bool block)
     char buf[256];
     while (1)
     {
-        nbytes = read(m_Fd, buf, 255);
+        nbytes = read(fd(), buf, 255);
         if (nbytes == -1)
         {
             if (errno == EINTR)
@@ -229,17 +243,17 @@ QByteArray PtyProcess::readLine(bool block)
             break;        // eof
 
         buf[nbytes] = '\000';
-        m_Inbuf += buf;
+        d->m_Inbuf += buf;
 
-        pos = m_Inbuf.indexOf('\n');
+        pos = d->m_Inbuf.indexOf('\n');
         if (pos == -1)
         {
-            ret = m_Inbuf;
-            m_Inbuf.resize(0);
+            ret = d->m_Inbuf;
+            d->m_Inbuf.resize(0);
         } else
         {
-            ret = m_Inbuf.left(pos);
-            m_Inbuf = m_Inbuf.mid(pos+1);
+            ret = d->m_Inbuf.left(pos);
+            d->m_Inbuf = d->m_Inbuf.mid(pos+1);
         }
         break;
     }
@@ -251,9 +265,9 @@ QByteArray PtyProcess::readLine(bool block)
 void PtyProcess::writeLine(const QByteArray &line, bool addnl)
 {
     if (!line.isEmpty())
-        write(m_Fd, line, line.length());
+        write(fd(), line, line.length());
     if (addnl)
-        write(m_Fd, "\n", 1);
+        write(fd(), "\n", 1);
 }
 
 
@@ -263,7 +277,12 @@ void PtyProcess::unreadLine(const QByteArray &line, bool addnl)
     if (addnl)
         tmp += '\n';
     if (!tmp.isEmpty())
-        m_Inbuf.prepend(tmp);
+        d->m_Inbuf.prepend(tmp);
+}
+
+void PtyProcess::setExitString(const QByteArray &exit)
+{
+    m_Exit = exit;
 }
 
 /*
@@ -278,14 +297,6 @@ int PtyProcess::exec(const QByteArray &command, const QList<QByteArray> &args)
     if (init() < 0)
         return -1;
 
-    // Open the pty slave before forking. See SetupTTY()
-    int slave = open(m_TTY, O_RDWR);
-    if (slave < 0)
-    {
-        kError(900) << k_lineinfo << "Could not open slave pty.\n";
-        return -1;
-    }
-
     if ((m_Pid = fork()) == -1)
     {
         kError(900) << k_lineinfo << "fork(): " << perror << "\n";
@@ -295,12 +306,11 @@ int PtyProcess::exec(const QByteArray &command, const QList<QByteArray> &args)
     // Parent
     if (m_Pid)
     {
-        close(slave);
         return 0;
     }
 
     // Child
-    if (SetupTTY(slave) < 0)
+    if (setupTTY() < 0)
         _exit(1);
 
     for (i = 0; i < d->env.count(); ++i)
@@ -361,70 +371,48 @@ int PtyProcess::exec(const QByteArray &command, const QList<QByteArray> &args)
 
 int PtyProcess::WaitSlave()
 {
-    int slave = open(m_TTY, O_RDWR);
-    if (slave < 0)
-    {
-        kError(900) << k_lineinfo << "Could not open slave tty.\n";
-        return -1;
-    }
-
-    kDebug(900) << k_lineinfo << "Child pid " << m_Pid << endl;
+    kDebug(900) << k_lineinfo << "Child pid " << m_Pid;
 
     struct termios tio;
     while (1)
     {
-	if (!checkPid(m_Pid))
-	{
-		close(slave);
-		return -1;
-	}
-        if (tcgetattr(slave, &tio) < 0)
+        if (!checkPid(m_Pid))
+        {
+            return -1;
+        }
+        if (!d->m_pPTY->tcGetAttr(&tio))
         {
             kError(900) << k_lineinfo << "tcgetattr(): " << perror << "\n";
-            close(slave);
             return -1;
         }
         if (tio.c_lflag & ECHO)
         {
             kDebug(900) << k_lineinfo << "Echo mode still on.\n";
-	    waitMS(slave,100);
+            usleep(10000);
             continue;
         }
         break;
     }
-    close(slave);
     return 0;
 }
 
 
 int PtyProcess::enableLocalEcho(bool enable)
 {
-    int slave = open(m_TTY, O_RDWR);
-    if (slave < 0)
-    {
-        kError(900) << k_lineinfo << "Could not open slave tty.\n";
-        return -1;
-    }
-    struct termios tio;
-    if (tcgetattr(slave, &tio) < 0)
-    {
-        kError(900) << k_lineinfo << "tcgetattr(): " << perror << "\n";
-        close(slave); return -1;
-    }
-    if (enable)
-        tio.c_lflag |= ECHO;
-    else
-        tio.c_lflag &= ~ECHO;
-    if (tcsetattr(slave, TCSANOW, &tio) < 0)
-    {
-        kError(900) << k_lineinfo << "tcsetattr(): " << perror << "\n";
-        close(slave); return -1;
-    }
-    close(slave);
-    return 0;
+    return d->m_pPTY->setEcho(enable) ? 0 : -1;
 }
 
 
+void PtyProcess::setTerminal(bool terminal)
+{
+    m_bTerminal = terminal;
+}
+
+void PtyProcess::setErase(bool erase)
+{
+    m_bErase = erase;
+}
+
 /*
  * Copy output to stdout until the child process exists, or a line of output
  * matches `m_Exit'.
@@ -442,8 +430,8 @@ int PtyProcess::waitForChild()
 
     while (1)
     {
-        FD_SET(m_Fd, &fds);
-        int ret = select(m_Fd+1, &fds, 0L, 0L, 0L);
+        FD_SET(fd(), &fds);
+        int ret = select(fd()+1, &fds, 0L, 0L, 0L);
         if (ret == -1)
         {
             if (errno != EINTR)
@@ -470,27 +458,27 @@ int PtyProcess::waitForChild()
             }
         }
 
-	ret = checkPidExited(m_Pid);
-	if (ret == Error)
-	{
-		if (errno == ECHILD) retval = 0;
-		else retval = 1;
-		break;
-	}
-	else if (ret == Killed)
-	{
-		retval = 0;
-		break;
-	}
-	else if (ret == NotExited)
-	{
-		// keep checking
-	}
-	else
-	{
-		retval = ret;
-		break;
-	}
+        ret = checkPidExited(m_Pid);
+        if (ret == Error)
+        {
+            if (errno == ECHILD) retval = 0;
+            else retval = 1;
+            break;
+        }
+        else if (ret == Killed)
+        {
+            retval = 0;
+            break;
+        }
+        else if (ret == NotExited)
+        {
+            // keep checking
+        }
+        else
+        {
+            retval = ret;
+            break;
+        }
     }
     return retval;
 }
@@ -502,52 +490,29 @@ int PtyProcess::waitForChild()
  * so we'll never get EIO when reading from it.
  */
 
-int PtyProcess::SetupTTY(int fd)
+int PtyProcess::setupTTY()
 {
     // Reset signal handlers
     for (int sig = 1; sig < NSIG; sig++)
         signal(sig, SIG_DFL);
     signal(SIGHUP, SIG_IGN);
 
-    // Close all file handles
-    struct rlimit rlp;
-    getrlimit(RLIMIT_NOFILE, &rlp);
-    for (int i = 0; i < (int)rlp.rlim_cur; i++)
-        if (i != fd) close(i);
-
-    // Create a new session.
-    setsid();
-
-    // Open slave. This will make it our controlling terminal
-    int slave = open(m_TTY, O_RDWR);
-    if (slave < 0)
-    {
-        kError(900) << k_lineinfo << "Could not open slave side: " << perror << "\n";
-        return -1;
-    }
-    close(fd);
-
-#if defined(__SVR4) && defined(sun)
-
-    // Solaris STREAMS environment.
-    // Push these modules to make the stream look like a terminal.
-    ioctl(slave, I_PUSH, "ptem");
-    ioctl(slave, I_PUSH, "ldterm");
-
-#endif
-
-#ifdef TIOCSCTTY
-    ioctl(slave, TIOCSCTTY, NULL);
-#endif
+    d->m_pPTY->setCTty();
 
     // Connect stdin, stdout and stderr
+    int slave = d->m_pPTY->slaveFd();
     dup2(slave, 0); dup2(slave, 1); dup2(slave, 2);
-    if (slave > 2)
-        close(slave);
+
+    // Close all file handles
+    // XXX this caused problems in KProcess - not sure why anymore.
+    struct rlimit rlp;
+    getrlimit(RLIMIT_NOFILE, &rlp);
+    for (int i = 3; i < (int)rlp.rlim_cur; i++)
+        close(i);
 
     // Disable OPOST processing. Otherwise, '\n' are (on Linux at least)
     // translated to '\r\n'.
-    struct termios tio;
+    struct ::termios tio;
     if (tcgetattr(0, &tio) < 0)
     {
         kError(900) << k_lineinfo << "tcgetattr(): " << perror << "\n";
