@@ -10,6 +10,9 @@
 * ssh.cpp: Execute a program on a remote machine using ssh.
 */
 
+#include "ssh.h"
+#include "kcookie.h"
+
 #include <config.h>
 
 #include <stdio.h>
@@ -25,34 +28,49 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
-#include <qglobal.h>
+#include <QtCore/QBool>
 
 #include <kdebug.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
 
-#include "ssh.h"
-#include "kcookie.h"
+class SshProcess::SshProcessPrivate
+{
+public:
+    SshProcessPrivate(const QByteArray &host)
+        : m_Host( host )
+        , m_Stub( "kdesu_stub" )
+    {}
+    QByteArray m_Prompt;
+    QByteArray m_Host;
+    QByteArray m_Error;
+    QByteArray m_Stub;
+};
 
 
 SshProcess::SshProcess(const QByteArray &host, const QByteArray &user, const QByteArray &command)
+    : d( new SshProcessPrivate(host) )
 {
-    m_Host = host;
     m_User = user;
     m_Command = command;
-    m_Stub = "kdesu_stub";
     srand(time(0L));
 }
 
 
 SshProcess::~SshProcess()
 {
+    delete d;
+}
+
+void SshProcess::setHost(const QByteArray &host)
+{
+    d->m_Host = host;
 }
 
 
 void SshProcess::setStub(const QByteArray &stub)
 {
-    m_Stub = stub;
+    d->m_Stub = stub;
 }
 
 
@@ -76,7 +94,7 @@ int SshProcess::exec(const char *password, int check)
     QList<QByteArray> args;
     args += "-l"; args += m_User;
     args += "-o"; args += "StrictHostKeyChecking=no";
-    args += m_Host; args += m_Stub;
+    args += d->m_Host; args += d->m_Stub;
 
     if (StubProcess::exec("ssh", args) < 0)
     {
@@ -128,6 +146,16 @@ int SshProcess::exec(const char *password, int check)
     return ret;
 }
 
+QByteArray SshProcess::prompt() const
+{
+    return d->m_Prompt;
+}
+
+QByteArray SshProcess::error() const
+{
+    return d->m_Error;
+}
+
 
 /*
 * Conversation with ssh.
@@ -180,18 +208,18 @@ int SshProcess::ConverseSsh(const char *password, int check)
             {
                 if (check == 2)
                 {
-                    m_Prompt = line;
+                    d->m_Prompt = line;
                     return SshNeedsPassword;
                 }
                 WaitSlave();
-                write(m_Fd, password, strlen(password));
-                write(m_Fd, "\n", 1);
+                write(fd(), password, strlen(password));
+                write(fd(), "\n", 1);
                 state++;
                 break;
             }
 
             // Warning/error message.
-            m_Error += line; m_Error += "\n";
+            d->m_Error += line; d->m_Error += '\n';
             if (m_bTerminal)
                 fprintf(stderr, "ssh: %s\n", line.constData());
             break;
