@@ -10,20 +10,21 @@
  * stub.cpp: Conversation with kdesu_stub.
  */
 
+#include "stub.h"
+#include "kcookie.h"
+
 #include <config.h>
 #include <stdlib.h>
 #include <unistd.h>
 
-#include <qglobal.h>
+#include <QtCore/QBool>
 
 #include <kapplication.h>
 #include <kdebug.h>
 
-#include "stub.h"
-#include "kcookie.h"
-
 
 StubProcess::StubProcess()
+    : d(0)
 {
     m_User = "root";
     m_Scheduler = SchedNormal;
@@ -39,6 +40,24 @@ StubProcess::~StubProcess()
 }
 
 
+void StubProcess::setCommand(const QByteArray &command)
+{
+    m_Command = command;
+}
+
+
+void StubProcess::setUser(const QByteArray &user)
+{
+    m_User = user;
+}
+
+
+void StubProcess::setXOnly(bool xonly)
+{
+    m_bXOnly = xonly;
+}
+
+
 void StubProcess::setPriority(int prio)
 {
     if (prio > 100)
@@ -50,6 +69,12 @@ void StubProcess::setPriority(int prio)
 }
 
 
+void StubProcess::setScheduler(int sched)
+{
+    m_Scheduler = sched;
+}
+
+
 QByteArray StubProcess::commaSeparatedList(const QList<QByteArray> &lst)
 {
     QByteArray str;
@@ -60,6 +85,14 @@ QByteArray StubProcess::commaSeparatedList(const QList<QByteArray> &lst)
     return str;
 }
 
+/* 
+ * Map pid_t to a signed integer type that makes sense for QByteArray;
+ * only the most common sizes 16 bit and 32 bit are special-cased.
+ */
+template<int T> struct PIDType { typedef pid_t PID_t; } ;
+template<> struct PIDType<2> { typedef qint16 PID_t; } ;
+template<> struct PIDType<4> { typedef qint32 PID_t; } ;
+
 /*
  * Conversation with kdesu_stub. This is how we pass the authentication
  * tokens (X11) and other stuff to kdesu_stub.
@@ -126,7 +159,10 @@ int StubProcess::ConverseStub(int check)
 		tmp = "0";
 	    writeLine(tmp);
 	} else if (line == "app_start_pid") { // obsolete
-	    tmp.setNum(getpid());
+	    // Force the pid_t returned from getpid() into
+	    // something QByteArray understands; avoids ambiguity
+	    // between short and unsigned short in particular.
+	    tmp.setNum((PIDType<sizeof(pid_t)>::PID_t)(getpid()));
 	    writeLine(tmp);
 	} else if (line == "environment") { // additional env vars
 	    QList<QByteArray> env = environment();
@@ -147,5 +183,19 @@ int StubProcess::ConverseStub(int check)
 }
 
 
+QByteArray StubProcess::display()
+{
+    return m_pCookie->display();
+}
+
+
+#ifdef Q_WS_X11
+QByteArray StubProcess::displayAuth()
+{
+    return m_pCookie->displayAuth();
+}
+#endif
+
+
 void StubProcess::virtual_hook( int id, void* data )
 { PtyProcess::virtual_hook( id, data ); }
