@@ -4,7 +4,7 @@
 * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
 *
 * Sudo support added by Jonathan Riddell <jriddell@ ubuntu.com>
-* Copyright (C) 2005 Canonical Ltd
+* Copyright (C) 2005 Canonical Ltd  // krazy:exclude=copyright (no email)
 *
 * This is free software; you can use this library under the GNU Library
 * General Public License, version 2. See the file "COPYING.LIB" for the
@@ -13,8 +13,11 @@
 * su.cpp: Execute a program as another user with "class SuProcess".
 */
 
+#include "su.h"
+#include "kcookie.h"
+
 #include <config.h>
-#include <config-prefix.h> // for __KDE_BINDIR
+#include <config-prefix.h> // for LIBEXEC_INSTALL_DIR
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -28,7 +31,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
-#include <qfile.h>
+#include <QtCore/QFile>
 
 #include <kconfig.h>
 #include <kconfiggroup.h>
@@ -37,9 +40,6 @@
 #include <kstandarddirs.h>
 #include <kuser.h>
 
-#include "su.h"
-#include "kcookie.h"
-
 
 #ifndef __PATH_SU
 #define __PATH_SU "false"
@@ -52,29 +52,37 @@
 //change to sudo or su according to your preferences
 #define DEFAULT_SUPER_USER_COMMAND "sudo"
 
+class SuProcess::SuProcessPrivate
+{
+public:
+    QString m_superUserCommand;
+};
+
 SuProcess::SuProcess(const QByteArray &user, const QByteArray &command)
+    : d( new SuProcessPrivate )
 {
     m_User = user;
     m_Command = command;
 
     KSharedConfig::Ptr config = KGlobal::config();
     KConfigGroup group(config, "super-user-command");
-    m_superUserCommand = group.readEntry("super-user-command", DEFAULT_SUPER_USER_COMMAND);
+    d->m_superUserCommand = group.readEntry("super-user-command", DEFAULT_SUPER_USER_COMMAND);
 
-    if ( m_superUserCommand != "sudo" && m_superUserCommand != "su" ) {
-      kWarning() << "unknown super user command" << endl;
-      m_superUserCommand = "su";
+    if ( d->m_superUserCommand != "sudo" && d->m_superUserCommand != "su" ) {
+      kWarning() << "unknown super user command";
+      d->m_superUserCommand = "su";
     }
 }
 
 
 SuProcess::~SuProcess()
 {
+    delete d;
 }
 
 QString SuProcess::superUserCommand()
 {
-    return m_superUserCommand;
+    return d->m_superUserCommand;
 }
 
 bool SuProcess::useUsersOwnPassword()
@@ -109,11 +117,11 @@ int SuProcess::exec(const char *password, int check)
     // since user may change after constructor (due to setUser())
     // we need to override sudo with su for non-root here
     if (m_User != "root") {
-        m_superUserCommand = "su";
+        d->m_superUserCommand = "su";
     }
 
     QList<QByteArray> args;
-    if (m_superUserCommand == "sudo") {
+    if (d->m_superUserCommand == "sudo") {
         args += "-u";
     }
 
@@ -122,14 +130,14 @@ int SuProcess::exec(const char *password, int check)
     else
         args += m_User;
 
-    if (m_superUserCommand == "su") {
+    if (d->m_superUserCommand == "su") {
         args += "-c";
     }
-    args += QByteArray(__KDE_BINDIR) + "/kdesu_stub";
-    args += "-";
+    args += QByteArray(LIBEXEC_INSTALL_DIR) + "/kdesu_stub";
+    args += "-"; // krazy:exclude=doublequote_chars (QList, not QString)
 
     QByteArray command;
-    if (m_superUserCommand == "sudo") {
+    if (d->m_superUserCommand == "sudo") {
         command = __PATH_SUDO;
     } else {
         command = __PATH_SU;
@@ -137,20 +145,20 @@ int SuProcess::exec(const char *password, int check)
  
     if (::access(command, X_OK) != 0)
     {
-        command = QFile::encodeName( KGlobal::dirs()->findExe(m_superUserCommand.toLatin1()) );
+        command = QFile::encodeName( KGlobal::dirs()->findExe(d->m_superUserCommand.toLatin1()) );
         if (command.isEmpty())
             return check ? SuNotFound : -1;
     }
 
-    // kDebug(900) << k_lineinfo << "Call StubProcess::exec()" << endl;
+    // kDebug(900) << k_lineinfo << "Call StubProcess::exec()";
     if (StubProcess::exec(command, args) < 0)
     {
         return check ? SuNotFound : -1;
     }
-    // kDebug(900) << k_lineinfo << "Done StubProcess::exec()" << endl;
+    // kDebug(900) << k_lineinfo << "Done StubProcess::exec()";
 
     SuErrors ret = (SuErrors) ConverseSU(password);
-    // kDebug(900) << k_lineinfo << "Conversation returned " << ret << endl;
+    // kDebug(900) << k_lineinfo << "Conversation returned " << ret;
 
     if (ret == error)
     {
@@ -162,12 +170,12 @@ int SuProcess::exec(const char *password, int check)
     {
         if (ret == killme)
         {
-            if ( m_superUserCommand == "sudo" ) {
+            if ( d->m_superUserCommand == "sudo" ) {
  	        // sudo can not be killed, just return
  	        return ret;
  	    }
  	    if (kill(m_Pid, SIGKILL) < 0) {
- 	        kDebug() << k_funcinfo << "kill < 0" << endl;
+ 	        kDebug() << "kill < 0";
  		//FIXME SIGKILL doesn't work for sudo,
  		//why is this different from su?
  		ret=error;
@@ -188,7 +196,7 @@ int SuProcess::exec(const char *password, int check)
     if (ret == notauthorized)
     {
         kill(m_Pid, SIGKILL);
-        if (m_superUserCommand != "sudo") {
+        if (d->m_superUserCommand != "sudo") {
             waitForChild();
         }
         return SuIncorrectPassword;
@@ -228,7 +236,7 @@ int SuProcess::ConverseSU(const char *password)
     enum { WaitForPrompt, CheckStar, HandleStub } state = WaitForPrompt;
     int colon;
     unsigned i, j;
-    // kDebug(900) << k_lineinfo << "ConverseSU starting." << endl;
+    // kDebug(900) << k_lineinfo << "ConverseSU starting.";
 
     QByteArray line;
     while (true)
@@ -236,7 +244,7 @@ int SuProcess::ConverseSU(const char *password)
         line = readLine();
         if (line.isNull())
             return ( state == HandleStub ? notauthorized : error);
-        kDebug(900) << k_lineinfo << "Read line <" << line << ">" << endl;
+        kDebug(900) << k_lineinfo << "Read line <" << line << ">";
 
         switch (state)
         {
@@ -250,7 +258,7 @@ int SuProcess::ConverseSU(const char *password)
                     return ok;
                 }
 
-                while(waitMS(m_Fd,100)>0)
+                while(waitMS(fd(),100)>0)
                 {
                     // There is more output available, so the previous line
                     // couldn't have been a password prompt (the definition
@@ -261,7 +269,7 @@ int SuProcess::ConverseSU(const char *password)
                         break;
 
                     line = more;
-                    kDebug(900) << k_lineinfo << "Read line <" << more << ">" << endl;
+                    kDebug(900) << k_lineinfo << "Read line <" << more << ">";
                 }
 
                 // Match "Password: " with the regex ^[^:]+:[\w]*$.
@@ -287,8 +295,8 @@ int SuProcess::ConverseSU(const char *password)
                     }
                     if ((WaitSlave() == 0) && checkPid(m_Pid))
                     {
-                        write(m_Fd, password, strlen(password));
-                        write(m_Fd, "\n", 1);
+                        write(fd(), password, strlen(password));
+                        write(fd(), "\n", 1);
                         state=CheckStar;
                     }
                     else
@@ -323,7 +331,7 @@ int SuProcess::ConverseSU(const char *password)
                 {
                     unreadLine(line);
                     return ok;
- 	        } else if (m_superUserCommand == "sudo") {
+ 	        } else if (d->m_superUserCommand == "sudo") {
  	            // sudo gives a "sorry" line so reaches here
  	            // with the wrong password
  	            return notauthorized;
