@@ -12,6 +12,7 @@
               (C) 2006 Albert Astals Cid <aacid@kde.org>
               (C) 2006 Clarence Dang <dang@kde.org>
               (C) 2006 Michel Hermier <michel.hermier@gmail.com>
+              (C) 2007 Nick Shaforostoff <shafff@ukr.net>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -29,6 +30,7 @@
 */
 
 #include "kselectaction.h"
+#include "kselectaction_p.h"
 
 #include <QActionEvent>
 #include <QEvent>
@@ -40,99 +42,75 @@
 #include "kcombobox.h"
 #include "kmenu.h"
 
-// BEGIN KSelectAction
-class KSelectAction::KSelectActionPrivate
+// QAction::setText("Hi") and then KPopupAccelManager exec'ing, causes
+// QAction::text() to return "&Hi" :(  Comboboxes don't have accels and
+// display ampersands literally.
+static QString DropAmpersands(const QString &text)
 {
-public:
-  KSelectActionPrivate()
-  {
-    q = 0;
-    m_edit = false;
-    m_menuAccelsEnabled = true;
-    m_comboWidth = -1;
-    m_maxComboViewCount = -1;
+    QString result;
+    for (int i = 0; i < text.count(); ++i) {
+        if (text.at(i) == '&') {
+            if (i + 1 < text.count() && text.at(i + 1) == '&')
+                result.append(text.at(i++)); // "&&" -> '&'
+            // else eat the ampersand
+        }
+        else
+            result.append(text.at(i));
+    }
+    return result;
+}
 
-    m_toolBarMode = KSelectAction::ComboBoxMode;
-    m_toolButtonPopupMode = QToolButton::InstantPopup; //InstantPopup by default because there is no default action
-
-    m_actionGroup = new QActionGroup(0L);
-  }
-
-  ~KSelectActionPrivate()
-  {
-    delete m_actionGroup;
-  }
-
-  void init(KSelectAction *q_ptr);
-
-  bool m_edit, m_menuAccelsEnabled;
-  int m_comboWidth;
-  int m_maxComboViewCount;
-
-  KSelectAction::ToolBarMode m_toolBarMode;
-  QToolButton::ToolButtonPopupMode m_toolButtonPopupMode;
-
-  QActionGroup* m_actionGroup;
-
-  QList<QToolButton*> m_buttons;
-  QList<KComboBox*> m_comboBoxes;
-
-  QString makeMenuText( const QString &_text )
-  {
-      if ( m_menuAccelsEnabled )
-        return _text;
-      QString text = _text;
-      int i = 0;
-      while ( i < text.length() ) {
-          if ( text[ i ] == '&' ) {
-              text.insert( i, '&' );
-              i += 2;
-          }
-          else
-              ++i;
-      }
-      return text;
-  }
-  KSelectAction *q;
-};
 
 KSelectAction::KSelectAction(QObject *parent)
   : KAction(parent)
-  , d(new KSelectActionPrivate())
+  , d_ptr(new KSelectActionPrivate())
 {
+  Q_D(KSelectAction);
   d->init(this);
 }
 
 KSelectAction::KSelectAction(const QString &text, QObject *parent)
   : KAction(parent)
-  , d(new KSelectActionPrivate())
+  , d_ptr(new KSelectActionPrivate())
 {
+  Q_D(KSelectAction);
   d->init(this);
   setText(text);
 }
 
 KSelectAction::KSelectAction(const KIcon & icon, const QString &text, QObject *parent)
   : KAction(icon, text, parent)
-  , d(new KSelectActionPrivate())
+  , d_ptr(new KSelectActionPrivate())
 {
+  Q_D(KSelectAction);
+  d->init(this);
+}
+
+KSelectAction::KSelectAction(KSelectActionPrivate &dd, QObject *parent)
+  : KAction(parent)
+  , d_ptr(&dd)
+{
+  Q_D(KSelectAction);
   d->init(this);
 }
 
 KSelectAction::~KSelectAction()
 {
-  delete d;
+  delete d_ptr;
   delete menu();
 }
 
-void KSelectAction::KSelectActionPrivate::init(KSelectAction *q_ptr)
+void KSelectActionPrivate::init(KSelectAction *q_ptr)
 {
   q = q_ptr;
   QObject::connect(q->selectableActionGroup(), SIGNAL(triggered(QAction*)), q, SLOT(actionTriggered(QAction*)));
+  QObject::connect(q, SIGNAL(toggled(bool)),q, SLOT(slotToggled(bool)));
   q->setMenu(new KMenu());
 }
 
 QActionGroup * KSelectAction::selectableActionGroup( ) const
 {
+  Q_D(const KSelectAction);
   return d->m_actionGroup;
 }
 
@@ -154,23 +132,25 @@ int KSelectAction::currentItem() const
 QString KSelectAction::currentText( ) const
 {
   if (QAction* a = currentAction())
-    return a->text();
+    return ::DropAmpersands(a->text());
 
   return QString();
 }
 
 bool KSelectAction::setCurrentAction(QAction* action)
 {
-  //kDebug (129) << "KSelectAction::setCurrentAction(" << action << ")" << endl;
+  //kDebug (129) << "KSelectAction::setCurrentAction(" << action << ")";
   if (action) {
     if (actions().contains(action)) {
       if (action->isVisible() && action->isEnabled() && action->isCheckable()) {
         action->setChecked(true);
+        if (isCheckable())
+            setChecked(true);
         return true;
       } else
-        kWarning (129) << k_funcinfo << "Action don't have the correct properties to be current:" << action->text() << endl;
+        kWarning (129) << "Action don't have the correct properties to be current:" << action->text();
     } else
-      kWarning (129) << k_funcinfo << "Action don't belong to group:" << action->text() << endl;
+      kWarning (129) << "Action don't belong to group:" << action->text();
     return false;
   }
 
@@ -182,7 +162,7 @@ bool KSelectAction::setCurrentAction(QAction* action)
 
 bool KSelectAction::setCurrentItem( int index )
 {
-  //kDebug (129) << "KSelectAction::setCurrentIndex(" << index << ")" << endl;
+  //kDebug (129) << "KSelectAction::setCurrentIndex(" << index << ")";
   return setCurrentAction(action(index));
 }
 
@@ -203,13 +183,14 @@ QAction * KSelectAction::action( const QString & text, Qt::CaseSensitivity cs )
     compare = text.toLower();
 
   foreach (QAction* action, selectableActionGroup()->actions()) {
+    const QString text = ::DropAmpersands(action->text());
     if (cs == Qt::CaseSensitive) {
-      if (action->text() == compare) {
+      if (text == compare) {
         return action;
       }
 
     } else if (cs == Qt::CaseInsensitive) {
-      if (action->text().toLower() == compare) {
+      if (text.toLower() == compare) {
         return action;
       }
     }
@@ -220,12 +201,13 @@ QAction * KSelectAction::action( const QString & text, Qt::CaseSensitivity cs )
 
 bool KSelectAction::setCurrentAction( const QString & text, Qt::CaseSensitivity cs)
 {
-  //kDebug (129) << "KSelectAction::setCurrentAction(" << text << ",cs=" << cs << ")" << endl;
+  //kDebug (129) << "KSelectAction::setCurrentAction(" << text << ",cs=" << cs << ")";
   return setCurrentAction(action(text, cs));
 }
 
 void KSelectAction::setComboWidth( int width )
 {
+  Q_D(KSelectAction);
   if ( width < 0 )
     return;
 
@@ -239,6 +221,7 @@ void KSelectAction::setComboWidth( int width )
 
 void KSelectAction::setMaxComboViewCount( int n )
 {
+  Q_D(KSelectAction);
   d->m_maxComboViewCount = n;
 
   foreach (KComboBox* box, d->m_comboBoxes)
@@ -253,7 +236,8 @@ void KSelectAction::setMaxComboViewCount( int n )
 
 void KSelectAction::addAction(QAction* action)
 {
-  //kDebug (129) << "KSelectAction::addAction(" << action << ")" << endl;
+  Q_D(KSelectAction);
+  //kDebug (129) << "KSelectAction::addAction(" << action << ")";
 
   action->setActionGroup(selectableActionGroup());
 
@@ -269,6 +253,7 @@ void KSelectAction::addAction(QAction* action)
 
 KAction* KSelectAction::addAction(const QString &text)
 {
+  Q_D(KSelectAction);
   KAction* newAction = new KAction(parent());
   newAction->setText(text);
   newAction->setCheckable( true );
@@ -292,11 +277,13 @@ KAction* KSelectAction::addAction(const KIcon& icon, const QString& text)
 
 QAction* KSelectAction::removeAction(QAction* action)
 {
-  //kDebug (129) << "KSelectAction::removeAction(" << action << ")" << endl;
+  Q_D(KSelectAction);
+  //kDebug (129) << "KSelectAction::removeAction(" << action << ")";
   //int index = selectableActionGroup()->actions().indexOf(action);
-  //kDebug (129) << "\tindex=" << index << endl;
+  //kDebug (129) << "\tindex=" << index;
 
-  action->setActionGroup(0L);
+  // Removes the action from the group and sets its parent to null.
+  d->m_actionGroup->removeAction(action);
 
   foreach (QToolButton* button, d->m_buttons)
     button->removeAction(action);
@@ -313,11 +300,14 @@ void KSelectAction::actionTriggered(QAction* action)
 {
   // cache values so we don't need access to members in the action
   // after we've done an emit()
-  QString text = action->text();
-  int index = selectableActionGroup()->actions().indexOf(action);
+  const QString text = ::DropAmpersands(action->text());
+  const int index = selectableActionGroup()->actions().indexOf(action);
   //kDebug (129) << "KSelectAction::actionTriggered(" << action << ") text=" << text
   //          << " index=" << index  << " emitting triggered()" << endl;
 
+  if (isCheckable()) // if this is subsidiary of other KSelectAction-derived class
+    trigger();       // then imitate usual QAction behaviour so that other submenus (and their items) become unchecked
+
   emit triggered(action);
   emit triggered(index);
   emit triggered(text);
@@ -325,19 +315,21 @@ void KSelectAction::actionTriggered(QAction* action)
 
 QStringList KSelectAction::items() const
 {
+  Q_D(const KSelectAction);
   QStringList ret;
 
   foreach (QAction* action, d->m_actionGroup->actions())
-    ret << action->text();
+    ret << ::DropAmpersands(action->text());
 
   return ret;
 }
 
 void KSelectAction::changeItem( int index, const QString& text )
 {
+  Q_D(KSelectAction);
   if ( index < 0 || index >= actions().count() )
   {
-    kWarning() << "KSelectAction::changeItem Index out of scope" << endl;
+    kWarning() << "KSelectAction::changeItem Index out of scope";
     return;
   }
 
@@ -346,7 +338,8 @@ void KSelectAction::changeItem( int index, const QString& text )
 
 void KSelectAction::setItems( const QStringList &lst )
 {
-  //kDebug (129) << "KSelectAction::setItems(" << lst << ")" << endl;
+  Q_D(KSelectAction);
+  //kDebug (129) << "KSelectAction::setItems(" << lst << ")";
 
   clear();
 
@@ -366,36 +359,41 @@ void KSelectAction::setItems( const QStringList &lst )
 
 int KSelectAction::comboWidth() const
 {
+  Q_D(const KSelectAction);
   return d->m_comboWidth;
 }
 
 void KSelectAction::clear()
 {
-  //kDebug (129) << "KSelectAction::clear()" << endl;
+  Q_D(KSelectAction);
+  //kDebug (129) << "KSelectAction::clear()";
 
   // we need to delete the actions later since we may get a call to clear()
   // from a method called due to a triggered(...) signal
-  foreach (QAction* action, d->m_actionGroup->actions())
+  const QList<QAction*> actions = d->m_actionGroup->actions();
+  for (int i = 0; i < actions.count(); ++i)
   {
     // deleteLater() only removes us from the actions() list (among
     // other things) on the next entry into the event loop.  Until then,
     // e.g. action() and setCurrentItem() will be working on items
     // that are supposed to have been deleted.  So detach the action to
     // prevent this from happening.
-    removeAction (action);
+    removeAction(actions[i]);
 
-    action->deleteLater();
+    actions[i]->deleteLater();
   }
 }
 
 void KSelectAction::removeAllActions( )
 {
+  Q_D(KSelectAction);
   while (d->m_actionGroup->actions().count())
     removeAction(d->m_actionGroup->actions().first());
 }
 
 void KSelectAction::setEditable( bool edit )
 {
+  Q_D(KSelectAction);
   d->m_edit = edit;
 
   foreach (KComboBox* comboBox, d->m_comboBoxes)
@@ -406,31 +404,44 @@ void KSelectAction::setEditable( bool edit )
 
 bool KSelectAction::isEditable() const
 {
+  Q_D(const KSelectAction);
   return d->m_edit;
 }
 
+void KSelectAction::slotToggled(bool checked)
+{
+    //if (checked && selectableActionGroup()->checkedAction())
+    if (!checked && currentAction()) // other's submenu item has been selected
+        currentAction()->setChecked(false);
+}
+
 KSelectAction::ToolBarMode KSelectAction::toolBarMode() const
 {
+  Q_D(const KSelectAction);
   return d->m_toolBarMode;
 }
 
 void KSelectAction::setToolBarMode( ToolBarMode mode )
 {
+  Q_D(KSelectAction);
   d->m_toolBarMode = mode;
 }
 
 QToolButton::ToolButtonPopupMode KSelectAction::toolButtonPopupMode( ) const
 {
+  Q_D(const KSelectAction);
   return d->m_toolButtonPopupMode;
 }
 
 void KSelectAction::setToolButtonPopupMode( QToolButton::ToolButtonPopupMode mode )
 {
+  Q_D(KSelectAction);
   d->m_toolButtonPopupMode = mode;
 }
 
 void KSelectAction::comboBoxDeleted(QObject* object)
 {
+  Q_D(KSelectAction);
   foreach (KComboBox* comboBox, d->m_comboBoxes)
     if (object == comboBox) {
       d->m_comboBoxes.removeAll(static_cast<KComboBox*>(object));
@@ -440,14 +451,14 @@ void KSelectAction::comboBoxDeleted(QObject* object)
 
 void KSelectAction::comboBoxCurrentIndexChanged(int index)
 {
-  //kDebug (129) << "KSelectAction::comboBoxCurrentIndexChanged(" << index << ")" << endl;
+  //kDebug (129) << "KSelectAction::comboBoxCurrentIndexChanged(" << index << ")";
 
   KComboBox *triggeringCombo = qobject_cast <KComboBox *> (sender ());
 
   QAction *a = action(index);
-  //kDebug (129) << "\ta=" << a << endl;
+  //kDebug (129) << "\ta=" << a;
   if (a) {
-    //kDebug (129) << "\t\tsetting as current action" << endl;
+    //kDebug (129) << "\t\tsetting as current action";
     a->trigger();
 
   } else if (isEditable () &&
@@ -456,12 +467,12 @@ void KSelectAction::comboBoxCurrentIndexChanged(int index)
 
     // User must have added a new item by typing and pressing enter.
     const QString newItemText = triggeringCombo->currentText ();
-    //kDebug (129) << "\t\tuser typed new item '" << newItemText << "'" << endl;
+    //kDebug (129) << "\t\tuser typed new item '" << newItemText << "'";
 
     // Only 1 combobox contains this and it's not a proper action.
-    triggeringCombo->blockSignals (true);
+    bool blocked = triggeringCombo->blockSignals (true);
     triggeringCombo->removeItem (index);
-    triggeringCombo->blockSignals (false);
+    triggeringCombo->blockSignals (blocked);
 
     KAction *newAction = addAction (newItemText);
 
@@ -476,16 +487,19 @@ void KSelectAction::comboBoxCurrentIndexChanged(int index)
 // think it did anyway esp. in the presence KCheckAccelerator - Clarence.
 void KSelectAction::setMenuAccelsEnabled( bool b )
 {
+  Q_D(KSelectAction);
   d->m_menuAccelsEnabled = b;
 }
 
 bool KSelectAction::menuAccelsEnabled() const
 {
+  Q_D(const KSelectAction);
   return d->m_menuAccelsEnabled;
 }
 
 QWidget * KSelectAction::createWidget( QWidget * parent )
 {
+  Q_D(KSelectAction);
   QToolBar *toolBar = qobject_cast<QToolBar *>(parent);
   if (!toolBar)
     return 0;
@@ -537,14 +551,14 @@ QWidget * KSelectAction::createWidget( QWidget * parent )
   return 0L;
 }
 
-// QAction::setText("Hi") and then KPopupAccelManager exec'ing, causes
-// QAction::text() to return "&Hi" :(  Comboboxes don't have accels and
-// display ampersands literally.
-static QString DropAmpersands (const QString &text)
+void KSelectAction::deleteWidget(QWidget *widget)
 {
-  QString ret = text;
-  ret.remove ('&');
-  return ret;
+    Q_D(KSelectAction);
+    if (QToolButton *toolButton = qobject_cast<QToolButton *>(widget))
+        d->m_buttons.removeAll(toolButton);
+    else if (KComboBox *comboBox = qobject_cast<KComboBox *>(widget))
+        d->m_comboBoxes.removeAll(comboBox);
+    KAction::deleteWidget(widget);
 }
 
 // KSelectAction::eventFilter() is called before action->setChecked()
@@ -562,24 +576,24 @@ static QString DropAmpersands (const QString &text)
 static int TrueCurrentItem (KSelectAction *sa)
 {
   QAction *curAction = sa->currentAction ();
-  //kDebug (129) << "\tTrueCurrentItem(" << sa << ") curAction=" << curAction << endl;
+  //kDebug (129) << "\tTrueCurrentItem(" << sa << ") curAction=" << curAction;
 
   foreach (QAction *action, sa->actions ())
   {
     if (action->isChecked ())
     {
-       //kDebug (129) << "\t\taction " << action << " (text=" << action->text () << ") isChecked" << endl;
+       //kDebug (129) << "\t\taction " << action << " (text=" << action->text () << ") isChecked";
 
        // 2 actions checked case?
        if (action != curAction)
        {
-         //kDebug (129) << "\t\t\tmust be newly selected one" << endl;
+         //kDebug (129) << "\t\t\tmust be newly selected one";
          return sa->actions ().indexOf (action);
        }
     }
   }
 
-  //kDebug (129) << "\t\tcurrent action still selected? " << (curAction && curAction->isChecked ()) << endl;
+  //kDebug (129) << "\t\tcurrent action still selected? " << (curAction && curAction->isChecked ());
   // 1 or 0 actions checked case (in that order)?
   return (curAction && curAction->isChecked ()) ? sa->actions ().indexOf (curAction) : -1;
 }
@@ -613,7 +627,7 @@ bool KSelectAction::eventFilter (QObject *watched, QEvent *event)
         e->reason () != Qt::PopupFocusReason/*menu*/ &&
         e->reason () != Qt::OtherFocusReason/*inconsistently reproduceable actions...*/) {
 
-      //kDebug (129) << "\tkilling text" << endl;
+      //kDebug (129) << "\tkilling text";
       comboBox->setEditText (comboBox->itemText (comboBox->currentIndex ()));
     }
 
@@ -621,7 +635,7 @@ bool KSelectAction::eventFilter (QObject *watched, QEvent *event)
   }
 
 
-  comboBox->blockSignals (true);
+  bool blocked = comboBox->blockSignals (true);
 
   if (event->type () == QEvent::ActionAdded)
   {
@@ -691,7 +705,7 @@ bool KSelectAction::eventFilter (QObject *watched, QEvent *event)
     comboBox->setCurrentIndex (newItem);
   }
 
-  comboBox->blockSignals (false);
+  comboBox->blockSignals (blocked);
 
   return false/*propagate event*/;
 }
