@@ -19,17 +19,16 @@
 #ifndef KSTANDARDACTION_H
 #define KSTANDARDACTION_H
 
+#include <kdeui_export.h>
+
 class QObject;
 class QStringList;
 class QWidget;
 class KAction;
-class KActionCollection;
 class KRecentFilesAction;
 class KToggleAction;
-class KToggleToolBarAction;
 class KToggleFullScreenAction;
 
-#include <kdelibs_export.h>
 
 /**
  * Convenience methods to access all standard KDE actions.
@@ -42,6 +41,8 @@ class KToggleFullScreenAction;
  * All of the documentation for KAction holds for KStandardAction
  * also.  When in doubt on how things work, check the KAction
  * documention first.
+ * Please note that calling any of these methods automatically adds the action
+ * to the actionCollection() of the QObject given by the 'parent' parameter.
  *
  * <b>Simple Example:</b>\n
  *
@@ -49,7 +50,7 @@ class KToggleFullScreenAction;
  * for regular actions.  For example, if you previously had:
  *
  * \code
- * KAction *newAct = new KAction(i18n("&New"), KIcon("filenew"),
+ * KAction *newAct = new KAction(i18n("&New"), KIcon("document-new"),
  *                               KStandardShortcut::shortcut(KStandardShortcut::New), this,
  *                               SLOT(fileNew()), actionCollection());
  * \endcode
@@ -156,7 +157,8 @@ namespace KStandardAction
     ConfigureNotifications,
     FullScreen,
     Clear,
-    PasteText
+    PasteText,
+    SwitchApplicationLanguage
   };
 
   /**
@@ -197,7 +199,6 @@ namespace KStandardAction
    * @param slot The SLOT to invoke when a URL is selected. The slot's
    * signature is slotURLSelected( const KUrl & ).
    * @param parent parent widget
-   * @param name name of widget
    */
   KDEUI_EXPORT KRecentFilesAction *openRecent(const QObject *recvr, const char *slot, QObject *parent);
 
