@@ -22,8 +22,6 @@
 
 #include <kpagedialog.h>
 
-class KAssistantDialogPrivate;
-
 /**
  * This class provides a framework for assistant dialogs.
  *
@@ -41,13 +39,13 @@ class KAssistantDialogPrivate;
  * and Help push buttons, as appropriate to the current position in the page sequence.
  * The Finish Button has the code KDialog::User1, The Next button is KDialog::User2 
  * and the Back button is KDialog::User3.
- * The help button may be hidden using KDialog::showButton( Help , false )
+ * The help button may be hidden using showButton(KDialog::Help, false)
  *
  * Create and populate dialog pages that inherit from QWidget and add them 
  * to the assistant dialog using addPage().
  *
- * The functions next() and back() are virtual you can inherit them if you want 
- * to override the defaults action of the next and back buttons.
+ * The functions next() and back() are virtual and may be reimplemented to
+ * override the default actions of the next and back buttons.
  *
  * @author Olivier Goffart <ogoffart at kde.org>
  */
@@ -61,7 +59,7 @@ class KDEUI_EXPORT KAssistantDialog : public KPageDialog
          * @flags the window flags to give to the assistant dialog. The
          * default of zero is usually what you want.
          */
-        KAssistantDialog(QWidget *parent=0, Qt::WFlags flags=0);
+        explicit KAssistantDialog(QWidget *parent=0, Qt::WFlags flags=0);
         virtual ~KAssistantDialog();
 
         /**
@@ -80,7 +78,7 @@ class KDEUI_EXPORT KAssistantDialog : public KPageDialog
          * @see setValid
          * @param page the page to check the validity of
          */
-        bool isValid(KPageWidgetItem *page);
+        bool isValid(KPageWidgetItem *page) const;
 
         /**
          * Specify whether a page is appropriate.
@@ -103,7 +101,7 @@ class KDEUI_EXPORT KAssistantDialog : public KPageDialog
          * @param page is the page to check the appropriateness of.
          * @return true if @p page is appropriate, false if it is not
          */
-        bool isAppropriate(KPageWidgetItem *page);
+        bool isAppropriate(KPageWidgetItem *page) const;
 
 
     public Q_SLOTS:
@@ -136,12 +134,15 @@ class KDEUI_EXPORT KAssistantDialog : public KPageDialog
          *
          * Calls the KPageDialog(KPageWidget *widget, QWidget *parent, Qt::WFlags flags) constructor
          */
-        KAssistantDialog(KPageWidget *widget, QWidget *parent=0, Qt::WFlags flags=0);
+        explicit KAssistantDialog(KPageWidget *widget, QWidget *parent=0, Qt::WFlags flags=0);
 
         virtual void showEvent(QShowEvent * event);
 
     private:
-        KAssistantDialogPrivate * const d;
+        class Private;
+        Private * const d;
+        Q_DISABLE_COPY( KAssistantDialog )
+
         void init();
 };
 
