@@ -30,51 +30,52 @@
 #include <kpagewidgetmodel.h>
 #include <kvbox.h>
 
-#include <qlayout.h>
-#include <qmap.h>
+#include <QtGui/QLayout>
+#include <QtCore/QMap>
 
-QHash<QString,KConfigDialog *> KConfigDialog::openDialogs;
-
-// This class is here purely so we don't break binary compatibility down the road.
 class KConfigDialog::KConfigDialogPrivate
 {
 public:
-  KConfigDialogPrivate()
-  : shown(false), manager(0) { }
+  KConfigDialogPrivate(KConfigDialog *q)
+    : q(q), shown(false), manager(0) { }
 
+  KConfigDialog *q;
   bool shown;
   KConfigDialogManager *manager;
   QMap<QWidget *, KConfigDialogManager *> managerForPage;
+
+  /**
+    * The list of existing dialogs.
+   */
+  static QHash<QString,KConfigDialog *> openDialogs;
 };
 
+QHash<QString,KConfigDialog *> KConfigDialog::KConfigDialogPrivate::openDialogs;
+
 KConfigDialog::KConfigDialog( QWidget *parent, const QString& name,
-          KConfigSkeleton *config,
-          FaceType faceType,
-          ButtonCodes dialogButtons,
-          ButtonCode defaultButton,
-          bool modal ) :
+          KConfigSkeleton *config ) :
     KPageDialog( parent, Qt::MSWindowsFixedSizeDialogHint ),
-    d(new KConfigDialogPrivate)
+    d(new KConfigDialogPrivate(this))
 {
   setCaption( i18n("Configure") );
-  setFaceType( faceType );
-  setButtons( dialogButtons );
-  setDefaultButton( defaultButton );
+  setFaceType( List );
+  setButtons( Default|Ok|Apply|Cancel|Help );
+  setDefaultButton( Ok );
   setObjectName( name );
-  setModal( modal );
 
   if ( !name.isEmpty() ) {
-    openDialogs.insert(name, this);
+    KConfigDialogPrivate::openDialogs.insert(name, this);
   } else {
     QString genericName;
     genericName.sprintf("SettingsDialog-%p", static_cast<void*>(this));
-    openDialogs.insert(genericName, this);
+    KConfigDialogPrivate::openDialogs.insert(genericName, this);
     setObjectName(genericName);
   }
 
   connect(this, SIGNAL(okClicked()), this, SLOT(updateSettings()));
   connect(this, SIGNAL(applyClicked()), this, SLOT(updateSettings()));
   connect(this, SIGNAL(applyClicked()), this, SLOT(updateButtons()));
+  connect(this, SIGNAL(cancelClicked()), this, SLOT(updateWidgets()));
   connect(this, SIGNAL(defaultClicked()), this, SLOT(updateWidgetsDefault()));
   connect(this, SIGNAL(defaultClicked()), this, SLOT(updateButtons()));
 
@@ -86,7 +87,7 @@ KConfigDialog::KConfigDialog( QWidget *parent, const QString& name,
 
 KConfigDialog::~KConfigDialog()
 {
-  openDialogs.remove(objectName());
+  KConfigDialogPrivate::openDialogs.remove(objectName());
   delete d;
 }
 
@@ -99,6 +100,13 @@ KPageWidgetItem* KConfigDialog::addPage(QWidget *page,
   KPageWidgetItem* item = addPageInternal(page, itemName, pixmapName, header);
   if(manage)
     d->manager->addWidget(page);
+  
+  if (d->shown && manage)
+  {
+    // update the default button if the dialog is shown
+    bool is_default = isButtonEnabled(Default) && d->manager->isDefault();
+    enableButton(Default,!is_default);
+  }
   return item;
 }
 
@@ -111,6 +119,13 @@ KPageWidgetItem* KConfigDialog::addPage(QWidget *page,
   KPageWidgetItem* item = addPageInternal(page, itemName, pixmapName, header);
   d->managerForPage[page] = new KConfigDialogManager(page, config);
   setupManagerConnections(d->managerForPage[page]);
+  
+  if (d->shown)
+  {
+    // update the default button if the dialog is shown
+    bool is_default = isButtonEnabled(Default) && d->managerForPage[page]->isDefault();
+    enableButton(Default,!is_default);
+  }
   return item;
 }
 
@@ -119,12 +134,6 @@ KPageWidgetItem* KConfigDialog::addPageInternal(QWidget *page,
                                         const QString &pixmapName,
                                         const QString &header)
 {
-  if(d->shown)
-  {
-    kDebug(240) << "KConfigDialog::addPage: can not add a page after the dialog has been shown.";
-    return 0;
-  }
-
   KVBox *frame = new KVBox();
   frame->setSpacing( 0 );
   frame->setMargin( 0 );
@@ -135,7 +144,6 @@ KPageWidgetItem* KConfigDialog::addPageInternal(QWidget *page,
   item->setIcon( KIcon( pixmapName ) );
 
   KPageDialog::addPage( item );
-
   return item;
 }
 
@@ -146,13 +154,14 @@ void KConfigDialog::setupManagerConnections(KConfigDialogManager *manager)
 
   connect(this, SIGNAL(okClicked()), manager, SLOT(updateSettings()));
   connect(this, SIGNAL(applyClicked()), manager, SLOT(updateSettings()));
+  connect(this, SIGNAL(cancelClicked()), manager, SLOT(updateWidgets()));
   connect(this, SIGNAL(defaultClicked()), manager, SLOT(updateWidgetsDefault()));
 }
 
 KConfigDialog* KConfigDialog::exists(const QString& name)
 {
-  QHash<QString,KConfigDialog *>::const_iterator it = openDialogs.find( name );
-  if ( it != openDialogs.end() )
+  QHash<QString,KConfigDialog *>::const_iterator it = KConfigDialogPrivate::openDialogs.find( name );
+  if ( it != KConfigDialogPrivate::openDialogs.end() )
       return *it;
   return 0;
 }
@@ -251,5 +260,15 @@ void KConfigDialog::updateWidgetsDefault()
 {
 }
 
+bool KConfigDialog::hasChanged()
+{
+    return false;
+}
+
+bool KConfigDialog::isDefault()
+{
+    return true;
+}
+
 
 #include "kconfigdialog.moc"
