@@ -20,9 +20,11 @@
  *  Boston, MA 02110-1301, USA.
  */
 
-#include <config.h>
-
 #include "kdialog.h"
+#include "kdialog_p.h"
+#include "kdialogqueue_p.h"
+
+#include <config.h>
 
 #include <QApplication>
 #include <QDesktopWidget>
@@ -37,14 +39,13 @@
 #include <QVBoxLayout>
 #include <QWhatsThis>
 
-#include <kconfig.h>
+#include <kconfiggroup.h>
 #include <kglobalsettings.h>
 #include <kguiitem.h>
 #include <kcomponentdata.h>
 #include <klocale.h>
 #include <kpushbutton.h>
 #include <kseparator.h>
-#include <kstaticdeleter.h>
 #include <kstandardguiitem.h>
 #include <ktoolinvocation.h>
 #include <kurllabel.h>
@@ -55,61 +56,18 @@
 #include <netwm.h>
 #endif
 
-struct KDialog::Private
-{
-  Private( KDialog *parent )
-    : mParent( parent ), mDetailsVisible( false ), mSettingDetails( false ), mDetailsWidget( 0 ),
-      mTopLayout( 0 ), mMainWidget( 0 ), mUrlHelp( 0 ), mActionSeparator( 0 ),
-      mButtonOrientation( Qt::Horizontal ),
-      mButtonBox( 0 )
-  {
-  }
+int KDialogPrivate::mMarginSize = 9;
+int KDialogPrivate::mSpacingSize = 6;
 
-  void setupLayout();
-  void setButtonFocus( QPushButton *p, bool isDefault, bool isFocus );
-  void appendButton( ButtonCode code , const KGuiItem &item );
-  KPushButton *button( ButtonCode code ) const;
-
-
-  KDialog* mParent;
-  bool mDetailsVisible;
-  bool mSettingDetails;
-  QWidget *mDetailsWidget;
-  QSize mIncSize;
-  QSize mMinSize;
-  QString mDetailsButtonText;
-
-  QBoxLayout *mTopLayout;
-  QWidget *mMainWidget;
-  KUrlLabel *mUrlHelp;
-  KSeparator *mActionSeparator;
-
-  QString mAnchor;
-  QString mHelpApp;
-  QString mHelpLinkText;
-
-  Qt::Orientation mButtonOrientation;
-  ButtonCode mEscapeButton;
-
-  QDialogButtonBox *mButtonBox;
-  QHash<int, KPushButton*> mButtonList;
-  QSignalMapper mButtonSignalMapper;
-
-  static int mMarginSize;
-  static int mSpacingSize;
-};
-
-int KDialog::Private::mMarginSize = 11;
-int KDialog::Private::mSpacingSize = 6;
-
-void KDialog::Private::setupLayout()
+void KDialogPrivate::setupLayout()
 {
+    Q_Q(KDialog);
   delete mTopLayout;
 
   if ( mButtonOrientation == Qt::Horizontal )
-    mTopLayout = new QVBoxLayout( mParent );
+        mTopLayout = new QVBoxLayout(q);
   else
-    mTopLayout = new QHBoxLayout( mParent );
+        mTopLayout = new QHBoxLayout(q);
 
   mTopLayout->setMargin( KDialog::marginHint() );
   mTopLayout->setSpacing( KDialog::spacingHint() );
@@ -132,47 +90,47 @@ void KDialog::Private::setupLayout()
   }
 }
 
-void KDialog::Private::setButtonFocus( QPushButton *button, bool isDefault, bool isFocus )
+void KDialogPrivate::setButtonFocus(QPushButton *button, bool isDefault, bool isFocus)
 {
   button->setDefault( isDefault );
   if ( isFocus )
       button->setFocus();
 }
 
-void KDialog::Private::appendButton( ButtonCode key, const KGuiItem &item )
+void KDialogPrivate::appendButton(KDialog::ButtonCode key, const KGuiItem &item)
 {
   QDialogButtonBox::ButtonRole role = QDialogButtonBox::InvalidRole;
   switch ( key ) {
-    case Help:
-    case Details:
+    case KDialog::Help:
+    case KDialog::Details:
       role = QDialogButtonBox::HelpRole;
       break;
-    case Default:
-      role = QDialogButtonBox::DestructiveRole;
+    case KDialog::Default:
+      role = QDialogButtonBox::ResetRole;
       break;
-    case Ok:
+    case KDialog::Ok:
       role = QDialogButtonBox::AcceptRole;
       break;
-    case Apply:
+    case KDialog::Apply:
       role = QDialogButtonBox::ApplyRole;
       break;
-    case Try:
-    case Close:
-    case Yes:
+    case KDialog::Try:
+    case KDialog::Close:
+    case KDialog::Yes:
       role = QDialogButtonBox::YesRole;
       break;
-    case Cancel:
+    case KDialog::Cancel:
       role = QDialogButtonBox::RejectRole;
       break;
-    case No:
+    case KDialog::No:
       role = QDialogButtonBox::NoRole;
       break;
-    case User1:
-    case User2:
-    case User3:
+    case KDialog::User1:
+    case KDialog::User2:
+    case KDialog::User3:
       role = QDialogButtonBox::ActionRole;
       break;
-    case NoDefault:
+    case KDialog::NoDefault:
     default:
       role = QDialogButtonBox::InvalidRole;
       break;
@@ -187,32 +145,42 @@ void KDialog::Private::appendButton( ButtonCode key, const KGuiItem &item )
   mButtonList.insert( key, button );
   mButtonSignalMapper.setMapping( button, key );
 
-  connect( button, SIGNAL( clicked() ),
+    QObject::connect(button, SIGNAL(clicked()),
            &mButtonSignalMapper, SLOT( map() ) );
 }
 
-KDialog::KDialog( QWidget *parent, Qt::WFlags flags )
-  : QDialog( parent, flags | Qt::MSWindowsFixedSizeDialogHint ),
-    d( new Private( this ) )
+void KDialogPrivate::init(KDialog *q)
 {
-  setModal( true );
-  KWhatsThisManager::init();
+    q_ptr = q;
+    KWhatsThisManager::init();
 
-  setButtons( Ok | Cancel );
-  setDefaultButton( Ok );
+    q->setButtons(KDialog::Ok | KDialog::Cancel);
+    q->setDefaultButton(KDialog::Ok);
 
-  connect( this, SIGNAL( layoutHintChanged() ), SLOT( updateGeometry() ) );
-  connect( &d->mButtonSignalMapper , SIGNAL( mapped( int ) ),
-           this, SLOT( slotButtonClicked( int ) ) );
+    q->connect(q, SIGNAL(layoutHintChanged()), q, SLOT(updateGeometry()));
+    q->connect(&mButtonSignalMapper, SIGNAL(mapped(int)), q, SLOT(slotButtonClicked(int)));
+}
+
+KDialog::KDialog( QWidget *parent, Qt::WFlags flags )
+  : QDialog(parent, flags), d_ptr(new KDialogPrivate)
+{
+    d_ptr->init(this);
+}
+
+KDialog::KDialog(KDialogPrivate &dd, QWidget *parent, Qt::WFlags flags)
+    : QDialog(parent, flags), d_ptr(&dd)
+{
+    d_ptr->init(this);
 }
 
 KDialog::~KDialog()
 {
-  delete d;
+    delete d_ptr;
 }
 
 void KDialog::setButtons( ButtonCodes buttonMask )
 {
+    Q_D(KDialog);
   if ( d->mButtonBox ) {
     d->mButtonList.clear();
 
@@ -272,6 +240,7 @@ void KDialog::setButtons( ButtonCodes buttonMask )
 
 void KDialog::setButtonsOrientation( Qt::Orientation orientation )
 {
+    Q_D(KDialog);
   if ( d->mButtonOrientation != orientation ) {
     d->mButtonOrientation = orientation;
 
@@ -285,20 +254,29 @@ void KDialog::setButtonsOrientation( Qt::Orientation orientation )
 
 void KDialog::setEscapeButton( ButtonCode id )
 {
-  d->mEscapeButton = id;
+    d_func()->mEscapeButton = id;
 }
 
-void KDialog::setDefaultButton( ButtonCode defaultButton )
+void KDialog::setDefaultButton( ButtonCode newDefaultButton )
 {
-  if ( defaultButton != NoDefault ) {
-    KPushButton *button = this->button( defaultButton );
-    if ( button )
-      d->setButtonFocus( button, true, false );
-  }
+    Q_D(KDialog);
+    bool makeDefault = true;
+    if (newDefaultButton == NoDefault) {
+        // if we already have a default, let's be sure to reset
+        // it to not be the default!
+        newDefaultButton = defaultButton();
+        makeDefault = false;
+    }
+
+    KPushButton *b = button(newDefaultButton);
+    if (b) {
+        d->setButtonFocus(b, makeDefault, false);
+    }
 }
 
 KDialog::ButtonCode KDialog::defaultButton() const
 {
+    Q_D(const KDialog);
   QHashIterator<int, KPushButton*> it( d->mButtonList );
   while ( it.hasNext() ) {
     it.next();
@@ -311,12 +289,14 @@ KDialog::ButtonCode KDialog::defaultButton() const
 
 void KDialog::setMainWidget( QWidget *widget )
 {
+    Q_D(KDialog);
   d->mMainWidget = widget;
   d->setupLayout();
 }
 
 QWidget *KDialog::mainWidget()
 {
+    Q_D(KDialog);
     if (!d->mMainWidget)
         setMainWidget( new QWidget(this) );
     return d->mMainWidget;
@@ -324,11 +304,13 @@ QWidget *KDialog::mainWidget()
 
 QSize KDialog::sizeHint() const
 {
+    Q_D(const KDialog);
     return d->mMinSize.expandedTo( minimumSizeHint() ) + d->mIncSize;
 }
 
 QSize KDialog::minimumSizeHint() const
 {
+    Q_D(const KDialog);
   const int m = marginHint();
   const int s = spacingHint();
 
@@ -403,6 +385,7 @@ QSize KDialog::minimumSizeHint() const
 //
 void KDialog::keyPressEvent( QKeyEvent *event )
 {
+    Q_D(KDialog);
   if ( event->modifiers() == 0 ) {
     if ( event->key() == Qt::Key_F1 ) {
       KPushButton *button = this->button( Help );
@@ -445,12 +428,12 @@ void KDialog::keyPressEvent( QKeyEvent *event )
 
 int KDialog::marginHint()
 {
-  return Private::mMarginSize;
+    return KDialogPrivate::mMarginSize;
 }
 
 int KDialog::spacingHint()
 {
-  return Private::mSpacingSize;
+    return KDialogPrivate::mSpacingSize;
 }
 
 QString KDialog::makeStandardCaption( const QString &userCaption,
@@ -505,7 +488,7 @@ void KDialog::setPlainCaption( const QString &caption )
 
 #ifdef Q_WS_X11
   NETWinInfo info( QX11Info::display(), winId(), QX11Info::appRootWindow(), 0 );
-  info.setName( caption.toUtf8().data() );
+  info.setName( caption.toUtf8().constData() );
 #endif
 }
 
@@ -544,11 +527,11 @@ void KDialog::resizeLayout( QLayout *layout, int margin, int spacing ) //static
 static QRect screenRect( QWidget *widget, int screen )
 {
   QDesktopWidget *desktop = QApplication::desktop();
-  KConfig gc( "kdeglobals", false, false );
-  gc.setGroup( "Windows" );
+  KConfig gc( "kdeglobals", KConfig::NoGlobals );
+  KConfigGroup cg(&gc, "Windows" );
   if ( desktop->isVirtualDesktop() &&
-       gc.readEntry( "XineramaEnabled", true ) &&
-       gc.readEntry( "XineramaPlacementEnabled", true ) ) {
+       cg.readEntry( "XineramaEnabled", true ) &&
+       cg.readEntry( "XineramaPlacementEnabled", true ) ) {
 
     if ( screen < 0 || screen >= desktop->numScreens() ) {
       if ( screen == -1 )
@@ -569,6 +552,13 @@ void KDialog::centerOnScreen( QWidget *widget, int screen )
   if ( !widget )
     return;
 
+#ifdef Q_WS_X11
+  if( !( widget->windowFlags() & Qt::X11BypassWindowManagerHint )
+      && NETRootInfo( QX11Info::display(), NET::Supported ).isSupported( NET::WM2FullPlacement )) {
+      return; // the WM can handle placement much better
+  }
+#endif
+
   QRect rect = screenRect( widget, screen );
 
   widget->move( rect.center().x() - widget->width() / 2,
@@ -629,6 +619,7 @@ bool KDialog::avoidArea( QWidget *widget, const QRect& area, int screen )
 
 void KDialog::showButtonSeparator( bool state )
 {
+    Q_D(KDialog);
   if ( state ) {
     if ( d->mActionSeparator )
       return;
@@ -650,18 +641,19 @@ void KDialog::showButtonSeparator( bool state )
 
 void KDialog::setInitialSize( const QSize &size )
 {
-  d->mMinSize = size;
+    d_func()->mMinSize = size;
   adjustSize();
 }
 
 void KDialog::incrementInitialSize( const QSize &size )
 {
-  d->mIncSize = size;
+    d_func()->mIncSize = size;
   adjustSize();
 }
 
 KPushButton *KDialog::button( ButtonCode id ) const
 {
+    Q_D(const KDialog);
   return d->mButtonList.contains( id ) ? d->mButtonList[ id ] : 0;
 }
 
@@ -715,15 +707,17 @@ void KDialog::setButtonGuiItem( ButtonCode id, const KGuiItem &item )
 void KDialog::setButtonMenu( ButtonCode id, QMenu *menu, ButtonPopupMode popupmode)
 {
   KPushButton *button = this->button( id );
-  if ( button )
+  if ( button ) {
     if (popupmode==InstantPopup)
       button->setMenu( menu );
     else
       button->setDelayedMenu(menu);
+  }
 }
 
 void KDialog::setButtonText( ButtonCode id, const QString &text )
 {
+    Q_D(KDialog);
   if ( !d->mSettingDetails && (id == Details) ) {
     d->mDetailsButtonText = text;
     setDetailsWidgetVisible( d->mDetailsVisible );
@@ -804,11 +798,12 @@ void KDialog::setButtonFocus( ButtonCode id )
 {
   KPushButton *button = this->button( id );
   if ( button )
-    d->setButtonFocus( button, false, true );
+        d_func()->setButtonFocus(button, false, true);
 }
 
 void KDialog::setDetailsWidget( QWidget *detailsWidget )
 {
+    Q_D(KDialog);
   delete d->mDetailsWidget;
   d->mDetailsWidget = detailsWidget;
 
@@ -824,11 +819,12 @@ void KDialog::setDetailsWidget( QWidget *detailsWidget )
 
 bool KDialog::isDetailsWidgetVisible() const
 {
-    return d->mDetailsVisible;
+    return d_func()->mDetailsVisible;
 }
 
 void KDialog::setDetailsWidgetVisible( bool visible )
 {
+    Q_D(KDialog);
   if ( d->mDetailsButtonText.isEmpty() )
     d->mDetailsButtonText = i18n( "&Details" );
 
@@ -875,6 +871,7 @@ void KDialog::delayedDestruct()
 
 void KDialog::slotButtonClicked( int button )
 {
+    Q_D(KDialog);
   emit buttonClicked( static_cast<KDialog::ButtonCode>(button) );
 
   switch( button ) {
@@ -929,6 +926,7 @@ void KDialog::slotButtonClicked( int button )
 
 void KDialog::enableLinkedHelp( bool state )
 {
+    Q_D(KDialog);
   if ( state ) {
     if ( d->mUrlHelp )
       return;
@@ -956,6 +954,7 @@ void KDialog::enableLinkedHelp( bool state )
 
 void KDialog::setHelp( const QString &anchor, const QString &appname )
 {
+    Q_D(KDialog);
   d->mAnchor  = anchor;
   d->mHelpApp = appname;
 }
@@ -963,6 +962,7 @@ void KDialog::setHelp( const QString &anchor, const QString &appname )
 
 void KDialog::setHelpLinkText( const QString &text )
 {
+    Q_D(KDialog);
   d->mHelpLinkText = text;
   if ( d->mUrlHelp )
     d->mUrlHelp->setText( helpLinkText() );
@@ -970,11 +970,13 @@ void KDialog::setHelpLinkText( const QString &text )
 
 QString KDialog::helpLinkText() const
 {
+    Q_D(const KDialog);
   return ( d->mHelpLinkText.isNull() ? i18n( "Get help..." ) : d->mHelpLinkText );
 }
 
 void KDialog::updateGeometry()
 {
+    Q_D(KDialog);
   if ( d->mTopLayout ) {
     d->mTopLayout->setMargin( marginHint() );
     d->mTopLayout->setSpacing( spacingHint() );
@@ -991,6 +993,7 @@ void KDialog::hideEvent( QHideEvent *event )
 
 void KDialog::closeEvent( QCloseEvent *event )
 {
+    Q_D(KDialog);
   KPushButton *button = this->button( d->mEscapeButton );
   if ( button && !isHidden() )
     button->animateClick();
@@ -998,7 +1001,7 @@ void KDialog::closeEvent( QCloseEvent *event )
     QDialog::closeEvent( event );
 }
 
-void KDialog::restoreDialogSize( KConfigBase *cfg )
+void KDialog::restoreDialogSize( const KConfigGroup& cfg )
 {
   int width, height;
   int scnum = QApplication::desktop()->screenNumber( parentWidget() );
@@ -1007,45 +1010,45 @@ void KDialog::restoreDialogSize( KConfigBase *cfg )
   width = sizeHint().width();
   height = sizeHint().height();
 
-  width = cfg->readEntry( QString::fromLatin1( "Width %1" ).arg( desk.width() ), width );
-  height = cfg->readEntry( QString::fromLatin1( "Height %1" ).arg( desk.height() ), height );
+  width = cfg.readEntry( QString::fromLatin1( "Width %1" ).arg( desk.width() ), width );
+  height = cfg.readEntry( QString::fromLatin1( "Height %1" ).arg( desk.height() ), height );
 
   resize( width, height );
 }
 
-void KDialog::saveDialogSize( KConfigBase* config, KConfigBase::WriteConfigFlags options ) const
+void KDialog::saveDialogSize( KConfigGroup& config, KConfigBase::WriteConfigFlags options ) const
 {
    int scnum = QApplication::desktop()->screenNumber( parentWidget() );
    QRect desk = QApplication::desktop()->screenGeometry( scnum );
 
    QSize sizeToSave = size();
 
-   config->writeEntry( QString::fromLatin1("Width %1").arg( desk.width() ), sizeToSave.width(), options );
-   config->writeEntry( QString::fromLatin1("Height %1").arg( desk.height() ), sizeToSave.height(), options );
+   config.writeEntry( QString::fromLatin1("Width %1").arg( desk.width() ), sizeToSave.width(), options );
+   config.writeEntry( QString::fromLatin1("Height %1").arg( desk.height() ), sizeToSave.height(), options );
 }
 
 
 class KDialogQueue::Private
 {
   public:
+    Private(KDialogQueue *q): q(q) {}
+  
+    void slotShowQueuedDialog(); 
+
+    KDialogQueue *q;
     QList< QPointer<QDialog> > queue;
     bool busy;
+    
 };
 
-static KStaticDeleter<KDialogQueue> ksdkdq;
-
-KDialogQueue *KDialogQueue::_self = 0;
-
 KDialogQueue* KDialogQueue::self()
 {
-  if ( !_self )
-    _self = ksdkdq.setObject( _self, new KDialogQueue );
-
+  K_GLOBAL_STATIC(KDialogQueue, _self)
   return _self;
 }
 
 KDialogQueue::KDialogQueue()
-  : d( new Private )
+  : d( new Private(this) )
 {
   d->busy = false;
 }
@@ -1053,7 +1056,6 @@ KDialogQueue::KDialogQueue()
 KDialogQueue::~KDialogQueue()
 {
   delete d;
-  _self = 0;
 }
 
 // static
@@ -1065,28 +1067,27 @@ void KDialogQueue::queueDialog( QDialog *dialog )
   QTimer::singleShot( 0, _this, SLOT( slotShowQueuedDialog() ) );
 }
 
-void KDialogQueue::slotShowQueuedDialog()
+void KDialogQueue::Private::slotShowQueuedDialog()
 {
-  if ( d->busy )
+  if ( busy )
     return;
 
   QDialog *dialog;
   do {
-    if ( d->queue.isEmpty() )
+    if ( queue.isEmpty() )
       return;
-    dialog = d->queue.first();
-    d->queue.pop_front();
+    dialog = queue.first();
+    queue.pop_front();
   } while( !dialog );
 
-  d->busy = true;
+  busy = true;
   dialog->exec();
-  d->busy = false;
+  busy = false;
   delete dialog;
 
-  if ( !d->queue.isEmpty() )
-    QTimer::singleShot( 20, this, SLOT( slotShowQueuedDialog() ) );
-  else
-    ksdkdq.destructObject(); // Suicide.
+  if ( !queue.isEmpty() )
+    QTimer::singleShot( 20, q, SLOT( slotShowQueuedDialog() ) );
 }
 
 #include "kdialog.moc"
+#include "kdialogqueue_p.moc"
