@@ -26,14 +26,15 @@
 
 class KPushButton;
 class QMenu;
+class KDialogPrivate;
 
-#include <QtGui/QDialog>
-
-#include <kdelibs_export.h>
+#include <kdeui_export.h>
 
 #include <kconfigbase.h>
 #include <kguiitem.h>
 
+#include <QtGui/QDialog>
+
 /**
  * @short A dialog base class with standard buttons and predefined layouts.
  *
@@ -47,7 +48,7 @@ class QMenu;
  * The class takes care of the geometry management. You only need to define
  * a minimum size for the widget you want to use as the main widget.
  *
- * By default, the dialog is modal
+ * By default, the dialog is non-modal.
  *
  * <b>Standard buttons (action buttons):</b>\n
  *
@@ -61,20 +62,17 @@ class QMenu;
  *
  * The default action of the Help button will open the help system if you have
  * provided a path to the help text.
- * The default action of Ok and Cancel will run QDialog::accept() and QDialog::reject()
- * that you can overide. The default action of the Close button will close the dialog.
+ * The default action of Ok and Cancel will run QDialog::accept() and QDialog::reject(),
+ * which you can override by reimplementing slotButtonClicked(). The default
+ * action of the Close button will close the dialog.
  *
  * Note that the KDialog will animate a button press
- * when the user press Escape. The button that is enabled is either Cancel,
+ * when the user presses Escape. The button that is enabled is either Cancel,
  * Close or the button that is defined by setEscapeButton().
  * Your custom dialog code should reimplement the keyPressEvent and
  * animate the cancel button so that the dialog behaves like regular
  * dialogs.
  *
- * NOTE: None of the regular slots (like slotOk() ) or
- * signals that are related to the standard action buttons will be used
- * when you don't use these buttons.
- *
  * <b>Layout:</b>\n
  *
  * The dialog consists of a help area on top (becomes visible if you define
@@ -89,9 +87,9 @@ class QMenu;
  * <b>Standard compliance:</b>\n
  *
  * The marginHint() and spacingHint() sizes shall be used
- * whenever you layout the interior of a dialog. One special note. If
+ * whenever you lay out the interior of a dialog. One special note. If
  * you make your own action buttons (OK, Cancel etc), the space
- * beteween the buttons shall be spacingHint(), whereas the space
+ * between the buttons shall be spacingHint(), whereas the space
  * above, below, to the right and to the left shall be marginHint().
  * If you add a separator line above the buttons, there shall be a
  * marginHint() between the buttons and the separator and a
@@ -108,7 +106,7 @@ class QMenu;
  *   dialog->setMainWidget( widget );
  *   connect( dialog, SIGNAL( applyClicked() ), widget, SLOT( save() ) );
  *   connect( dialog, SIGNAL( okClicked() ), widget, SLOT( save() ) );
- *   connect( widget, SIGNAL( changed( bool ) ), dialog, SLOT( enabledButtonApply( bool ) ) );
+ *   connect( widget, SIGNAL( changed( bool ) ), dialog, SLOT( enableButtonApply( bool ) ) );
  *
  *   dialog->enableButtonApply( false );
  *   dialog->show();
@@ -131,6 +129,7 @@ class KDEUI_EXPORT KDialog : public QDialog
 {
   Q_OBJECT
   Q_ENUMS(ButtonCode)
+    Q_DECLARE_PRIVATE(KDialog)
 
   public:
 
@@ -314,7 +313,7 @@ class KDEUI_EXPORT KDialog : public QDialog
     void setButtonMenu( ButtonCode id, QMenu *menu, ButtonPopupMode popupmode=InstantPopup);
 
     /**
-     * Sets the focus to the button of the passed @param id.
+     * Sets the focus to the button of the passed @p id.
      */
     void setButtonFocus( ButtonCode id );
 
@@ -325,7 +324,7 @@ class KDEUI_EXPORT KDialog : public QDialog
      * The initial size will be ignored if smaller than
      * the dialog's minimum size.
      *
-     * @param s Startup size.
+     * @param size Startup size.
      */
     void setInitialSize( const QSize &size );
 
@@ -335,7 +334,7 @@ class KDEUI_EXPORT KDialog : public QDialog
      *
      * This method should only be called right before show() or exec().
      *
-     * @param s  Size added to minimum size.
+     * @param size  Size added to minimum size.
      */
     void incrementInitialSize( const QSize &size );
 
@@ -345,9 +344,9 @@ class KDEUI_EXPORT KDialog : public QDialog
      *
      * @note the group must be set before calling
      *
-     * @param config The object to read from. That may be a KConfigGroup
+     * @param config The config group to read from.
      */
-    void restoreDialogSize( KConfigBase* config ) ;
+    void restoreDialogSize( const KConfigGroup& config ) ;
 
     /**
      * Saves the dialogs size dependant on the screen dimension either to the
@@ -355,10 +354,10 @@ class KDEUI_EXPORT KDialog : public QDialog
      *
      * @note the group must be set before calling
      *
-     * @param config The object to read from. That is recommended to use a KConfigGroup
-     * @param options passed to KConfigBase::writeEntry
+     * @param config The config group to read from.
+     * @param options passed to KConfigBase::writeEntry()
      */
-    void saveDialogSize( KConfigBase* config, KConfigBase::WriteConfigFlags options = 0 ) const;
+    void saveDialogSize( KConfigGroup& config, KConfigBase::WriteConfigFlags options = 0 ) const;
 
     /**
      * Returns the help link text.
@@ -367,6 +366,10 @@ class KDEUI_EXPORT KDialog : public QDialog
      * "Get help..." (internationalized) is returned.
      *
      * @return The help link text.
+     *
+     * @see enableLinkedHelp()
+     * @see setHelpLinkText()
+     * @see setHelp()
      */
     QString helpLinkText() const;
 
@@ -570,6 +573,10 @@ class KDEUI_EXPORT KDialog : public QDialog
      * Display or hide the help link area on the top of the dialog.
      *
      * @param state @p true will display the area.
+     *
+     * @see helpLinkText()
+     * @see setHelpLinkText()
+     * @see setHelp()
      */
     void enableLinkedHelp( bool state );
 
@@ -580,6 +587,10 @@ class KDEUI_EXPORT KDialog : public QDialog
      * the text "Get help..." (internationalized) is used instead.
      *
      * @param text The link text.
+     *
+     * @see helpLinkText()
+     * @see enableLinkedHelp()
+     * @see setHelp()
      */
     void setHelpLinkText( const QString &text );
 
@@ -775,50 +786,15 @@ class KDEUI_EXPORT KDialog : public QDialog
      */
     void updateGeometry();
 
-  private:
-    struct Private;
-    Private* const d;
+    protected:
+        KDialog(KDialogPrivate &dd, QWidget *parent, Qt::WFlags flags = 0);
+        KDialogPrivate *const d_ptr;
+
+    private:
+        Q_DISABLE_COPY(KDialog)
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KDialog::ButtonCodes)
 Q_DECLARE_OPERATORS_FOR_FLAGS(KDialog::CaptionFlags)
 
-
-/**
- * \brief Queue for showing modal dialogs one after the other.
- *
- * This is useful if you want to show a modal dialog but are not in the
- * position to start a new event loop at that point in your code.
- *
- * The disadvantage is that you will not be able to get any information from
- * the dialog, so it can currently only be used for simple dialogs.
- *
- * You probably want to use KMessageBox::queueMessageBox() instead
- * of this class directly.
- *
- * @author Waldo Bastian <bastian@kde.org>
- */
-class KDEUI_EXPORT KDialogQueue : public QObject
-{
-  Q_OBJECT
-
-  public:
-    static void queueDialog(QDialog *);
-
-    ~KDialogQueue();
-
-  protected:
-    KDialogQueue();
-    static KDialogQueue *self();
-
-  private Q_SLOTS:
-    void slotShowQueuedDialog();
-
-  protected:
-    class Private;
-    Private* const d;
-
-    static KDialogQueue *_self;
-};
-
 #endif // KDIALOG_H
