@@ -17,9 +17,11 @@
   Boston, MA 02110-1301, USA.
 */
 
-#include <qlayout.h>
-#include <qlabel.h>
-#include <qvalidator.h>
+#include "kinputdialog.h"
+
+#include <QtGui/QLayout>
+#include <QtGui/QLabel>
+#include <QtGui/QDoubleValidator>
 
 #include <kguiitem.h>
 #include <klineedit.h>
@@ -28,14 +30,17 @@
 #include <klistwidget.h>
 #include <kstandardguiitem.h>
 #include <ktextedit.h>
-
-#include "kinputdialog.h"
+#include <kcompletion.h>
 
 class KInputDialogPrivate
 {
   public:
-    KInputDialogPrivate();
+    KInputDialogPrivate(KInputDialog *q);
 
+    void slotEditTextChanged( const QString& );
+    void slotUpdateButtons( const QString& );
+
+    KInputDialog *q;
     QLabel *m_label;
     KLineEdit *m_lineEdit;
     KIntSpinBox *m_intSpinBox;
@@ -45,8 +50,8 @@ class KInputDialogPrivate
     KTextEdit *m_textEdit;
 };
 
-KInputDialogPrivate::KInputDialogPrivate()
-    : m_label( 0L ), m_lineEdit( 0L ), m_intSpinBox( 0L ),
+KInputDialogPrivate::KInputDialogPrivate(KInputDialog *q)
+    : q(q), m_label( 0L ), m_lineEdit( 0L ), m_intSpinBox( 0L ),
       m_doubleSpinBox( 0L ), m_comboBox( 0L )
 {
 }
@@ -55,7 +60,7 @@ KInputDialog::KInputDialog( const QString &caption, const QString &label,
     const QString &value, QWidget *parent,
     QValidator *validator, const QString &mask )
     : KDialog( parent ),
-    d( new KInputDialogPrivate() )
+    d( new KInputDialogPrivate(this) )
 {
   setCaption( caption );
   setButtons( Ok | Cancel );
@@ -65,6 +70,7 @@ KInputDialog::KInputDialog( const QString &caption, const QString &label,
 
   QWidget *frame = new QWidget( this );
   QVBoxLayout *layout = new QVBoxLayout( frame );
+    layout->setMargin(0);
   layout->setSpacing( spacingHint() );
 
   d->m_label = new QLabel( label, frame );
@@ -89,14 +95,14 @@ KInputDialog::KInputDialog( const QString &caption, const QString &label,
       SLOT( slotEditTextChanged( const QString & ) ) );
 
   setMainWidget(frame);
-  slotEditTextChanged( value );
+  d->slotEditTextChanged( value );
   setMinimumWidth( 350 );
 }
 
 KInputDialog::KInputDialog( const QString &caption, const QString &label,
     const QString &value, QWidget *parent )
     : KDialog( parent ),
-    d( new KInputDialogPrivate() )
+    d( new KInputDialogPrivate(this) )
 {
   setCaption( caption );
   setButtons( Ok | Cancel | User1 );
@@ -106,6 +112,7 @@ KInputDialog::KInputDialog( const QString &caption, const QString &label,
   setModal(true);
   QWidget *frame = new QWidget( this );
   QVBoxLayout *layout = new QVBoxLayout( frame );
+    layout->setMargin(0);
   layout->setSpacing( spacingHint() );
 
   d->m_label = new QLabel( label, frame );
@@ -128,7 +135,7 @@ KInputDialog::KInputDialog( const QString &caption, const QString &label,
     int value, int minValue, int maxValue, int step, int base,
     QWidget *parent )
     : KDialog( parent ),
-    d( new KInputDialogPrivate() )
+    d( new KInputDialogPrivate(this) )
 {
   setCaption( caption );
   setButtons( Ok | Cancel );
@@ -147,6 +154,7 @@ KInputDialog::KInputDialog( const QString &caption, const QString &label,
   layout->addWidget( d->m_intSpinBox );
 
   layout->addStretch();
+    layout->setMargin(0);
 
   d->m_intSpinBox->setFocus();
   setMainWidget(frame);
@@ -157,7 +165,7 @@ KInputDialog::KInputDialog( const QString &caption, const QString &label,
     double value, double minValue, double maxValue, double step, int decimals,
     QWidget *parent )
     : KDialog( parent ),
-    d( new KInputDialogPrivate() )
+    d( new KInputDialogPrivate(this) )
 {
   setCaption( caption );
   setButtons( Ok | Cancel );
@@ -176,6 +184,7 @@ KInputDialog::KInputDialog( const QString &caption, const QString &label,
   layout->addWidget( d->m_doubleSpinBox );
 
   layout->addStretch();
+    layout->setMargin(0);
 
   d->m_doubleSpinBox->setFocus();
   setMainWidget(frame);
@@ -185,7 +194,7 @@ KInputDialog::KInputDialog( const QString &caption, const QString &label,
 KInputDialog::KInputDialog( const QString &caption, const QString &label,
     const QStringList &list, int current, bool editable, QWidget *parent )
     : KDialog( parent ),
-    d( new KInputDialogPrivate() )
+    d( new KInputDialogPrivate(this) )
 {
   setCaption( caption );
   setButtons( Ok | Cancel );
@@ -212,22 +221,23 @@ KInputDialog::KInputDialog( const QString &caption, const QString &label,
 
     connect( d->m_comboBox, SIGNAL( editTextChanged( const QString & ) ),
       SLOT( slotUpdateButtons( const QString & ) ) );
-    slotUpdateButtons( d->m_comboBox->currentText() );
+    d->slotUpdateButtons( d->m_comboBox->currentText() );
     d->m_comboBox->setFocus();
   } else {
     d->m_listBox = new KListWidget( frame );
     d->m_listBox->addItems( list );
     d->m_listBox->setCurrentRow(current);
     layout->addWidget( d->m_listBox, 10 );
-    connect( d->m_listBox, SIGNAL( doubleClicked( QListWidgetItem * ) ),
-      SLOT( accept() ) );
-    connect( d->m_listBox, SIGNAL( returnPressed( QListWidgetItem * ) ),
+    connect( d->m_listBox, SIGNAL( executed( QListWidgetItem * ) ),
       SLOT( accept() ) );
+    /*connect( d->m_listBox, SIGNAL( returnPressed( QListWidgetItem * ) ),
+      SLOT( accept() ) );*/
 
     d->m_listBox->setFocus();
   }
 
   layout->addStretch();
+    layout->setMargin(0);
   setMainWidget(frame);
   setMinimumWidth( 320 );
 }
@@ -236,7 +246,7 @@ KInputDialog::KInputDialog( const QString &caption, const QString &label,
     const QStringList &list, const QStringList &select, bool multiple,
     QWidget *parent )
     : KDialog( parent ),
-    d( new KInputDialogPrivate() )
+    d( new KInputDialogPrivate(this) )
 {
   setCaption( caption );
   setButtons( Ok | Cancel );
@@ -267,21 +277,25 @@ KInputDialog::KInputDialog( const QString &caption, const QString &label,
   }
   else
   {
-    connect( d->m_listBox, SIGNAL( doubleClicked( QListWidgetItem * ) ),
-      SLOT( accept() ) );
-    connect( d->m_listBox, SIGNAL( returnPressed( QListWidgetItem * ) ),
+    connect( d->m_listBox, SIGNAL( executed( QListWidgetItem * ) ),
       SLOT( accept() ) );
+    /*connect( d->m_listBox, SIGNAL( returnPressed( QListWidgetItem * ) ),
+      SLOT( accept() ) );*/
 
-    QString text = select.first();
+    if(!select.isEmpty())
+    {
+    	QString text = select.first();
     
-    QList<QListWidgetItem*> matches = d->m_listBox->findItems(text,Qt::MatchCaseSensitive|Qt::MatchExactly);
-    if ( !matches.isEmpty() )
-      d->m_listBox->setCurrentItem( matches.first() );
+    	QList<QListWidgetItem*> matches = d->m_listBox->findItems(text,Qt::MatchCaseSensitive|Qt::MatchExactly);
+    	if ( !matches.isEmpty() )
+      		d->m_listBox->setCurrentItem( matches.first() );
+    }
   }
 
   d->m_listBox->setFocus();
 
   layout->addStretch();
+    layout->setMargin(0);
   setMainWidget(frame);
   setMinimumWidth( 320 );
 }
@@ -295,13 +309,20 @@ KInputDialog::~KInputDialog()
 QString KInputDialog::getText( const QString &caption,
     const QString &label, const QString &value, bool *ok, QWidget *parent,
     QValidator *validator, const QString &mask,
-    const QString &whatsThis )
+    const QString &whatsThis,const QStringList &completionList )
 {
   KInputDialog dlg( caption, label, value, parent, validator, mask );
 
   if( !whatsThis.isEmpty() )
     dlg.lineEdit()->setWhatsThis(whatsThis );
 
+  if (!completionList.isEmpty())
+  {
+    KCompletion *comp=dlg.lineEdit()->completionObject();
+    for(QStringList::const_iterator it=completionList.constBegin();it!=completionList.constEnd();++it)
+      comp->addItem(*it);
+  }
+
   bool _ok = ( dlg.exec() == Accepted );
 
   if ( ok )
@@ -398,7 +419,7 @@ QString KInputDialog::getItem( const QString &caption, const QString &label,
     editable, parent );
   if ( !editable)
   {
-      connect( dlg.listBox(),  SIGNAL(doubleClicked ( QListWidgetItem *)), &dlg, SLOT( accept()));
+      connect( dlg.listBox(),  SIGNAL(executed( QListWidgetItem *)), &dlg, SLOT( accept()));
   }
   bool _ok = ( dlg.exec() == Accepted );
 
@@ -444,24 +465,24 @@ QStringList KInputDialog::getItemList( const QString &caption,
   return result;
 }
 
-void KInputDialog::slotEditTextChanged( const QString &text )
+void KInputDialogPrivate::slotEditTextChanged( const QString &text )
 {
   bool on;
-  if ( lineEdit()->validator() ) {
-    QString str = lineEdit()->text();
-    int index = lineEdit()->cursorPosition();
-    on = ( lineEdit()->validator()->validate( str, index )
+  if ( m_lineEdit->validator() ) {
+    QString str = m_lineEdit->text();
+    int index = m_lineEdit->cursorPosition();
+    on = ( m_lineEdit->validator()->validate( str, index )
       == QValidator::Acceptable );
   } else {
     on = !text.trimmed().isEmpty();
   }
 
-  enableButton( Ok, on );
+  q->enableButton( KDialog::Ok, on );
 }
 
-void KInputDialog::slotUpdateButtons( const QString &text )
+void KInputDialogPrivate::slotUpdateButtons( const QString &text )
 {
-  enableButton( Ok, !text.isEmpty() );
+  q->enableButton( KDialog::Ok, !text.isEmpty() );
 }
 
 KLineEdit *KInputDialog::lineEdit() const
