@@ -80,11 +80,6 @@ class KDEUI_EXPORT KInputDialog : public KDialog
     KListWidget *listBox() const;
     KTextEdit *textEdit() const;
 
-  private Q_SLOTS:
-
-    void slotEditTextChanged( const QString& );
-    void slotUpdateButtons( const QString& );
-
   public:
 
     /**
@@ -111,13 +106,15 @@ class KDEUI_EXPORT KInputDialog : public KDialog
      * @param mask      Mask associated with the line edit. See the
      *                  documentation for @ref QLineEdit about masks
      * @param whatsThis a QWhatsThis text for the input widget.
+     * @param completionList a list of items which should be used for input completion
      * @return String user entered if Ok was pressed, else a null string
      */
     static QString getText( const QString &caption, const QString &label,
         const QString &value=QString(), bool *ok=0, QWidget *parent=0,
         QValidator *validator=0,
         const QString &mask=QString(),
-	const QString& whatsThis=QString()  );
+	const QString& whatsThis=QString(),
+        const QStringList &completionList=QStringList()  );
 
     /**
      * Static convenience function to get a multiline string from the user.
@@ -258,9 +255,14 @@ class KDEUI_EXPORT KInputDialog : public KDialog
         bool *ok=0, QWidget *parent=0 );
 
   private:
+    Q_PRIVATE_SLOT(d, void slotEditTextChanged( const QString& ))
+    Q_PRIVATE_SLOT(d, void slotUpdateButtons( const QString& ))
 
+  private:
     KInputDialogPrivate* const d;
     friend class KInputDialogPrivate;
+    
+    Q_DISABLE_COPY(KInputDialog)
 };
 
 #endif // KINPUTDIALOG_H
