@@ -32,18 +32,27 @@
 #include <khbox.h>
 #include <kdebug.h>
 #include <kconfiggroup.h>
+#include <ktitlewidget.h>
 
 #include "ui_kpassworddialog.h"
 
 /** @internal */
-struct KPasswordDialog::KPasswordDialogPrivate
+class KPasswordDialog::KPasswordDialogPrivate
 {
-    KPasswordDialogPrivate()
-        : userEditCombo(0),
+public:
+    KPasswordDialogPrivate(KPasswordDialog *q)
+        : q(q),
+          userEditCombo(0),
           pixmapLabel(0),
           commentRow(0)
     {}
 
+    void actuallyAccept();
+    void activated( const QString& userName );
+
+    void init( const KPasswordDialogFlags& flags );
+
+    KPasswordDialog *q;
     Ui_KPasswordDialog ui;
     QMap<QString,QString> knownLogins;
     KComboBox* userEditCombo;
@@ -51,69 +60,50 @@ struct KPasswordDialog::KPasswordDialogPrivate
     unsigned int commentRow;
 };
 
-static QString qrichtextify( const QString& text )
-{
-    if ( text.isEmpty() || text[0] == '<' ) {
-        return text;
-    }
-
-    QStringList lines = text.split('\n', QString::SkipEmptyParts);
-    for(QStringList::Iterator it = lines.begin(); it != lines.end(); ++it)
-    {
-        *it = Qt::convertFromPlainText( *it, Qt::WhiteSpaceNormal );
-    }
-
-    return lines.join(QString());
-}
-
 KPasswordDialog::KPasswordDialog( QWidget* parent ,
                                   const KPasswordDialogFlags& flags,
                                   const KDialog::ButtonCodes otherButtons )
-   : KDialog( parent ),d(new KPasswordDialogPrivate)
+   : KDialog( parent ), d(new KPasswordDialogPrivate(this))
 {
     setCaption( i18n("Password") );
     setButtons( Ok | Cancel | otherButtons );
     showButtonSeparator( true );
     setDefaultButton( Ok );
-    init ( flags );
+    d->init ( flags );
 }
 
-
-
 KPasswordDialog::~KPasswordDialog()
 {
     delete d;
 }
 
-void KPasswordDialog::init( const KPasswordDialogFlags& flags )
+void KPasswordDialog::KPasswordDialogPrivate::init( const KPasswordDialogFlags& flags )
 {
-    d->ui.setupUi( mainWidget() );
-
-    //d->ui.comment->setVisible( false );
-    d->ui.errorMessage->setVisible( false );
+    ui.setupUi( q->mainWidget() );
+    ui.errorMessage->setHidden(true);
 
     // Row 4: Username field
-    if ( flags & ShowUsernameLine ) {
-        d->ui.userEdit->setFocus();
-        connect( d->ui.userEdit, SIGNAL(returnPressed()), d->ui.passEdit, SLOT(setFocus()) );
+    if ( flags & KPasswordDialog::ShowUsernameLine ) {
+        ui.userEdit->setFocus();
+        QObject::connect( ui.userEdit, SIGNAL(returnPressed()), ui.passEdit, SLOT(setFocus()) );
     } else {
-        d->ui.userNameLabel->hide();
-        d->ui.userEdit->hide();
-        d->ui.passEdit->setFocus();
+        ui.userNameLabel->hide();
+        ui.userEdit->hide();
+        ui.passEdit->setFocus();
     }
 
-    if ( flags ^ ShowKeepPassword )
+    if ( !( flags & KPasswordDialog::ShowKeepPassword ) )
     {
-        d->ui.keepCheckBox->hide();
+        ui.keepCheckBox->hide();
     }
 
     // Configure necessary key-bindings and connect necessary slots and signals
-    connect( d->ui.passEdit, SIGNAL(returnPressed()), SLOT(accept()) );
+    QObject::connect( ui.passEdit, SIGNAL(returnPressed()), q, SLOT(accept()) );
 
-    QRect desktop = KGlobalSettings::desktopGeometry(topLevelWidget());
-    setFixedWidth(qMin(1000, qMax(400, desktop.width() / 4)));
-    //setMinimumHeight( minimumSizeHint().height() );
-    mainWidget()->setMinimumHeight( mainWidget()->sizeHint().height() );
+    QRect desktop = KGlobalSettings::desktopGeometry(q->topLevelWidget());
+    q->setFixedWidth(qMin(1000, qMax(400, desktop.width() / 4)));
+    //q->setMinimumHeight( q->minimumSizeHint().height() );
+    q->mainWidget()->setMinimumHeight( q->mainWidget()->sizeHint().height() );
 }
 
 void KPasswordDialog::setPixmap(const QPixmap &pixmap)
@@ -141,7 +131,7 @@ QPixmap KPasswordDialog::pixmap() const
 void KPasswordDialog::setUsername(const QString& user)
 {
     d->ui.userEdit->setText(user);
-    activated(user);
+    d->activated(user);
     if ( d->ui.userEdit->isVisibleTo( this ) )
     {
         d->ui.passEdit->setFocus();
@@ -173,7 +163,8 @@ void KPasswordDialog::addCommentLine( const QString& label,
                                       const QString& comment )
 {
     QLabel* l = new QLabel(label, mainWidget());
-    QLabel* c = new QLabel(qrichtextify(comment), mainWidget());
+    QLabel* c = new QLabel(comment, mainWidget());
+    c->setWordWrap(true);
 
     d->ui.gridLayout->addWidget(l, d->commentRow, 0);
     d->ui.gridLayout->addWidget(c, d->commentRow, 1);
@@ -189,8 +180,7 @@ void KPasswordDialog::addCommentLine( const QString& label,
 
 void KPasswordDialog::showErrorMessage( const QString& message, const ErrorType type )
 {
-    d->ui.errorMessage->setVisible( true );
-    d->ui.errorMessage->setText( message );
+    d->ui.errorMessage->setText( message, KTitleWidget::ErrorMessage );
     mainWidget()->setMinimumHeight( mainWidget()->sizeHint().height() );
 
     QFont bold = font();
@@ -223,7 +213,8 @@ void KPasswordDialog::showErrorMessage( const QString& message, const ErrorType
 
 void KPasswordDialog::setPrompt(const QString& prompt)
 {
-    d->ui.prompt->setText( qrichtextify( prompt ) );
+    d->ui.prompt->setText( prompt );
+    d->ui.prompt->setWordWrap( true );
     mainWidget()->setMinimumHeight( mainWidget()->sizeHint().height() );
 }
 
@@ -280,17 +271,17 @@ void KPasswordDialog::setKnownLogins( const QMap<QString, QString>& knownLogins
              this, SLOT( activated( const QString& ) ) );
 }
 
-void KPasswordDialog::activated( const QString& userName )
+void KPasswordDialog::KPasswordDialogPrivate::activated( const QString& userName )
 {
-    QMap<QString, QString>::ConstIterator it = d->knownLogins.find( userName );
-    if ( it != d->knownLogins.end() ) {
-        setPassword( it.value() );
+    QMap<QString, QString>::ConstIterator it = knownLogins.find( userName );
+    if ( it != knownLogins.end() ) {
+        q->setPassword( it.value() );
     }
 }
 
 void KPasswordDialog::accept()
 {
-    d->ui.errorMessage->setVisible( false );
+    d->ui.errorMessage->setText( QString() );
 
     // reset the font in case we had an error previously
     d->ui.passwordLabel->setFont( font() );
@@ -301,21 +292,21 @@ void KPasswordDialog::accept()
     QTimer::singleShot( 0, this, SLOT(actuallyAccept()) );
 }
 
-void KPasswordDialog::actuallyAccept()
+void KPasswordDialog::KPasswordDialogPrivate::actuallyAccept()
 {
-    if ( !checkPassword() )
+    if ( !q->checkPassword() )
     {
         return;
     }
 
-    bool keep = d->ui.keepCheckBox->isVisibleTo( this ) && d->ui.keepCheckBox->isChecked();
-    emit gotPassword( password() , keep);
+    bool keep = ui.keepCheckBox->isVisibleTo( q ) && ui.keepCheckBox->isChecked();
+    emit q->gotPassword( q->password(), keep);
 
-    if ( d->ui.userEdit->isVisibleTo( this ) ) {
-        emit gotUsernameAndPassword( username(), password() , keep);
+    if ( ui.userEdit->isVisibleTo( q ) ) {
+        emit q->gotUsernameAndPassword( q->username(), q->password() , keep);
     }
 
-    KDialog::accept();
+    q->KDialog::accept();
 }
 
 bool KPasswordDialog::checkPassword()
