@@ -1,6 +1,6 @@
 /* This file is part of the KDE libraries
-   Copyright (C) 1996 Martynas Kunigelis
-   Copyright (C) 2006 Urs Wolfer <uwolfer at kde.org>
+   Copyright (C) 1996 Martynas Kunigelis // krazy:exclude=copyright (email unknown)
+   Copyright (C) 2006-2007 Urs Wolfer <uwolfer at kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -16,9 +16,6 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
-/**
- * KProgressDialog -- a dialog with a progress indicator
- */
 
 #include "kprogressdialog.h"
 
@@ -30,10 +27,12 @@
 #include <kguiitem.h>
 #include <kpushbutton.h>
 
-struct KProgressDialog::KProgressDialogPrivate
+class KProgressDialog::KProgressDialogPrivate
 {
-    KProgressDialogPrivate()
-        : cancelButtonShown(true),
+public:
+    KProgressDialogPrivate(KProgressDialog *q)
+        : q(q),
+          cancelButtonShown(true),
           mAutoClose(true),
           mAutoReset(false),
           mCancelled(false),
@@ -42,6 +41,11 @@ struct KProgressDialog::KProgressDialogPrivate
           mMinDuration(2000)
     {
     }
+
+    void slotAutoShow();
+    void slotAutoActions(int percentage);
+
+    KProgressDialog *q;
     bool          cancelButtonShown;
     bool          mAutoClose;
     bool          mAutoReset;
@@ -56,13 +60,12 @@ struct KProgressDialog::KProgressDialogPrivate
 };
 
 KProgressDialog::KProgressDialog(QWidget* parent, const QString& caption,
-                                 const QString& text, bool modal)
-  : KDialog(parent),
-    d(new KProgressDialogPrivate)
+                                 const QString& text, Qt::WFlags flags)
+  : KDialog(parent, flags),
+    d(new KProgressDialogPrivate(this))
 {
-    setCaption( caption );
-    setButtons( KDialog::Cancel );
-    setModal(modal);
+    setCaption(caption);
+    setButtons(KDialog::Cancel);
 
     d->mShowTimer = new QTimer(this);
 
@@ -92,20 +95,20 @@ KProgressDialog::~KProgressDialog()
     delete d;
 }
 
-void KProgressDialog::slotAutoShow()
+void KProgressDialog::KProgressDialogPrivate::slotAutoShow()
 {
-    if (d->mShown || d->mCancelled)
+    if (mShown || mCancelled)
     {
         return;
     }
 
-    show();
+    q->show();
 }
 
-void KProgressDialog::show()
+void KProgressDialog::showEvent(QShowEvent *event)
 {
-    KDialog::show();
     d->mShown = true;
+    KDialog::showEvent(event);
 }
 
 void KProgressDialog::reject()
@@ -165,7 +168,7 @@ const QProgressBar* KProgressDialog::progressBar() const
     return d->mProgressBar;
 }
 
-void KProgressDialog::setLabel(const QString& text)
+void KProgressDialog::setLabelText(const QString& text)
 {
     d->mLabel->setText(text);
 }
@@ -211,40 +214,40 @@ QString KProgressDialog::buttonText() const
     return d->mCancelText;
 }
 
-void KProgressDialog::slotAutoActions(int percentage)
+void KProgressDialog::KProgressDialogPrivate::slotAutoActions(int percentage)
 {
-    if (percentage < d->mProgressBar->maximum())
+    if (percentage < mProgressBar->maximum())
     {
-        if (!d->cancelButtonShown)
+        if (!cancelButtonShown)
         {
-            setButtonGuiItem(Cancel, KGuiItem(d->mCancelText));
-            d->cancelButtonShown = true;
+            q->setButtonGuiItem(KDialog::Cancel, KGuiItem(mCancelText));
+            cancelButtonShown = true;
         }
         return;
     }
 
-    d->mShowTimer->stop();
+    mShowTimer->stop();
 
-    if (d->mAutoReset)
+    if (mAutoReset)
     {
-        d->mProgressBar->setValue(0);
+        mProgressBar->setValue(0);
     }
     else
     {
-        setAllowCancel(true);
-        setButtonGuiItem(Cancel, KStandardGuiItem::close());
-        d->cancelButtonShown = false;
+        q->setAllowCancel(true);
+        q->setButtonGuiItem(Cancel, KStandardGuiItem::close());
+        cancelButtonShown = false;
     }
 
-    if (d->mAutoClose)
+    if (mAutoClose)
     {
-        if (d->mShown)
+        if (mShown)
         {
-            hide();
+            q->hide();
         }
         else
         {
-            emit finished();
+            emit q->finished();
         }
     }
 }
