@@ -19,16 +19,19 @@
 */
 
 #include "kfinddialog.h"
-#include <qcheckbox.h>
-#include <qcursor.h>
-#include <qgroupbox.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qlineedit.h>
-#include <qmenu.h>
-#include <qpushbutton.h>
-#include <qregexp.h>
+#include "kfinddialog_p.h"
+
+#include <QtGui/QCheckBox>
+#include <QtGui/QCursor>
+#include <QtGui/QGroupBox>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtGui/QLineEdit>
+#include <QtGui/QMenu>
+#include <QtGui/QPushButton>
+#include <QtCore/QRegExp>
 #include <kcombobox.h>
+#include <khistorycombobox.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
@@ -37,28 +40,11 @@
 #include <kregexpeditorinterface.h>
 #include <kservicetypetrader.h>
 
-class KFindDialog::KFindDialogPrivate
-{
-public:
-    KFindDialogPrivate() : m_regexpDialog(0),
-        m_regexpDialogQueryDone(false),
-        m_enabled(KFind::WholeWordsOnly | KFind::FromCursor |  KFind::SelectedText | KFind::CaseSensitive | KFind::FindBackwards | KFind::RegularExpression), m_initialShowDone(false) {}
-    QDialog* m_regexpDialog;
-    bool m_regexpDialogQueryDone;
-    long m_enabled; // uses Options to define which search options are enabled
-    bool m_initialShowDone;
-    QStringList findStrings;
-    QString pattern;
-};
-
-KFindDialog::KFindDialog(QWidget *parent, const char *name, long options, const QStringList &findStrings, bool hasSelection) :
+KFindDialog::KFindDialog(QWidget *parent, long options, const QStringList &findStrings, bool hasSelection) :
     KDialog(parent),
-    m_findExtension (0),
-    m_replaceExtension (0),
-	d(new KFindDialogPrivate)
+    d(new KFindDialogPrivate)
 {
-    setObjectName( name );
-    setModal( true );
+
     setCaption( i18n("Find Text") );
     setButtons( Ok | Cancel );
     setDefaultButton( Ok );
@@ -68,57 +54,25 @@ KFindDialog::KFindDialog(QWidget *parent, const char *name, long options, const
     setButtonGuiItem( KDialog::Cancel, KStandardGuiItem::close() );
 }
 
-KFindDialog::KFindDialog(bool modal, QWidget *parent, const char *name, long options, const QStringList &findStrings, bool hasSelection) :
-    KDialog(parent),
-    m_findExtension (0),
-    m_replaceExtension (0),
-	d(new KFindDialogPrivate)
-{
-    setObjectName( name );
-    setModal( modal );
-    setCaption( i18n("Find Text") );
-    setButtons( Ok | Cancel );
-    setDefaultButton( Ok );
-
-    init(false, findStrings, hasSelection);
-    setOptions(options);
-    setButtonGuiItem( KDialog::Cancel, KStandardGuiItem::close() );
-}
-
-KFindDialog::KFindDialog(QWidget *parent, const char *name, bool /*forReplace*/) :
-    KDialog(parent),
-    m_findExtension (0),
-    m_replaceExtension (0),
-	d(new KFindDialogPrivate)
-{
-    setObjectName( name );
-    setModal( true );
-    setCaption( i18n("Replace Text") );
-    setButtons( Ok | Cancel );
-    setDefaultButton( Ok );
-
-    setButtonGuiItem( KDialog::Cancel,  KStandardGuiItem::close() );
-}
-
 KFindDialog::~KFindDialog()
 {
     delete d;
 }
 
-QWidget *KFindDialog::findExtension()
+QWidget *KFindDialog::findExtension() const
 {
-    if (!m_findExtension)
+    if (!d->findExtension)
     {
-      m_findExtension = new QWidget(m_findGrp);
-      m_findLayout->addWidget(m_findExtension, 3, 0, 1, 2);
+      d->findExtension = new QWidget(d->findGrp);
+      d->findLayout->addWidget(d->findExtension, 3, 0, 1, 2);
     }
 
-    return m_findExtension;
+    return d->findExtension;
 }
 
 QStringList KFindDialog::findHistory() const
 {
-    return m_find->historyItems();
+    return d->find->historyItems();
 }
 
 void KFindDialog::init(bool forReplace, const QStringList &findStrings, bool hasSelection)
@@ -134,121 +88,121 @@ void KFindDialog::init(bool forReplace, const QStringList &findStrings, bool has
     topLayout->setSpacing( KDialog::spacingHint() );
     topLayout->setMargin( 0 );
 
-    m_findGrp = new QGroupBox(i18n("Find"), page);
-   // m_findGrp->layout()->setMargin( KDialog::marginHint() );
-    m_findLayout = new QGridLayout(m_findGrp);
-    m_findLayout->setSpacing( KDialog::spacingHint() );
-   // m_findLayout->setMargin( KDialog::marginHint() );
+    d->findGrp = new QGroupBox(i18n("Find"), page);
+   // d->findGrp->layout()->setMargin( KDialog::marginHint() );
+    d->findLayout = new QGridLayout(d->findGrp);
+    d->findLayout->setSpacing( KDialog::spacingHint() );
+   // d->findLayout->setMargin( KDialog::marginHint() );
 
-    m_findLabel = new QLabel(i18n("&Text to find:"), m_findGrp);
-    m_find = new KHistoryCombo(true, m_findGrp);
-    m_find->setMaxCount(10);
-    m_find->setDuplicatesEnabled(false);
-    m_regExp = new QCheckBox(i18n("Regular e&xpression"), m_findGrp);
-    m_regExpItem = new QPushButton(i18n("&Edit..."), m_findGrp);
-    m_regExpItem->setEnabled(false);
+    QLabel *findLabel = new QLabel(i18n("&Text to find:"), d->findGrp);
+    d->find = new KHistoryComboBox(d->findGrp);
+    d->find->setMaxCount(10);
+    d->find->setDuplicatesEnabled(false);
+    d->regExp = new QCheckBox(i18n("Regular e&xpression"), d->findGrp);
+    d->regExpItem = new QPushButton(i18n("&Edit..."), d->findGrp);
+    d->regExpItem->setEnabled(false);
 
-    m_findLayout->addWidget(m_findLabel, 0, 0);
-    m_findLayout->addWidget(m_find, 1, 0, 1, 2);
-    m_findLayout->addWidget(m_regExp, 2, 0);
-    m_findLayout->addWidget(m_regExpItem, 2, 1);
-    topLayout->addWidget(m_findGrp);
+    d->findLayout->addWidget(findLabel, 0, 0);
+    d->findLayout->addWidget(d->find, 1, 0, 1, 2);
+    d->findLayout->addWidget(d->regExp, 2, 0);
+    d->findLayout->addWidget(d->regExpItem, 2, 1);
+    topLayout->addWidget(d->findGrp);
 
-    m_replaceGrp = new QGroupBox( i18n("Replace With"), page);
-  //  m_replaceGrp->layout()->setMargin( KDialog::marginHint() );
-    m_replaceLayout = new QGridLayout(m_replaceGrp);
-    m_replaceLayout->setSpacing( KDialog::spacingHint() );
-//    m_replaceLayout->setMargin( KDialog::marginHint() );
+    d->replaceGrp = new QGroupBox( i18n("Replace With"), page);
+  //  d->replaceGrp->layout()->setMargin( KDialog::marginHint() );
+    d->replaceLayout = new QGridLayout(d->replaceGrp);
+    d->replaceLayout->setSpacing( KDialog::spacingHint() );
+//    d->replaceLayout->setMargin( KDialog::marginHint() );
 
-    m_replaceLabel = new QLabel(i18n("Replace&ment text:"), m_replaceGrp);
-    m_replace = new KHistoryCombo(true, m_replaceGrp);
-    m_replace->setMaxCount(10);
-    m_replace->setDuplicatesEnabled(false);
-    m_backRef = new QCheckBox(i18n("Use p&laceholders"), m_replaceGrp);
-    m_backRefItem = new QPushButton(i18n("Insert Place&holder"), m_replaceGrp);
-    m_backRefItem->setEnabled(false);
+    QLabel *replaceLabel = new QLabel(i18n("Replace&ment text:"), d->replaceGrp);
+    d->replace = new KHistoryComboBox(d->replaceGrp);
+    d->replace->setMaxCount(10);
+    d->replace->setDuplicatesEnabled(false);
+    d->backRef = new QCheckBox(i18n("Use p&laceholders"), d->replaceGrp);
+    d->backRefItem = new QPushButton(i18n("Insert Place&holder"), d->replaceGrp);
+    d->backRefItem->setEnabled(false);
 
-    m_replaceLayout->addWidget(m_replaceLabel, 0, 0);
-    m_replaceLayout->addWidget(m_replace, 1, 0, 1, 2);
-    m_replaceLayout->addWidget(m_backRef, 2, 0);
-    m_replaceLayout->addWidget(m_backRefItem, 2, 1);
-    topLayout->addWidget(m_replaceGrp);
+    d->replaceLayout->addWidget(replaceLabel, 0, 0);
+    d->replaceLayout->addWidget(d->replace, 1, 0, 1, 2);
+    d->replaceLayout->addWidget(d->backRef, 2, 0);
+    d->replaceLayout->addWidget(d->backRefItem, 2, 1);
+    topLayout->addWidget(d->replaceGrp);
 
-    m_optionGrp = new QGroupBox(i18n("Options"), page);
+    QGroupBox *optionGrp = new QGroupBox(i18n("Options"), page);
   //  m_optionGrp->layout()->setMargin(KDialog::marginHint());
-    optionsLayout = new QGridLayout(m_optionGrp);
+    optionsLayout = new QGridLayout(optionGrp);
     optionsLayout->setSpacing( KDialog::spacingHint() );
    // optionsLayout->setMargin( KDialog::marginHint() );
 
-    m_caseSensitive = new QCheckBox(i18n("C&ase sensitive"), m_optionGrp);
-    m_wholeWordsOnly = new QCheckBox(i18n("&Whole words only"), m_optionGrp);
-    m_fromCursor = new QCheckBox(i18n("From c&ursor"), m_optionGrp);
-    m_findBackwards = new QCheckBox(i18n("Find &backwards"), m_optionGrp);
-    m_selectedText = new QCheckBox(i18n("&Selected text"), m_optionGrp);
+    d->caseSensitive = new QCheckBox(i18n("C&ase sensitive"), optionGrp);
+    d->wholeWordsOnly = new QCheckBox(i18n("&Whole words only"), optionGrp);
+    d->fromCursor = new QCheckBox(i18n("From c&ursor"), optionGrp);
+    d->findBackwards = new QCheckBox(i18n("Find &backwards"), optionGrp);
+    d->selectedText = new QCheckBox(i18n("&Selected text"), optionGrp);
     setHasSelection( hasSelection );
     // If we have a selection, we make 'find in selection' default
     // and if we don't, then the option has to be unchecked, obviously.
-    m_selectedText->setChecked( hasSelection );
+    d->selectedText->setChecked( hasSelection );
     slotSelectedTextToggled( hasSelection );
 
-    m_promptOnReplace = new QCheckBox(i18n("&Prompt on replace"), m_optionGrp);
-    m_promptOnReplace->setChecked( true );
+    d->promptOnReplace = new QCheckBox(i18n("&Prompt on replace"), optionGrp);
+    d->promptOnReplace->setChecked( true );
 
-    optionsLayout->addWidget(m_caseSensitive, 0, 0);
-    optionsLayout->addWidget(m_wholeWordsOnly, 1, 0);
-    optionsLayout->addWidget(m_fromCursor, 2, 0);
-    optionsLayout->addWidget(m_findBackwards, 0, 1);
-    optionsLayout->addWidget(m_selectedText, 1, 1);
-    optionsLayout->addWidget(m_promptOnReplace, 2, 1);
-    topLayout->addWidget(m_optionGrp);
+    optionsLayout->addWidget(d->caseSensitive, 0, 0);
+    optionsLayout->addWidget(d->wholeWordsOnly, 1, 0);
+    optionsLayout->addWidget(d->fromCursor, 2, 0);
+    optionsLayout->addWidget(d->findBackwards, 0, 1);
+    optionsLayout->addWidget(d->selectedText, 1, 1);
+    optionsLayout->addWidget(d->promptOnReplace, 2, 1);
+    topLayout->addWidget(optionGrp);
 
     // We delay creation of these until needed.
-    m_patterns = 0;
-    m_placeholders = 0;
+    d->patterns = 0;
+    d->placeholders = 0;
 
     // signals and slots connections
-    connect(m_selectedText, SIGNAL(toggled(bool)), this, SLOT(slotSelectedTextToggled(bool)));
-    connect(m_regExp, SIGNAL(toggled(bool)), m_regExpItem, SLOT(setEnabled(bool)));
-    connect(m_backRef, SIGNAL(toggled(bool)), m_backRefItem, SLOT(setEnabled(bool)));
-    connect(m_regExpItem, SIGNAL(clicked()), this, SLOT(showPatterns()));
-    connect(m_backRefItem, SIGNAL(clicked()), this, SLOT(showPlaceholders()));
+    connect(d->selectedText, SIGNAL(toggled(bool)), this, SLOT(slotSelectedTextToggled(bool)));
+    connect(d->regExp, SIGNAL(toggled(bool)), d->regExpItem, SLOT(setEnabled(bool)));
+    connect(d->backRef, SIGNAL(toggled(bool)), d->backRefItem, SLOT(setEnabled(bool)));
+    connect(d->regExpItem, SIGNAL(clicked()), this, SLOT(showPatterns()));
+    connect(d->backRefItem, SIGNAL(clicked()), this, SLOT(showPlaceholders()));
 
-    connect(m_find, SIGNAL(editTextChanged(const QString &)),this, SLOT(textSearchChanged(const QString &)));
+    connect(d->find, SIGNAL(editTextChanged(const QString &)),this, SLOT(textSearchChanged(const QString &)));
 
-    connect(m_regExp, SIGNAL(toggled(bool)), this, SIGNAL(optionsChanged()));
-    connect(m_backRef, SIGNAL(toggled(bool)), this, SIGNAL(optionsChanged()));
-    connect(m_caseSensitive, SIGNAL(toggled(bool)), this, SIGNAL(optionsChanged()));
-    connect(m_wholeWordsOnly, SIGNAL(toggled(bool)), this, SIGNAL(optionsChanged()));
-    connect(m_fromCursor, SIGNAL(toggled(bool)), this, SIGNAL(optionsChanged()));
-    connect(m_findBackwards, SIGNAL(toggled(bool)), this, SIGNAL(optionsChanged()));
-    connect(m_selectedText, SIGNAL(toggled(bool)), this, SIGNAL(optionsChanged()));
-    connect(m_promptOnReplace, SIGNAL(toggled(bool)), this, SIGNAL(optionsChanged()));
+    connect(d->regExp, SIGNAL(toggled(bool)), this, SIGNAL(optionsChanged()));
+    connect(d->backRef, SIGNAL(toggled(bool)), this, SIGNAL(optionsChanged()));
+    connect(d->caseSensitive, SIGNAL(toggled(bool)), this, SIGNAL(optionsChanged()));
+    connect(d->wholeWordsOnly, SIGNAL(toggled(bool)), this, SIGNAL(optionsChanged()));
+    connect(d->fromCursor, SIGNAL(toggled(bool)), this, SIGNAL(optionsChanged()));
+    connect(d->findBackwards, SIGNAL(toggled(bool)), this, SIGNAL(optionsChanged()));
+    connect(d->selectedText, SIGNAL(toggled(bool)), this, SIGNAL(optionsChanged()));
+    connect(d->promptOnReplace, SIGNAL(toggled(bool)), this, SIGNAL(optionsChanged()));
 
     // tab order
-    setTabOrder(m_find, m_regExp);
-    setTabOrder(m_regExp, m_regExpItem);
-    setTabOrder(m_regExpItem, m_replace);
-    setTabOrder(m_replace, m_backRef);
-    setTabOrder(m_backRef, m_backRefItem);
-    setTabOrder(m_backRefItem, m_caseSensitive);
-    setTabOrder(m_caseSensitive, m_wholeWordsOnly);
-    setTabOrder(m_wholeWordsOnly, m_fromCursor);
-    setTabOrder(m_fromCursor, m_findBackwards);
-    setTabOrder(m_findBackwards, m_selectedText);
-    setTabOrder(m_selectedText, m_promptOnReplace);
+    setTabOrder(d->find, d->regExp);
+    setTabOrder(d->regExp, d->regExpItem);
+    setTabOrder(d->regExpItem, d->replace);
+    setTabOrder(d->replace, d->backRef);
+    setTabOrder(d->backRef, d->backRefItem);
+    setTabOrder(d->backRefItem, d->caseSensitive);
+    setTabOrder(d->caseSensitive, d->wholeWordsOnly);
+    setTabOrder(d->wholeWordsOnly, d->fromCursor);
+    setTabOrder(d->fromCursor, d->findBackwards);
+    setTabOrder(d->findBackwards, d->selectedText);
+    setTabOrder(d->selectedText, d->promptOnReplace);
 
     // buddies
-    m_findLabel->setBuddy(m_find);
-    m_replaceLabel->setBuddy(m_replace);
+    findLabel->setBuddy(d->find);
+    replaceLabel->setBuddy(d->replace);
 
     if (!forReplace)
     {
-        m_promptOnReplace->hide();
-        m_replaceGrp->hide();
+        d->promptOnReplace->hide();
+        d->replaceGrp->hide();
     }
 
     d->findStrings = findStrings;
-    m_find->setFocus();
+    d->find->setFocus();
     enableButtonOk( !pattern().isEmpty() );
     if (forReplace)
     {
@@ -260,43 +214,43 @@ void KFindDialog::init(bool forReplace, const QStringList &findStrings, bool has
     }
     else
     {
-      setButtonGuiItem( KDialog::Ok, KGuiItem( i18n("&Find"), "find",
+      setButtonGuiItem( KDialog::Ok, KGuiItem( i18n("&Find"), "edit-find",
                     i18n("Start searching"),
                     i18n("<qt>If you press the <b>Find</b> button, the text you entered "
                          "above is searched for within the document.</qt>")));
     }
 
     // QWhatsthis texts
-    m_find->setWhatsThis(i18n(
+    d->find->setWhatsThis(i18n(
             "Enter a pattern to search for, or select a previous pattern from "
             "the list.") );
-    m_regExp->setWhatsThis(i18n(
+    d->regExp->setWhatsThis(i18n(
             "If enabled, search for a regular expression.") );
-    m_regExpItem->setWhatsThis(i18n(
+    d->regExpItem->setWhatsThis(i18n(
             "Click here to edit your regular expression using a graphical editor.") );
-    m_replace->setWhatsThis(i18n(
+    d->replace->setWhatsThis(i18n(
             "Enter a replacement string, or select a previous one from the list.") );
-    m_backRef->setWhatsThis(i18n(
+    d->backRef->setWhatsThis(i18n(
             "<qt>If enabled, any occurrence of <code><b>\\N</b></code>, where "
             "<code><b>N</b></code> is a integer number, will be replaced with "
             "the corresponding capture (\"parenthesized substring\") from the "
             "pattern.<p>To include (a literal <code><b>\\N</b></code> in your "
             "replacement, put an extra backslash in front of it, like "
-            "<code><b>\\\\N</b></code>.</qt>") );
-    m_backRefItem->setWhatsThis(i18n(
+            "<code><b>\\\\N</b></code>.</p></qt>") );
+    d->backRefItem->setWhatsThis(i18n(
             "Click for a menu of available captures.") );
-    m_wholeWordsOnly->setWhatsThis(i18n(
+    d->wholeWordsOnly->setWhatsThis(i18n(
             "Require word boundaries in both ends of a match to succeed.") );
-    m_fromCursor->setWhatsThis(i18n(
+    d->fromCursor->setWhatsThis(i18n(
             "Start searching at the current cursor location rather than at the top.") );
-    m_selectedText->setWhatsThis(i18n(
+    d->selectedText->setWhatsThis(i18n(
             "Only search within the current selection.") );
-    m_caseSensitive->setWhatsThis(i18n(
+    d->caseSensitive->setWhatsThis(i18n(
             "Perform a case sensitive search: entering the pattern "
             "'Joe' will not match 'joe' or 'JOE', only 'Joe'.") );
-    m_findBackwards->setWhatsThis(i18n(
+    d->findBackwards->setWhatsThis(i18n(
             "Search backwards.") );
-    m_promptOnReplace->setWhatsThis(i18n(
+    d->promptOnReplace->setWhatsThis(i18n(
             "Ask before replacing each match found.") );
 
     connect(this,SIGNAL(okClicked()),this,SLOT(slotOk()));
@@ -309,16 +263,16 @@ void KFindDialog::textSearchChanged( const QString & text)
 
 void KFindDialog::showEvent( QShowEvent *e )
 {
-    if ( !d->m_initialShowDone )
+    if ( !d->initialShowDone )
     {
-        d->m_initialShowDone = true; // only once
+        d->initialShowDone = true; // only once
         kDebug() << "showEvent\n";
         if (!d->findStrings.isEmpty())
             setFindHistory(d->findStrings);
         d->findStrings = QStringList();
         if (!d->pattern.isEmpty()) {
-            m_find->lineEdit()->setText( d->pattern );
-            m_find->lineEdit()->selectAll();
+            d->find->lineEdit()->setText( d->pattern );
+            d->find->lineEdit()->selectAll();
             d->pattern.clear();
         }
     }
@@ -329,54 +283,54 @@ long KFindDialog::options() const
 {
     long options = 0;
 
-    if (m_caseSensitive->isChecked())
+    if (d->caseSensitive->isChecked())
         options |= KFind::CaseSensitive;
-    if (m_wholeWordsOnly->isChecked())
+    if (d->wholeWordsOnly->isChecked())
         options |= KFind::WholeWordsOnly;
-    if (m_fromCursor->isChecked())
+    if (d->fromCursor->isChecked())
         options |= KFind::FromCursor;
-    if (m_findBackwards->isChecked())
+    if (d->findBackwards->isChecked())
         options |= KFind::FindBackwards;
-    if (m_selectedText->isChecked())
+    if (d->selectedText->isChecked())
         options |= KFind::SelectedText;
-    if (m_regExp->isChecked())
+    if (d->regExp->isChecked())
         options |= KFind::RegularExpression;
     return options;
 }
 
 QString KFindDialog::pattern() const
 {
-    return m_find->currentText();
+    return d->find->currentText();
 }
 
 void KFindDialog::setPattern (const QString &pattern)
 {
-    m_find->lineEdit()->setText( pattern );
-    m_find->lineEdit()->selectAll();
+    d->find->lineEdit()->setText( pattern );
+    d->find->lineEdit()->selectAll();
     d->pattern = pattern;
-    kDebug() << "setPattern " << pattern<<endl;
+    kDebug() << "setPattern " << pattern;
 }
 
 void KFindDialog::setFindHistory(const QStringList &strings)
 {
     if (strings.count() > 0)
     {
-        m_find->setHistoryItems(strings, true);
-        m_find->lineEdit()->setText( strings.first() );
-        m_find->lineEdit()->selectAll();
+        d->find->setHistoryItems(strings, true);
+        d->find->lineEdit()->setText( strings.first() );
+        d->find->lineEdit()->selectAll();
     }
     else
-        m_find->clearHistory();
+        d->find->clearHistory();
 }
 
 void KFindDialog::setHasSelection(bool hasSelection)
 {
-    if (hasSelection) d->m_enabled |= KFind::SelectedText;
-    else d->m_enabled &= ~KFind::SelectedText;
-    m_selectedText->setEnabled( hasSelection );
+    if (hasSelection) d->enabled |= KFind::SelectedText;
+    else d->enabled &= ~KFind::SelectedText;
+    d->selectedText->setEnabled( hasSelection );
     if ( !hasSelection )
     {
-        m_selectedText->setChecked( false );
+        d->selectedText->setChecked( false );
         slotSelectedTextToggled( hasSelection );
     }
 }
@@ -384,82 +338,91 @@ void KFindDialog::setHasSelection(bool hasSelection)
 void KFindDialog::slotSelectedTextToggled(bool selec)
 {
     // From cursor doesn't make sense if we have a selection
-    m_fromCursor->setEnabled( !selec && (d->m_enabled & KFind::FromCursor) );
+    d->fromCursor->setEnabled( !selec && (d->enabled & KFind::FromCursor) );
     if ( selec ) // uncheck if disabled
-        m_fromCursor->setChecked( false );
+        d->fromCursor->setChecked( false );
 }
 
 void KFindDialog::setHasCursor(bool hasCursor)
 {
-    if (hasCursor) d->m_enabled |= KFind::FromCursor;
-    else d->m_enabled &= ~KFind::FromCursor;
-    m_fromCursor->setEnabled( hasCursor );
-    m_fromCursor->setChecked( hasCursor && (options() & KFind::FromCursor) );
+    if (hasCursor) d->enabled |= KFind::FromCursor;
+    else d->enabled &= ~KFind::FromCursor;
+    d->fromCursor->setEnabled( hasCursor );
+    d->fromCursor->setChecked( hasCursor && (options() & KFind::FromCursor) );
 }
 
 void KFindDialog::setSupportsBackwardsFind( bool supports )
 {
     // ########## Shouldn't this hide the checkbox instead?
-    if (supports) d->m_enabled |= KFind::FindBackwards;
-    else d->m_enabled &= ~KFind::FindBackwards;
-    m_findBackwards->setEnabled( supports );
-    m_findBackwards->setChecked( supports && (options() & KFind::FindBackwards) );
+    if (supports) d->enabled |= KFind::FindBackwards;
+    else d->enabled &= ~KFind::FindBackwards;
+    d->findBackwards->setEnabled( supports );
+    d->findBackwards->setChecked( supports && (options() & KFind::FindBackwards) );
 }
 
 void KFindDialog::setSupportsCaseSensitiveFind( bool supports )
 {
     // ########## This should hide the checkbox instead
-    if (supports) d->m_enabled |= KFind::CaseSensitive;
-    else d->m_enabled &= ~KFind::CaseSensitive;
-    m_caseSensitive->setEnabled( supports );
-    m_caseSensitive->setChecked( supports && (options() & KFind::CaseSensitive) );
+    if (supports) d->enabled |= KFind::CaseSensitive;
+    else d->enabled &= ~KFind::CaseSensitive;
+    d->caseSensitive->setEnabled( supports );
+    d->caseSensitive->setChecked( supports && (options() & KFind::CaseSensitive) );
 }
 
 void KFindDialog::setSupportsWholeWordsFind( bool supports )
 {
     // ########## This should hide the checkbox instead
-    if (supports) d->m_enabled |= KFind::WholeWordsOnly;
-    else d->m_enabled &= ~KFind::WholeWordsOnly;
-    m_wholeWordsOnly->setEnabled( supports );
-    m_wholeWordsOnly->setChecked( supports && (options() & KFind::WholeWordsOnly) );
+    if (supports) d->enabled |= KFind::WholeWordsOnly;
+    else d->enabled &= ~KFind::WholeWordsOnly;
+    d->wholeWordsOnly->setEnabled( supports );
+    d->wholeWordsOnly->setChecked( supports && (options() & KFind::WholeWordsOnly) );
 }
 
 void KFindDialog::setSupportsRegularExpressionFind( bool supports )
 {
-    // ########## This should hide the checkbox instead
-    if (supports) d->m_enabled |= KFind::RegularExpression;
-    else d->m_enabled &= ~KFind::RegularExpression;
-    m_regExp->setEnabled( supports );
-    m_regExp->setChecked( supports && (options() & KFind::RegularExpression) );
+    if (supports) d->enabled |= KFind::RegularExpression;
+    else d->enabled &= ~KFind::RegularExpression;
+    d->regExp->setEnabled( supports );
+    d->regExp->setChecked( supports && (options() & KFind::RegularExpression) );
+    if( !supports)
+    {
+       d->regExpItem->hide();
+       d->regExp->hide();
+    }
+    else
+    {
+       d->regExpItem->show();
+       d->regExp->show();
+    }
 }
 
 void KFindDialog::setOptions(long options)
 {
-    m_caseSensitive->setChecked((d->m_enabled & KFind::CaseSensitive) && (options & KFind::CaseSensitive));
-    m_wholeWordsOnly->setChecked((d->m_enabled & KFind::WholeWordsOnly) && (options & KFind::WholeWordsOnly));
-    m_fromCursor->setChecked((d->m_enabled & KFind::FromCursor) && (options & KFind::FromCursor));
-    m_findBackwards->setChecked((d->m_enabled & KFind::FindBackwards) && (options & KFind::FindBackwards));
-    m_selectedText->setChecked((d->m_enabled & KFind::SelectedText) && (options & KFind::SelectedText));
-    m_regExp->setChecked((d->m_enabled & KFind::RegularExpression) && (options & KFind::RegularExpression));
+    d->caseSensitive->setChecked((d->enabled & KFind::CaseSensitive) && (options & KFind::CaseSensitive));
+    d->wholeWordsOnly->setChecked((d->enabled & KFind::WholeWordsOnly) && (options & KFind::WholeWordsOnly));
+    d->fromCursor->setChecked((d->enabled & KFind::FromCursor) && (options & KFind::FromCursor));
+    d->findBackwards->setChecked((d->enabled & KFind::FindBackwards) && (options & KFind::FindBackwards));
+    d->selectedText->setChecked((d->enabled & KFind::SelectedText) && (options & KFind::SelectedText));
+    d->regExp->setChecked((d->enabled & KFind::RegularExpression) && (options & KFind::RegularExpression));
 }
 
 // Create a popup menu with a list of regular expression terms, to help the user
 // compose a regular expression search pattern.
 void KFindDialog::showPatterns()
 {
-    if ( !d->m_regexpDialogQueryDone )
+    if ( !d->regexpDialogQueryDone )
     {
-        d->m_regexpDialog = KServiceTypeTrader::createInstanceFromQuery<QDialog>( "KRegExpEditor/KRegExpEditor", QString(), this );
-        d->m_regexpDialogQueryDone = true;
+        d->regexpDialog = KServiceTypeTrader::createInstanceFromQuery<QDialog>( "KRegExpEditor/KRegExpEditor", QString(), this );
+        d->regexpDialogQueryDone = true;
     }
 
-    if ( d->m_regexpDialog )
+    if ( d->regexpDialog )
     {
-        KRegExpEditorInterface *iface = dynamic_cast<KRegExpEditorInterface*>( d->m_regexpDialog );
+        KRegExpEditorInterface *iface = qobject_cast<KRegExpEditorInterface*>( d->regexpDialog );
         assert( iface );
 
         iface->setRegExp( pattern() );
-        if ( d->m_regexpDialog->exec() == QDialog::Accepted )
+        if ( d->regexpDialog->exec() == QDialog::Accepted )
             setPattern( iface->regExp() );
     }
     else // No complete regexp-editor available, bring up the old popupmenu
@@ -509,24 +472,24 @@ void KFindDialog::showPatterns()
         int i;
 
         // Populate the popup menu.
-        if (!m_patterns)
+        if (!d->patterns)
         {
-            m_patterns = new QMenu(this);
+            d->patterns = new QMenu(this);
             for (i = 0; (unsigned)i < sizeof(items) / sizeof(items[0]); i++)
             {
-                m_patterns->addAction(new RegExpAction(m_patterns, i18n(items[i].description),
+                d->patterns->addAction(new RegExpAction(d->patterns, i18n(items[i].description),
                                                        items[i].regExp,
                                                        items[i].cursorAdjustment));
             }
         }
 
         // Insert the selection into the edit control.
-        QAction *action = m_patterns->exec(m_regExpItem->mapToGlobal(m_regExpItem->rect().bottomLeft()));
+        QAction *action = d->patterns->exec(d->regExpItem->mapToGlobal(d->regExpItem->rect().bottomLeft()));
         if (action)
         {
             RegExpAction *regExpAction = static_cast<RegExpAction*>( action );
             if ( regExpAction ) {
-              QLineEdit *editor = m_find->lineEdit();
+              QLineEdit *editor = d->find->lineEdit();
 
               editor->insert(regExpAction->regExp());
               editor->setCursorPosition(editor->cursorPosition() + regExpAction->cursor());
@@ -556,19 +519,19 @@ class PlaceHolderAction : public QAction
 void KFindDialog::showPlaceholders()
 {
     // Populate the popup menu.
-    if (!m_placeholders)
+    if (!d->placeholders)
     {
-        m_placeholders = new QMenu(this);
-        connect( m_placeholders, SIGNAL(aboutToShow()), this, SLOT(slotPlaceholdersAboutToShow()) );
+        d->placeholders = new QMenu(this);
+        connect( d->placeholders, SIGNAL(aboutToShow()), this, SLOT(slotPlaceholdersAboutToShow()) );
     }
 
     // Insert the selection into the edit control.
-    QAction *action = m_placeholders->exec(m_backRefItem->mapToGlobal(m_backRefItem->rect().bottomLeft()));
+    QAction *action = d->placeholders->exec(d->backRefItem->mapToGlobal(d->backRefItem->rect().bottomLeft()));
     if (action)
     {
         PlaceHolderAction *placeHolderAction = static_cast<PlaceHolderAction*>(action);
         if (placeHolderAction) {
-          QLineEdit *editor = m_replace->lineEdit();
+          QLineEdit *editor = d->replace->lineEdit();
           editor->insert( QString("\\%1").arg( placeHolderAction->id() ) );
         }
     }
@@ -576,13 +539,13 @@ void KFindDialog::showPlaceholders()
 
 void KFindDialog::slotPlaceholdersAboutToShow()
 {
-    m_placeholders->clear();
-    m_placeholders->addAction( new PlaceHolderAction(m_placeholders, i18n("Complete Match"), 0));
+    d->placeholders->clear();
+    d->placeholders->addAction( new PlaceHolderAction(d->placeholders, i18n("Complete Match"), 0));
 
     QRegExp r( pattern() );
     uint n = r.numCaptures();
     for ( uint i=0; i < n; i++ )
-        m_placeholders->addAction( new PlaceHolderAction(m_placeholders, i18n("Captured Text (%1)",  i+1 ), i+1 ) );
+        d->placeholders->addAction( new PlaceHolderAction(d->placeholders, i18n("Captured Text (%1)",  i+1 ), i+1 ) );
 }
 
 void KFindDialog::slotOk()
@@ -594,7 +557,7 @@ void KFindDialog::slotOk()
         return;
     }
 
-    if (m_regExp->isChecked())
+    if (d->regExp->isChecked())
     {
         // Check for a valid regular expression.
         QRegExp regExp(pattern());
@@ -605,7 +568,7 @@ void KFindDialog::slotOk()
             return;
         }
     }
-    m_find->addToHistory(pattern());
+    d->find->addToHistory(pattern());
     if ( windowModality() != Qt::NonModal )
         accept();
 }
