@@ -23,11 +23,10 @@
 
 #include <kdialog.h>
 
-class KHistoryCombo;
+class KHistoryComboBox;
 class QPushButton;
 class QMenu;
 class QGridLayout;
-class QLabel;
 class QCheckBox;
 class QGroupBox;
 
@@ -57,7 +56,7 @@ class QGroupBox;
  * To create a non-modal find dialog:
  * \code
  *   if ( m_findDia )
- *     KWin::setActiveWindow( m_findDia->winId() );
+ *     KWindowSystem::activateWindow( m_findDia->winId() );
  *   else
  *   {
  *     m_findDia = new KFindDialog(false,...);
@@ -82,29 +81,12 @@ public:
      * Construct a modal find dialog
      *
      * @param parent The parent object of this widget.
-     * @param name The name of this widget.
      * @param options A bitfield of the Options to be checked.
      * @param findStrings The find history, see findHistory()
      * @param hasSelection Whether a selection exists
      */
-    KFindDialog( QWidget *parent = 0, const char *name = 0, long options = 0,
+    explicit KFindDialog( QWidget *parent = 0, long options = 0,
                  const QStringList &findStrings = QStringList(), bool hasSelection = false );
-    // KDE4: fix ambiguity with private constructor
-    // Maybe remove options (there's setOptions) and findStrings (setFindHistory) and hasSelection (setHasSelection)
-
-    /**
-     * Construct a non-modal find dialog
-     *
-     * @param modal set to false to get a non-modal dialog
-     * @param parent The parent object of this widget.
-     * @param name The name of this widget.
-     * @param options A bitfield of the Options to be checked.
-     * @param findStrings The find history, see findHistory()
-     * @param hasSelection Whether a selection exists
-     */
-    KFindDialog( bool modal, QWidget *parent = 0, const char *name = 0, long options = 0,
-                 const QStringList &findStrings = QStringList(), bool hasSelection = false );
-    // KDE4: consider simplifying
 
     /**
      * Destructor.
@@ -184,8 +166,10 @@ public:
     /**
      * Set the options which are checked.
      *
-     * @see setOptions KFind::Options
      * @param options The setting of the Options.
+     *
+     * @see options()
+     * @see KFind::Options
      */
     void setOptions( long options );
 
@@ -193,7 +177,8 @@ public:
      * Returns the state of the options. Disabled options may be returned in
      * an indeterminate state.
      *
-     * @see setOptions KFind::Options
+     * @see setOptions()
+     * @see KFind::Options
      */
     long options() const;
 
@@ -213,7 +198,7 @@ public:
      * and is positioned immediately below the regular expression support
      * widgets for the pattern string.
      */
-    QWidget *findExtension();
+    QWidget *findExtension() const;
 
 Q_SIGNALS:
     /**
@@ -242,50 +227,14 @@ private Q_SLOTS:
 
 private:
 
-    QGroupBox *m_findGrp;
-    QLabel *m_findLabel;
-    KHistoryCombo *m_find;
-    QCheckBox *m_regExp;
-    QPushButton *m_regExpItem;
-    QGridLayout *m_findLayout;
-    QWidget *m_findExtension;
-
-    QGroupBox *m_optionGrp;
-    QCheckBox *m_wholeWordsOnly;
-    QCheckBox *m_fromCursor;
-    QCheckBox *m_selectedText;
-    QCheckBox *m_caseSensitive;
-    QCheckBox *m_findBackwards;
-
-    QMenu *m_patterns;
-
     // Our dirty little secret is that we also implement the "replace" dialog. But we
     // keep that fact hidden from all but our friends.
 
     friend class KReplaceDialog;
 
-    /**
-     * Construct a find dialog with a parent object and a name. This version of the
-     * constructor is for use by friends only!
-     *
-     * @param forReplace Is this a replace dialog?
-     */
-    KFindDialog( QWidget *parent, const char *name, bool forReplace );
+
     void init( bool forReplace, const QStringList &findStrings, bool hasSelection );
 
-    QGroupBox *m_replaceGrp;
-    QLabel *m_replaceLabel;
-    KHistoryCombo *m_replace;
-    QCheckBox* m_backRef;
-    QPushButton* m_backRefItem;
-    QGridLayout *m_replaceLayout;
-    QWidget *m_replaceExtension;
-
-    QCheckBox* m_promptOnReplace;
-
-    QMenu *m_placeholders;
-
-    // Binary compatible extensibility.
     class KFindDialogPrivate;
     KFindDialogPrivate* const d;
 };
