@@ -19,14 +19,15 @@
 */
 
 #include "kreplacedialog.h"
+#include "kfinddialog_p.h"
 
-#include <qcheckbox.h>
-#include <qgroupbox.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qlineedit.h>
-#include <qregexp.h>
-#include <kcombobox.h>
+#include <QtGui/QCheckBox>
+#include <QtGui/QGroupBox>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtGui/QLineEdit>
+#include <QtCore/QRegExp>
+#include <khistorycombobox.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kdebug.h>
@@ -38,13 +39,19 @@
  */
 class KReplaceDialog::KReplaceDialogPrivate {
   public:
-    KReplaceDialogPrivate() : m_initialShowDone(false) {}
+    KReplaceDialogPrivate()
+    : initialShowDone(false)
+    , replaceExtension (0)
+    {}
+
     QStringList replaceStrings;
-    bool m_initialShowDone;
+    bool initialShowDone;
+    QWidget *replaceExtension;
 };
 
-KReplaceDialog::KReplaceDialog(QWidget *parent, const char *name, long options, const QStringList &findStrings, const QStringList &replaceStrings, bool hasSelection) :
-    KFindDialog(parent, name, true),
+KReplaceDialog::KReplaceDialog(QWidget *parent, long options, const QStringList &findStrings,
+                               const QStringList &replaceStrings, bool hasSelection) :
+    KFindDialog(parent),
 	d(new KReplaceDialogPrivate)
 {
     d->replaceStrings = replaceStrings;
@@ -59,14 +66,14 @@ KReplaceDialog::~KReplaceDialog()
 
 void KReplaceDialog::showEvent( QShowEvent *e )
 {
-    if ( !d->m_initialShowDone )
+    if ( !d->initialShowDone )
     {
-        d->m_initialShowDone = true; // only once
+        d->initialShowDone = true; // only once
 
         if (!d->replaceStrings.isEmpty())
         {
           setReplacementHistory(d->replaceStrings);
-          m_replace->lineEdit()->setText( d->replaceStrings[0] );
+          KFindDialog::d->replace->lineEdit()->setText( d->replaceStrings[0] );
         }
     }
 
@@ -78,34 +85,34 @@ long KReplaceDialog::options() const
     long options = 0;
 
     options = KFindDialog::options();
-    if (m_promptOnReplace->isChecked())
+    if (KFindDialog::d->promptOnReplace->isChecked())
         options |= PromptOnReplace;
-    if (m_backRef->isChecked())
+    if (KFindDialog::d->backRef->isChecked())
         options |= BackReference;
     return options;
 }
 
-QWidget *KReplaceDialog::replaceExtension()
+QWidget *KReplaceDialog::replaceExtension() const
 {
-    if (!m_replaceExtension)
+    if (!d->replaceExtension)
     {
-      m_replaceExtension = new QWidget(m_replaceGrp);
-      m_replaceLayout->addWidget(m_replaceExtension, 3, 0, 1, 2);
+      d->replaceExtension = new QWidget(KFindDialog::d->replaceGrp);
+      KFindDialog::d->replaceLayout->addWidget(d->replaceExtension, 3, 0, 1, 2);
     }
 
-    return m_replaceExtension;
+    return d->replaceExtension;
 }
 
 QString KReplaceDialog::replacement() const
 {
-    return m_replace->currentText();
+    return KFindDialog::d->replace->currentText();
 }
 
 QStringList KReplaceDialog::replacementHistory() const
 {
-    QStringList lst = m_replace->historyItems();
+    QStringList lst = KFindDialog::d->replace->historyItems();
     // historyItems() doesn't tell us about the case of replacing with an empty string
-    if ( m_replace->lineEdit()->text().isEmpty() )
+    if ( KFindDialog::d->replace->lineEdit()->text().isEmpty() )
         lst.prepend( QString() );
     return lst;
 }
@@ -113,22 +120,22 @@ QStringList KReplaceDialog::replacementHistory() const
 void KReplaceDialog::setOptions(long options)
 {
     KFindDialog::setOptions(options);
-    m_promptOnReplace->setChecked(options & PromptOnReplace);
-    m_backRef->setChecked(options & BackReference);
+    KFindDialog::d->promptOnReplace->setChecked(options & PromptOnReplace);
+    KFindDialog::d->backRef->setChecked(options & BackReference);
 }
 
 void KReplaceDialog::setReplacementHistory(const QStringList &strings)
 {
     if (strings.count() > 0)
-        m_replace->setHistoryItems(strings, true);
+        KFindDialog::d->replace->setHistoryItems(strings, true);
     else
-        m_replace->clearHistory();
+        KFindDialog::d->replace->clearHistory();
 }
 
 void KReplaceDialog::slotOk()
 {
     // If regex and backrefs are enabled, do a sanity check.
-    if ( m_regExp->isChecked() && m_backRef->isChecked() )
+    if ( KFindDialog::d->regExp->isChecked() && KFindDialog::d->backRef->isChecked() )
     {
         QRegExp r ( pattern() );
         int caps = r.numCaptures();
@@ -154,7 +161,7 @@ void KReplaceDialog::slotOk()
     }
 
     KFindDialog::slotOk();
-    m_replace->addToHistory(replacement());
+    KFindDialog::d->replace->addToHistory(replacement());
 }
 
 // kate: space-indent on; indent-width 4; replace-tabs on;
