@@ -2,45 +2,63 @@
  *
  * This file is part of the KDE project, module kdecore.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
+ * (C) 2007 Daniel M. Duley <daniel.duley@verizon.net>
  * with minor additions and based on ideas from
  * Torsten Rahn <torsten@kde.org>
  *
- * This is free software; it comes under the GNU Library General
- * Public License, version 2. See the file "COPYING.LIB" for the
- * exact licensing terms.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License version 2 as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public License
+ * along with this library; see the file COPYING.LIB.  If not, write to
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
+#include "kiconeffect.h"
+
 #include <config.h>
 #include <unistd.h>
 #include <math.h>
 
-#include <qapplication.h>
-#include <qpaintengine.h>
-#include <qdesktopwidget.h>
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qbitmap.h>
-#include <qpixmap.h>
-#include <qimage.h>
-#include <qcolor.h>
-#include <qwidget.h>
-#include <qpainter.h>
-#include <qpen.h>
+#include <QtCore/QSysInfo>
+#include <QtGui/QApplication>
+#include <QtGui/QPaintEngine>
+#include <QtGui/QDesktopWidget>
+#include <QtCore/QCharRef>
+#include <QtCore/QMutableStringListIterator>
+#include <QtGui/QBitmap>
+#include <QtGui/QPixmap>
+#include <QtGui/QImage>
+#include <QtGui/QColor>
+#include <QtGui/QWidget>
+#include <QtGui/QPainter>
+#include <QtGui/QPen>
 
 #include <kdebug.h>
 #include <kglobal.h>
-#include <kconfig.h>
+#include <ksharedconfig.h>
 #include <kglobalsettings.h>
+#include <kcolorscheme.h>
 #include <kicontheme.h>
-#include "kiconeffect.h"
 #include <kconfiggroup.h>
 
 
 class KIconEffectPrivate
 {
 public:
-	QString mKey[6][3];
-	QColor  mColor2[6][3];
+    int effect[6][3];
+    float value[6][3];
+    QColor color[6][3];
+    bool trans[6][3];
+    QString key[6][3];
+    QColor color2[6][3];
 };
 
 KIconEffect::KIconEffect()
@@ -82,22 +100,22 @@ void KIconEffect::init()
     for (it=groups.begin(), i=0; it!=groups.end(); it++, i++)
     {
 	// Default effects
-	mEffect[i][0] = NoEffect;
-	mEffect[i][1] =  ((i==0)||(i==4)) ? ToGamma : NoEffect;
-	mEffect[i][2] = ToGray;
+	d->effect[i][0] = NoEffect;
+	d->effect[i][1] =  ((i==0)||(i==4)) ? ToGamma : NoEffect;
+	d->effect[i][2] = ToGray;
 
-	mTrans[i][0] = false;
-	mTrans[i][1] = false;
-	mTrans[i][2] = true;
-        mValue[i][0] = 1.0;
-        mValue[i][1] = ((i==0)||(i==4)) ? 0.7 : 1.0;
-        mValue[i][2] = 1.0;
-        mColor[i][0] = QColor(144,128,248);
-        mColor[i][1] = QColor(169,156,255);
-        mColor[i][2] = QColor(34,202,0);
-        d->mColor2[i][0] = QColor(0,0,0);
-        d->mColor2[i][1] = QColor(0,0,0);
-        d->mColor2[i][2] = QColor(0,0,0);
+	d->trans[i][0] = false;
+	d->trans[i][1] = false;
+	d->trans[i][2] = true;
+        d->value[i][0] = 1.0;
+        d->value[i][1] = ((i==0)||(i==4)) ? 0.7 : 1.0;
+        d->value[i][2] = 1.0;
+        d->color[i][0] = QColor(144,128,248);
+        d->color[i][1] = QColor(169,156,255);
+        d->color[i][2] = QColor(34,202,0);
+        d->color2[i][0] = QColor(0,0,0);
+        d->color2[i][1] = QColor(0,0,0);
+        d->color2[i][2] = QColor(0,0,0);
 
 	KConfigGroup cg(config, *it + "Icons");
 	for (it2=states.begin(), j=0; it2!=states.end(); it2++, j++)
@@ -118,11 +136,11 @@ void KIconEffect::init()
 	    else
 		continue;
 	    if(effect != -1)
-                mEffect[i][j] = effect;
-	    mValue[i][j] = cg.readEntry(*it2 + "Value", 0.0);
-	    mColor[i][j] = cg.readEntry(*it2 + "Color", QColor());
-	    d->mColor2[i][j] = cg.readEntry(*it2 + "Color2", QColor());
-	    mTrans[i][j] = cg.readEntry(*it2 + "SemiTransparent", false);
+                d->effect[i][j] = effect;
+	    d->value[i][j] = cg.readEntry(*it2 + "Value", 0.0);
+	    d->color[i][j] = cg.readEntry(*it2 + "Color", QColor());
+	    d->color2[i][j] = cg.readEntry(*it2 + "Color2", QColor());
+	    d->trans[i][j] = cg.readEntry(*it2 + "SemiTransparent", false);
 
 	}
     }
@@ -130,40 +148,40 @@ void KIconEffect::init()
 
 bool KIconEffect::hasEffect(int group, int state) const
 {
-    return mEffect[group][state] != NoEffect;
+    return d->effect[group][state] != NoEffect;
 }
 
 QString KIconEffect::fingerprint(int group, int state) const
 {
     if ( group >= K3Icon::LastGroup ) return "";
-    QString cached = d->mKey[group][state];
+    QString cached = d->key[group][state];
     if (cached.isEmpty())
     {
         QString tmp;
-        cached = tmp.setNum(mEffect[group][state]);
+        cached = tmp.setNum(d->effect[group][state]);
         cached += ':';
-        cached += tmp.setNum(mValue[group][state]);
+        cached += tmp.setNum(d->value[group][state]);
         cached += ':';
-        cached += mTrans[group][state] ? QLatin1String("trans")
+        cached += d->trans[group][state] ? QLatin1String("trans")
             : QLatin1String("notrans");
-        if (mEffect[group][state] == Colorize || mEffect[group][state] == ToMonochrome)
+        if (d->effect[group][state] == Colorize || d->effect[group][state] == ToMonochrome)
         {
             cached += ':';
-            cached += mColor[group][state].name();
+            cached += d->color[group][state].name();
         }
-        if (mEffect[group][state] == ToMonochrome)
+        if (d->effect[group][state] == ToMonochrome)
         {
             cached += ':';
-            cached += d->mColor2[group][state].name();
+            cached += d->color2[group][state].name();
         }
 
-        d->mKey[group][state] = cached;
+        d->key[group][state] = cached;
     }
 
     return cached;
 }
 
-QImage KIconEffect::apply(QImage image, int group, int state) const
+QImage KIconEffect::apply(const QImage &image, int group, int state) const
 {
     if (state >= K3Icon::LastState)
     {
@@ -175,17 +193,21 @@ QImage KIconEffect::apply(QImage image, int group, int state) const
 	kDebug(265) << "Illegal icon group: " << group << "\n";
 	return image;
     }
-    return apply(image, mEffect[group][state], mValue[group][state],
-	    mColor[group][state], d->mColor2[group][state], mTrans[group][state]);
+    return apply(image, d->effect[group][state], d->value[group][state],
+	    d->color[group][state], d->color2[group][state], d->trans[group][state]);
 }
 
-QImage KIconEffect::apply(QImage image, int effect, float value, const QColor &col, bool trans) const
+QImage KIconEffect::apply(const QImage &image, int effect, float value,
+                          const QColor &col, bool trans) const
 {
-    return apply (image, effect, value, col, KGlobalSettings::baseColor(), trans);
+    return apply(image, effect, value, col,
+                 KColorScheme(KColorScheme::View).background().color(), trans);
 }
 
-QImage KIconEffect::apply(QImage image, int effect, float value, const QColor &col, const QColor &col2, bool trans) const
+QImage KIconEffect::apply(const QImage &img, int effect, float value,
+                          const QColor &col, const QColor &col2, bool trans) const
 {
+    QImage image = img;
     if (effect >= LastEffect )
     {
 	kDebug(265) << "Illegal icon effect: " << effect << "\n";
@@ -220,7 +242,7 @@ QImage KIconEffect::apply(QImage image, int effect, float value, const QColor &c
     return image;
 }
 
-QPixmap KIconEffect::apply(QPixmap pixmap, int group, int state) const
+QPixmap KIconEffect::apply(const QPixmap &pixmap, int group, int state) const
 {
     if (state >= K3Icon::LastState)
     {
@@ -232,17 +254,18 @@ QPixmap KIconEffect::apply(QPixmap pixmap, int group, int state) const
 	kDebug(265) << "Illegal icon group: " << group << "\n";
 	return pixmap;
     }
-    return apply(pixmap, mEffect[group][state], mValue[group][state],
-	    mColor[group][state], d->mColor2[group][state], mTrans[group][state]);
+    return apply(pixmap, d->effect[group][state], d->value[group][state],
+	    d->color[group][state], d->color2[group][state], d->trans[group][state]);
 }
 
-QPixmap KIconEffect::apply(QPixmap pixmap, int effect, float value,
+QPixmap KIconEffect::apply(const QPixmap &pixmap, int effect, float value,
 	const QColor &col, bool trans) const
 {
-    return apply (pixmap, effect, value, col, KGlobalSettings::baseColor(), trans);
+    return apply(pixmap, effect, value, col,
+                 KColorScheme(KColorScheme::View).background().color(), trans);
 }
 
-QPixmap KIconEffect::apply(QPixmap pixmap, int effect, float value,
+QPixmap KIconEffect::apply(const QPixmap &pixmap, int effect, float value,
 	const QColor &col, const QColor &col2, bool trans) const
 {
     QPixmap result;
@@ -280,8 +303,10 @@ struct KIEImgEdit
     KIEImgEdit(QImage& _img):img(_img)
     {
 	if (img.depth() > 8)
-	{
-	    data   = (unsigned int*)img.bits();
+        {
+            if(img.format() == QImage::Format_ARGB32_Premultiplied)
+                img = img.convertToFormat(QImage::Format_ARGB32);
+            data   = (unsigned int*)img.bits();
 	    pixels = img.width()*img.height();
 	}
 	else
@@ -304,227 +329,252 @@ struct KIEImgEdit
 
 void KIconEffect::toGray(QImage &img, float value)
 {
+    if(value == 0.0)
+        return;
+
     KIEImgEdit ii(img);
-    unsigned int* data = ii.data;
+    QRgb *data = ii.data;
+    QRgb *end = data + ii.pixels;
 
-
-    int rval, gval, bval, val, alpha;
-    for (unsigned int i=0; i<ii.pixels; i++)
-    {
-	val = qGray(data[i]);
-	alpha = qAlpha(data[i]);
-	if (value < 1.0)
-	{
-	    rval = static_cast<int>(value*val+(1.0-value)*qRed(data[i]));
-	    gval = static_cast<int>(value*val+(1.0-value)*qGreen(data[i]));
-	    bval = static_cast<int>(value*val+(1.0-value)*qBlue(data[i]));
-	    data[i] = qRgba(rval, gval, bval, alpha);
-	} else
-	    data[i] = qRgba(val, val, val, alpha);
+    unsigned char gray;
+    if(value == 1.0){
+        while(data != end){
+            gray = qGray(*data);
+            *data = qRgba(gray, gray, gray, qAlpha(*data));
+            ++data;
+        }
+    }
+    else{
+        unsigned char val = (unsigned char)(255.0*value);
+        while(data != end){
+            gray = qGray(*data);
+            *data = qRgba((val*gray+(0xFF-val)*qRed(*data)) >> 8,
+                          (val*gray+(0xFF-val)*qGreen(*data)) >> 8,
+                          (val*gray+(0xFF-val)*qBlue(*data)) >> 8,
+                          qAlpha(*data));
+            ++data;
+        }
     }
-
 }
 
 void KIconEffect::colorize(QImage &img, const QColor &col, float value)
 {
+    if(value == 0.0)
+        return;
+
     KIEImgEdit ii(img);
-    unsigned int* data = ii.data;
+    QRgb *data = ii.data;
+    QRgb *end = data + ii.pixels;
 
-    int rval, gval, bval, val, alpha;
     float rcol = col.red(), gcol = col.green(), bcol = col.blue();
-    for (unsigned int i=0; i<ii.pixels; i++)
-    {
-        val = qGray(data[i]);
-        if (val < 128)
-        {
-             rval = static_cast<int>(rcol/128*val);
-             gval = static_cast<int>(gcol/128*val);
-             bval = static_cast<int>(bcol/128*val);
+    unsigned char red, green, blue, gray;
+    unsigned char val = (unsigned char)(255.0*value);
+    while(data != end){
+        gray = qGray(*data);
+        if(gray < 128){
+            red = static_cast<unsigned char>(rcol/128*gray);
+            green = static_cast<unsigned char>(gcol/128*gray);
+            blue = static_cast<unsigned char>(bcol/128*gray);
         }
-        else if (val > 128)
-        {
-             rval = static_cast<int>((val-128)*(2-rcol/128)+rcol-1);
-             gval = static_cast<int>((val-128)*(2-gcol/128)+gcol-1);
-             bval = static_cast<int>((val-128)*(2-bcol/128)+bcol-1);
+        else if(gray > 128){
+            red = static_cast<unsigned char>((gray-128)*(2-rcol/128)+rcol-1);
+            green = static_cast<unsigned char>((gray-128)*(2-gcol/128)+gcol-1);
+            blue = static_cast<unsigned char>((gray-128)*(2-bcol/128)+bcol-1);
+        }
+        else{
+            red = static_cast<unsigned char>(rcol);
+            green = static_cast<unsigned char>(gcol);
+            blue = static_cast<unsigned char>(bcol);
         }
-	else // val == 128
-	{
-             rval = static_cast<int>(rcol);
-             gval = static_cast<int>(gcol);
-             bval = static_cast<int>(bcol);
-	}
-	if (value < 1.0)
-	{
-	    rval = static_cast<int>(value*rval+(1.0 - value)*qRed(data[i]));
-	    gval = static_cast<int>(value*gval+(1.0 - value)*qGreen(data[i]));
-	    bval = static_cast<int>(value*bval+(1.0 - value)*qBlue(data[i]));
-	}
 
-	alpha = qAlpha(data[i]);
-	data[i] = qRgba(rval, gval, bval, alpha);
+        *data = qRgba((val*red+(0xFF-val)*qRed(*data)) >> 8,
+                      (val*green+(0xFF-val)*qGreen(*data)) >> 8,
+                      (val*blue+(0xFF-val)*qBlue(*data)) >> 8,
+                      qAlpha(*data));
+        ++data;
     }
 }
 
-void KIconEffect::toMonochrome(QImage &img, const QColor &black, const QColor &white, float value) {
+void KIconEffect::toMonochrome(QImage &img, const QColor &black,
+                               const QColor &white, float value)
+{
+    if(value == 0.0)
+        return;
+
     KIEImgEdit ii(img);
-    unsigned int* data = ii.data;
-    int         pixels = ii.pixels;
+    QRgb *data = ii.data;
+    QRgb *end = data + ii.pixels;
 
-   int rval, gval, bval, alpha, i;
-   int rw = white.red(), gw = white.green(), bw = white.blue();
-   int rb = black.red(), gb = black.green(), bb = black.blue();
+    // Step 1: determine the average brightness
+    double values = 0.0, sum = 0.0;
+    bool grayscale = true;
+    while(data != end){
+        sum += qGray(*data)*qAlpha(*data) + 255*(255-qAlpha(*data));
+        values += 255;
+        if((qRed(*data) != qGreen(*data) ) || (qGreen(*data) != qBlue(*data)))
+            grayscale = false;
+        ++data;
+    }
+    double medium = sum/values;
 
-   double values = 0, sum = 0;
-   bool grayscale = true;
-   // Step 1: determine the average brightness
-   for (i=0; i<pixels; i++) {
-       sum += qGray(data[i])*qAlpha(data[i]) + 255*(255-qAlpha(data[i]));
-       values += 255;
-       if ((qRed(data[i]) != qGreen(data[i]) ) || (qGreen(data[i]) != qBlue(data[i]) ))
-           grayscale = false;
-   }
-   double medium = sum/values;
+    // Step 2: Modify the image
+    unsigned char val = (unsigned char)(255.0*value);
+    int rw = white.red(), gw = white.green(), bw = white.blue();
+    int rb = black.red(), gb = black.green(), bb = black.blue();
+    data = ii.data;
 
-   // Step 2: Modify the image
-   if (grayscale) {
-       for (i=0; i<pixels; i++) {
-           int v = qRed(data[i]);
-           rval = static_cast<int>( ((255-v)*rb + v*rw)*value/255 + (1.0-value)*qRed(data[i]));
-           gval = static_cast<int>( ((255-v)*gb + v*gw)*value/255 + (1.0-value)*qGreen(data[i]));
-           bval = static_cast<int>( ((255-v)*bb + v*bw)*value/255 + (1.0-value)*qBlue(data[i]));
-
-           alpha = qAlpha(data[i]);
-           data[i] = qRgba(rval, gval, bval, alpha);
-       }
-   }
-   else {
-      for (i=0; i<pixels; i++) {
-         if (qGray(data[i]) <= medium) {
-            rval = static_cast<int>(value*rb+(1.0-value)*qRed(data[i]));
-            gval = static_cast<int>(value*gb+(1.0-value)*qGreen(data[i]));
-            bval = static_cast<int>(value*bb+(1.0-value)*qBlue(data[i]));
-         }
-         else {
-            rval = static_cast<int>(value*rw+(1.0-value)*qRed(data[i]));
-            gval = static_cast<int>(value*gw+(1.0-value)*qGreen(data[i]));
-            bval = static_cast<int>(value*bw+(1.0-value)*qBlue(data[i]));
-         }
-
-         alpha = qAlpha(data[i]);
-         data[i] = qRgba(rval, gval, bval, alpha);
-      }
-   }
+    if(grayscale){
+        while(data != end){
+            if(qRed(*data) <= medium)
+                *data = qRgba((val*rb+(0xFF-val)*qRed(*data)) >> 8,
+                              (val*gb+(0xFF-val)*qGreen(*data)) >> 8,
+                              (val*bb+(0xFF-val)*qBlue(*data)) >> 8,
+                              qAlpha(*data));
+            else
+                *data = qRgba((val*rw+(0xFF-val)*qRed(*data)) >> 8,
+                              (val*gw+(0xFF-val)*qGreen(*data)) >> 8,
+                              (val*bw+(0xFF-val)*qBlue(*data)) >> 8,
+                              qAlpha(*data));
+            ++data;
+        }
+    }
+    else{
+        while(data != end){
+            if(qGray(*data) <= medium) 
+                *data = qRgba((val*rb+(0xFF-val)*qRed(*data)) >> 8,
+                              (val*gb+(0xFF-val)*qGreen(*data)) >> 8,
+                              (val*bb+(0xFF-val)*qBlue(*data)) >> 8,
+                              qAlpha(*data));
+            else
+                *data = qRgba((val*rw+(0xFF-val)*qRed(*data)) >> 8,
+                              (val*gw+(0xFF-val)*qGreen(*data)) >> 8,
+                              (val*bw+(0xFF-val)*qBlue(*data)) >> 8,
+                              qAlpha(*data));
+            ++data;
+        }
+    }
 }
 
 void KIconEffect::deSaturate(QImage &img, float value)
 {
+    if(value == 0.0)
+        return;
+
     KIEImgEdit ii(img);
-    unsigned int* data = ii.data;
-    int         pixels = ii.pixels;
+    QRgb *data = ii.data;
+    QRgb *end = data + ii.pixels;
 
     QColor color;
-    int h, s, v, i;
-    for (i=0; i<pixels; i++)
-    {
-        color.setRgb(data[i]);
+    int h, s, v;
+    while(data != end){
+        color.setRgb(*data);
         color.getHsv(&h, &s, &v);
         color.setHsv(h, (int) (s * (1.0 - value) + 0.5), v);
-	data[i] = qRgba(color.red(), color.green(), color.blue(),
-		qAlpha(data[i]));
+	*data = qRgba(color.red(), color.green(), color.blue(),
+                      qAlpha(*data));
+        ++data;
     }
 }
 
 void KIconEffect::toGamma(QImage &img, float value)
 {
     KIEImgEdit ii(img);
-    unsigned int* data = ii.data;
-    int         pixels = ii.pixels;
+    QRgb *data = ii.data;
+    QRgb *end = data + ii.pixels;
 
-
-    QColor color;
-    int i, rval, gval, bval;
-    float gamma;
-    gamma = 1/(2*value+0.5);
-
-    for (i=0; i<pixels; i++)
-    {
-        color.setRgb(data[i]);
-        color.getRgb(&rval, &gval, &bval);
-        rval = static_cast<int>(pow(static_cast<float>(rval)/255 , gamma)*255);
-        gval = static_cast<int>(pow(static_cast<float>(gval)/255 , gamma)*255);
-        bval = static_cast<int>(pow(static_cast<float>(bval)/255 , gamma)*255);
-	data[i] = qRgba(rval, gval, bval, qAlpha(data[i]));
+    float gamma = 1/(2*value+0.5);
+    while(data != end){
+        *data = qRgba(static_cast<unsigned char>
+                      (pow(static_cast<float>(qRed(*data))/255 , gamma)*255),
+                      static_cast<unsigned char>
+                      (pow(static_cast<float>(qGreen(*data))/255 , gamma)*255),
+                      static_cast<unsigned char>
+                      (pow(static_cast<float>(qBlue(*data))/255 , gamma)*255),
+                      qAlpha(*data));
+        ++data;
     }
 }
 
 void KIconEffect::semiTransparent(QImage &img)
 {
     int x, y;
-    if (img.depth() == 32)
-    {
-	int width  = img.width();
+    if(img.depth() == 32){
+        if(img.format() == QImage::Format_ARGB32_Premultiplied)
+            img = img.convertToFormat(QImage::Format_ARGB32);
+        int width  = img.width();
 	int height = img.height();
 
-	if (QApplication::desktop()->paintEngine()->hasFeature(QPaintEngine::Antialiasing))
-	  for (y=0; y<height; y++)
-	  {
-#ifdef WORDS_BIGENDIAN
-	    uchar *line = (uchar*) img.scanLine(y);
-#else
-	    uchar *line = (uchar*) img.scanLine(y) + 3;
-#endif
-	    for (x=0; x<width; x++)
-	    {
-		*line >>= 1;
-		line += 4;
-	    }
-	  }
-	else
-	  for (y=0; y<height; y++)
-	  {
-	    QRgb* line = (QRgb*)img.scanLine(y);
-	    for (x=(y%2); x<width; x+=2)
-		line[x] &= 0x00ffffff;
-	  }
-
-    } else
-    {
-	// Insert transparent pixel into the clut.
-	int transColor = -1;
+        if(QApplication::desktop()->paintEngine()->hasFeature(QPaintEngine::Antialiasing)){
+            unsigned char *line;
+            for(y=0; y<height; y++){
+                if(QSysInfo::ByteOrder == QSysInfo::BigEndian)
+                    line = img.scanLine(y);
+                else
+                    line = img.scanLine(y) + 3;
+                for(x=0; x<width; x++){
+                    *line >>= 1;
+                    line += 4;
+                }
+            }
+        }
+        else{
+            for(y=0; y<height; y++){
+                QRgb* line = (QRgb*)img.scanLine(y);
+                for(x=(y%2); x<width; x+=2)
+                    line[x] &= 0x00ffffff;
+            }
+        }
+    }
+    else{
+        // Insert transparent pixel into the clut.
+        int transColor = -1;
 
         // search for a color that is already transparent
-        for (x=0; x<img.numColors(); x++)
-        {
+        for(x=0; x<img.numColors(); x++){
             // try to find already transparent pixel
-            if (qAlpha(img.color(x)) < 127)
-            {
+            if(qAlpha(img.color(x)) < 127){
                 transColor = x;
                 break;
             }
         }
 
-
         // FIXME: image must have transparency
         if(transColor < 0 || transColor >= img.numColors())
             return;
 
 	img.setColor(transColor, 0);
-        if(img.depth() == 8)
-        {
-            for (y=0; y<img.height(); y++)
-            {
-                unsigned char *line = img.scanLine(y);
-                for (x=(y%2); x<img.width(); x+=2)
+        unsigned char *line;
+        if(img.depth() == 8){
+            for(y=0; y<img.height(); y++){
+                line = img.scanLine(y);
+                for(x=(y%2); x<img.width(); x+=2)
                     line[x] = transColor;
             }
 	}
-        else
-        {
-            // SLOOW, but simple, as we would have to
-            // deal with endianess etc on our own here
-            for (y=0; y<img.height(); y++)
-                for (x=(y%2); x<img.width(); x+=2)
-                    img.setPixel(x, y, transColor);
+        else{
+            bool setOn = (transColor != 0);
+            if(img.format() == QImage::Format_MonoLSB){
+                for(y=0; y<img.height(); y++){
+                    line = img.scanLine(y);
+                    for(x=(y%2); x<img.width(); x+=2){
+                        if(!setOn)
+                            *(line + (x >> 3)) &= ~(1 << (x & 7));
+                        else
+                            *(line + (x >> 3)) |= (1 << (x & 7));
+                    }
+                }
+            }
+            else{
+                for(y=0; y<img.height(); y++){
+                    line = img.scanLine(y);
+                    for(x=(y%2); x<img.width(); x+=2){
+                        if(!setOn)
+                            *(line + (x >> 3)) &= ~(1 << (7-(x & 7)));
+                        else
+                            *(line + (x >> 3)) |= (1 << (7-(x & 7)));
+                    }
+                }
+            }
         }
     }
 }
@@ -560,7 +610,7 @@ void KIconEffect::semiTransparent(QPixmap &pix)
     pix.setMask(mask);
 }
 
-QImage KIconEffect::doublePixels(QImage src) const
+QImage KIconEffect::doublePixels(const QImage &src) const
 {
     int w = src.width();
     int h = src.height();
@@ -592,7 +642,8 @@ QImage KIconEffect::doublePixels(QImage src) const
 	for (x=0; x<src.numColors(); x++)
 	    dst.setColor(x, src.color(x));
 
-	unsigned char *l1, *l2;
+	const unsigned char *l1;
+	unsigned char *l2;
 	for (y=0; y<h; y++)
 	{
 	    l1 = src.scanLine(y);
@@ -620,11 +671,16 @@ void KIconEffect::overlay(QImage &src, QImage &overlay)
 	kDebug(265) << "Image size src != overlay\n";
 	return;
     }
+    if (src.format() == QImage::Format_ARGB32_Premultiplied)
+        src.convertToFormat(QImage::Format_ARGB32);
+
     if (overlay.format() == QImage::Format_RGB32)
     {
 	kDebug(265) << "Overlay doesn't have alpha buffer!\n";
 	return;
     }
+    else if (overlay.format() == QImage::Format_ARGB32_Premultiplied)
+        overlay.convertToFormat(QImage::Format_ARGB32);
 
     int i, j;
 
@@ -725,9 +781,9 @@ void KIconEffect::overlay(QImage &src, QImage &overlay)
     void
 KIconEffect::visualActivate(QWidget * widget, const QRect &rect)
 {
-#ifdef __GNUC__
     Q_UNUSED(widget);
     Q_UNUSED(rect);
+#ifdef __GNUC__
     #warning "visualActivate is stubbed out. Needs fixing (or better) replacement"
 #endif
 #if 0
@@ -761,7 +817,7 @@ KIconEffect::visualActivate(QWidget * widget, const QRect &rect)
 
     unsigned int actDelay = (1000 * (100 - actSpeed)) / actCount;
 
-    //kDebug() << "actCount=" << actCount << " actDelay=" << actDelay << endl;
+    //kDebug() << "actCount=" << actCount << " actDelay=" << actDelay;
 
     QPoint c = rect.center();
 
