@@ -4,15 +4,25 @@
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
  *                    Antonio Larrosa <larrosa@kde.org>
  *
- * This is free software; it comes under the GNU Library General
- * Public License, version 2. See the file "COPYING.LIB" for the
- * exact licensing terms.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License version 2 as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public License
+ * along with this library; see the file COPYING.LIB.  If not, write to
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef KICONLOADER_H
 #define KICONLOADER_H
 
-#include <qstring.h>
+#include <QtCore/QString>
 #include <QtCore/QObject>
 
 #include <kglobal.h>
@@ -26,7 +36,6 @@ class QPixmap;
 struct KIconGroup;
 class KIconThemeNode;
 class KComponentData;
-class KConfig;
 struct KIconLoaderPrivate;
 class KStandardDirs;
 class KIconEffect;
@@ -130,6 +139,9 @@ public:
      * @param state The icon state: @p DefaultState, @p ActiveState or
      * @p DisabledState. Depending on the user's preferences, the iconloader
      * may apply a visual effect to hint about its state.
+     * @param overlays a list of emblem icons to overlay, by name. the emblem
+     *                 prefix is applied automatically to each name, e.g.
+     *                 "zip" becomes "emblem-zip"
      * @param path_store If not null, the path of the icon is stored here.
      * @param canReturnNull Can return a null pixmap? If false, the
      * "unknown" pixmap is returned when no appropriate icon has been found.
@@ -137,8 +149,9 @@ public:
      *         @p canReturnNull.
      */
     QPixmap loadIcon(const QString& name, K3Icon::Group group, int size=0,
-		     int state=K3Icon::DefaultState, QString *path_store=0L,
-		     bool canReturnNull=false) const;
+                     int state=K3Icon::DefaultState, const QStringList &overlays = QStringList(),
+                     QString *path_store=0L,
+                     bool canReturnNull=false) const;
 
     /**
      * Loads an icon for a mimetype.
@@ -153,11 +166,15 @@ public:
      * @p DisabledState. Depending on the user's preferences, the iconloader
      * may apply a visual effect to hint about its state.
      * @param path_store If not null, the path of the icon is stored here.
+     * @param overlays a list of emblem icons to overlay, by name. the emblem
+     *                 prefix is applied automatically to each name, e.g.
+     *                 "zip" becomes "emblem-zip"
      * @return the QPixmap. Can not be null, the
      * "unknown" pixmap is returned when no appropriate icon has been found.
      */
     QPixmap loadMimeTypeIcon( const QString& iconName, K3Icon::Group group, int size=0,
-                              int state=K3Icon::DefaultState, QString *path_store=0 ) const;
+                              int state=K3Icon::DefaultState, const QStringList &overlays = QStringList(),
+                              QString *path_store=0 ) const;
 
     /**
      * Creates an icon set, that will do on-demand loading of the icon.
@@ -194,7 +211,7 @@ public:
      *         not found, depending on @p canReturnNull.
      */
     QString iconPath(const QString& name, int group_or_size,
-		     bool canReturnNull=false) const;
+                     bool canReturnNull=false) const;
 
     /**
      * Loads an animated icon.
@@ -255,7 +272,7 @@ public:
      * available for that context
      */
     QStringList queryIconsByContext(int group_or_size,
-				    K3Icon::Context context=K3Icon::Any) const;
+                                    K3Icon::Context context=K3Icon::Any) const;
 
     /**
      * @internal
@@ -338,6 +355,11 @@ public:
      */
     void init( const QString& _appname, KStandardDirs *_dirs );
 
+    /**
+     * @internal
+     */
+    bool initIconThemes();
+
     /**
      * @internal
      * tries to find an icon with the name. It tries some extension and
@@ -345,12 +367,6 @@ public:
      */
     K3Icon findMatchingIcon(const QString& name, int size) const;
 
-    /**
-     * @internal
-     * Loads and caches an overlay.
-     */
-    QImage *loadOverlay(const QString& name, int size) const;
-
     /**
      * @internal
      * Adds themes installed in the application's directory.
@@ -385,7 +401,7 @@ public:
  * Load a desktop icon.
  */
 KDEUI_EXPORT QPixmap DesktopIcon(const QString& name, int size=0,
-		    int state=K3Icon::DefaultState);
+                    int state=K3Icon::DefaultState, const QStringList& overlays = QStringList());
 
 /**
  * \relates KIconLoader
@@ -398,7 +414,8 @@ KDEUI_EXPORT_DEPRECATED QIcon DesktopIconSet(const QString& name, int size=0);
  * \relates KIconLoader
  * Load a toolbar icon.
  */
-KDEUI_EXPORT QPixmap BarIcon(const QString& name, int size=0, int state=K3Icon::DefaultState);
+KDEUI_EXPORT QPixmap BarIcon(const QString& name, int size=0, int state=K3Icon::DefaultState,
+                             const QStringList& overlays = QStringList());
 
 /**
  * \relates KIconLoader
@@ -412,7 +429,7 @@ KDEUI_EXPORT_DEPRECATED QIcon BarIconSet(const QString& name, int size=0);
  * Load a small icon.
  */
 KDEUI_EXPORT QPixmap SmallIcon(const QString& name, int size=0,
-		  int state=K3Icon::DefaultState);
+                  int state=K3Icon::DefaultState, const QStringList &overlays = QStringList());
 
 /**
  * \relates KIconLoader
@@ -426,7 +443,7 @@ KDEUI_EXPORT_DEPRECATED QIcon SmallIconSet(const QString& name, int size=0);
  * Load a main toolbar icon.
  */
 KDEUI_EXPORT QPixmap MainBarIcon(const QString& name, int size=0,
-		    int state=K3Icon::DefaultState);
+                    int state=K3Icon::DefaultState, const QStringList &overlays = QStringList());
 
 /**
  * \relates KIconLoader
@@ -439,7 +456,7 @@ KDEUI_EXPORT_DEPRECATED QIcon MainBarIconSet(const QString& name, int size=0);
  * \relates KIconLoader
  * Load a user icon. User icons are searched in $appdir/pics.
  */
-KDEUI_EXPORT QPixmap UserIcon(const QString& name, int state=K3Icon::DefaultState);
+KDEUI_EXPORT QPixmap UserIcon(const QString& name, int state=K3Icon::DefaultState, const QStringList &overlays = QStringList());
 
 /**
  * \relates KIconLoader
