@@ -1,50 +1,70 @@
 /* vi: ts=8 sts=4 sw=4
+ *
+ * kicontheme.cpp: Lowlevel icon theme handling.
  *
  * This file is part of the KDE project, module kdecore.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
  *                    Antonio Larrosa <larrosa@kde.org>
  *
- * This is free software; it comes under the GNU Library General
- * Public License, version 2. See the file "COPYING.LIB" for the
- * exact licensing terms.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License version 2 as published by the Free Software Foundation.
  *
- * kicontheme.cpp: Lowlevel icon theme handling.
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public License
+ * along with this library; see the file COPYING.LIB.  If not, write to
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
+#include "kicontheme.h"
+
 #include <sys/stat.h>
 #include <unistd.h>
 #include <stdlib.h>
 
 #include <QtGui/QAction>
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qmap.h>
-#include <qpixmap.h>
-#include <qpixmapcache.h>
-#include <qimage.h>
-#include <qfileinfo.h>
-#include <qdir.h>
+#include <QtCore/QCharRef>
+#include <QtCore/QMutableStringListIterator>
+#include <QtCore/QMap>
+#include <QtGui/QPixmap>
+#include <QtGui/QPixmapCache>
+#include <QtGui/QImage>
+#include <QtCore/QFileInfo>
+#include <QtCore/QDir>
 
 #include <kdebug.h>
 #include <kicon.h>
 #include <kstandarddirs.h>
 #include <kglobal.h>
+#include <ksharedconfig.h>
 #include <kconfig.h>
-#include <ksimpleconfig.h>
 #include <kcomponentdata.h>
 
-#include "kicontheme.h"
-#include "kstaticdeleter.h"
 #include <kconfiggroup.h>
 
-class KIconThemePrivate
+class KIconTheme::KIconThemePrivate
 {
 public:
     QString example, screenshot;
     QString linkOverlay, lockOverlay, zipOverlay, shareOverlay;
     bool hidden;
     KSharedConfig::Ptr sharedConfig;
+
+    int mDefSize[6];
+    QList<int> mSizes[6];
+
+    int mDepth;
+    QString mDir, mName, mInternalName, mDesc;
+    QStringList mInherits;
+    QList<KIconThemeDir *> mDirs;
 };
+K_GLOBAL_STATIC(QString, _theme)
+K_GLOBAL_STATIC(QStringList, _theme_list)
 
 /**
  * A subdirectory in an icon theme.
@@ -52,7 +72,7 @@ public:
 class KIconThemeDir
 {
 public:
-    KIconThemeDir(const QString& dir, const KConfigBase *config);
+    KIconThemeDir(const QString& dir, const KConfigGroup &config);
 
     bool isValid() const { return mbValid; }
     QString iconPath(const QString& name) const;
@@ -77,12 +97,31 @@ private:
 };
 
 
+/*** K3Icon ***/
+
+K3Icon::K3Icon()
+{
+    size = 0;
+}
+
+K3Icon::~K3Icon()
+{
+}
+
+bool K3Icon::isValid() const
+{
+    return size != 0;
+}
+
+
 /*** KIconTheme ***/
 
 KIconTheme::KIconTheme(const QString& name, const QString& appName)
     :d(new KIconThemePrivate)
 {
 
+    d->mInternalName = name;
+
     QStringList icnlibs;
     QStringList::ConstIterator it, itDir;
     QStringList themeDirs;
@@ -93,7 +132,7 @@ KIconTheme::KIconTheme(const QString& name, const QString& appName)
     // files are used..
 
     if (!appName.isEmpty() &&
-       ( name == "crystalsvg" || name== "hicolor" || name == "locolor" ) )
+       ( name == defaultThemeName() || name== "hicolor" || name == "locolor" ) )
     {
 	icnlibs = KGlobal::dirs()->resourceDirs("data");
 	for (it=icnlibs.begin(); it!=icnlibs.end(); ++it)
@@ -116,65 +155,63 @@ KIconTheme::KIconTheme(const QString& name, const QString& appName)
         if (KStandardDirs::exists(cDir))
         {
             themeDirs += cDir;
-	    if (mDir.isEmpty()
-		    && (KStandardDirs::exists( cDir + "index.desktop") || KStandardDirs::exists( cDir + "index.theme")))
-		mDir = cDir;
+            if (d->mDir.isEmpty() &&
+                (KStandardDirs::exists( cDir + "index.desktop") || KStandardDirs::exists( cDir + "index.theme")))
+                d->mDir = cDir;
         }
     }
 
-    if (mDir.isEmpty())
+    if (d->mDir.isEmpty())
     {
         kDebug(264) << "Icon theme " << name << " not found.\n";
         return;
     }
 
     QString fileName, mainSection;
-    if(QFile::exists(mDir + "index.desktop")) {
-	fileName = mDir + "index.desktop";
+    if(QFile::exists(d->mDir + "index.desktop")) {
+	fileName = d->mDir + "index.desktop";
 	mainSection="KDE Icon Theme";
     } else {
-	fileName = mDir + "index.theme";
+	fileName = d->mDir + "index.theme";
 	mainSection="Icon Theme";
     }
     // Use KSharedConfig to avoid parsing the file many times, from each kinstance.
     // Need to keep a ref to it to make this useful
-    d->sharedConfig = KSharedConfig::openConfig( fileName, true /*readonly*/, false /*useKDEGlobals*/ );
-    KConfig& cfg = *d->sharedConfig;
-    //was: KSimpleConfig cfg(fileName);
+    d->sharedConfig = KSharedConfig::openConfig( fileName );
 
-    cfg.setGroup(mainSection);
-    mName = cfg.readEntry("Name");
-    mDesc = cfg.readEntry("Comment");
-    mDepth = cfg.readEntry("DisplayDepth", 32);
-    mInherits = cfg.readEntry("Inherits", QStringList());
-    if ( name != "crystalsvg" )
-      for ( QStringList::Iterator it = mInherits.begin(); it != mInherits.end(); ++it )
-         if ( *it == "default" || *it == "hicolor" ) *it="crystalsvg";
+    KConfigGroup cfg(d->sharedConfig, mainSection);
+    d->mName = cfg.readEntry("Name");
+    d->mDesc = cfg.readEntry("Comment");
+    d->mDepth = cfg.readEntry("DisplayDepth", 32);
+    d->mInherits = cfg.readEntry("Inherits", QStringList());
+    if ( name != defaultThemeName() ) {
+      for ( QStringList::Iterator it = d->mInherits.begin(); it != d->mInherits.end(); ++it ) {
+         if ( *it == "default" || *it == "hicolor" ) {
+             *it = defaultThemeName();
+         }
+      }
+    }
 
     d->hidden = cfg.readEntry("Hidden", false);
     d->example = cfg.readPathEntry("Example");
     d->screenshot = cfg.readPathEntry("ScreenShot");
-    d->linkOverlay = cfg.readEntry("LinkOverlay", "link");
-    d->lockOverlay = cfg.readEntry("LockOverlay", "lock");
-    d->zipOverlay = cfg.readEntry("ZipOverlay", "zip");
-    d->shareOverlay = cfg.readEntry("ShareOverlay","share");
 
     QStringList dirs = cfg.readPathListEntry("Directories");
     for (it=dirs.begin(); it!=dirs.end(); ++it)
     {
-	cfg.setGroup(*it);
+        KConfigGroup cg(d->sharedConfig, *it);
 	for (itDir=themeDirs.begin(); itDir!=themeDirs.end(); ++itDir)
 	{
 	    if (KStandardDirs::exists(*itDir + *it + '/'))
 	    {
-	        KIconThemeDir *dir = new KIconThemeDir(*itDir + *it, &cfg);
+	        KIconThemeDir *dir = new KIconThemeDir(*itDir + *it, cg);
 	        if (!dir->isValid())
 	        {
 	            kDebug(264) << "Icon directory " << *itDir << " group " << *it << " not valid.\n";
 	            delete dir;
 	        }
 	        else
-	            mDirs.append(dir);
+	            d->mDirs.append(dir);
             }
         }
     }
@@ -182,7 +219,7 @@ KIconTheme::KIconTheme(const QString& name, const QString& appName)
     // Expand available sizes for scalable icons to their full range
     int i;
     QMap<int,QList<int> > scIcons;
-    foreach(KIconThemeDir *dir, mDirs)
+    foreach(KIconThemeDir *dir, d->mDirs)
     {
         if(!dir) break;
         if ((dir->type() == K3Icon::Scalable) && !scIcons.contains(dir->size()))
@@ -200,12 +237,13 @@ KIconTheme::KIconTheme(const QString& name, const QString& appName)
     groups += "MainToolbar";
     groups += "Small";
     groups += "Panel";
-    const int defDefSizes[] = { 32, 22, 22, 16, 32 };
-    cfg.setGroup(mainSection);
+    groups += "Dialog";
+    const int defDefSizes[] = { 32, 22, 22, 16, 32, 32 };
+    KConfigGroup cg(d->sharedConfig, mainSection);
     for (it=groups.begin(), i=0; it!=groups.end(); ++it, i++)
     {
-        mDefSize[i] = cfg.readEntry(*it + "Default", defDefSizes[i]);
-        QList<int> exp, lst = cfg.readEntry(*it + "Sizes", QList<int>());
+        d->mDefSize[i] = cg.readEntry(*it + "Default", defDefSizes[i]);
+        QList<int> exp, lst = cg.readEntry(*it + "Sizes", QList<int>());
         QList<int>::ConstIterator it2;
         for (it2=lst.begin(); it2!=lst.end(); ++it2)
         {
@@ -214,20 +252,55 @@ KIconTheme::KIconTheme(const QString& name, const QString& appName)
             else
                 exp += *it2;
         }
-        mSizes[i] = exp;
+        d->mSizes[i] = exp;
     }
 
 }
 
 KIconTheme::~KIconTheme()
 {
-    qDeleteAll(mDirs);
+    qDeleteAll(d->mDirs);
     delete d;
 }
 
+QString KIconTheme::name() const
+{
+    return d->mName;
+}
+
+QString KIconTheme::internalName() const
+{
+    return d->mInternalName;
+}
+
+QString KIconTheme::description() const
+{
+    return d->mDesc;
+}
+
+QString KIconTheme::example() const
+{
+    return d->example;
+}
+
+QString KIconTheme::screenshot() const
+{
+    return d->screenshot;
+}
+
+QString KIconTheme::dir() const
+{
+    return d->mDir;
+}
+
+QStringList KIconTheme::inherits() const
+{
+    return d->mInherits;
+}
+
 bool KIconTheme::isValid() const
 {
-    return !mDirs.isEmpty();
+    return !d->mDirs.isEmpty();
 }
 
 bool KIconTheme::isHidden() const
@@ -235,12 +308,10 @@ bool KIconTheme::isHidden() const
     return d->hidden;
 }
 
-QString KIconTheme::example() const { return d->example; }
-QString KIconTheme::screenshot() const { return d->screenshot; }
-QString KIconTheme::linkOverlay() const { return d->linkOverlay; }
-QString KIconTheme::lockOverlay() const { return d->lockOverlay; }
-QString KIconTheme::zipOverlay() const { return d->zipOverlay; }
-QString KIconTheme::shareOverlay() const { return d->shareOverlay; }
+int KIconTheme::depth() const
+{
+    return d->mDepth;
+}
 
 int KIconTheme::defaultSize(K3Icon::Group group) const
 {
@@ -249,7 +320,7 @@ int KIconTheme::defaultSize(K3Icon::Group group) const
         kDebug(264) << "Illegal icon group: " << group << "\n";
         return -1;
     }
-    return mDefSize[group];
+    return d->mDefSize[group];
 }
 
 QList<int> KIconTheme::querySizes(K3Icon::Group group) const
@@ -260,7 +331,7 @@ QList<int> KIconTheme::querySizes(K3Icon::Group group) const
         kDebug(264) << "Illegal icon group: " << group << "\n";
         return empty;
     }
-    return mSizes[group];
+    return d->mSizes[group];
 }
 
 QStringList KIconTheme::queryIcons(int size, K3Icon::Context context) const
@@ -271,9 +342,9 @@ QStringList KIconTheme::queryIcons(int size, K3Icon::Context context) const
 
     // Try to find exact match
     QStringList result;
-    for(int i=0; i<mDirs.size(); ++i)
+    for(int i=0; i<d->mDirs.size(); ++i)
     {
-        dir = mDirs.at(i);
+        dir = d->mDirs.at(i);
         if ((context != K3Icon::Any) && (context != dir->context()))
             continue;
         if ((dir->type() == K3Icon::Fixed) && (dir->size() == size))
@@ -296,10 +367,10 @@ QStringList KIconTheme::queryIcons(int size, K3Icon::Context context) const
 
     // Find close match
     KIconThemeDir *best = 0L;
-    for(int i=0; i<mDirs.size(); ++i)
+    for(int i=0; i<d->mDirs.size(); ++i)
     {
-        dir = mDirs.at(i);
-      if ((context != K3Icon::Any) && (context != dir->context()))
+        dir = d->mDirs.at(i);
+        if ((context != K3Icon::Any) && (context != dir->context()))
             continue;
         dw = dir->size() - size;
         if ((dw > 6) || (abs(dw) >= abs(delta)))
@@ -326,9 +397,9 @@ QStringList KIconTheme::queryIconsByContext(int size, K3Icon::Context context) c
     // 26 (48-22) and 32 (48-16) will be used, but who knows if someone
     // will make icon themes with different icon sizes.
 
-    for(int i=0;i<mDirs.size();++i)
+    for(int i=0;i<d->mDirs.size();++i)
     {
-        dir = mDirs.at(i);
+        dir = d->mDirs.at(i);
         if ((context != K3Icon::Any) && (context != dir->context()))
             continue;
         dw = abs(dir->size() - size);
@@ -343,7 +414,7 @@ QStringList KIconTheme::queryIconsByContext(int size, K3Icon::Context context) c
 
 bool KIconTheme::hasContext(K3Icon::Context context) const
 {
-    foreach(KIconThemeDir *dir, mDirs)
+    foreach(KIconThemeDir *dir, d->mDirs)
         if ((context == K3Icon::Any) || (context == dir->context()))
             return true;
     return false;
@@ -358,9 +429,9 @@ K3Icon KIconTheme::iconPath(const QString& name, int size, K3Icon::MatchType mat
 
     dw = 1000; // shut up, gcc
 
-    for(int i=0;i<mDirs.size();++i)
+    for(int i=0;i<d->mDirs.size();++i)
     {
-        dir = mDirs.at(i);
+        dir = d->mDirs.at(i);
 
         if (match == K3Icon::MatchExact)
         {
@@ -425,25 +496,15 @@ K3Icon KIconTheme::iconPath(const QString& name, int size, K3Icon::MatchType mat
     return icon;
 }
 
-// static
-QString *KIconTheme::_theme = 0L;
-static KStaticDeleter<QString> themeStaticDeleter;
-
-// static
-QStringList *KIconTheme::_theme_list = 0L;
-static KStaticDeleter<QStringList> themelistStaticDeleter;
-
 // static
 QString KIconTheme::current()
 {
     // Static pointer because of unloading problems wrt DSO's.
-    if (_theme != 0L)
+    if (!_theme->isEmpty())
         return *_theme;
 
-    themeStaticDeleter.setObject(_theme, new QString);
-
     KConfigGroup cg(KGlobal::config(), "Icons");
-    *_theme = cg.readEntry("Theme",defaultThemeName());
+    *_theme = cg.readEntry("Theme", defaultThemeName());
     if ( *_theme == QLatin1String("hicolor") ) *_theme = defaultThemeName();
 /*    if (_theme->isEmpty())
     {
@@ -459,10 +520,9 @@ QString KIconTheme::current()
 QStringList KIconTheme::list()
 {
     // Static pointer because of unloading problems wrt DSO's.
-    if (_theme_list != 0L)
+    if (!_theme_list->isEmpty())
         return *_theme_list;
 
-    themelistStaticDeleter.setObject(_theme_list, new QStringList);
     QStringList icnlibs = KGlobal::dirs()->resourceDirs("icon")
      << KGlobal::dirs()->resourceDirs("xdgdata-icon")
      << "/usr/share/pixmaps"
@@ -496,16 +556,15 @@ QStringList KIconTheme::list()
 // static
 void KIconTheme::reconfigure()
 {
-    delete _theme;
-    _theme=0L;
-    delete _theme_list;
-    _theme_list=0L;
+    _theme->clear();
+    _theme_list->clear();
+
 }
 
 // static
 QString KIconTheme::defaultThemeName()
 {
-    return QLatin1String("crystalsvg");
+    return QLatin1String("oxygen");
 }
 
 void KIconTheme::assignIconsToContextMenu( ContextMenus type,
@@ -519,12 +578,12 @@ void KIconTheme::assignIconsToContextMenu( ContextMenus type,
                 return;
             }
 
-            actions[UndoAct]->setIcon( KIcon("undo") );
-            actions[RedoAct]->setIcon( KIcon("redo") );
-            actions[CutAct]->setIcon( KIcon("editcut") );
-            actions[CopyAct]->setIcon( KIcon("editcopy") );
-            actions[PasteAct]->setIcon( KIcon("editpaste") );
-            actions[ClearAct]->setIcon( KIcon("editclear") );
+            actions[UndoAct]->setIcon( KIcon("edit-undo") );
+            actions[RedoAct]->setIcon( KIcon("edit-redo") );
+            actions[CutAct]->setIcon( KIcon("edit-cut") );
+            actions[CopyAct]->setIcon( KIcon("edit-copy") );
+            actions[PasteAct]->setIcon( KIcon("edit-paste") );
+            actions[ClearAct]->setIcon( KIcon("edit-clear") );
             break;
 
         case ReadOnlyText:
@@ -532,18 +591,18 @@ void KIconTheme::assignIconsToContextMenu( ContextMenus type,
                 return;
             }
 
-            actions[0]->setIcon( KIcon("editcopy") );
+            actions[0]->setIcon( KIcon("edit-copy") );
             break;
     }
 }
 
 /*** KIconThemeDir ***/
 
-KIconThemeDir::KIconThemeDir(const QString& dir, const KConfigBase *config)
+KIconThemeDir::KIconThemeDir(const QString& dir, const KConfigGroup &config)
 {
     mbValid = false;
     mDir = dir;
-    mSize = config->readEntry("Size", 0);
+    mSize = config.readEntry("Size", 0);
     mMinSize = 1;    // just set the variables to something
     mMaxSize = 50;   // meaningful in case someone calls minSize or maxSize
     mType = K3Icon::Fixed;
@@ -551,7 +610,7 @@ KIconThemeDir::KIconThemeDir(const QString& dir, const KConfigBase *config)
     if (mSize == 0)
         return;
 
-    QString tmp = config->readEntry("Context");
+    QString tmp = config.readEntry("Context");
     if (tmp == "Devices")
         mContext = K3Icon::Device;
     else if (tmp == "MimeTypes")
@@ -580,7 +639,7 @@ KIconThemeDir::KIconThemeDir(const QString& dir, const KConfigBase *config)
         kDebug(264) << "Invalid Context= line for icon theme: " << mDir << "\n";
         return;
     }
-    tmp = config->readEntry("Type");
+    tmp = config.readEntry("Type");
     if (tmp == "Fixed")
         mType = K3Icon::Fixed;
     else if (tmp == "Scalable")
@@ -588,15 +647,15 @@ KIconThemeDir::KIconThemeDir(const QString& dir, const KConfigBase *config)
     else if (tmp == "Threshold")
         mType = K3Icon::Threshold;
     else {
-        kDebug(264) << "Invalid Type= line for icon theme: " <<  mDir << "\n";
+        kDebug(264) << "Invalid Type= line for icon theme: " << mDir << "\n";
         return;
     }
     if (mType == K3Icon::Scalable)
     {
-        mMinSize = config->readEntry("MinSize", mSize);
-        mMaxSize = config->readEntry("MaxSize", mSize);
+        mMinSize = config.readEntry("MinSize", mSize);
+        mMaxSize = config.readEntry("MaxSize", mSize);
     } else if (mType == K3Icon::Threshold)
-	mThreshold = config->readEntry("Threshold", 2);
+	mThreshold = config.readEntry("Threshold", 2);
     mbValid = true;
 }
 
