@@ -18,6 +18,8 @@
    Boston, MA 02110-1301, USA.
 */
 
+#include "ktreewidgetsearchline.h"
+
 #include <QtCore/QList>
 #include <QtCore/QTimer>
 #include <QtGui/QApplication>
@@ -34,8 +36,6 @@
 #include <klocale.h>
 #include <ktoolbar.h>
 
-#include "ktreewidgetsearchline.h"
-
 class KTreeWidgetSearchLine::Private
 {
   public:
@@ -270,7 +270,7 @@ QTreeWidget *KTreeWidgetSearchLine::treeWidget() const
     return 0;
 }
 
-const QList<QTreeWidget *> &KTreeWidgetSearchLine::treeWidgets() const
+QList<QTreeWidget *> KTreeWidgetSearchLine::treeWidgets() const
 {
   return d->treeWidgets;
 }
@@ -585,6 +585,7 @@ void KTreeWidgetSearchLineWidget::createWidgets()
 
   QHBoxLayout* layout = new QHBoxLayout( this );
   layout->setSpacing( 5 );
+  layout->setMargin( 0 );
   layout->addWidget( label );
   layout->addWidget( d->searchLine );
 }
