@@ -18,32 +18,26 @@
     Boston, MA 02110-1301, USA.
         */
 
-#include "config.h"
-
-#undef QT_NO_TRANSLATION
-#include <qtranslator.h>
-#define QT_NO_TRANSLATION
-#include <qtextedit.h>
-#include <qdatetime.h>
-#include <qdir.h>
-#include <qfile.h>
-#include <qicon.h>
-#include <qlineedit.h>
-#include <qmessagebox.h>
-#include <qmetaobject.h>
-#include <qregexp.h>
-#include <qsessionmanager.h>
-#include <qstylefactory.h>
-#include <qtextstream.h>
-#include <qtimer.h>
-#include <qtooltip.h>
-#include <qwidget.h>
-#include <qlist.h>
-#include <QtDBus/QtDBus>
-
 #undef QT_NO_TRANSLATION
 #include "kapplication.h"
 #define QT_NO_TRANSLATION
+
+#include <config.h>
+
+#undef QT_NO_TRANSLATION
+#include <QtCore/QTranslator>
+#define QT_NO_TRANSLATION
+#include <QtCore/QDir>
+#include <QtCore/QFile>
+#include <QtGui/QIcon>
+#include <QtGui/QSessionManager>
+#include <QtGui/QStyleFactory>
+#include <QtCore/QTimer>
+#include <QtGui/QWidget>
+#include <QtCore/QList>
+#include <QtDBus/QtDBus>
+#include <QtCore/QMetaType>
+
 #include "kauthorized.h"
 #include "kaboutdata.h"
 #include "kcheckaccelerators.h"
@@ -55,12 +49,15 @@
 #include "kdebug.h"
 #include "kglobal.h"
 #include "kiconloader.h"
-#include "klibloader.h"
 #include "klocale.h"
 #include "ksessionmanager.h"
 #include "kstandarddirs.h"
 #include "kstandardshortcut.h"
 #include "ktoolinvocation.h"
+#include "kgesturemap.h"
+#include "kurl.h"
+#include "kmessage.h"
+#include "kmessageboxmessagehandler.h"
 
 #if defined Q_WS_X11
 #include <QtGui/qx11info_x11.h>
@@ -74,18 +71,12 @@
 #include <sys/wait.h>
 
 #ifndef Q_WS_WIN
-#include "kwin.h"
+#include "kwindowsystem.h"
 #endif
 
 #include <fcntl.h>
 #include <stdlib.h> // getenv(), srand(), rand()
-#include <signal.h>
 #include <unistd.h>
-#include <time.h>
-#include <sys/time.h>
-#include <errno.h>
-#include <string.h>
-#include <netdb.h>
 #if defined Q_WS_X11
 //#ifndef Q_WS_QWS //FIXME(E): NetWM should talk to QWS...
 #include <netwm.h>
@@ -113,10 +104,13 @@
 #include <QSystemTrayIcon>
 #endif
 
-#include <qevent.h>
-#include <QDesktopWidget>
-#include <QMetaObject>
+#ifdef Q_OS_UNIX
+#include <signal.h>
+#endif
+
+#include <QtGui/QActionEvent>
 #include <kcomponentdata.h>
+#include <klibloader.h>
 
 KApplication* KApplication::KApp = 0L;
 bool KApplication::loadedByKdeinit = false;
@@ -125,6 +119,7 @@ bool KApplication::loadedByKdeinit = false;
 static Atom atom_DesktopWindow;
 static Atom atom_NetSupported;
 static Atom kde_xdnd_drop;
+static QByteArray* startup_id_tmp;
 #endif
 
 // duplicated from patched Qt, so that there won't be unresolved symbols if Qt gets
@@ -152,6 +147,10 @@ static int kde_x_errhandler( Display *dpy, XErrorEvent *err )
 void KApplication_init_windows();
 #endif
 
+#ifdef Q_WS_MAC
+void KApplication_early_init_mac();
+#endif
+
 /*
   Private data to make keeping binary compatibility easier
  */
@@ -169,6 +168,8 @@ public:
       , oldXErrorHandler(0)
       , oldXIOErrorHandler(0)
 #endif
+      ,pSessionConfig( 0 )
+      ,bSessionManagement( true )
   {
   }
 
@@ -183,6 +184,8 @@ public:
       , oldXErrorHandler(0)
       , oldXIOErrorHandler(0)
 #endif
+      ,pSessionConfig( 0 )
+      ,bSessionManagement( true )
   {
   }
 
@@ -197,6 +200,8 @@ public:
       ,oldXErrorHandler( 0 )
       ,oldXIOErrorHandler( 0 )
 #endif
+      ,pSessionConfig( 0 )
+      ,bSessionManagement( true )
   {
   }
 
@@ -217,6 +222,9 @@ public:
 
   QString sessionKey;
   QString pSessionConfigFile;
+
+  KConfig* pSessionConfig; //instance specific application config object
+  bool bSessionManagement;
 };
 
 
@@ -323,34 +331,34 @@ static SmcConn mySmcConnection = 0;
 #endif
 
 KApplication::KApplication(bool GUIenabled)
-    : QApplication(KCmdLineArgs::qtArgc(), KCmdLineArgs::qtArgv(), GUIenabled),
+    : QApplication((preqapplicationhack(),KCmdLineArgs::qtArgc()), KCmdLineArgs::qtArgv(), GUIenabled),
     d(new Private)
 {
     read_app_startup_id();
-    setApplicationName(QLatin1String(d->componentData.componentName()));
-    setOrganizationDomain( KCmdLineArgs::about->organizationDomain() );
+    setApplicationName(d->componentData.componentName());
+    setOrganizationDomain(d->componentData.aboutData()->organizationDomain());
     installSigpipeHandler();
-    init();
+    init(GUIenabled);
 }
 
 #ifdef Q_WS_X11
 KApplication::KApplication(Display *dpy, Qt::HANDLE visual, Qt::HANDLE colormap)
-    : QApplication(dpy, KCmdLineArgs::qtArgc(), KCmdLineArgs::qtArgv(), visual, colormap),
+    : QApplication((preqapplicationhack(),dpy), KCmdLineArgs::qtArgc(), KCmdLineArgs::qtArgv(), visual, colormap),
     d(new Private)
 {
     read_app_startup_id();
-    setApplicationName(QLatin1String(d->componentData.componentName()));
-    setOrganizationDomain( KCmdLineArgs::about->organizationDomain() );
+    setApplicationName(d->componentData.componentName());
+    setOrganizationDomain(d->componentData.aboutData()->organizationDomain());
     installSigpipeHandler();
     init();
 }
 
 KApplication::KApplication(Display *dpy, Qt::HANDLE visual, Qt::HANDLE colormap, const KComponentData &cData)
-    : QApplication(dpy, KCmdLineArgs::qtArgc(), KCmdLineArgs::qtArgv(), visual, colormap),
+    : QApplication((preqapplicationhack(),dpy), KCmdLineArgs::qtArgc(), KCmdLineArgs::qtArgv(), visual, colormap),
     d (new Private(cData))
 {
     read_app_startup_id();
-    setApplicationName(QLatin1String(d->componentData.componentName()));
+    setApplicationName(d->componentData.componentName());
     setOrganizationDomain(d->componentData.aboutData()->organizationDomain());
     installSigpipeHandler();
     init();
@@ -358,11 +366,11 @@ KApplication::KApplication(Display *dpy, Qt::HANDLE visual, Qt::HANDLE colormap,
 #endif
 
 KApplication::KApplication(bool GUIenabled, const KComponentData &cData)
-    : QApplication(KCmdLineArgs::qtArgc(), KCmdLineArgs::qtArgv(), GUIenabled),
+    : QApplication((preqapplicationhack(),KCmdLineArgs::qtArgc()), KCmdLineArgs::qtArgv(), GUIenabled),
     d (new Private(cData))
 {
     read_app_startup_id();
-    setApplicationName(QLatin1String(d->componentData.componentName()));
+    setApplicationName(d->componentData.componentName());
     setOrganizationDomain(d->componentData.aboutData()->organizationDomain());
     installSigpipeHandler();
     init();
@@ -371,7 +379,7 @@ KApplication::KApplication(bool GUIenabled, const KComponentData &cData)
 #ifdef Q_WS_X11
 KApplication::KApplication(Display *display, int& argc, char** argv, const QByteArray& rAppName,
         bool GUIenabled)
-    : QApplication(display),
+    : QApplication((preqapplicationhack(),display)),
     d(new Private(rAppName))
 {
     Q_UNUSED(GUIenabled);
@@ -383,6 +391,13 @@ KApplication::KApplication(Display *display, int& argc, char** argv, const QByte
 }
 #endif
 
+// this function is called in KApplication ctors while evaluating arguments to QApplication ctor,
+// i.e. before QApplication ctor is called
+void KApplication::preqapplicationhack()
+{
+    preread_app_startup_id();
+}
+
 int KApplication::xioErrhandler( Display* dpy )
 {
     if(kapp)
@@ -407,6 +422,10 @@ int KApplication::xErrhandler( Display* dpy, void* err_ )
         // add KDE specific stuff here
         d->oldXErrorHandler( dpy, err );
     }
+    const QByteArray fatalXError = getenv("KDE_FATAL_X_ERROR");
+    if (!fatalXError.isEmpty()) {
+        abort();
+    }
 #endif
     return 0;
 }
@@ -438,7 +457,7 @@ public:
   }
 };
 
-void KApplication::init()
+void KApplication::init(bool GUIenabled)
 {
   if ((getuid() != geteuid()) ||
       (getgid() != getegid()))
@@ -447,6 +466,10 @@ void KApplication::init()
      ::exit(127);
   }
 
+#ifdef Q_WS_MAC
+  KApplication_early_init_mac();
+#endif
+
   if ( type() == GuiClient )
   {
     QStringList plugins = KGlobal::dirs()->resourceDirs( "qtplugins" );
@@ -461,7 +484,8 @@ void KApplication::init()
 
   parseCommandLine();
 
-  (void) KClipboardSynchronizer::self();
+  if(GUIenabled)
+    (void) KClipboardSynchronizer::self();
 
   extern KDECORE_EXPORT bool kde_kdebug_enable_dbus_interface;
   kde_kdebug_enable_dbus_interface = true;
@@ -499,12 +523,10 @@ void KApplication::init()
   qDBusBindToApplication();
   QDBusConnectionInterface *bus = 0;
   if (!QDBusConnection::sessionBus().isConnected() || !(bus = QDBusConnection::sessionBus().interface())) {
-      kFatal(101) << "Session bus not found" << endl;
-      ::exit(125);
   }
 
   extern bool s_kuniqueapplication_startCalled;
-  if ( !s_kuniqueapplication_startCalled ) // don't register again if KUniqueApplication did so already
+  if ( bus && !s_kuniqueapplication_startCalled ) // don't register again if KUniqueApplication did so already
   {
       QStringList parts = organizationDomain().split(QLatin1Char('.'), QString::SkipEmptyParts);
       QString reversedDomain;
@@ -552,17 +574,22 @@ void KApplication::init()
     // Trigger initial settings
     KGlobalSettings::self();
 
+    KMessage::setMessageHandler( new KMessageBoxMessageHandler(0) );
+
     d->checkAccelerators = new KCheckAccelerators( this );
+    KGestureMap::self()->installEventFilterOnMe( this );
 
     connect(KToolInvocation::self(), SIGNAL(kapplication_hook(QStringList&, QByteArray&)),
-            this, SLOT(slot_KToolInvication_hook(QStringList&,QByteArray&)));
+            this, SLOT(slot_KToolInvocation_hook(QStringList&,QByteArray&)));
+    connect(KLibLoader::self(), SIGNAL(kapplication_hook_clearClipboard()),
+            this, SLOT(slot_KLibLoader_hook_clearClipboard()));
   }
 
 #ifdef Q_WS_MAC
   if (type() == GuiClient) {
       QSystemTrayIcon *trayIcon;
       QPixmap pixmap = KIconLoader::global()->loadIcon( KCmdLineArgs::appName(),
-              K3Icon::NoGroup, K3Icon::SizeEnormous, K3Icon::DefaultState, 0L, false );
+              K3Icon::NoGroup, K3Icon::SizeEnormous, K3Icon::DefaultState, QStringList(), false );
       if (!pixmap.isNull() && QSystemTrayIcon::isSystemTrayAvailable())
       {
           trayIcon = new QSystemTrayIcon(this);
@@ -588,19 +615,24 @@ void KApplication::init()
       rtl = !rtl;
   setLayoutDirection( rtl ? Qt::RightToLeft:Qt::LeftToRight);
 
-  pSessionConfig = 0L;
-  bSessionManagement = true;
+  qRegisterMetaType<KUrl>();
+  qRegisterMetaType<KUrl::List>();
 
 #ifdef Q_WS_WIN
   KApplication_init_windows();
 #endif
 }
 
+KApplication* KApplication::kApplication()
+{
+    return KApp;
+}
+
 KConfig* KApplication::sessionConfig()
 {
-    if (!pSessionConfig) // create an instance specific config object
-        pSessionConfig = new KConfig( sessionConfigName(), false, false);
-    return pSessionConfig;
+    if (!d->pSessionConfig) // create an instance specific config object
+        d->pSessionConfig = new KConfig( sessionConfigName(), KConfig::NoGlobals );
+    return d->pSessionConfig;
 }
 
 void KApplication::reparseConfiguration()
@@ -614,11 +646,11 @@ void KApplication::quit()
 }
 
 void KApplication::disableSessionManagement() {
-  bSessionManagement = false;
+  d->bSessionManagement = false;
 }
 
 void KApplication::enableSessionManagement() {
-  bSessionManagement = true;
+  d->bSessionManagement = true;
 #ifdef Q_WS_X11
   // Session management support in Qt/KDE is awfully broken.
   // If konqueror disables session management right after its startup,
@@ -682,7 +714,7 @@ commitDataRestart:
         }
     }
 
-    if ( !bSessionManagement )
+    if ( !d->bSessionManagement )
         sm.setRestartHint( QSessionManager::RestartNever );
     else
         sm.setRestartHint( QSessionManager::RestartIfRunning );
@@ -696,7 +728,7 @@ void KApplication::saveState( QSessionManager& sm )
     static bool firstTime = true;
     mySmcConnection = (SmcConn) sm.handle();
 
-    if ( !bSessionManagement ) {
+    if ( !d->bSessionManagement ) {
         sm.setRestartHint( QSessionManager::RestartNever );
 	d->session_save = false;
         return;
@@ -716,9 +748,9 @@ void KApplication::saveState( QSessionManager& sm )
     // discard commands. In fact it would be harmful to remove the
     // file here, as the session might be stored under a different
     // name, meaning the user still might need it eventually.
-    if ( pSessionConfig ) {
-        delete pSessionConfig;
-        pSessionConfig = 0;
+    if ( d->pSessionConfig ) {
+        delete d->pSessionConfig;
+        d->pSessionConfig = 0;
     }
 
     // tell the session manager about our new lifecycle
@@ -752,8 +784,8 @@ void KApplication::saveState( QSessionManager& sm )
     }
 
     // if we created a new session config object, register a proper discard command
-    if ( pSessionConfig ) {
-        pSessionConfig->sync();
+    if ( d->pSessionConfig ) {
+        d->pSessionConfig->sync();
         QStringList discard;
         discard  << QLatin1String("rm") << KStandardDirs::locateLocal("config", sessionConfigName());
         sm.setDiscardCommand( discard );
@@ -778,17 +810,29 @@ void KApplication::parseCommandLine( )
 {
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs("kde");
 
+#ifdef Q_WS_X11
+    if (args && args->isSet("style"))
+    {
+        extern QString kde_overrideStyle; // see KGlobalSettings. Should we have a static setter?
+        QString reqStyle(args->getOption("style").toLower());
+        if (QStyleFactory::keys().contains(reqStyle, Qt::CaseInsensitive))
+            kde_overrideStyle = reqStyle;
+        else
+            qWarning() << i18n("The style '%1' was not found", reqStyle);
+    }
+#endif
+
     if ( type() != Tty ) {
         if (args && args->isSet("icon"))
         {
-            QPixmap largeIcon = DesktopIcon(QFile::decodeName(args->getOption("icon")));
+            QPixmap largeIcon = DesktopIcon(args->getOption("icon"));
             QIcon icon = windowIcon();
             icon.addPixmap(largeIcon, QIcon::Normal, QIcon::On);
             setWindowIcon(icon);
         }
         else {
             QIcon icon = windowIcon();
-            QPixmap largeIcon = DesktopIcon(QFile::decodeName(d->componentData.componentName()));
+            QPixmap largeIcon = DesktopIcon(d->componentData.componentName());
             icon.addPixmap(largeIcon, QIcon::Normal, QIcon::On);
             setWindowIcon(icon);
         }
@@ -799,26 +843,10 @@ void KApplication::parseCommandLine( )
 
     if (args->isSet("config"))
     {
-        QString config = QString::fromLocal8Bit(args->getOption("config"));
+        QString config = args->getOption("config");
         d->componentData.setConfigName(config);
     }
 
-    if (args->isSet("style"))
-    {
-        extern KDEUI_EXPORT QString kde_overrideStyle; // see KGlobalSettings. Should we have a static setter?
-        QStringList styles = QStyleFactory::keys();
-        QString reqStyle(QLatin1String(args->getOption("style").toLower()));
-
-        for (QStringList::ConstIterator it = styles.begin(); it != styles.end(); ++it)
-            if ((*it).toLower() == reqStyle) {
-                kde_overrideStyle = *it;
-                break;
-            }
-
-        if (kde_overrideStyle.isEmpty())
-            fprintf(stderr, "%s", i18n("The style %1 was not found\n", reqStyle).toLocal8Bit().data());
-    }
-
     bool nocrashhandler = (getenv("KDE_DEBUG") != NULL);
     if (!nocrashhandler && args->isSet("crashhandler"))
     {
@@ -826,7 +854,7 @@ void KApplication::parseCommandLine( )
         KCrash::setCrashHandler(KCrash::defaultCrashHandler);
         KCrash::setEmergencySaveFunction(NULL);
 
-        KCrash::setApplicationName(QLatin1String(args->appName()));
+        KCrash::setApplicationName(args->appName());
     }
 
 #ifdef Q_WS_X11
@@ -853,7 +881,7 @@ void KApplication::parseCommandLine( )
 
     if (args->isSet("smkey"))
     {
-        d->sessionKey = QLatin1String(args->getOption("smkey"));
+        d->sessionKey = args->getOption("smkey");
     }
 
 }
@@ -862,11 +890,6 @@ extern void kDebugCleanup();
 
 KApplication::~KApplication()
 {
-  // First call the static deleters and then call KLibLoader::cleanup()
-  // The static deleters may delete libraries for which they need KLibLoader.
-  // KLibLoader will take care of the remaining ones.
-  KGlobal::deleteStaticDeleters();
-
 #ifdef Q_WS_X11
   if ( d->oldXErrorHandler != NULL )
       XSetErrorHandler( d->oldXErrorHandler );
@@ -904,7 +927,9 @@ bool KApplication::x11EventFilter( XEvent *_event )
         case ClientMessage:
         {
 #if KDE_IS_VERSION( 3, 90, 90 )
+#ifdef __GNUC__
 #warning This should be already in Qt, check.
+#endif
 #endif
         // Workaround for focus stealing prevention not working when dragging e.g. text from KWrite
         // to KDesktop -> the dialog asking for filename doesn't get activated. This is because
@@ -995,7 +1020,7 @@ QString KApplication::tempSaveName( const QString& pFilename )
 
   if( QDir::isRelativePath(pFilename) )
     {
-      kWarning(101) << "Relative filename passed to KApplication::tempSaveName" << endl;
+      kWarning(101) << "Relative filename passed to KApplication::tempSaveName";
       aFilename = QFileInfo( QDir( QLatin1String(".") ), pFilename ).absoluteFilePath();
     }
   else
@@ -1027,7 +1052,7 @@ QString KApplication::checkRecoverFile( const QString& pFilename,
 
   if( QDir::isRelativePath(pFilename) )
     {
-      kWarning(101) << "Relative filename passed to KApplication::tempSaveName" << endl;
+      kWarning(101) << "Relative filename passed to KApplication::tempSaveName";
       aFilename = QFileInfo( QDir( QLatin1String(".") ), pFilename ).absoluteFilePath();
     }
   else
@@ -1106,19 +1131,36 @@ void KApplication::setStartupId( const QByteArray& startup_id )
         }
 }
 
+void KApplication::clearStartupId()
+{
+    d->startup_id = "0";
+}
+
+// Qt reads and unsets the value and doesn't provide any way to reach the value,
+// so steal it from it beforehand. If Qt gets API for taking (reading and unsetting)
+// the startup id from it, this can be dumped.
+void KApplication::preread_app_startup_id()
+{
+#if defined Q_WS_X11
+    KStartupInfoId id = KStartupInfo::currentStartupIdEnv();
+    KStartupInfo::resetStartupEnv();
+    startup_id_tmp = new QByteArray( id.id());
+#endif
+}
+
 // read the startup notification env variable, save it and unset it in order
 // not to propagate it to processes started from this app
 void KApplication::read_app_startup_id()
 {
 #if defined Q_WS_X11
-    KStartupInfoId id = KStartupInfo::currentStartupIdEnv();
-    KStartupInfo::resetStartupEnv();
-    d->startup_id = id.id();
+    d->startup_id = *startup_id_tmp;
+    delete startup_id_tmp;
+    startup_id_tmp = NULL;
 #endif
 }
 
 // Hook called by KToolInvocation
-void KApplication::slot_KToolInvication_hook(QStringList& envs,QByteArray& startup_id)
+void KApplication::slot_KToolInvocation_hook(QStringList& envs,QByteArray& startup_id)
 {
 #ifdef Q_WS_X11
     if (QX11Info::display()) {
@@ -1143,5 +1185,18 @@ void KApplication::setSynchronizeClipboard(bool synchronize)
     KClipboardSynchronizer::self()->setReverseSynchronizing(synchronize);
 }
 
+void KApplication::slot_KLibLoader_hook_clearClipboard()
+{
+    kDebug() ;
+    if( clipboard()->ownsSelection()) {
+	clipboard()->setText(
+            clipboard()->text( QClipboard::Selection ), QClipboard::Selection );
+    }
+    if( clipboard()->ownsClipboard()) {
+	clipboard()->setText(
+            clipboard()->text( QClipboard::Clipboard ), QClipboard::Clipboard );
+    }
+}
+
 #include "kapplication.moc"
 
