@@ -16,21 +16,10 @@
    Boston, MA 02110-1301, USA.
 */
 
-#include <config.h>
 #include "kglobalsettings.h"
+#include <config.h>
 
 #include <kconfig.h>
-#include <ksimpleconfig.h>
-
-#ifdef Q_WS_WIN
-#include <windows.h>
-#include "qt_windows.h"
-#include <win32_utils.h>
-static QRgb qt_colorref2qrgb(COLORREF col)
-{
-    return qRgb(GetRValue(col),GetGValue(col),GetBValue(col));
-}
-#endif
 
 #include <kdebug.h>
 #include <kglobal.h>
@@ -39,25 +28,37 @@ static QRgb qt_colorref2qrgb(COLORREF col)
 #include <klocale.h>
 #include <kprotocolinfo.h>
 #include <kcomponentdata.h>
-#include "kstaticdeleter.h"
+#include <kcolorscheme.h>
 
-#include <qcolor.h>
-#include <qcursor.h>
-#include <qdesktopwidget.h>
-#include <qdir.h>
-#include <qfont.h>
-#include <qfontdatabase.h>
-#include <qfontinfo.h>
-#include <qkeysequence.h>
-#include <qpixmap.h>
-#include <qpixmapcache.h>
+#include <QtGui/QColor>
+#include <QtGui/QCursor>
+#include <QtGui/QDesktopWidget>
+#include <QtCore/QDir>
+#include <QtGui/QFont>
+#include <QtGui/QFontDatabase>
+#include <QtGui/QFontInfo>
+#include <QtGui/QKeySequence>
+#include <QtGui/QPixmap>
+#include <QtGui/QPixmapCache>
 //#include <q3stylesheet.h> // no equivalent in Qt4
 #include <QApplication>
 #include <QtDBus/QtDBus>
-#include <qstylefactory.h>
+#include <QtGui/QStyleFactory>
 
+#ifdef Q_WS_WIN
+#include <windows.h>
+#include <kkernel_win.h>
+
+static QRgb qt_colorref2qrgb(COLORREF col)
+{
+    return qRgb(GetRValue(col),GetGValue(col),GetBValue(col));
+}
+#endif
 #ifdef Q_WS_X11
 #include <X11/Xlib.h>
+#ifdef HAVE_XCURSOR
+#include <X11/Xcursor/Xcursor.h>
+#endif
 #include "fixx11h.h"
 #include <QX11Info>
 #endif
@@ -65,33 +66,27 @@ static QRgb qt_colorref2qrgb(COLORREF col)
 #include <stdlib.h>
 #include <kconfiggroup.h>
 
-QString* KGlobalSettings::s_desktopPath = 0;
-QString* KGlobalSettings::s_autostartPath = 0;
-QString* KGlobalSettings::s_documentPath = 0;
-QFont *KGlobalSettings::_generalFont = 0;
-QFont *KGlobalSettings::_fixedFont = 0;
-QFont *KGlobalSettings::_toolBarFont = 0;
-QFont *KGlobalSettings::_menuFont = 0;
-QFont *KGlobalSettings::_windowTitleFont = 0;
-QFont *KGlobalSettings::_taskbarFont = 0;
-QFont *KGlobalSettings::_largeFont = 0;
-QColor *KGlobalSettings::_kde34Blue = 0;
-QColor *KGlobalSettings::_inactiveBackground = 0;
-QColor *KGlobalSettings::_inactiveForeground = 0;
-QColor *KGlobalSettings::_activeBackground = 0;
-QColor *KGlobalSettings::_buttonBackground = 0;
-QColor *KGlobalSettings::_selectBackground = 0;
-QColor *KGlobalSettings::_linkColor = 0;
-QColor *KGlobalSettings::_visitedLinkColor = 0;
-QColor *KGlobalSettings::alternateColor = 0;
+static QString* s_desktopPath = 0;
+static QString* s_autostartPath = 0;
+static QString* s_documentPath = 0;
+static QFont *_generalFont = 0;
+static QFont *_fixedFont = 0;
+static QFont *_toolBarFont = 0;
+static QFont *_menuFont = 0;
+static QFont *_windowTitleFont = 0;
+static QFont *_taskbarFont = 0;
+static QFont *_largeFont = 0;
+static QFont *_smallestReadableFont = 0;
+static QColor *_inactiveBackground = 0;
+static QColor *_inactiveForeground = 0;
+static QColor *_activeBackground = 0;
+//static QColor *_buttonBackground = 0;
 
-KGlobalSettings::KMouseSettings *KGlobalSettings::s_mouseSettings = 0;
-static KGlobalSettings* s_self = 0;
-static KStaticDeleter<KGlobalSettings> s_kglobalSettingsDeleter;
+static KGlobalSettings::KMouseSettings *s_mouseSettings = 0;
 
-KGlobalSettings* KGlobalSettings::self() {
-    if (!s_self)
-        s_kglobalSettingsDeleter.setObject(s_self, new KGlobalSettings);
+KGlobalSettings* KGlobalSettings::self()
+{
+    K_GLOBAL_STATIC(KGlobalSettings, s_self)
     return s_self;
 }
 
@@ -207,9 +202,7 @@ int KGlobalSettings::contextMenuKey ()
 
 QColor KGlobalSettings::toolBarHighlightColor()
 {
-    initColors();
-    KConfigGroup g( KGlobal::config(), "Toolbar style" );
-    return g.readEntry("HighlightColor", *_kde34Blue);
+    return KColorScheme(QPalette::Active, KColorScheme::Button).decoration(KColorScheme::HoverColor).color();
 }
 
 QColor KGlobalSettings::inactiveTitleColor()
@@ -241,7 +234,6 @@ QColor KGlobalSettings::activeTitleColor()
 #ifdef Q_WS_WIN
     return qt_colorref2qrgb(GetSysColor(COLOR_ACTIVECAPTION));
 #else
-    initColors();
     if (!_activeBackground)
       _activeBackground = new QColor(65,142,220);
     KConfigGroup g( KGlobal::config(), "WM" );
@@ -255,7 +247,7 @@ QColor KGlobalSettings::activeTextColor()
     return qt_colorref2qrgb(GetSysColor(COLOR_CAPTIONTEXT));
 #else
     KConfigGroup g( KGlobal::config(), "WM" );
-    return g.readEntry( "activeForeground", Qt::white );
+    return g.readEntry( "activeForeground", QColor(Qt::white) );
 #endif
 }
 
@@ -265,65 +257,48 @@ int KGlobalSettings::contrast()
     return g.readEntry( "contrast", 7 );
 }
 
+qreal KGlobalSettings::contrastF(const KSharedConfigPtr &config)
+{
+    if (config) {
+        KConfigGroup g( config, "KDE" );
+        return 0.1 * g.readEntry( "contrast", 7 );
+    }
+    return 0.1 * (qreal)contrast();
+}
+
 QColor KGlobalSettings::buttonBackground()
 {
-    if (!_buttonBackground)
-      _buttonBackground = new QColor(221,223,228);
-    KConfigGroup g( KGlobal::config(), "General" );
-    return g.readEntry( "buttonBackground", *_buttonBackground );
+    return KColorScheme(QPalette::Active, KColorScheme::Button).background().color();
 }
 
 QColor KGlobalSettings::buttonTextColor()
 {
-    KConfigGroup g( KGlobal::config(), "General" );
-    return g.readEntry( "buttonForeground", Qt::black );
+    return KColorScheme(QPalette::Active, KColorScheme::Button).foreground().color();
 }
 
-// IMPORTANT:
-//  This function should be get in sync with
-//   KGlobalSettings::kdisplaySetPalette()
 QColor KGlobalSettings::baseColor()
 {
-    KConfigGroup g( KGlobal::config(), "General" );
-    return g.readEntry( "windowBackground", Qt::white );
+    return KColorScheme(QPalette::Active, KColorScheme::View).background().color();
 }
 
-// IMPORTANT:
-//  This function should be get in sync with
-//   KGlobalSettings::kdisplaySetPalette()
 QColor KGlobalSettings::textColor()
 {
-    KConfigGroup g( KGlobal::config(), "General" );
-    return g.readEntry( "windowForeground", Qt::black );
+    return KColorScheme(QPalette::Active, KColorScheme::View).foreground().color();
 }
 
-// IMPORTANT:
-//  This function should be get in sync with
-//   KGlobalSettings::kdisplaySetPalette()
 QColor KGlobalSettings::highlightedTextColor()
 {
-    KConfigGroup g( KGlobal::config(), "General" );
-    return g.readEntry( "selectForeground", Qt::white );
+    return KColorScheme(QPalette::Active, KColorScheme::Selection).foreground().color();
 }
 
-// IMPORTANT:
-//  This function should be get in sync with
-//   KGlobalSettings::kdisplaySetPalette()
 QColor KGlobalSettings::highlightColor()
 {
-    initColors();
-    if (!_selectBackground)
-        _selectBackground = new QColor(103,141,178);
-    KConfigGroup g( KGlobal::config(), "General" );
-    return g.readEntry( "selectBackground", *_selectBackground );
+    return KColorScheme(QPalette::Active, KColorScheme::Selection).background().color();
 }
 
 QColor KGlobalSettings::alternateBackgroundColor()
 {
-    initColors();
-    KConfigGroup g( KGlobal::config(), "General" );
-    *alternateColor = calculateAlternateBackgroundColor( baseColor() );
-    return g.readEntry( "alternateBackground", *alternateColor );
+    return KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::AlternateBackground).color();
 }
 
 QColor KGlobalSettings::calculateAlternateBackgroundColor(const QColor& base)
@@ -349,21 +324,20 @@ bool KGlobalSettings::shadeSortColumn()
     return g.readEntry( "shadeSortColumn", KDE_DEFAULT_SHADE_SORT_COLUMN );
 }
 
+bool KGlobalSettings::allowDefaultBackgroundImages()
+{
+    KConfigGroup g( KGlobal::config(), "General" );
+    return g.readEntry( "allowDefaultBackgroundImages", KDE_DEFAULT_ALLOW_DEFAULT_BACKGROUND_IMAGES );
+}
+
 QColor KGlobalSettings::linkColor()
 {
-    initColors();
-    if (!_linkColor)
-        _linkColor = new QColor(0,0,238);
-    KConfigGroup g( KGlobal::config(), "General" );
-    return g.readEntry( "linkColor", *_linkColor );
+    return KColorScheme(QPalette::Active, KColorScheme::View).foreground(KColorScheme::LinkText).color();
 }
 
 QColor KGlobalSettings::visitedLinkColor()
 {
-    if (!_visitedLinkColor)
-        _visitedLinkColor = new QColor(82,24,139);
-    KConfigGroup g( KGlobal::config(), "General" );
-    return g.readEntry( "visitedLinkColor", *_visitedLinkColor );
+    return KColorScheme(QPalette::Active, KColorScheme::View).foreground(KColorScheme::VisitedText).color();
 }
 
 QFont KGlobalSettings::generalFont()
@@ -541,6 +515,22 @@ QFont KGlobalSettings::largeFont(const QString &text)
     return *_largeFont;
 }
 
+QFont KGlobalSettings::smallestReadableFont()
+{
+    if(_smallestReadableFont)
+        return *_smallestReadableFont;
+
+    // Sync default with kdebase/kcontrol/fonts/fonts.cpp
+    _smallestReadableFont = new QFont("Sans Serif", 8);
+    _smallestReadableFont->setPointSize(8);
+    _smallestReadableFont->setStyleHint(QFont::SansSerif);
+
+    KConfigGroup g( KGlobal::config(), "General" );
+    *_smallestReadableFont = g.readEntry("smallestReadableFont", *_smallestReadableFont);
+
+    return *_smallestReadableFont;
+}
+
 void KGlobalSettings::initPaths()
 {
     //this code is duplicated in kde_config.cpp.in
@@ -560,15 +550,17 @@ void KGlobalSettings::initPaths()
     *s_desktopPath = QDir::homePath() + "/Desktop/";
     *s_desktopPath = g.readPathEntry( "Desktop", *s_desktopPath);
     *s_desktopPath = QDir::cleanPath( *s_desktopPath );
-    if ( !s_desktopPath->endsWith("/") )
-      s_desktopPath->append(QLatin1Char('/'));
+    if ( !s_desktopPath->endsWith('/') ) {
+        s_desktopPath->append( QLatin1Char( '/' ) );
+    }
 
     // Autostart Path
     *s_autostartPath = KGlobal::dirs()->localkdedir() + "Autostart/";
     *s_autostartPath = g.readPathEntry( "Autostart" , *s_autostartPath);
     *s_autostartPath = QDir::cleanPath( *s_autostartPath );
-    if ( !s_autostartPath->endsWith("/") )
-      s_autostartPath->append(QLatin1Char('/'));
+    if ( !s_autostartPath->endsWith('/') ) {
+        s_autostartPath->append( QLatin1Char( '/' ) );
+    }
 
     // Document Path
     *s_documentPath = g.readPathEntry( "Documents",
@@ -579,20 +571,9 @@ void KGlobalSettings::initPaths()
 #endif
     );
     *s_documentPath = QDir::cleanPath( *s_documentPath );
-    if ( !s_documentPath->endsWith("/"))
-      s_documentPath->append(QLatin1Char('/'));
-}
-
-void KGlobalSettings::initColors()
-{
-    if (!_kde34Blue) {
-      if (QPixmap::defaultDepth() > 8)
-        _kde34Blue = new QColor(103,141,178);
-      else
-        _kde34Blue = new QColor(0, 0, 192);
+    if ( !s_documentPath->endsWith('/')) {
+        s_documentPath->append( QLatin1Char( '/' ) );
     }
-    if (!alternateColor)
-      alternateColor = new QColor(237, 244, 249);
 }
 
 void KGlobalSettings::rereadFontSettings()
@@ -609,11 +590,12 @@ void KGlobalSettings::rereadFontSettings()
     _windowTitleFont = 0L;
     delete _taskbarFont;
     _taskbarFont = 0L;
+    delete _smallestReadableFont;
+    _smallestReadableFont = 0L;
 }
 
 void KGlobalSettings::rereadPathSettings()
 {
-    kDebug() << "KGlobalSettings::rereadPathSettings" << endl;
     delete s_autostartPath;
     s_autostartPath = 0L;
     delete s_desktopPath;
@@ -680,6 +662,24 @@ void KGlobalSettings::rereadMouseSettings()
 #endif
 }
 
+QString KGlobalSettings::desktopPath()
+{
+    initPaths();
+    return *s_desktopPath;
+}
+
+QString KGlobalSettings::autostartPath()
+{
+    initPaths();
+    return *s_autostartPath;
+}
+
+QString KGlobalSettings::documentPath()
+{
+    initPaths();
+    return *s_documentPath;
+}
+
 bool KGlobalSettings::isMultiHead()
 {
 #ifdef Q_WS_WIN
@@ -735,7 +735,7 @@ QRect KGlobalSettings::desktopGeometry(const QPoint& point)
     }
 }
 
-QRect KGlobalSettings::desktopGeometry(QWidget* w)
+QRect KGlobalSettings::desktopGeometry(const QWidget* w)
 {
     QDesktopWidget *dw = QApplication::desktop();
 
@@ -832,6 +832,10 @@ void KGlobalSettings::slotNotifyChange(int changeType, int arg)
         emit iconChanged(arg);
         break;
 
+    case CursorChanged:
+        applyCursorTheme();
+        break;
+
     case BlockShortcuts:
         // FIXME KAccel port
         //KGlobalAccel::blockShortcuts(arg);
@@ -839,22 +843,19 @@ void KGlobalSettings::slotNotifyChange(int changeType, int arg)
         break;
 
     default:
-        kWarning(101) << "Unknown type of change in KGlobalSettings::slotNotifyChange: " << changeType << endl;
+        kWarning(101) << "Unknown type of change in KGlobalSettings::slotNotifyChange: " << changeType;
     }
 }
 
 // Set by KApplication - which is now in kdeui so this needs to be exported
 // In the long run, KGlobalSettings probably belongs to kdeui as well...
-KDEUI_EXPORT QString kde_overrideStyle;
+QString kde_overrideStyle;
 
 void KGlobalSettings::applyGUIStyle()
 {
+#ifdef Q_WS_X11
     KConfigGroup pConfig (KGlobal::config(), "General");
-#ifdef Q_WS_MACX
-    QString defaultStyle = "macintosh";
-#else
     QString defaultStyle = QLatin1String("plastique");// = KStyle::defaultStyle(); ### wait for KStyle4
-#endif
     QString styleStr = pConfig.readEntry("widgetStyle", defaultStyle);
 
     if (kde_overrideStyle.isEmpty()) {
@@ -874,105 +875,42 @@ void KGlobalSettings::applyGUIStyle()
         qApp->setStyle(kde_overrideStyle);
     // Reread palette from config file.
     kdisplaySetPalette();
+#endif
 }
 
-QPalette KGlobalSettings::createApplicationPalette()
+QPalette KGlobalSettings::createApplicationPalette(const KSharedConfigPtr &config)
 {
-    KConfigGroup cg( KGlobal::config(), "General" );
-    return createApplicationPalette( &cg, KGlobalSettings::contrast() );
-}
-
-QPalette KGlobalSettings::createApplicationPalette( KConfigBase *config, int contrast_ )
-{
-    QColor kde34Background( 239, 239, 239 );
-    QColor kde34Blue( 103,141,178 );
-
-    QColor kde34Button;
-    if ( QPixmap::defaultDepth() > 8 )
-      kde34Button.setRgb( 221, 223, 228 );
-    else
-      kde34Button.setRgb( 220, 220, 220 );
-
-    QColor kde34Link( 0, 0, 238 );
-    QColor kde34VisitedLink( 82, 24, 139 );
-
-    QColor background = config->readEntry( "background", kde34Background );
-    QColor foreground = config->readEntry( "foreground", Qt::black );
-    QColor button = config->readEntry( "buttonBackground", kde34Button );
-    QColor buttonText = config->readEntry( "buttonForeground", Qt::black );
-    QColor highlight = config->readEntry( "selectBackground", kde34Blue );
-    QColor highlightedText = config->readEntry( "selectForeground", Qt::white );
-    QColor base = config->readEntry( "windowBackground", Qt::white );
-    QColor baseText = config->readEntry( "windowForeground", Qt::black );
-    QColor link = config->readEntry( "linkColor", kde34Link );
-    QColor visitedLink = config->readEntry( "visitedLinkColor", kde34VisitedLink );
-
-    int highlightVal, lowlightVal;
-    highlightVal = 100 + (2*contrast_+4)*16/10;
-    lowlightVal = 100 + (2*contrast_+4)*10;
-
-    QColor disfg = foreground;
-
-    int h, s, v;
-    disfg.getHsv( &h, &s, &v );
-    if (v > 128)
-        // dark bg, light fg - need a darker disabled fg
-        disfg = disfg.dark(lowlightVal);
-    else if (disfg != Qt::black)
-        // light bg, dark fg - need a lighter disabled fg - but only if !black
-        disfg = disfg.light(highlightVal);
-    else
-        // black fg - use darkgray disabled fg
-        disfg = Qt::darkGray;
-
     QPalette palette;
-    palette.setColor( QPalette::Foreground, foreground );
-    palette.setColor( QPalette::Window, background );
-    palette.setColor( QPalette::Light, background.light( highlightVal ) );
-    palette.setColor( QPalette::Dark, background.dark( lowlightVal ) );
-    palette.setColor( QPalette::Midlight, background.dark( 120 ) );
-    palette.setColor( QPalette::Text, baseText );
-    palette.setColor( QPalette::Base, base );
 
-    palette.setColor( QPalette::Highlight, highlight );
-    palette.setColor( QPalette::HighlightedText, highlightedText );
-    palette.setColor( QPalette::Button, button );
-    palette.setColor( QPalette::ButtonText, buttonText );
-    palette.setColor( QPalette::Midlight, background.light( 110 ) );
-    palette.setColor( QPalette::Link, link );
-    palette.setColor( QPalette::LinkVisited, visitedLink );
+    QPalette::ColorGroup states[3] = { QPalette::Active, QPalette::Inactive,
+                                       QPalette::Disabled };
 
-    palette.setColor( QPalette::Disabled, QPalette::Foreground, disfg );
-    palette.setColor( QPalette::Disabled, QPalette::Window, background );
-    palette.setColor( QPalette::Disabled, QPalette::Light, background.light( highlightVal ) );
-    palette.setColor( QPalette::Disabled, QPalette::Dark, background.dark( lowlightVal ) );
-    palette.setColor( QPalette::Disabled, QPalette::Midlight, background.dark( 120 ) );
-    palette.setColor( QPalette::Disabled, QPalette::Text, background.dark( 120 ) );
-    palette.setColor( QPalette::Disabled, QPalette::Base, base );
-    palette.setColor( QPalette::Disabled, QPalette::Button, button );
+    for ( int i = 0; i < 3 ; i++ ) {
+        QPalette::ColorGroup state = states[i];
+        KColorScheme schemeView(state, KColorScheme::View, config);
+        KColorScheme schemeWindow(state, KColorScheme::Window, config);
+        KColorScheme schemeButton(state, KColorScheme::Button, config);
+        KColorScheme schemeSelection(state, KColorScheme::Selection, config);
 
+        palette.setBrush( state, QPalette::WindowText, schemeWindow.foreground() );
+        palette.setBrush( state, QPalette::Window, schemeWindow.background() );
+        palette.setBrush( state, QPalette::Base, schemeView.background() );
+        palette.setBrush( state, QPalette::Text, schemeView.foreground() );
+        palette.setBrush( state, QPalette::Button, schemeButton.background() );
+        palette.setBrush( state, QPalette::ButtonText, schemeButton.foreground() );
+        palette.setBrush( state, QPalette::Highlight, schemeSelection.background() );
+        palette.setBrush( state, QPalette::HighlightedText, schemeSelection.foreground() );
 
-    int inlowlightVal = lowlightVal-25;
-    if (inlowlightVal < 120)
-        inlowlightVal = 120;
+        palette.setColor( state, QPalette::Light, schemeWindow.shade( KColorScheme::LightShade ) );
+        palette.setColor( state, QPalette::Midlight, schemeWindow.shade( KColorScheme::MidlightShade ) );
+        palette.setColor( state, QPalette::Mid, schemeWindow.shade( KColorScheme::MidShade ) );
+        palette.setColor( state, QPalette::Dark, schemeWindow.shade( KColorScheme::DarkShade ) );
+        palette.setColor( state, QPalette::Shadow, schemeWindow.shade( KColorScheme::ShadowShade ) );
 
-    QColor disbtntext = buttonText;
-    disbtntext.getHsv( &h, &s, &v );
-    if (v > 128)
-        // dark button, light buttonText - need a darker disabled buttonText
-        disbtntext = disbtntext.dark(lowlightVal);
-    else if (disbtntext != Qt::black)
-        // light buttonText, dark button - need a lighter disabled buttonText - but only if !black
-        disbtntext = disbtntext.light(highlightVal);
-    else
-        // black button - use darkgray disabled buttonText
-        disbtntext = Qt::darkGray;
-
-    palette.setColor( QPalette::Disabled, QPalette::Highlight, highlight.dark( 120 ) );
-    palette.setColor( QPalette::Disabled, QPalette::ButtonText, disbtntext );
-    palette.setColor( QPalette::Disabled, QPalette::Midlight, background.light( 110 ) );
-    palette.setColor( QPalette::Disabled, QPalette::Link, link );
-    palette.setColor( QPalette::Disabled, QPalette::LinkVisited, visitedLink );
+        palette.setBrush( state, QPalette::AlternateBase, schemeView.background( KColorScheme::AlternateBackground) );
+        palette.setBrush( state, QPalette::Link, schemeView.foreground( KColorScheme::LinkText ) );
+        palette.setBrush( state, QPalette::LinkVisited, schemeView.foreground( KColorScheme::VisitedText ) );
+    }
 
     return palette;
 }
@@ -1000,6 +938,7 @@ void KGlobalSettings::kdisplaySetFont()
         QApplication::setFont(KGlobalSettings::menuFont(), "QMenuBar");
         QApplication::setFont(KGlobalSettings::menuFont(), "QPopupMenu");
         QApplication::setFont(KGlobalSettings::menuFont(), "KPopupTitle");
+        QApplication::setFont(smallestReadableFont(), "QDockWidget");
 
 #if 0
         // "patch" standard QStyleSheet to follow our fonts
@@ -1026,6 +965,35 @@ void KGlobalSettings::kdisplaySetStyle()
 }
 
 
+void KGlobalSettings::applyCursorTheme()
+{
+#if defined(Q_WS_X11) && defined(HAVE_XCURSOR)
+    KConfig config("kcminputrc");
+    KConfigGroup g(&config, "Mouse");
+
+    QString theme = g.readEntry("cursorTheme", QString());
+    int size      = g.readEntry("cursorSize", -1);
+
+    // Default cursor size is 16 points
+    if (size == -1)
+    {
+        QApplication *app = static_cast<QApplication*>(QApplication::instance());
+        size = app->desktop()->screen(0)->logicalDpiY() * 16 / 72;
+    }
+
+    // Note that in X11R7.1 and earlier, calling XcursorSetTheme()
+    // with a NULL theme would cause Xcursor to use "default", but
+    // in 7.2 and later it will cause it to revert to the theme that
+    // was configured when the application was started.
+    XcursorSetTheme(QX11Info::display(), theme.isNull() ?
+                    "default" : QFile::encodeName(theme));
+    XcursorSetDefaultSize(QX11Info::display(), size);
+
+    emit cursorChanged();
+#endif
+}
+
+
 void KGlobalSettings::propagateSettings(SettingsCategory arg)
 {
     KConfigGroup cg( KGlobal::config(), "KDE" );
