@@ -18,7 +18,8 @@
 #ifndef _KGLOBALSETTINGS_H
 #define _KGLOBALSETTINGS_H
 
-#include "kdelibs_export.h"
+#include <kdeui_export.h>
+#include <ksharedconfig.h>
 #include <QtCore/QObject>
 #include <QtCore/QString>
 #include <QtGui/QPalette>
@@ -35,6 +36,7 @@
 #define KDE_DEFAULT_OPAQUE_RESIZE true
 #define KDE_DEFAULT_BUTTON_LAYOUT 0
 #define KDE_DEFAULT_SHADE_SORT_COLUMN true
+#define KDE_DEFAULT_ALLOW_DEFAULT_BACKGROUND_IMAGES true
 
 class KConfigBase;
 class KUrl;
@@ -48,7 +50,7 @@ class QWidget;
 /**
  * Access the KDE global configuration.
  *
- * @author David Faure <faure@kde.org>
+ * @author David Faure \<faure@kde.org\>
  */
 class KDEUI_EXPORT KGlobalSettings : public QObject
 {
@@ -229,26 +231,32 @@ public:
      * The path to the desktop directory of the current user.
      * @return the user's desktop directory
      */
-    static QString desktopPath() { initPaths(); return *s_desktopPath; }
+    static QString desktopPath();
 
     /**
      * The path to the autostart directory of the current user.
      * @return the path of the autostart directory
      */
-    static QString autostartPath() { initPaths(); return *s_autostartPath; }
+    static QString autostartPath();
 
     /**
      * The path where documents are stored of the current user.
      * @return the path of the document directory
      */
-    static QString documentPath() { initPaths(); return *s_documentPath; }
+    static QString documentPath();
 
 
     /**
      * The default color to use when highlighting toolbar buttons.
      * @return the toolbar highlight color
+     * @deprecated use KColorScheme(Button).decoration(HoverColor) instead.
+     * Color accessors in KGlobalSettings are broken because they do not take
+     * widget state into account. KColorScheme fixes this, as well as offering
+     * access to the full range of new color roles in KDE4. Note that each
+     * color set now provides its own colors to be used for focus and hover
+     * effects.
      */
-    static QColor toolBarHighlightColor();
+    static KDE_DEPRECATED QColor toolBarHighlightColor();
 
     /**
      * The default color to use for inactive titles.
@@ -281,67 +289,119 @@ public:
      */
     static int contrast();
 
+    /**
+     * Returns the contrast for borders as a floating point value.
+     * @param config pointer to the config from which to read the contrast
+     * setting (the default is to use KGlobal::config())
+     * @return the contrast (between 0.0 for minimum and 1.0 for maximum
+     *         contrast)
+     */
+    static qreal contrastF(const KSharedConfigPtr &config = KSharedConfigPtr());
+
     /**
      * Returns the button background color
      * @return the button background color
+     * @deprecated use KColorScheme(Button).background() instead.
+     * Color accessors in KGlobalSettings are broken because they do not take
+     * widget state into account. KColorScheme fixes this, as well as offering
+     * access to the full range of new color roles in KDE4.
      */
-    static QColor buttonBackground();
+    static KDE_DEPRECATED QColor buttonBackground();
 
     /**
      * Returns the button text color
      * @return the button text color
+     * @deprecated use KColorScheme(Button).foreground() instead.
+     * Color accessors in KGlobalSettings are broken because they do not take
+     * widget state into account. KColorScheme fixes this, as well as offering
+     * access to the full range of new color roles in KDE4.
      */
-    static QColor buttonTextColor();
+    static KDE_DEPRECATED QColor buttonTextColor();
 
     /**
      * Returns the default base (background) color.
      * @return the default base (background) color
      * @see QPalette::base()
+     * @deprecated use KColorScheme(View).background() instead.
+     * Color accessors in KGlobalSettings are broken because they do not take
+     * widget state into account. KColorScheme fixes this, as well as offering
+     * access to the full range of new color roles in KDE4.
      */
-    static QColor baseColor();
+    static KDE_DEPRECATED QColor baseColor();
 
     /**
      * Returns the default text color.
      * @return the default text color
      * @see QPalette::text()
+     * @deprecated use KColorScheme(View).foreground() instead.
+     * Color accessors in KGlobalSettings are broken because they do not take
+     * widget state into account. KColorScheme fixes this, as well as offering
+     * access to the full range of new color roles in KDE4.
      */
-    static QColor textColor();
+    static KDE_DEPRECATED QColor textColor();
 
     /**
      * Returns the default link color.
      * @return the default link color
+     * @deprecated use KColorScheme([set]).foreground(LinkText) instead.
+     * Color accessors in KGlobalSettings are broken because they do not take
+     * widget state into account. KColorScheme fixes this, as well as offering
+     * access to the full range of new color roles in KDE4. Also note that link
+     * color is now a standard foreground role, defined for each color set; the
+     * link color for one set may be different from the link color for another
+     * set.
      */
-    static QColor linkColor();
+    static KDE_DEPRECATED QColor linkColor();
 
     /**
      * Returns the default color for visited links.
      * @return the default color for visited links
+     * @deprecated use KColorScheme([set]).foreground(VisitedText) instead.
+     * Color accessors in KGlobalSettings are broken because they do not take
+     * widget state into account. KColorScheme fixes this, as well as offering
+     * access to the full range of new color roles in KDE4. Also note that
+     * visited link color is now a standard foreground role, defined for each
+     * color set; the cisited link color for one set may be different from the
+     * visited link color for another set.
      */
-    static QColor visitedLinkColor();
+    static KDE_DEPRECATED QColor visitedLinkColor();
 
     /**
      * Returns the default color for highlighted text.
      * @return the default color for highlighted text
      * @see QPalette::hightlightedText()
+     * @deprecated use KColorScheme(Selection).foreground() instead.
+     * Color accessors in KGlobalSettings are broken because they do not take
+     * widget state into account. KColorScheme fixes this, as well as offering
+     * access to the full range of new color roles in KDE4.
      */
-    static QColor highlightedTextColor();
+    static KDE_DEPRECATED QColor highlightedTextColor();
 
     /**
      * Returns the default color for text highlights.
      * @return the default color for text highlights
      * @see QPalette::hightlight()
+     * @deprecated use KColorScheme(Selection).background() instead.
+     * Color accessors in KGlobalSettings are broken because they do not take
+     * widget state into account. KColorScheme fixes this, as well as offering
+     * access to the full range of new color roles in KDE4.
      */
-    static QColor highlightColor();
+    static KDE_DEPRECATED QColor highlightColor();
 
     /**
      * Returns the alternate background color used by K3ListView with
      * K3ListViewItem. Any other list that uses alternating background
      * colors should use this too, to obey to the user's preferences. Returns
-     * an invalid color if the user doesn't want alternating backgrounds.
+     * the same as color(View, BackgroundNormal) if the user doesn't want
+     * alternating backgrounds.
      * @return the alternate background color
      * @see calculateAlternateBackgroundColor
+     * @deprecated use KColorScheme(View).background(AlternateBackground) instead.
+     * Color accessors in KGlobalSettings are broken because they do not take
+     * widget state into account. KColorScheme fixes this, as well as offering
+     * access to the full range of new color roles in KDE4.
      */
-    static QColor alternateBackgroundColor();
+    static KDE_DEPRECATED QColor alternateBackgroundColor();
 
     /**
      * Calculates a color based on @p base to be used as alternating
@@ -349,8 +409,14 @@ public:
      * @param base the base for the calculation
      * @return the calculated color
      * @see alternateBackgroundColor
+     * @deprecated use KColorScheme([set]).background(AlternateBackground) instead.
+     * You shouldn't need to use this; all color sets now provide their own
+     * alternate background color (as well as a variety of other colors) that
+     * KColorScheme provides access to. If for some reason KColorScheme does
+     * not meet your needs, you probably want to look at KColorUtils for
+     * various methods to manipulate colors.
      */
-    static QColor calculateAlternateBackgroundColor(const QColor& base);
+    static KDE_DEPRECATED QColor calculateAlternateBackgroundColor(const QColor& base);
 
     /**
      * Returns if the sorted column in a K3ListView shall be drawn with a
@@ -359,6 +425,14 @@ public:
      */
     static bool shadeSortColumn();
 
+    /**
+     * Returns if default background images are allowed by the color scheme.
+     * A "default" background image is just that, i.e. the user has not
+     * actively selected a background image to use.
+     * @return true if default background images may be used
+     */
+    static bool allowDefaultBackgroundImages();
+
     /**
      * Returns the default general font.
      * @return the default general font.
@@ -402,6 +476,12 @@ public:
      */
     static QFont largeFont(const QString &text = QString());
 
+    /**
+     * Returns the smallest readable font. This can be used in dockers,
+     * rulers and other places where space is at a premium.
+     */
+    static QFont smallestReadableFont();
+
     /**
      * Returns if the user specified multihead. In case the display
      * has multiple screens, the return value of this function specifies
@@ -464,7 +544,7 @@ public:
      * @return the geometry to use for the desktop.  Note that it might not
      *         start at (0,0).
      */
-    static QRect desktopGeometry(QWidget* w);
+    static QRect desktopGeometry(const QWidget* w);
 
     /**
      * This function determines if the user wishes to see icons on the
@@ -503,24 +583,19 @@ public:
      *
      * This is only useful for configuration modules such as krdb and should not be
      * used in normal circumstances.
+     *
      * @return the QPalette
      */
-    static QPalette createApplicationPalette();
-
-    /**
-     * @internal
-     * Raw access for use by KDM.
-     * note: expects config to be in the correct group already.
-     */
-    static QPalette createApplicationPalette( KConfigBase *config, int contrast );
+    // TODO should the parameter be documented, or should it be hidden from doxygen?
+    static QPalette createApplicationPalette(const KSharedConfigPtr &config = KSharedConfigPtr());
 
     /**
      * An identifier for change signals.
      * \see emitChange
      */
     enum ChangeType { PaletteChanged = 0, FontChanged, StyleChanged,
-                      SettingsChanged, IconChanged, ToolbarStyleChanged,
-                      ClipboardConfigChanged,
+                      SettingsChanged, IconChanged, CursorChanged,
+                      ToolbarStyleChanged, ClipboardConfigChanged,
                       BlockShortcuts };
 
     /**
@@ -601,6 +676,11 @@ Q_SIGNALS:
      */
     void iconChanged(int group);
 
+    /**
+     * Emitted when the cursor theme has been changed.
+     */
+    void cursorChanged();
+
     /**
      * Emitted by BlockShortcuts
      */
@@ -621,14 +701,23 @@ private:
     void kdisplaySetFont();
     void applyGUIStyle();
 
+    /**
+     * @internal
+     *
+     * Ensures that cursors are loaded from the theme KDE is configured
+     * to use. Note that calling this function doesn't cause existing
+     * cursors to be reloaded. Reloading already created cursors is
+     * handled by the KCM when a cursor theme is applied.
+     *
+     * It is not necessary to call this function when KGlobalSettings
+     * is initialized.
+     */
+    void applyCursorTheme();
+
     /**
      * reads in all paths from kdeglobals
      */
     static void initPaths();
-    /**
-     * initialize colors
-     */
-    static void initColors();
     /**
      * drop cached values for fonts (called by KApplication)
      */
@@ -642,28 +731,6 @@ private:
      */
     static void rereadMouseSettings();
 
-
-    static QString* s_desktopPath;
-    static QString* s_autostartPath;
-    static QString* s_documentPath;
-    static QFont *_generalFont;
-    static QFont *_fixedFont;
-    static QFont *_toolBarFont;
-    static QFont *_menuFont;
-    static QFont *_windowTitleFont;
-    static QFont *_taskbarFont;
-    static QFont *_largeFont;
-    static QColor * _kde34Blue;
-    static QColor * _inactiveBackground;
-    static QColor * _inactiveForeground;
-    static QColor * _activeBackground;
-    static QColor * _buttonBackground;
-    static QColor * _selectBackground;
-    static QColor * _linkColor;
-    static QColor * _visitedLinkColor;
-    static QColor * alternateColor;
-    static KMouseSettings *s_mouseSettings;
-
     friend class KApplication;
 };
 
