@@ -25,29 +25,28 @@ DEALINGS IN THE SOFTWARE.
 // kDebug() can't be turned off in kdeinit
 #if 0
 #define KSTARTUPINFO_ALL_DEBUG
+#ifdef __GNUC__
 #warning Extra KStartupInfo debug messages enabled.
 #endif
-
-#include <qwidget.h>
-
-#include "config.h"
-#include <qglobal.h>
-#ifdef HAVE_CONFIG_H
-#include <config.h>
 #endif
 
+#include "kstartupinfo.h"
+
+#include <QtGui/QWidget>
+#include <QtCore/QBool>
+
+#include <config.h>
+
 // need to resolve INT32(qglobal.h)<>INT32(Xlibint.h) conflict
 #ifndef QT_CLEAN_NAMESPACE
 #define QT_CLEAN_NAMESPACE
 #endif
 
-#include "kstartupinfo.h"
-
 #include <unistd.h>
 #include <sys/time.h>
 #include <stdlib.h>
-#include <qtimer.h>
-#include <qevent.h>
+#include <QtCore/QTimer>
+#include <QtGui/QActionEvent>
 #ifdef Q_WS_X11
 #include <qx11info_x11.h>
 #include <netwm.h>
@@ -56,9 +55,8 @@ DEALINGS IN THE SOFTWARE.
 #include <kapplication.h>
 #include <signal.h>
 #ifdef Q_WS_X11
-#include <kwinmodule.h>
+#include <kwindowsystem.h>
 #include <kxmessages.h>
-#include <kwin.h>
 #endif
 
 static const char* const NET_STARTUP_MSG = "_NET_STARTUP_INFO";
@@ -84,82 +82,115 @@ class KStartupInfo::Data
     : public KStartupInfoData
     {
     public:
-        Data() : age(0) {}; // just because it's in a QMap
+        Data() : age(0) {} // just because it's in a QMap
         Data( const QString& txt_P )
-            : KStartupInfoData( txt_P ), age( 0 ) {};
+            : KStartupInfoData( txt_P ), age( 0 ) {}
         unsigned int age;
     };
 
 class KStartupInfo::Private
     {
     public:
+        // private slots
+        void startups_cleanup();
+        void startups_cleanup_no_age();
+        void got_message( const QString& msg );
+        void window_added( WId w );
+        void slot_window_added( WId w );
+
+        void init( int flags );
+        void got_startup_info( const QString& msg_P, bool update_only_P );
+        void got_remove_startup_info( const QString& msg_P );
+        void new_startup_info_internal( const KStartupInfoId& id_P,
+            Data& data_P, bool update_only_P );
+        void remove_startup_info_internal( const KStartupInfoId& id_P );
+        void remove_startup_pids( const KStartupInfoId& id, const KStartupInfoData& data );
+        void remove_startup_pids( const KStartupInfoData& data );
+        startup_t check_startup_internal( WId w, KStartupInfoId* id, KStartupInfoData* data );
+        bool find_id( const QByteArray& id_P, KStartupInfoId* id_O,
+            KStartupInfoData* data_O );
+        bool find_pid( pid_t pid_P, const QByteArray& hostname, KStartupInfoId* id_O,
+            KStartupInfoData* data_O );
+        bool find_wclass( const QByteArray &res_name_P, const QByteArray &res_class_P,
+            KStartupInfoId* id_O, KStartupInfoData* data_O );
+        static QByteArray get_window_hostname( WId w_P );
+        void startups_cleanup_internal( bool age_P );
+        void clean_all_noncompliant();
+        static QString check_required_startup_fields( const QString& msg,
+            const KStartupInfoData& data, int screen );
+
+
+        KStartupInfo *q;
+        unsigned int timeout;
         QMap< KStartupInfoId, KStartupInfo::Data > startups;
 	// contains silenced ASN's only if !AnnounceSilencedChanges
         QMap< KStartupInfoId, KStartupInfo::Data > silent_startups;
         // contains ASN's that had change: but no new: yet
         QMap< KStartupInfoId, KStartupInfo::Data > uninited_startups;
 #ifdef Q_WS_X11
-        KWinModule* wm_module;
         KXMessages msgs;
 #endif
 	QTimer* cleanup;
 	int flags;
-	Private( int flags_P )
-    	    :
+
+	Private( int flags_P, KStartupInfo *q )
+    	    : q( q ),
+            timeout( 60 ),
 #ifdef Q_WS_X11
 	    msgs( NET_STARTUP_MSG, NULL, false ),
 #endif
-	      flags( flags_P ) {}
+	      flags( flags_P )
+        {
+        }
+
+        void createConnections()
+        {
+#ifdef Q_WS_X11
+            // d == NULL means "disabled"
+            if( !KApplication::kApplication())
+                return;
+            if( !QX11Info::display())
+                return;
+
+            if( !( flags & DisableKWinModule )) {
+                QObject::connect( KWindowSystem::self(), SIGNAL( windowAdded( WId )), q, SLOT( slot_window_added( WId )));
+#ifdef __GNUC__
+#warning "systemTrayWindowAdded signal was remove from KWindowSystem class"
+#endif		
+                //QObject::connect( KWindowSystem::self(), SIGNAL( systemTrayWindowAdded( WId )), q, SLOT( slot_window_added( WId )));
+            }
+            QObject::connect( &msgs, SIGNAL( gotMessage( const QString& )), q, SLOT( got_message( const QString& )));
+            cleanup = new QTimer( q );
+            QObject::connect( cleanup, SIGNAL( timeout()), q, SLOT( startups_cleanup()));
+#endif
+        }
     };
 
 KStartupInfo::KStartupInfo( int flags_P, QObject* parent_P )
     : QObject( parent_P ),
-        timeout( 60 ), d( NULL )
+      d(new Private(flags_P, this))
     {
-    init( flags_P );
+        d->createConnections();
     }
 
 KStartupInfo::KStartupInfo( bool clean_on_cantdetect_P, QObject* parent_P )
     : QObject( parent_P ),
-        timeout( 60 ), d( NULL )
+      d(new Private(clean_on_cantdetect_P ? CleanOnCantDetect : 0, this))
     {
-    init( clean_on_cantdetect_P ? CleanOnCantDetect : 0 );
+        d->createConnections();
     }
 
-void KStartupInfo::init( int flags_P )
-    {
-#ifdef Q_WS_X11
-    // d == NULL means "disabled"
-    if( !KApplication::kApplication())
-        return;
-    if( !QX11Info::display())
-        return;
-
-    d = new Private( flags_P );
-    if( !( d->flags & DisableKWinModule ))
-        {
-        d->wm_module = new KWinModule( this );
-        connect( d->wm_module, SIGNAL( windowAdded( WId )), SLOT( slot_window_added( WId )));
-        connect( d->wm_module, SIGNAL( systemTrayWindowAdded( WId )), SLOT( slot_window_added( WId )));
-        }
-    else
-        d->wm_module = NULL;
-    connect( &d->msgs, SIGNAL( gotMessage( const QString& )), SLOT( got_message( const QString& )));
-    d->cleanup = new QTimer( this );
-    connect( d->cleanup, SIGNAL( timeout()), SLOT( startups_cleanup()));
-#endif
-    }
 
 KStartupInfo::~KStartupInfo()
     {
     delete d;
     }
 
-void KStartupInfo::got_message( const QString& msg_P )
+void KStartupInfo::Private::got_message( const QString& msg_P )
     {
 #ifdef Q_WS_X11
 // TODO do something with SCREEN= ?
-    kDebug( 172 ) << "got:" << msg_P << endl;
+    kDebug( 172 ) << "got:" << msg_P;
     QString msg = msg_P.trimmed();
     if( msg.startsWith( QLatin1String("new:") )) // must match length below
         got_startup_info( msg.mid( 4 ), false );
@@ -170,11 +201,11 @@ void KStartupInfo::got_message( const QString& msg_P )
 #endif
     }
 
-// if the application stops responding for a while, KWinModule may get
+// if the application stops responding for a while, KWindowSystem may get
 // the information about the already mapped window before KXMessages
 // actually gets the info about the started application (depends
 // on their order in X11 event filter in KApplication)
-// simply delay info from KWinModule a bit
+// simply delay info from KWindowSystem a bit
 // SELI???
 namespace
 {
@@ -193,22 +224,22 @@ class DelayedWindowEvent
     };
 }
 
-void KStartupInfo::slot_window_added( WId w_P )
+void KStartupInfo::Private::slot_window_added( WId w_P )
     {
-    qApp->postEvent( this, new DelayedWindowEvent( w_P ));
+    qApp->postEvent( q, new DelayedWindowEvent( w_P ));
     }
 
 void KStartupInfo::customEvent( QEvent* e_P )
     {
 #ifdef Q_WS_X11
     if( e_P->type() == DelayedWindowEvent::uniqueType() )
-	window_added( static_cast< DelayedWindowEvent* >( e_P )->w );
+	d->window_added( static_cast< DelayedWindowEvent* >( e_P )->w );
     else
 #endif
 	QObject::customEvent( e_P );
     }
 
-void KStartupInfo::window_added( WId w_P )
+void KStartupInfo::Private::window_added( WId w_P )
     {
     KStartupInfoId id;
     KStartupInfoData data;
@@ -216,18 +247,18 @@ void KStartupInfo::window_added( WId w_P )
     switch( ret )
         {
         case Match:
-            kDebug( 172 ) << "new window match" << endl;
+            kDebug( 172 ) << "new window match";
           break;
         case NoMatch:
           break; // nothing
         case CantDetect:
-            if( d->flags & CleanOnCantDetect )
+            if( flags & CleanOnCantDetect )
                 clean_all_noncompliant();
           break;
         }
     }
 
-void KStartupInfo::got_startup_info( const QString& msg_P, bool update_P )
+void KStartupInfo::Private::got_startup_info( const QString& msg_P, bool update_P )
     {
     KStartupInfoId id( msg_P );
     if( id.none())
@@ -236,53 +267,51 @@ void KStartupInfo::got_startup_info( const QString& msg_P, bool update_P )
     new_startup_info_internal( id, data, update_P );
     }
 
-void KStartupInfo::new_startup_info_internal( const KStartupInfoId& id_P,
-    Data& data_P, bool update_P )
+void KStartupInfo::Private::new_startup_info_internal( const KStartupInfoId& id_P,
+                                                       KStartupInfo::Data& data_P, bool update_P )
     {
-    if( d == NULL )
-        return;
     if( id_P.none())
         return;
-    if( d->startups.contains( id_P ))
+    if( startups.contains( id_P ))
         { // already reported, update
-        d->startups[ id_P ].update( data_P );
-        d->startups[ id_P ].age = 0; // CHECKME
-        kDebug( 172 ) << "updating" << endl;
-	if( d->startups[ id_P ].silent() == Data::Yes
-	    && !( d->flags & AnnounceSilenceChanges ))
+        startups[ id_P ].update( data_P );
+        startups[ id_P ].age = 0; // CHECKME
+        kDebug( 172 ) << "updating";
+	if( startups[ id_P ].silent() == KStartupInfo::Data::Yes
+	    && !( flags & AnnounceSilenceChanges ))
 	    {
-	    d->silent_startups[ id_P ] = d->startups[ id_P ];
-	    d->startups.remove( id_P );
-	    emit gotRemoveStartup( id_P, d->silent_startups[ id_P ] );
+	    silent_startups[ id_P ] = startups[ id_P ];
+	    startups.remove( id_P );
+	    emit q->gotRemoveStartup( id_P, silent_startups[ id_P ] );
 	    return;
 	    }
-        emit gotStartupChange( id_P, d->startups[ id_P ] );
+        emit q->gotStartupChange( id_P, startups[ id_P ] );
         return;
         }
-    if( d->silent_startups.contains( id_P ))
+    if( silent_startups.contains( id_P ))
         { // already reported, update
-        d->silent_startups[ id_P ].update( data_P );
-        d->silent_startups[ id_P ].age = 0; // CHECKME
-        kDebug( 172 ) << "updating silenced" << endl;
-	if( d->silent_startups[ id_P ].silent() != Data::Yes )
+        silent_startups[ id_P ].update( data_P );
+        silent_startups[ id_P ].age = 0; // CHECKME
+        kDebug( 172 ) << "updating silenced";
+	if( silent_startups[ id_P ].silent() != Data::Yes )
 	    {
-	    d->startups[ id_P ] = d->silent_startups[ id_P ];
-	    d->silent_startups.remove( id_P );
-	    emit gotNewStartup( id_P, d->startups[ id_P ] );
+	    startups[ id_P ] = silent_startups[ id_P ];
+	    silent_startups.remove( id_P );
+	    q->emit gotNewStartup( id_P, startups[ id_P ] );
 	    return;
 	    }
-        emit gotStartupChange( id_P, d->silent_startups[ id_P ] );
+        emit q->gotStartupChange( id_P, silent_startups[ id_P ] );
         return;
         }
-    if( d->uninited_startups.contains( id_P ))
+    if( uninited_startups.contains( id_P ))
         {
-        d->uninited_startups[ id_P ].update( data_P );
-        kDebug( 172 ) << "updating uninited" << endl;
+        uninited_startups[ id_P ].update( data_P );
+        kDebug( 172 ) << "updating uninited";
         if( !update_P ) // uninited finally got new:
             {
-            d->startups[ id_P ] = d->uninited_startups[ id_P ];
-            d->uninited_startups.remove( id_P );
-            emit gotNewStartup( id_P, d->startups[ id_P ] );
+            startups[ id_P ] = uninited_startups[ id_P ];
+            uninited_startups.remove( id_P );
+            emit q->gotNewStartup( id_P, startups[ id_P ] );
             return;
             }
         // no change announce, it's still uninited
@@ -290,24 +319,24 @@ void KStartupInfo::new_startup_info_internal( const KStartupInfoId& id_P,
         }
     if( update_P ) // change: without any new: first
         {
-        kDebug( 172 ) << "adding uninited" << endl;
-	d->uninited_startups.insert( id_P, data_P );
+        kDebug( 172 ) << "adding uninited";
+	uninited_startups.insert( id_P, data_P );
         }
-    else if( data_P.silent() != Data::Yes || d->flags & AnnounceSilenceChanges )
+    else if( data_P.silent() != Data::Yes || flags & AnnounceSilenceChanges )
 	{
-        kDebug( 172 ) << "adding" << endl;
-        d->startups.insert( id_P, data_P );
-	emit gotNewStartup( id_P, data_P );
+        kDebug( 172 ) << "adding";
+        startups.insert( id_P, data_P );
+	emit q->gotNewStartup( id_P, data_P );
 	}
     else // new silenced, and silent shouldn't be announced
 	{
-        kDebug( 172 ) << "adding silent" << endl;
-	d->silent_startups.insert( id_P, data_P );
+        kDebug( 172 ) << "adding silent";
+	silent_startups.insert( id_P, data_P );
 	}
-    d->cleanup->start( 1000 ); // 1 sec
+    cleanup->start( 1000 ); // 1 sec
     }
 
-void KStartupInfo::got_remove_startup_info( const QString& msg_P )
+void KStartupInfo::Private::got_remove_startup_info( const QString& msg_P )
     {
     KStartupInfoId id( msg_P );
     KStartupInfoData data( msg_P );
@@ -322,35 +351,31 @@ void KStartupInfo::got_remove_startup_info( const QString& msg_P )
     remove_startup_info_internal( id );
     }
 
-void KStartupInfo::remove_startup_info_internal( const KStartupInfoId& id_P )
+void KStartupInfo::Private::remove_startup_info_internal( const KStartupInfoId& id_P )
     {
-    if( d == NULL )
-        return;
-    if( d->startups.contains( id_P ))
+    if( startups.contains( id_P ))
         {
-	kDebug( 172 ) << "removing" << endl;
-	emit gotRemoveStartup( id_P, d->startups[ id_P ]);
-	d->startups.remove( id_P );
+	kDebug( 172 ) << "removing";
+	emit q->gotRemoveStartup( id_P, startups[ id_P ]);
+	startups.remove( id_P );
 	}
-    else if( d->silent_startups.contains( id_P ))
+    else if( silent_startups.contains( id_P ))
 	{
-	kDebug( 172 ) << "removing silent" << endl;
-	d->silent_startups.remove( id_P );
+	kDebug( 172 ) << "removing silent";
+	silent_startups.remove( id_P );
 	}
-    else if( d->uninited_startups.contains( id_P ))
+    else if( uninited_startups.contains( id_P ))
 	{
-	kDebug( 172 ) << "removing uninited" << endl;
-	d->uninited_startups.remove( id_P );
+	kDebug( 172 ) << "removing uninited";
+	uninited_startups.remove( id_P );
 	}
     return;
     }
 
-void KStartupInfo::remove_startup_pids( const KStartupInfoData& data_P )
+void KStartupInfo::Private::remove_startup_pids( const KStartupInfoData& data_P )
     { // first find the matching info
-    if( d == NULL )
-        return;
-    for( QMap< KStartupInfoId, Data >::Iterator it = d->startups.begin();
-         it != d->startups.end();
+    for( QMap< KStartupInfoId, KStartupInfo::Data >::Iterator it = startups.begin();
+         it != startups.end();
          ++it )
         {
         if( ( *it ).hostname() != data_P.hostname())
@@ -362,19 +387,17 @@ void KStartupInfo::remove_startup_pids( const KStartupInfoData& data_P )
         }
     }
 
-void KStartupInfo::remove_startup_pids( const KStartupInfoId& id_P,
+void KStartupInfo::Private::remove_startup_pids( const KStartupInfoId& id_P,
     const KStartupInfoData& data_P )
     {
-    if( d == NULL )
-        return;
     kFatal( data_P.pids().count() == 0, 172 );
     Data* data = NULL;
-    if( d->startups.contains( id_P ))
-	data = &d->startups[ id_P ];
-    else if( d->silent_startups.contains( id_P ))
-	data = &d->silent_startups[ id_P ];
-    else if( d->uninited_startups.contains( id_P ))
-        data = &d->uninited_startups[ id_P ];
+    if( startups.contains( id_P ))
+	data = &startups[ id_P ];
+    else if( silent_startups.contains( id_P ))
+	data = &silent_startups[ id_P ];
+    else if( uninited_startups.contains( id_P ))
+        data = &uninited_startups[ id_P ];
     else
 	return;
     for( QList< pid_t >::ConstIterator it2 = data_P.pids().begin();
@@ -394,8 +417,8 @@ bool KStartupInfo::sendStartup( const KStartupInfoId& id_P, const KStartupInfoDa
     QString msg = QString::fromLatin1( "new: %1 %2" )
         .arg( id_P.to_text()).arg( data_P.to_text());
 	QX11Info inf;
-    msg = check_required_startup_fields( msg, data_P, inf.screen());
-    kDebug( 172 ) << "sending " << msg << endl;
+    msg = Private::check_required_startup_fields( msg, data_P, inf.screen());
+    kDebug( 172 ) << "sending " << msg;
     msgs.broadcastMessage( NET_STARTUP_MSG, msg, -1, false );
 #endif
     return true;
@@ -409,9 +432,9 @@ bool KStartupInfo::sendStartupX( Display* disp_P, const KStartupInfoId& id_P,
 #ifdef Q_WS_X11
     QString msg = QString::fromLatin1( "new: %1 %2" )
         .arg( id_P.to_text()).arg( data_P.to_text());
-    msg = check_required_startup_fields( msg, data_P, DefaultScreen( disp_P ));
+    msg = Private::check_required_startup_fields( msg, data_P, DefaultScreen( disp_P ));
 #ifdef KSTARTUPINFO_ALL_DEBUG
-    kDebug( 172 ) << "sending " << msg << endl;
+    kDebug( 172 ) << "sending " << msg;
 #endif
     return KXMessages::broadcastMessageX( disp_P, NET_STARTUP_MSG, msg, -1, false );
 #else
@@ -419,13 +442,13 @@ bool KStartupInfo::sendStartupX( Display* disp_P, const KStartupInfoId& id_P,
 #endif
     }
 
-QString KStartupInfo::check_required_startup_fields( const QString& msg, const KStartupInfoData& data_P,
+QString KStartupInfo::Private::check_required_startup_fields( const QString& msg, const KStartupInfoData& data_P,
     int screen )
     {
     QString ret = msg;
     if( data_P.name().isEmpty())
         {
-//        kWarning( 172 ) << "NAME not specified in initial startup message" << endl;
+//        kWarning( 172 ) << "NAME not specified in initial startup message";
         QString name = data_P.bin();
         if( name.isEmpty())
             name = "UNKNOWN";
@@ -444,7 +467,7 @@ bool KStartupInfo::sendChange( const KStartupInfoId& id_P, const KStartupInfoDat
     KXMessages msgs;
     QString msg = QString::fromLatin1( "change: %1 %2" )
         .arg( id_P.to_text()).arg( data_P.to_text());
-    kDebug( 172 ) << "sending " << msg << endl;
+    kDebug( 172 ) << "sending " << msg;
     msgs.broadcastMessage( NET_STARTUP_MSG, msg, -1, false );
 #endif
     return true;
@@ -459,7 +482,7 @@ bool KStartupInfo::sendChangeX( Display* disp_P, const KStartupInfoId& id_P,
     QString msg = QString::fromLatin1( "change: %1 %2" )
         .arg( id_P.to_text()).arg( data_P.to_text());
 #ifdef KSTARTUPINFO_ALL_DEBUG
-    kDebug( 172 ) << "sending " << msg << endl;
+    kDebug( 172 ) << "sending " << msg;
 #endif
     return KXMessages::broadcastMessageX( disp_P, NET_STARTUP_MSG, msg, -1, false );
 #else
@@ -474,7 +497,7 @@ bool KStartupInfo::sendFinish( const KStartupInfoId& id_P )
 #ifdef Q_WS_X11
     KXMessages msgs;
     QString msg = QString::fromLatin1( "remove: %1" ).arg( id_P.to_text());
-    kDebug( 172 ) << "sending " << msg << endl;
+    kDebug( 172 ) << "sending " << msg;
     msgs.broadcastMessage( NET_STARTUP_MSG, msg, -1, false );
 #endif
     return true;
@@ -487,7 +510,7 @@ bool KStartupInfo::sendFinishX( Display* disp_P, const KStartupInfoId& id_P )
 #ifdef Q_WS_X11
     QString msg = QString::fromLatin1( "remove: %1" ).arg( id_P.to_text());
 #ifdef KSTARTUPINFO_ALL_DEBUG
-    kDebug( 172 ) << "sending " << msg << endl;
+    kDebug( 172 ) << "sending " << msg;
 #endif
     return KXMessages::broadcastMessageX( disp_P, NET_STARTUP_MSG, msg, -1, false );
 #else
@@ -503,7 +526,7 @@ bool KStartupInfo::sendFinish( const KStartupInfoId& id_P, const KStartupInfoDat
     KXMessages msgs;
     QString msg = QString::fromLatin1( "remove: %1 %2" )
         .arg( id_P.to_text()).arg( data_P.to_text());
-    kDebug( 172 ) << "sending " << msg << endl;
+    kDebug( 172 ) << "sending " << msg;
     msgs.broadcastMessage( NET_STARTUP_MSG, msg, -1, false );
 #endif
     return true;
@@ -518,7 +541,7 @@ bool KStartupInfo::sendFinishX( Display* disp_P, const KStartupInfoId& id_P,
     QString msg = QString::fromLatin1( "remove: %1 %2" )
         .arg( id_P.to_text()).arg( data_P.to_text());
 #ifdef KSTARTUPINFO_ALL_DEBUG
-    kDebug( 172 ) << "sending " << msg << endl;
+    kDebug( 172 ) << "sending " << msg;
 #endif
     return KXMessages::broadcastMessageX( disp_P, NET_STARTUP_MSG, msg, -1, false );
 #else
@@ -529,9 +552,15 @@ bool KStartupInfo::sendFinishX( Display* disp_P, const KStartupInfoId& id_P,
 void KStartupInfo::appStarted()
     {
     if( kapp != NULL )  // KApplication constructor unsets the env. variable
+        {
         appStarted( kapp->startupId());
+        kapp->clearStartupId(); // reset the id, no longer valid (must use clearStartupId() to avoid infinite loop)
+        }
     else
-        appStarted( KStartupInfo::currentStartupIdEnv().id());
+        {
+        appStarted( currentStartupIdEnv().id());
+        resetStartupEnv();
+        }
     }
 
 void KStartupInfo::appStarted( const QByteArray& startup_id )
@@ -595,12 +624,12 @@ void KStartupInfo::setNewStartupId( QWidget* window, const QByteArray& startup_i
             }
         if( activate )
             {
-            KWin::setOnDesktop( window->winId(), KWin::currentDesktop());
+            KWindowSystem::setOnDesktop( window->winId(), KWindowSystem::currentDesktop());
         // This is not very nice, but there's no way how to get any
         // usable timestamp without ASN, so force activating the window.
         // And even with ASN, it's not possible to get the timestamp here,
         // so if the WM doesn't have support for ASN, it can't be used either.
-            KWin::forceActiveWindow( window->winId());
+            KWindowSystem::forceActiveWindow( window->winId());
             }
         }
 #endif
@@ -610,30 +639,28 @@ void KStartupInfo::setNewStartupId( QWidget* window, const QByteArray& startup_i
 KStartupInfo::startup_t KStartupInfo::checkStartup( WId w_P, KStartupInfoId& id_O,
     KStartupInfoData& data_O )
     {
-    return check_startup_internal( w_P, &id_O, &data_O );
+    return d->check_startup_internal( w_P, &id_O, &data_O );
     }
 
 KStartupInfo::startup_t KStartupInfo::checkStartup( WId w_P, KStartupInfoId& id_O )
     {
-    return check_startup_internal( w_P, &id_O, NULL );
+    return d->check_startup_internal( w_P, &id_O, NULL );
     }
 
 KStartupInfo::startup_t KStartupInfo::checkStartup( WId w_P, KStartupInfoData& data_O )
     {
-    return check_startup_internal( w_P, NULL, &data_O );
+    return d->check_startup_internal( w_P, NULL, &data_O );
     }
 
 KStartupInfo::startup_t KStartupInfo::checkStartup( WId w_P )
     {
-    return check_startup_internal( w_P, NULL, NULL );
+    return d->check_startup_internal( w_P, NULL, NULL );
     }
 
-KStartupInfo::startup_t KStartupInfo::check_startup_internal( WId w_P, KStartupInfoId* id_O,
+KStartupInfo::startup_t KStartupInfo::Private::check_startup_internal( WId w_P, KStartupInfoId* id_O,
     KStartupInfoData* data_O )
     {
-    if( d == NULL )
-        return NoMatch;
-    if( d->startups.count() == 0 )
+    if( startups.count() == 0 )
         return NoMatch; // no startups
     // Strategy:
     //
@@ -642,13 +669,13 @@ KStartupInfo::startup_t KStartupInfo::check_startup_internal( WId w_P, KStartupI
     //  - No - Is this a NET_WM compliant app ?
     //           - Yes - test for pid match
     //           - No - test for WM_CLASS match
-    kDebug( 172 ) << "check_startup" << endl;
+    kDebug( 172 ) << "check_startup";
     QByteArray id = windowStartupId( w_P );
     if( !id.isNull())
         {
         if( id.isEmpty() || id == "0" ) // means ignore this window
             {
-            kDebug( 172 ) << "ignore" << endl;
+            kDebug( 172 ) << "ignore";
             return NoMatch;
             }
         return find_id( id, id_O, data_O ) ? Match : NoMatch;
@@ -693,38 +720,34 @@ KStartupInfo::startup_t KStartupInfo::check_startup_internal( WId w_P, KStartupI
         && transient_for != None )
 	return NoMatch;
 #endif
-    kDebug( 172 ) << "check_startup:cantdetect" << endl;
+    kDebug( 172 ) << "check_startup:cantdetect";
     return CantDetect;
     }
 
-bool KStartupInfo::find_id( const QByteArray& id_P, KStartupInfoId* id_O,
+bool KStartupInfo::Private::find_id( const QByteArray& id_P, KStartupInfoId* id_O,
     KStartupInfoData* data_O )
     {
-    if( d == NULL )
-        return false;
-    kDebug( 172 ) << "find_id:" << id_P << endl;
+    kDebug( 172 ) << "find_id:" << id_P;
     KStartupInfoId id;
     id.initId( id_P );
-    if( d->startups.contains( id ))
+    if( startups.contains( id ))
         {
         if( id_O != NULL )
             *id_O = id;
         if( data_O != NULL )
-            *data_O = d->startups[ id ];
-        kDebug( 172 ) << "check_startup_id:match" << endl;
+            *data_O = startups[ id ];
+        kDebug( 172 ) << "check_startup_id:match";
         return true;
         }
     return false;
     }
 
-bool KStartupInfo::find_pid( pid_t pid_P, const QByteArray& hostname_P,
+bool KStartupInfo::Private::find_pid( pid_t pid_P, const QByteArray& hostname_P,
     KStartupInfoId* id_O, KStartupInfoData* data_O )
     {
-    if( d == NULL )
-        return false;
-    kDebug( 172 ) << "find_pid:" << pid_P << endl;
-    for( QMap< KStartupInfoId, Data >::Iterator it = d->startups.begin();
-         it != d->startups.end();
+    kDebug( 172 ) << "find_pid:" << pid_P;
+    for( QMap< KStartupInfoId, KStartupInfo::Data >::Iterator it = startups.begin();
+         it != startups.end();
          ++it )
         {
         if( ( *it ).is_pid( pid_P ) && ( *it ).hostname() == hostname_P )
@@ -735,23 +758,21 @@ bool KStartupInfo::find_pid( pid_t pid_P, const QByteArray& hostname_P,
                 *data_O = *it;
             // non-compliant, remove on first match
             remove_startup_info_internal( it.key());
-            kDebug( 172 ) << "check_startup_pid:match" << endl;
+            kDebug( 172 ) << "check_startup_pid:match";
             return true;
             }
         }
     return false;
     }
 
-bool KStartupInfo::find_wclass( QByteArray res_name, QByteArray res_class,
+bool KStartupInfo::Private::find_wclass( const QByteArray &_res_name, const QByteArray &_res_class,
     KStartupInfoId* id_O, KStartupInfoData* data_O )
     {
-    if( d == NULL )
-        return false;
-    res_name = res_name.toLower();
-    res_class = res_class.toLower();
-    kDebug( 172 ) << "find_wclass:" << res_name << ":" << res_class << endl;
-    for( QMap< KStartupInfoId, Data >::Iterator it = d->startups.begin();
-         it != d->startups.end();
+    QByteArray res_name = _res_name.toLower();
+    QByteArray res_class = _res_class.toLower();
+    kDebug( 172 ) << "find_wclass:" << res_name << ":" << res_class;
+    for( QMap< KStartupInfoId, Data >::Iterator it = startups.begin();
+         it != startups.end();
          ++it )
         {
         const QByteArray wmclass = ( *it ).findWMClass();
@@ -763,7 +784,7 @@ bool KStartupInfo::find_wclass( QByteArray res_name, QByteArray res_class,
                 *data_O = *it;
             // non-compliant, remove on first match
             remove_startup_info_internal( it.key());
-            kDebug( 172 ) << "check_startup_wclass:match" << endl;
+            kDebug( 172 ) << "check_startup_wclass:match";
             return true;
             }
         }
@@ -830,7 +851,7 @@ void KStartupInfo::setWindowStartupId( WId w_P, const QByteArray& id_P )
 #endif
     }
 
-QByteArray KStartupInfo::get_window_hostname( WId w_P )
+QByteArray KStartupInfo::Private::get_window_hostname( WId w_P )
     {
 #ifdef Q_WS_X11
     XTextProperty tp;
@@ -854,35 +875,31 @@ QByteArray KStartupInfo::get_window_hostname( WId w_P )
 
 void KStartupInfo::setTimeout( unsigned int secs_P )
     {
-    timeout = secs_P;
+    d->timeout = secs_P;
  // schedule removing entries that are older than the new timeout
     QTimer::singleShot( 0, this, SLOT( startups_cleanup_no_age()));
     }
 
-void KStartupInfo::startups_cleanup_no_age()
+void KStartupInfo::Private::startups_cleanup_no_age()
     {
     startups_cleanup_internal( false );
     }
 
-void KStartupInfo::startups_cleanup()
+void KStartupInfo::Private::startups_cleanup()
     {
-    if( d == NULL )
-        return;
-    if( d->startups.count() == 0 && d->silent_startups.count() == 0
-        && d->uninited_startups.count() == 0 )
+    if( startups.count() == 0 && silent_startups.count() == 0
+        && uninited_startups.count() == 0 )
         {
-        d->cleanup->stop();
+        cleanup->stop();
         return;
         }
     startups_cleanup_internal( true );
     }
 
-void KStartupInfo::startups_cleanup_internal( bool age_P )
+void KStartupInfo::Private::startups_cleanup_internal( bool age_P )
     {
-    if( d == NULL )
-        return;
-    for( QMap< KStartupInfoId, Data >::Iterator it = d->startups.begin();
-         it != d->startups.end();
+    for( QMap< KStartupInfoId, KStartupInfo::Data >::Iterator it = startups.begin();
+         it != startups.end();
          )
         {
         if( age_P )
@@ -894,14 +911,14 @@ void KStartupInfo::startups_cleanup_internal( bool age_P )
             {
             const KStartupInfoId& key = it.key();
             ++it;
-            kDebug( 172 ) << "entry timeout:" << key.id() << endl;
+            kDebug( 172 ) << "entry timeout:" << key.id();
             remove_startup_info_internal( key );
             }
         else
             ++it;
         }
-    for( QMap< KStartupInfoId, Data >::Iterator it = d->silent_startups.begin();
-         it != d->silent_startups.end();
+    for( QMap< KStartupInfoId, KStartupInfo::Data >::Iterator it = silent_startups.begin();
+         it != silent_startups.end();
          )
         {
         if( age_P )
@@ -913,14 +930,14 @@ void KStartupInfo::startups_cleanup_internal( bool age_P )
             {
             const KStartupInfoId& key = it.key();
             ++it;
-            kDebug( 172 ) << "entry timeout:" << key.id() << endl;
+            kDebug( 172 ) << "entry timeout:" << key.id();
             remove_startup_info_internal( key );
             }
         else
             ++it;
         }
-    for( QMap< KStartupInfoId, Data >::Iterator it = d->uninited_startups.begin();
-         it != d->uninited_startups.end();
+    for( QMap< KStartupInfoId, KStartupInfo::Data >::Iterator it = uninited_startups.begin();
+         it != uninited_startups.end();
          )
         {
         if( age_P )
@@ -932,7 +949,7 @@ void KStartupInfo::startups_cleanup_internal( bool age_P )
             {
             const KStartupInfoId& key = it.key();
             ++it;
-            kDebug( 172 ) << "entry timeout:" << key.id() << endl;
+            kDebug( 172 ) << "entry timeout:" << key.id();
             remove_startup_info_internal( key );
             }
         else
@@ -940,12 +957,10 @@ void KStartupInfo::startups_cleanup_internal( bool age_P )
         }
     }
 
-void KStartupInfo::clean_all_noncompliant()
+void KStartupInfo::Private::clean_all_noncompliant()
     {
-    if( d == NULL )
-        return;
-    for( QMap< KStartupInfoId, Data >::Iterator it = d->startups.begin();
-         it != d->startups.end();
+    for( QMap< KStartupInfoId, KStartupInfo::Data >::Iterator it = startups.begin();
+         it != startups.end();
          )
         {
         if( ( *it ).WMClass() != "0" )
@@ -955,7 +970,7 @@ void KStartupInfo::clean_all_noncompliant()
             }
         const KStartupInfoId& key = it.key();
         ++it;
-        kDebug( 172 ) << "entry cleaning:" << key.id() << endl;
+        kDebug( 172 ) << "entry cleaning:" << key.id();
         remove_startup_info_internal( key );
         }
     }
@@ -977,14 +992,14 @@ QByteArray KStartupInfo::createNewStartupId()
 #endif
     QByteArray id = QString::fromLatin1( "%1;%2;%3;%4_TIME%5" ).arg( hostname ).arg( tm.tv_sec )
         .arg( tm.tv_usec ).arg( getpid()).arg( qt_x_user_time ).toUtf8();
-    kDebug( 172 ) << "creating: " << id << ":" << (qApp ? qAppName() : QString("unnamed app") /* e.g. kdeinit */) << endl;
+    kDebug( 172 ) << "creating: " << id << ":" << (qApp ? qAppName() : QString("unnamed app") /* e.g. kdeinit */);
     return id;
     }
 
 
 struct KStartupInfoId::Private
     {
-    Private() : id( "" ) {};
+    Private() : id( "" ) {}
     QByteArray id; // id
     };
 
@@ -1018,7 +1033,7 @@ void KStartupInfoId::initId( const QByteArray& id_P )
         {
         d->id = id_P;
 #ifdef KSTARTUPINFO_ALL_DEBUG
-        kDebug( 172 ) << "using: " << d->id << endl;
+        kDebug( 172 ) << "using: " << d->id;
 #endif
         return;
         }
@@ -1027,7 +1042,7 @@ void KStartupInfoId::initId( const QByteArray& id_P )
         { // already has id
         d->id = startup_env;
 #ifdef KSTARTUPINFO_ALL_DEBUG
-        kDebug( 172 ) << "reusing: " << d->id << endl;
+        kDebug( 172 ) << "reusing: " << d->id;
 #endif
         return;
         }
@@ -1137,7 +1152,7 @@ unsigned long KStartupInfoId::timestamp() const
 struct KStartupInfoData::Private
     {
     Private() : desktop( 0 ), wmclass( "" ), hostname( "" ),
-	silent( KStartupInfoData::Unknown ), timestamp( ~0U ), screen( -1 ) { }
+        silent( KStartupInfoData::Unknown ), timestamp( ~0U ), screen( -1 ), xinerama( -1 ), launched_by( 0 ) {}
     QString bin;
     QString name;
     QString description;
@@ -1149,6 +1164,8 @@ struct KStartupInfoData::Private
     KStartupInfoData::TriState silent;
     unsigned long timestamp;
     int screen;
+    int xinerama;
+    WId launched_by;
     };
 
 QString KStartupInfoData::to_text() const
@@ -1183,6 +1200,10 @@ QString KStartupInfoData::to_text() const
         ret += QString::fromLatin1( " TIMESTAMP=%1" ).arg( d->timestamp );
     if( d->screen != -1 )
         ret += QString::fromLatin1( " SCREEN=%1" ).arg( d->screen );
+    if( d->xinerama != -1 )
+        ret += QString::fromLatin1( " XINERAMA=%1" ).arg( d->xinerama );
+    if( d->launched_by != 0 )
+        ret += QString::fromLatin1( " LAUNCHED_BY=%1" ).arg( (long)d->launched_by );
     return ret;
     }
 
@@ -1200,6 +1221,8 @@ KStartupInfoData::KStartupInfoData( const QString& txt_P ) : d(new Private)
     const QString silent_str = QString::fromLatin1( "SILENT=" );
     const QString timestamp_str = QString::fromLatin1( "TIMESTAMP=" );
     const QString screen_str = QString::fromLatin1( "SCREEN=" );
+    const QString xinerama_str = QString::fromLatin1( "XINERAMA=" );
+    const QString launched_by_str = QString::fromLatin1( "LAUNCHED_BY=" );
     for( QStringList::Iterator it = items.begin();
          it != items.end();
          ++it )
@@ -1232,6 +1255,10 @@ KStartupInfoData::KStartupInfoData( const QString& txt_P ) : d(new Private)
             d->timestamp = get_unum( *it );
         else if( ( *it ).startsWith( screen_str ))
             d->screen = get_num( *it );
+        else if( ( *it ).startsWith( xinerama_str ))
+            d->xinerama = get_num( *it );
+        else if( ( *it ).startsWith( launched_by_str ))
+            d->launched_by = ( WId ) get_num( *it );
         }
     }
 
@@ -1273,6 +1300,10 @@ void KStartupInfoData::update( const KStartupInfoData& data_P )
         d->timestamp = data_P.timestamp();
     if( data_P.screen() != -1 )
         d->screen = data_P.screen();
+    if( data_P.xinerama() != -1 && xinerama() != -1 ) // don't overwrite
+        d->xinerama = data_P.xinerama();
+    if( data_P.launchedBy() != 0 && launchedBy() != 0 ) // don't overwrite
+        d->launched_by = data_P.launchedBy();
     }
 
 KStartupInfoData::KStartupInfoData() : d(new Private)
@@ -1367,7 +1398,7 @@ const QByteArray KStartupInfoData::findWMClass() const
     return bin().toUtf8();
     }
 
-const QByteArray& KStartupInfoData::WMClass() const
+QByteArray KStartupInfoData::WMClass() const
     {
     return d->wmclass;
     }
@@ -1386,7 +1417,7 @@ void KStartupInfoData::setHostname( const QByteArray& hostname_P )
         }
     }
 
-const QByteArray& KStartupInfoData::hostname() const
+QByteArray KStartupInfoData::hostname() const
     {
     return d->hostname;
     }
@@ -1402,7 +1433,7 @@ void KStartupInfoData::remove_pid( pid_t pid_P )
     d->pids.removeAll( pid_P );
     }
 
-const QList< pid_t >& KStartupInfoData::pids() const
+QList< pid_t > KStartupInfoData::pids() const
     {
     return d->pids;
     }
@@ -1442,6 +1473,26 @@ int KStartupInfoData::screen() const
     return d->screen;
     }
 
+void KStartupInfoData::setXinerama( int xinerama )
+    {
+    d->xinerama = xinerama;
+    }
+
+int KStartupInfoData::xinerama() const
+    {
+    return d->xinerama;
+    }
+
+void KStartupInfoData::setLaunchedBy( WId window )
+    {
+    d->launched_by = window;
+    }
+
+WId KStartupInfoData::launchedBy() const
+    {
+    return d->launched_by;
+    }
+
 static
 long get_num( const QString& item_P )
     {
