@@ -25,13 +25,14 @@ DEALINGS IN THE SOFTWARE.
 #ifndef KSTARTUPINFO_H
 #define KSTARTUPINFO_H
 
-#include <sys/types.h>
-#include <qobject.h>
+#include <kdeui_export.h>
 
-#include <qstring.h>
-#include <qcoreevent.h>
-#include <qwindowdefs.h>
-#include <kdelibs_export.h>
+#include <QtCore/QObject>
+#include <QtCore/QString>
+#include <QtCore/QChildEvent>
+#include <QtGui/QWidgetList>
+
+#include <sys/types.h>
 
 #if !defined(Q_WS_X11)
 typedef void Display;
@@ -308,6 +309,11 @@ class KDEUI_EXPORT KStartupInfo
 	 * @internal
 	 */
         class Data;
+        
+	/**
+          * @internal
+	 */
+        class Private;
     Q_SIGNALS:
 	/**
 	 * Emitted when a new startup notification is created (i.e. a new application is
@@ -329,42 +335,23 @@ class KDEUI_EXPORT KStartupInfo
 	 * @param data the notification data
 	 */
         void gotRemoveStartup( const KStartupInfoId& id, const KStartupInfoData& data );
+
     protected:
 	/**
 	 *
 	 */
 	virtual void customEvent( QEvent* e_P );
-    private Q_SLOTS:
-        void startups_cleanup();
-        void startups_cleanup_no_age();
-        void got_message( const QString& msg );
-        void window_added( WId w );
-	void slot_window_added( WId w );
+
     private:
-        void init( int flags );
-        friend class KStartupInfoPrivate;
-        void got_startup_info( const QString& msg_P, bool update_only_P );
-        void got_remove_startup_info( const QString& msg_P );
-        void new_startup_info_internal( const KStartupInfoId& id_P,
-            Data& data_P, bool update_only_P );
-        void remove_startup_info_internal( const KStartupInfoId& id_P );
-        void remove_startup_pids( const KStartupInfoId& id, const KStartupInfoData& data );
-        void remove_startup_pids( const KStartupInfoData& data );
-        startup_t check_startup_internal( WId w, KStartupInfoId* id, KStartupInfoData* data );
-        bool find_id( const QByteArray& id_P, KStartupInfoId* id_O,
-            KStartupInfoData* data_O );
-        bool find_pid( pid_t pid_P, const QByteArray& hostname, KStartupInfoId* id_O,
-            KStartupInfoData* data_O );
-        bool find_wclass( QByteArray res_name_P, QByteArray res_class_P,
-            KStartupInfoId* id_O, KStartupInfoData* data_O );
-        static QByteArray get_window_hostname( WId w_P );
-        void startups_cleanup_internal( bool age_P );
-        void clean_all_noncompliant();
-        static QString check_required_startup_fields( const QString& msg,
-            const KStartupInfoData& data, int screen );
-        unsigned int timeout;
-        class Private;
-        Private* d;
+        Q_PRIVATE_SLOT(d, void startups_cleanup())
+        Q_PRIVATE_SLOT(d, void startups_cleanup_no_age())
+        Q_PRIVATE_SLOT(d, void got_message( const QString& msg ))
+        Q_PRIVATE_SLOT(d, void window_added( WId w ))
+        Q_PRIVATE_SLOT(d, void slot_window_added( WId w ))
+
+        Private* const d;
+
+        Q_DISABLE_COPY(KStartupInfo)
     };
 
 /**
@@ -434,6 +421,7 @@ class KDEUI_EXPORT KStartupInfoId
         explicit KStartupInfoId( const QString& txt );
         QString to_text() const;
         friend class KStartupInfo;
+        friend class KStartupInfo::Private;
         struct Private;
         Private *const d;
     };
@@ -543,7 +531,7 @@ class KDEUI_EXPORT KStartupInfoData
 	 * @return the WM_CLASS value for the startup notification, or empty
 	 *         if not set
 	 */
-        const QByteArray& WMClass() const;
+        QByteArray WMClass() const;
 	/**
 	 * Adds a PID to the list of processes that belong to the startup notification. It
 	 * may be used to increase the chance that the windows created by the starting
@@ -556,7 +544,7 @@ class KDEUI_EXPORT KStartupInfoData
 	 * Returns all PIDs for the startup notification.
 	 * @return the list of all PIDs
 	 */
-        const QList< pid_t >& pids() const;
+        QList< pid_t > pids() const;
 	/**
 	 * Checks whether the given @p pid is in the list of PIDs for starup
 	 * notification.
@@ -573,7 +561,7 @@ class KDEUI_EXPORT KStartupInfoData
 	 * Returns the hostname for the startup notification.
 	 * @return the hostname
 	 */
-        const QByteArray& hostname() const;
+        QByteArray hostname() const;
 
 	/**
 	 *
@@ -619,6 +607,30 @@ class KDEUI_EXPORT KStartupInfoData
          * This is usually not necessary to set, as it's set by default to QX11Info::screen().
          */
         void setScreen( int screen );
+        
+        /**
+         * The Xinerama screen for the startup notification, -1 if unknown.
+         */
+        int xinerama() const;
+
+        /**        
+	 * Sets the Xinerama screen for the startup notification ( i.e. the screeen on which
+	 * the starting application should appear ).
+	 * @param xinerama the Xinerama screen for the startup notification
+         */
+        void setXinerama( int xinerama );
+
+        /**
+         * The toplevel window of the application that caused this startup notification,
+         * 0 if unknown.
+         */
+        WId launchedBy() const;
+        
+        /**
+	 * Sets the toplevel window of the application that caused this startup notification.
+	 * @param window window ID of the toplevel window that is responsible for this startup
+         */
+        void setLaunchedBy( WId window );
 
 	/**
 	 * Updates the notification data from the given data. Some data, such as the desktop
@@ -644,6 +656,7 @@ class KDEUI_EXPORT KStartupInfoData
         void remove_pid( pid_t pid );
         friend class KStartupInfo;
         friend class KStartupInfo::Data;
+        friend class KStartupInfo::Private;
         struct Private;
         Private *const d;
     };
