@@ -22,13 +22,13 @@
 #include <kaboutdata.h>
 #include <kdebug.h>
 
-#include <QApplication>
-#include <QListWidget>
+#include <QtGui/QApplication>
+#include <QtGui/QListWidget>
 
 int main( int argc, char *argv[] )
 {
   QApplication app( argc, argv );
-  KAboutData aboutData( "kactionselectortest", "kactionselectortest", "1.0" );
+  KAboutData aboutData( "kactionselectortest", 0, ki18n("kactionselectortest"), "1.0" );
   KComponentData i( &aboutData );
 
   KActionSelector actionSelector(0);
