@@ -1,9 +1,9 @@
 #ifndef KCOLORTEST_H
 #define KCOLORTEST_H
 
-#include <qwidget.h>
-#include <qimage.h>
-#include <qpixmap.h>
+#include <QtGui/QWidget>
+#include <QtGui/QImage>
+#include <QtGui/QPixmap>
 
 class KColorWidget : public QWidget
 {
