@@ -5,8 +5,8 @@
 #ifndef KGRADIENT_TEST_H
 #define KGRADIENT_TEST_H
 
-#include <qwidget.h>
-#include <qpixmap.h>
+#include <QtGui/QWidget>
+#include <QtGui/QPixmap>
 
 class KGradientWidget : public QWidget
 {
