@@ -5,8 +5,8 @@
 #ifndef KHASH_TEST_H
 #define KHASH_TEST_H
 
-#include <qwidget.h>
-#include <qpixmap.h>
+#include <QtGui/QWidget>
+#include <QtGui/QPixmap>
 
 class KHashWidget : public QWidget
 {
