@@ -1,5 +1,5 @@
-#include <qtimer.h>
-#include <qlabel.h>
+#include <QtCore/QTimer>
+#include <QtGui/QLabel>
 
 #include <kapplication.h>
 #include <kcmdlineargs.h>
@@ -25,7 +25,7 @@ void MainWindow::showMessage()
 
 int main( int argc, char **argv )
 {
-    KCmdLineArgs::init( argc, argv, "kmainwindowtest", "KMainWindowTest", "kmainwindow test app", "1.0" );
+    KCmdLineArgs::init( argc, argv, "kmainwindowtest", 0, ki18n("KMainWindowTest"), "1.0", ki18n("kmainwindow test app"));
     KApplication app;
 
     MainWindow* mw = new MainWindow; // deletes itself when closed
