@@ -18,7 +18,7 @@
 
 #include <kcmdlineargs.h>
 #include <kapplication.h>
-#include <kmainwindow.h>
+#include <kxmlguiwindow.h>
 #include <klineedit.h>
 #include <kstandarddirs.h>
 #include <ktoolbarlabelaction.h>
@@ -28,12 +28,17 @@
 
 #include <assert.h>
 
-class MainWindow : public KMainWindow
+class MainWindow : public KXmlGuiWindow
 {
   public:
 
     MainWindow()
     {
+
+      // KXMLGUIClient looks in the "data" resource for the .rc files
+      // This line is for test programs only!
+      KGlobal::dirs()->addResourceDir( "data", KDESRCDIR );
+
       KVBox* main = new KVBox( this );
       setCentralWidget( main );
 
@@ -67,13 +72,13 @@ class MainWindow : public KMainWindow
       // set buddy for label3
       label3->setBuddy( lineEditAction );
 
-      createGUI( "ktoolbarlabelactiontestui.rc" );
+      setupGUI( Default, "ktoolbarlabelactiontestui.rc" );
     }
 };
 
 int main( int argc, char **argv )
 {
-  KCmdLineArgs::init( argc, argv, "test", "Test" ,"test app" ,"1.0" );
+  KCmdLineArgs::init( argc, argv, "test", 0, ki18n("Test"), "1.0", ki18n("test app"));
   KApplication app;
 
   KGlobal::mainComponent().dirs()->addResourceDir( "data", "." );
