@@ -7,11 +7,11 @@
 #ifndef KGRADIENT_TEST_H
 #define KGRADIENT_TEST_H
 
-#include <qwidget.h>
-#include <qpixmap.h>
-#include <qslider.h>
-#include <qlabel.h>
-#include <qdatetime.h>
+#include <QtGui/QWidget>
+#include <QtGui/QPixmap>
+#include <QtGui/QSlider>
+#include <QtGui/QLabel>
+#include <QtCore/QDate>
 
 class KGradientWidget : public QWidget
 {
