@@ -1,24 +1,24 @@
 #ifndef testwindow_h
 #define testwindow_h
 
-#include <qtimer.h>
-#include <qprogressbar.h>
+#include <QtCore/QTimer>
+#include <QtGui/QProgressBar>
 #include <kmenubar.h>
 #include <kstatusbar.h>
 #include <ktoolbar.h>
-#include <kmainwindow.h>
+#include <kxmlguiwindow.h>
 
 class QTextEdit;
 class KToolBarRadioGroup;
 class KHelpMenu;
 
-class testWindow  : public KMainWindow
+class TestWindow  : public KXmlGuiWindow
 {
     Q_OBJECT
 
 public:
-    testWindow (QWidget *parent=0);
-    ~testWindow ();
+    TestWindow (QWidget *parent=0);
+    ~TestWindow ();
 
 public Q_SLOTS:
     void beFixed();
@@ -32,11 +32,9 @@ public Q_SLOTS:
     void slotOpen();
     void slotCompletion();
     void slotCompletionsMenu(QAction* action);
-    void slotHide2 ();
     void slotInsertClock();
-    void slotHide1 ();
-    void slotLined ();
-    void slotImportant ();
+    void slotLined();
+    void slotImportant();
     void slotExit();
     void slotFrame();
     void slotListCompletion();
@@ -44,17 +42,14 @@ public Q_SLOTS:
     void slotToggle(bool);
     void slotClearCombo();
     void slotGoGoGoo();
-    void slotInsertListInCombo ();
-    void slotMakeItem3Current ();
+    void slotInsertListInCombo();
+    void slotMakeItem3Current();
     void slotToggled(QAction* action);
+
 protected:
-    KMenuBar *menuBar;
-    QMenu *fileMenu;
     QMenu *itemsMenu;
     QMenu *completions;
-    QMenu *toolBarMenu;
     KStatusBar *statusBar;
-    KHelpMenu *helpMenu;
     KToolBar *tb;
     KToolBar *tb1;
     class KLineEdit* testLineEdit;
@@ -68,7 +63,6 @@ protected:
     QTextEdit *widget;
     QTimer *timer;
     QProgressBar *pr;
-    KToolBarRadioGroup *rg;
 };
 #endif
 
