@@ -20,17 +20,17 @@
 #ifndef KCOMPLETION_H
 #define KCOMPLETION_H
 
-#include <qmap.h>
-#include <qobject.h>
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qpointer.h>
-
-#include "kdelibs_export.h"
+#include <kdeui_export.h>
 #include <kglobalsettings.h>
 #include <ksortablelist.h>
 #include <kshortcut.h>
 
+#include <QtCore/QMap>
+#include <QtCore/QObject>
+#include <QtCore/QString>
+#include <QtCore/QStringList>
+#include <QtCore/QPointer>
+
 class KCompTreeNode;
 class KCompletionPrivate;
 class KCompletionBasePrivate;
@@ -219,7 +219,7 @@ public:
      * @return the last match. QString() is returned when there is no
      *         last match.
      */
-    virtual const QString& lastMatch() const { return myLastMatch; }
+    virtual const QString& lastMatch() const;
 
     /**
      * Returns a list of all items inserted into KCompletion. This is useful
@@ -264,9 +264,7 @@ public:
      * @return the current completion mode
      * @see setCompletionMode
      */
-    KGlobalSettings::Completion completionMode() const {
-        return myCompletionMode;
-    }
+    KGlobalSettings::Completion completionMode() const;
 
     /**
      * KCompletion offers three different ways in which it offers its items:
@@ -295,7 +293,7 @@ public:
      * @return the current completion order.
      * @see setOrder
      */
-    CompOrder order() const { return myOrder; }
+    CompOrder order() const;
 
     /**
      * Setting this to true makes KCompletion behave case insensitively.
@@ -312,7 +310,7 @@ public:
      * @return true if the case will be ignored
      * @see setIgnoreCase
      */
-    bool ignoreCase() const { return myIgnoreCase; }
+    bool ignoreCase() const;
 
     /**
      * Returns a list of all items matching the last completed string.
@@ -363,7 +361,7 @@ public:
      * @param enable true to enable sounds
      * @see soundsEnabled
      */
-    virtual void setSoundsEnabled( bool enable ) { myBeep = enable; }
+    virtual void setSoundsEnabled( bool enable );
 
     /**
      * Tells you whether KCompletion will play sounds on certain occasions.
@@ -371,14 +369,14 @@ public:
      * @return true if sounds are enabled
      * @see setSoundsEnabled
      */
-    bool soundsEnabled() const { return myBeep; }
+    bool soundsEnabled() const;
 
     /**
      * Returns true when more than one match is found.
      * @return true if there are more than one match
      * @see multipleMatches
      */
-    bool hasMultipleMatches() const { return myHasMultipleMatches; }
+    bool hasMultipleMatches() const;
 
 public Q_SLOTS:
     /**
@@ -387,7 +385,7 @@ public Q_SLOTS:
      * @param string the string to complete
      * @see makeCompletion
      */
-    void slotMakeCompletion( const QString& string ) {
+    void slotMakeCompletion( const QString& string ) { //inline (redirect)
         (void) makeCompletion( string );
     }
 
@@ -396,7 +394,7 @@ public Q_SLOTS:
      * Same as previousMatch() (just as a slot).
      * @see previousMatch
      */
-    void slotPreviousMatch() {
+    void slotPreviousMatch() { //inline (redirect)
         (void) previousMatch();
     }
 
@@ -405,7 +403,7 @@ public Q_SLOTS:
      * Same as nextMatch() (just as a slot).
      * @see nextMatch
      */
-    void slotNextMatch() {
+    void slotNextMatch() { //inline (redirect)
         (void) nextMatch();
     }
 
@@ -508,7 +506,7 @@ protected:
      * @param pMatch the match to process
      * @see postProcessMatches
      */
-    virtual void postProcessMatch( QString *pMatch ) const { Q_UNUSED(pMatch) }
+    virtual void postProcessMatch( QString *pMatch ) const;
 
     /**
      * This method is called before a list of all available completions is
@@ -520,7 +518,7 @@ protected:
      * @param pMatches the matches to process
      * @see postProcessMatch
      */
-    virtual void postProcessMatches( QStringList * pMatches ) const { Q_UNUSED(pMatches)}
+    virtual void postProcessMatches( QStringList * pMatches ) const;
 
     /**
      * This method is called before a list of all available completions is
@@ -532,7 +530,7 @@ protected:
      * @param pMatches the matches to process
      * @see postProcessMatch
      */
-    virtual void postProcessMatches( KCompletionMatches * pMatches ) const {Q_UNUSED(pMatches)}
+    virtual void postProcessMatches( KCompletionMatches * pMatches ) const;
 
 private:
     void            addWeightedItem( const QString& );
@@ -553,19 +551,6 @@ private:
     enum        BeepMode { NoMatch, PartialMatch, Rotation };
     void        doBeep( BeepMode ) const;
 
-    KGlobalSettings::Completion myCompletionMode;
-
-    CompOrder       myOrder;
-    QString         myLastString;
-    QString         myLastMatch;
-    QString         myCurrentMatch;
-    KCompTreeNode * myTreeRoot;
-    QStringList     myRotations;
-    bool            myBeep;
-    bool            myIgnoreCase;
-    bool            myHasMultipleMatches;
-    int            myRotationIndex;
-
 private:
     KCompletionPrivate* const d;
 };
@@ -618,12 +603,9 @@ public:
      * even if true is passed to list().
      * @return true if the matches won't be sorted
      */
-    bool sorting() const {
-        return _sorting;
-    }
+    bool sorting() const;
 private:
-    bool _sorting;
-    KCompletionMatchesPrivate* d;
+    KCompletionMatchesPrivate * const d;
 };
 
 /**
@@ -740,9 +722,7 @@ public:
      * @return true if the completion object will be deleted
      *              automatically
      */
-    bool isCompletionObjectAutoDeleted() const {
-        return m_delegate ? m_delegate->isCompletionObjectAutoDeleted() : m_bAutoDelCompObj;
-    }
+    bool isCompletionObjectAutoDeleted() const;
 
     /**
      * Sets the completion object when this widget's destructor
@@ -753,12 +733,7 @@ public:
      *
      * @param autoDelete if true, delete completion object on destruction.
      */
-    void setAutoDeleteCompletionObject( bool autoDelete ) {
-        if ( m_delegate )
-            m_delegate->setAutoDeleteCompletionObject( autoDelete );
-        else
-            m_bAutoDelCompObj = autoDelete;
-    }
+    void setAutoDeleteCompletionObject( bool autoDelete );
 
     /**
      * Sets the widget's ability to emit text completion and
@@ -780,26 +755,21 @@ public:
      *
      * @param enable if false, disables the emition of completion & rotation signals.
      */
-    void setEnableSignals( bool enable ) {
-        if ( m_delegate )
-            m_delegate->setEnableSignals( enable );
-        else
-            m_bEmitSignals = enable;
-    }
+    void setEnableSignals( bool enable );
 
     /**
      * Returns true if the object handles the signals.
      *
      * @return true if this signals are handled internally.
      */
-    bool handleSignals() const { return m_delegate ? m_delegate->handleSignals() : m_bHandleSignals; }
+    bool handleSignals() const;
 
     /**
      * Returns true if the object emits the signals.
      *
      * @return true if signals are emitted
      */
-    bool emitSignals() const { return m_delegate ? m_delegate->emitSignals() : m_bEmitSignals; }
+    bool emitSignals() const;
 
     /**
      * Sets the type of completion to be used.
@@ -831,9 +801,7 @@ public:
      *
      * @return the completion mode.
      */
-    KGlobalSettings::Completion completionMode() const {
-        return m_delegate ? m_delegate->completionMode() : m_iCompletionMode;
-    }
+    KGlobalSettings::Completion completionMode() const;
 
     /**
      * Sets the key-binding to be used for manual text
@@ -879,9 +847,7 @@ public:
      * @return the key-binding used for the feature given by @p item.
      * @see setKeyBinding
      */
-    KShortcut getKeyBinding( KeyBindingType item ) const {
-        return m_delegate ? m_delegate->getKeyBinding( item ) : m_keyMap[ item ];
-    }
+    KShortcut getKeyBinding( KeyBindingType item ) const;
 
     /**
      * Sets this object to use global values for key-bindings.
@@ -932,7 +898,7 @@ public:
      *
      * @return the completion object or @c NULL if one does not exist.
      */
-    KCompletion* compObj() const { return m_delegate ? m_delegate->compObj() : static_cast<KCompletion*>(m_pCompObj); }
+    KCompletion* compObj() const;
 
 protected:
     /**
@@ -943,7 +909,7 @@ protected:
      *
      * @return the key-binding used for the feature given by @p item.
      */
-    KeyBindingMap getKeyBindings() const { return m_delegate ? m_delegate->getKeyBindings() : m_keyMap; }
+    KeyBindingMap getKeyBindings() const;
 
     /**
      * Sets or removes the delegation object. If a delegation object is
@@ -957,7 +923,7 @@ protected:
      * @return the delegation object, or 0 if there is none
      * @see setDelegate()
      */
-    KCompletionBase *delegate() const { return m_delegate; }
+    KCompletionBase *delegate() const;
 
 private:
     // This method simply sets the autodelete boolean for
@@ -965,23 +931,6 @@ private:
     // signals internally flags to the provided values.
     void setup( bool, bool, bool );
 
-    // Flag that determined whether the completion object
-    // should be deleted when this object is destroyed.
-    bool m_bAutoDelCompObj;
-    // Determines whether this widget handles completion signals
-    // internally or not
-    bool m_bHandleSignals;
-    // Determines whether this widget fires rotation signals
-    bool m_bEmitSignals;
-    // Stores the completion mode locally.
-    KGlobalSettings::Completion m_iCompletionMode;
-    // Pointer to Completion object.
-    QPointer<KCompletion> m_pCompObj;
-    // Keybindings
-    KeyBindingMap m_keyMap;
-    // we may act as a proxy to another KCompletionBase object
-    KCompletionBase *m_delegate;
-
     // BCI
 protected:
     /** Virtual hook, used to add new "virtual" functions while maintaining
@@ -989,7 +938,7 @@ protected:
     */
     virtual void virtual_hook( int id, void* data );
 private:
-    KCompletionBasePrivate* d;
+    KCompletionBasePrivate * const d;
 };
 
 #endif // KCOMPLETION_H
