@@ -20,21 +20,20 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include <config.h>
-
-#include <qnamespace.h>
-#include <qwindowdefs.h>
-#include <QFlags>
-
 #include "kkeyserver_x11.h"
 #include "kshortcut.h"
 
+#include <config.h>
+
+#include <QtCore/QCOORD>
+#include <QtGui/QWidgetList>
+#include <QFlags>
+
 #include <kconfig.h>
 #include <kdebug.h>
 #include <kglobal.h>
 #include <klocale.h>
 
-#ifdef Q_WS_X11
 #include <QX11Info>
 # define XK_MISCELLANY
 # define XK_XKB_KEYS
@@ -43,18 +42,7 @@
 # include <X11/Xutil.h>
 # include <X11/keysymdef.h>
 # define X11_ONLY(arg) arg, //allows to omit an argument
-#else
-# include <kckey.h>
-# define X11_ONLY(arg)
-# define XK_ISO_Left_Tab Qt::Key_Backtab
-# define XK_BackSpace Qt::Key_Backspace
-# define XK_Sys_Req Qt::Key_SysReq
-# define XK_Caps_Lock Qt::Key_CapsLock
-# define XK_Num_Lock Qt::Key_NumLock
-# define XK_Scroll_Lock Qt::Key_ScrollLock
-# define XK_Prior Qt::Key_PageUp
-# define XK_Next Qt::Key_PageDown
-#endif
+
 
 namespace KKeyServer
 {
@@ -72,12 +60,10 @@ struct Mod
 // Array Structures
 //---------------------------------------------------------------------
 
-struct ModInfo
+struct X11ModInfo
 {
 	int modQt;
-#ifdef Q_WS_X11
 	int modX;
-#endif
 };
 
 struct SymVariation
@@ -101,7 +87,7 @@ struct TransKey {
 // Arrays
 //---------------------------------------------------------------------
 
-static ModInfo g_rgModInfo[4] =
+static X11ModInfo g_rgX11ModInfo[4] =
 {
 	{ Qt::SHIFT,   X11_ONLY(ShiftMask) },
 	{ Qt::CTRL,    X11_ONLY(ControlMask) },
@@ -135,9 +121,6 @@ static const SymName g_rgSymNames[] = {
 	{ 0, 0 }
 };
 
-#ifdef Q_WS_X11
-// TODO: Add Mac key names list: Key_Backspace => "Delete", Key_Delete => "Del"
-
 // These are the X equivalents to the Qt keycodes 0x1000 - 0x1026
 static const TransKey g_rgQtToSymX[] =
 {
@@ -300,7 +283,6 @@ static const TransKey g_rgQtToSymX[] =
 	{ Qt::Key_LaunchE,    XF86XK_LaunchC },
 	{ Qt::Key_LaunchF,    XF86XK_LaunchD },
 };
-#endif //Q_WS_X11
 
 //---------------------------------------------------------------------
 // Debugging
@@ -308,14 +290,12 @@ static const TransKey g_rgQtToSymX[] =
 #ifndef NDEBUG 
 inline void checkDisplay()
 {
-#ifdef Q_WS_X11
 	// Some non-GUI apps might try to use us.
 	if ( !QX11Info::display() ) {
 		kError() << "QX11Info::display() returns 0.  I'm probably going to crash now." << endl;
 		kError() << "If this is a KApplication initialized without GUI stuff, change it to be "
 	                "initialized with GUI stuff." << endl;
 	}
-#endif // Q_WS_X11
 }
 #else // NDEBUG
 # define checkDisplay()
@@ -324,8 +304,8 @@ inline void checkDisplay()
 //---------------------------------------------------------------------
 // Initialization
 //---------------------------------------------------------------------
+
 static bool g_bInitializedMods;
-#ifdef Q_WS_X11
 static uint g_modXNumLock, g_modXScrollLock, g_modXModeSwitch, g_alt_mask, g_meta_mask;
 
 bool initializeMods()
@@ -333,7 +313,7 @@ bool initializeMods()
 	checkDisplay();
 	XModifierKeymap* xmk = XGetModifierMapping( QX11Info::display() );
 
-	g_rgModInfo[3].modX = g_modXNumLock = g_modXScrollLock = g_modXModeSwitch = 0; 
+	g_rgX11ModInfo[3].modX = g_modXNumLock = g_modXScrollLock = g_modXModeSwitch = 0; 
 
 	int min_keycode, max_keycode;	
 	int keysyms_per_keycode = 0;
@@ -372,8 +352,8 @@ bool initializeMods()
 		}
 	}
 
-	g_rgModInfo[3].modX = g_meta_mask;
-	g_rgModInfo[2].modX = g_alt_mask;
+	g_rgX11ModInfo[3].modX = g_meta_mask;
+	g_rgX11ModInfo[2].modX = g_alt_mask;
 
 	XFreeModifiermap( xmk );
 
@@ -382,18 +362,15 @@ bool initializeMods()
 
 	g_bInitializedMods = true;
 
-	kDebug(125) << "KKeyServer::initializeMods(): Win Mod = 0x" << QString::number(g_rgModInfo[3].modX, 16) << endl;
+	kDebug(125) << "KKeyServer::initializeMods(): Win Mod = 0x" << QString::number(g_rgX11ModInfo[3].modX, 16);
 	return true;
 }
 
-#endif //Q_WS_X11
-
 
 //---------------------------------------------------------------------
 // Public functions
 //---------------------------------------------------------------------
 
-#ifdef Q_WS_X11
 
 uint modXShift()      { return ShiftMask; }
 uint modXCtrl()       { return ControlMask; }
@@ -407,28 +384,11 @@ uint modXModeSwitch() { if( !g_bInitializedMods ) { initializeMods(); } return g
 
 bool keyboardHasMetaKey() { return modXMeta() != 0; }
 
-#else
-
-/* FIXME: why is this stuff still all tied to X11 interfaces?  Is it used anywhere other than the
-X11-specific portions of kglobalaccel? */
-
-uint modXShift() { return 0; }
-uint modXCtrl() { return 0; }
-uint modXAlt() { return 0; }
-uint modXMeta() { return 0; }
-
-uint modXNumLock() { return 0; }
-uint modXLock() { return 0; }
-uint modXScrollLock() { return 0; }
-uint modXModeSwitch() { return 0; }
-
-#endif //Q_WS_X11
 
 uint getModsRequired(uint sym)
 {
 	uint mod = 0;
 
-#ifdef Q_WS_X11
 	// FIXME: This might not be true on all keyboard layouts!
 	if( sym == XK_Sys_Req ) return Qt::ALT;
 	if( sym == XK_Break ) return Qt::CTRL;
@@ -453,164 +413,124 @@ uint getModsRequired(uint sym)
 		else if( sym == XKeycodeToKeysym( QX11Info::display(), code, 3 ) )
 			mod = Qt::SHIFT | MODE_SWITCH;
 	}
-#endif
 	return mod;
 }
 
-bool keyQtToCodeX( int keyQt, int& keyCode )
+bool keyQtToCodeX( int keyQt, int* keyCode )
 {
 	int sym;
 	uint mod;
-	keyQtToSymX(keyQt, sym);
-	keyQtToModX(keyQt, mod);
+	keyQtToSymX(keyQt, &sym);
+	keyQtToModX(keyQt, &mod);
 
 	// Get any extra mods required by the sym.
 	//  E.g., XK_Plus requires SHIFT on the en layout.
 	uint modExtra = getModsRequired(sym);
 	// Get the X modifier equivalent.
-	if( !sym || !keyQtToModX( (keyQt & Qt::KeyboardModifierMask) | modExtra, mod ) ) {
-		keyCode = 0;
+	if( !sym || !keyQtToModX( (keyQt & Qt::KeyboardModifierMask) | modExtra, &mod ) ) {
+		*keyCode = 0;
 		return false;
 	}
 
-#ifdef Q_WS_X11
 	// XKeysymToKeycode returns the wrong keycode for XK_Print and XK_Break.
 	// Specifically, it returns the code for SysReq instead of Print
 	// Only do this for the default Xorg layout, other keycode mappings
 	// (e.g. evdev) don't need or want it.
 	if( sym == XK_Print && !(mod & Mod1Mask) &&
 			XKeycodeToKeysym( QX11Info::display(), 111, 0 ) == XK_Print )
-		keyCode = 111; // code for Print
+		*keyCode = 111; // code for Print
 	else if( sym == XK_Break || ((sym == XK_Pause && (mod & ControlMask)) &&
 			XKeycodeToKeysym( QX11Info::display(), 114, 0 ) == XK_Pause) )
-		keyCode = 114;
+		*keyCode = 114;
 	else
-		keyCode = XKeysymToKeycode( QX11Info::display(), sym );
-#endif
+		*keyCode = XKeysymToKeycode( QX11Info::display(), sym );
 
 	return true;
 }
 
-bool keyQtToSymX( int keyQt, int& keySym )
+bool keyQtToSymX( int keyQt, int* keySym )
 {
 	int symQt = keyQt & ~Qt::KeyboardModifierMask;
 
 	if( symQt < 0x1000 ) {
-		keySym = QChar(symQt).toLower().unicode();
+		*keySym = QChar(symQt).toLower().unicode();
 		return true;
 	}
 
-#ifdef Q_WS_WIN
-	keySym = symQt;
-	return true;
-#elif defined(Q_WS_MAC)
-	keySym = symQt;
-	return true;
-#elif defined(Q_WS_X11)
+
 	for( uint i = 0; i < sizeof(g_rgQtToSymX)/sizeof(TransKey); i++ ) {
 		if( g_rgQtToSymX[i].keySymQt == symQt ) {
-			keySym = g_rgQtToSymX[i].keySymX;
+			*keySym = g_rgQtToSymX[i].keySymX;
 			return true;
 		}
 	}
 
-	keySym = 0;
+	*keySym = 0;
 	if( symQt != Qt::Key_Shift && symQt != Qt::Key_Control && symQt != Qt::Key_Alt &&
 	    symQt != Qt::Key_Meta && symQt != Qt::Key_Direction_L && symQt != Qt::Key_Direction_R )
-		kDebug(125) << "Sym::initQt( " << QString::number(keyQt,16) << " ): failed to convert key." << endl;
+		kDebug(125) << "Sym::initQt( " << QString::number(keyQt,16) << " ): failed to convert key.";
 	return false;
-#endif
 }
 
-bool symXToKeyQt( uint keySym, int& keyQt )
+bool symXToKeyQt( uint keySym, int* keyQt )
 {
-	keyQt = Qt::Key_unknown;
+	*keyQt = Qt::Key_unknown;
 	if( keySym < 0x1000 ) {
 		if( keySym >= 'a' && keySym <= 'z' )
-			keyQt = QChar(keySym).toLower().unicode();
+			*keyQt = QChar(keySym).toLower().unicode();
 		else
-			keyQt = keySym;
+			*keyQt = keySym;
 	}
-#if defined(Q_WS_WIN) || defined(Q_WS_MAC)
+
 	else if( keySym < 0x3000 )
-		keyQt = keySym;
-#elif defined(Q_WS_X11)
-	else if( keySym < 0x3000 )
-		keyQt = keySym;
+		*keyQt = keySym;
 
 	else {
 		for( uint i = 0; i < sizeof(g_rgQtToSymX)/sizeof(TransKey); i++ )
 			if( g_rgQtToSymX[i].keySymX == keySym ) {
-				keyQt = g_rgQtToSymX[i].keySymQt;
+				*keyQt = g_rgQtToSymX[i].keySymQt;
 				break;
 			}
 	}
-#endif
 	
-	return (keyQt != Qt::Key_unknown);
+	return (*keyQt != Qt::Key_unknown);
 }
 
 /* are these things actually used anywhere?  there's no way
    they can do anything on non-X11 */
 
-bool keyQtToModX( int modQt, uint & modX )
+bool keyQtToModX( int modQt, uint* modX )
 {
-#ifdef Q_WS_X11
 	if( !g_bInitializedMods )
 		initializeMods();
 
-	modX = 0;
+	*modX = 0;
 	for( int i = 0; i < 4; i++ ) {
-		if( modQt & g_rgModInfo[i].modQt ) {
-			modX |= g_rgModInfo[i].modX;
+		if( modQt & g_rgX11ModInfo[i].modQt ) {
+			*modX |= g_rgX11ModInfo[i].modX;
 			continue;
 		}
 	}
-#endif
 	return true;
 }
 
-bool modXToQt( uint modX, int& modQt )
+bool modXToQt( uint modX, int* modQt )
 {
-#ifdef Q_WS_X11
 	if( !g_bInitializedMods )
 		initializeMods();
 
-	modQt = 0;
+	*modQt = 0;
 	for( int i = 0; i < 4; i++ ) {
-		if( modX & g_rgModInfo[i].modX ) {
-			modQt |= g_rgModInfo[i].modQt;
+		if( modX & g_rgX11ModInfo[i].modX ) {
+			*modQt |= g_rgX11ModInfo[i].modQt;
 			continue;
 		}
 	}
-#endif
 	return true;
 }
 
-#ifdef Q_WS_WIN
-//wrapped
-bool modXToModQt( uint modX, int& modQt )
-{
-	return modToModQt( modX, modQt );
-}
 
-KDEUI_EXPORT int qtButtonStateToMod( Qt::KeyboardModifiers s )
-{
-	int modQt = 0;
-	if (s & Qt::ShiftModifier) modQt |= KKey::SHIFT;
-	if (s & Qt::ControlModifier) modQt |= KKey::CTRL;
-	if (s & Qt::AltModifier) modQt |= KKey::ALT;
-	return modQt;
-}
-
-bool keyboardHasWinKey() { 
-//! TODO
-  return true;
-}
-
-#elif defined(Q_WS_X11)
-
-bool codeXToSym( uchar codeX, uint modX, uint& sym )
+bool codeXToSym( uchar codeX, uint modX, uint* sym )
 {
 	KeySym keySym;
 	XKeyPressedEvent event;
@@ -623,18 +543,18 @@ bool codeXToSym( uchar codeX, uint modX, uint& sym )
 	event.keycode = codeX;
 
 	XLookupString( &event, 0, 0, &keySym, 0 );
-	sym = (uint) keySym;
+	*sym = (uint) keySym;
 	return true;
 }
-#endif //!Q_WS_WIN
+
 
 uint accelModMaskX()
 {
 	return modXShift() | modXCtrl() | modXAlt() | modXMeta();
 }
 
-#ifdef Q_WS_X11
-bool xEventToQt( XEvent* e, int& keyQt )
+
+bool xEventToQt( XEvent* e, int* keyQt )
 {
 	uchar keyCodeX = e->xkey.keycode;
 	uint keyModX = e->xkey.state & (accelModMaskX() | MODE_SWITCH);
@@ -669,12 +589,12 @@ bool xEventToQt( XEvent* e, int& keyQt )
 
 	int keyCodeQt;
 	int keyModQt;
-	symXToKeyQt(keySymX, keyCodeQt);
-	modXToQt(keyModX, keyModQt);
+	symXToKeyQt(keySymX, &keyCodeQt);
+	modXToQt(keyModX, &keyModQt);
 	
-	keyQt = keyCodeQt | keyModQt;
+	*keyQt = keyCodeQt | keyModQt;
 	return true;
 }
-#endif
+
 
 } // end of namespace KKeyServer block
