@@ -35,7 +35,7 @@
 #include <kpassivepopup.h>
 #include <kdialog.h>
 #include <kmacroexpander.h>
-#include <kwin.h>
+#include <kwindowsystem.h>
 #include <kdebug.h>
 #include <kvbox.h>
 #include <kapplication.h>
@@ -68,6 +68,12 @@ struct KNotification::Private
     QTimer updateTimer;
 
     Private() : id(0), ref(1), widget(0l) {}
+    /**
+     * recursive function that raise the widget. @p w
+     *
+     * @see raiseWidget()
+     */
+    static void raiseWidget(QWidget *w);
 };
 
 KNotification::KNotification(const QString& eventId, QWidget *parent, const NotificationFlags& flags) :
@@ -83,7 +89,7 @@ KNotification::KNotification(const QString& eventId, QWidget *parent, const Noti
 
 KNotification::~KNotification()
 {
-//	kDebug( 299 ) << k_funcinfo << d->id << endl;
+//	kDebug( 299 ) << d->id;
 	if(d ->id != 0)
 		KNotificationManager::self()->remove( d->id );
 	delete d;
@@ -106,8 +112,11 @@ QWidget *KNotification::widget() const
 
 void KNotification::setWidget(QWidget *wid)
 {
-	d->widget = wid;
-	setParent(wid);
+    d->widget = wid;
+    setParent(wid);
+    if ( wid && d->flags &  CloseWhenWidgetActivated ) {
+        wid->installEventFilter(this);
+    }
 }
 
 void KNotification::setText(const QString &text)
@@ -210,23 +219,24 @@ void KNotification::close()
 
 void KNotification::raiseWidget()
 {
-	if(!d->widget)
-		return;
+    if ( !d->widget ) {
+        return;
+    }
 
-	raiseWidget(d->widget);
+    Private::raiseWidget( d->widget );
 }
 
 
-void KNotification::raiseWidget(QWidget *w)
+void KNotification::Private::raiseWidget(QWidget *w)
 {
 	//TODO  this function is far from finished.
 	if(w->isTopLevel())
 	{
 		w->raise();
-#ifdef Q_WS_WIN
+#if defined(Q_WS_WIN) || defined(Q_WS_MAC)
 		w->activateWindow();
 #else
-		KWin::activateWindow( w->winId() );
+		KWindowSystem::activateWindow( w->winId() );
 #endif
 	}
 	else
@@ -309,9 +319,9 @@ void KNotification::sendEventSync()
 		if(d->flags & DefaultEvent)
 			appname = QLatin1String("kde");
                 else if(d->componentData.isValid()) {
-                    appname = QString::fromLatin1(d->componentData.componentName());
+                    appname = d->componentData.componentName();
                 } else {
-                    appname = QString::fromLatin1(KGlobal::mainComponent().componentName());
+                    appname = KGlobal::mainComponent().componentName();
                 }
 
 		if(!(d->flags & Persistant))
@@ -323,7 +333,7 @@ void KNotification::sendEventSync()
 		d->id=KNotificationManager::self()->notify( this , d->pixmap , d->actions , d->contexts , appname );
 		if(d->id>0)
 			ref();
-//		kDebug(299) << k_funcinfo << d->id << endl;
+//		kDebug(299) << d->id;
 		
 		//after a small timeout, the notification will be deleted if all presentation are finished
 		QTimer::singleShot(100, this, SLOT(deref()));
@@ -339,5 +349,20 @@ void KNotification::update()
 	KNotificationManager::self()->update(this, d->id);
 }
 
+bool KNotification::eventFilter( QObject * watched, QEvent * event )
+{
+	if( watched == d->widget )
+	{
+		if( event->type() == QEvent::WindowActivate )
+		{
+			if( d->flags &  CloseWhenWidgetActivated )
+				QTimer::singleShot(500, this, SLOT(close()));
+		}
+		//kDebug(299) << event->type();
+	}
+
+	return false;
+}
+
 
 #include "knotification.moc"
