@@ -20,13 +20,13 @@
 #ifndef KNOTIFICATION_H
 #define KNOTIFICATION_H
 
-
-#include <qpixmap.h>
-#include <qobject.h>
-#include <qpair.h>
-#include <kdelibs_export.h>
+#include <kdeui_export.h>
 #include <kcomponentdata.h>
 
+#include <QtGui/QPixmap>
+#include <QtCore/QObject>
+#include <QtCore/QPair>
+
 class QWidget;
 
 /**
@@ -210,7 +210,9 @@ public:
 		 *
 		 * If the widget is already activated when the notification occurs, the
 		 * notification will be closed after a small timeout.
-		 * @todo doesn't works yet
+		 * 
+		 * This only works if the widget is the toplevel widget
+		 * @todo make it work with tabulated widget
 		 */
 		CloseWhenWidgetActivated=0x04,
         
@@ -437,22 +439,22 @@ private Q_SLOTS:
 private:
 	struct Private;
 	Private *const d;
+	
+protected:
 	/**
-	 * recursive function that raise the widget. @p w
-	 *
-	 * @see raiseWidget()
+	 * reimplemented for internals raison
 	 */
-	static void raiseWidget(QWidget *w);
+	virtual bool eventFilter( QObject * watched, QEvent * event );
 
 
 public:
 	/**
 	 * @brief emit an event
 	 * 
-	 * This method crate the KNotification, assing every parametter, and fire the event.
+	 * This method creates the KNotification, setting every parameter, and fire the event.
 	 * You don't need to call sendEvent
 	 *
-	 * A popup may be showed, a sound may be played, depending the config.
+	 * A popup may be displayed or a sound may be played, depending the config.
 	 *
 	 * return a KNotification .  You may use that pointer to connect some signals or slot.
 	 * the pointer is automatically deleted when the event is closed.
@@ -460,14 +462,12 @@ public:
 	 * Make sure you use one of the CloseOnTimeOut or CloseWhenWidgetActivated, if not,
 	 * you have to close yourself the notification.
 	 *
-	 * @note the text is shown in a QLabel, you should make sure to escape the html is needed.
+	 * @note the text is shown in a QLabel, you should escape HTML, if needed.
 	 *
 	 * @param eventId is the name of the event
 	 * @param text is the text of the notification to show in the popup.
 	 * @param pixmap is a picture which may be shown in the popup.
 	 * @param widget is a widget where the notification reports to
-	 * @param actions is a list of action texts.
-	 * @param contexts is the lists of contexts, see ContextList
 	 * @param flags is a bitmask of NotificationFlag
          * @param componentData used to determine the location of the config file.  by default, kapp is used
 	 */
