@@ -23,7 +23,6 @@
 #include <QWidget>
 #include <QtDBus/QtDBus>
 
-#include <kstaticdeleter.h>
 #include <kdebug.h>
 #include <kapplication.h>
 #include <kiconloader.h>
@@ -38,13 +37,9 @@ struct KNotificationManager::Private
     QDBusInterface *knotify;
 };
 
-KNotificationManager * KNotificationManager::s_self = 0L;
-
 KNotificationManager * KNotificationManager::self()
 {
-    static KStaticDeleter<KNotificationManager> deleter;
-    if(!s_self)
-        deleter.setObject( s_self, new KNotificationManager() );
+    K_GLOBAL_STATIC(KNotificationManager, s_self)
     return s_self;
 }
 
@@ -54,23 +49,25 @@ KNotificationManager::KNotificationManager()
 {
     d->knotify =
         new QDBusInterface(QLatin1String("org.kde.knotify"), QLatin1String("/Notify"), QLatin1String("org.kde.KNotify"), QDBusConnection::sessionBus(), this);
-    QObject::connect(d->knotify, SIGNAL(notificationClosed(int)),
-                     this, SLOT(notificationClosed(int)));
-    QObject::connect(d->knotify, SIGNAL(notificationActivated(int,int)),
-                     this, SLOT(notificationActivated(int,int)));
+    if (d->knotify->isValid())
+    {
+        QObject::connect(d->knotify, SIGNAL(notificationClosed(int)),
+                         this, SLOT(notificationClosed(int)));
+        QObject::connect(d->knotify, SIGNAL(notificationActivated(int,int)),
+                         this, SLOT(notificationActivated(int,int)));
+    }
 }
 
 
 KNotificationManager::~KNotificationManager()
 {
-    s_self = 0L;
     delete d->knotify;
     delete d;
 }
 
 void KNotificationManager::notificationActivated( int id, int action )
 {
-    kDebug(299) << k_funcinfo << id << " " << action << endl;
+    kDebug(299) << id << " " << action;
     if(d->notifications.contains(id))
     {
         KNotification *n = d->notifications[id];
@@ -81,7 +78,7 @@ void KNotificationManager::notificationActivated( int id, int action )
 
 void KNotificationManager::notificationClosed( int id )
 {
-	kDebug( 299 ) << k_funcinfo << id  << endl;
+    kDebug( 299 ) << id;
     if(d->notifications.contains(id))
     {
         KNotification *n = d->notifications[id];
@@ -96,7 +93,7 @@ void KNotificationManager::close( int id )
     QDBusReply<void> reply = d->knotify->call("closeNotification", id);
     if (!reply.isValid())
     {
-        kWarning(299) << k_funcinfo << "error while contacting knotify server" << endl;
+        kWarning(299) << "error while contacting knotify server";
     }
 }
 
@@ -108,7 +105,7 @@ unsigned int KNotificationManager::notify( KNotification* n, const QPixmap &pix,
     WId winId=n->widget() ? n->widget()->topLevelWidget()->winId()  : 0;
 
     QByteArray pixmapData;
-    
+
     {
         QDataStream arg(&pixmapData, QIODevice::WriteOnly);
         arg << pix;
@@ -122,14 +119,14 @@ unsigned int KNotificationManager::notify( KNotification* n, const QPixmap &pix,
         vl << ctx.first << ctx.second;
         contextList << vl;
     }
-    
+
     QDBusReply<int> reply =
         d->knotify->call("event", n->eventId(),
                          (appname.isEmpty() ? KGlobal::mainComponent().componentName() : appname),
                          contextList, n->text(), pixmapData, actions, qlonglong(winId));
     if (!reply.isValid())
     {
-        kWarning(299) << k_funcinfo << "error while contacting knotify server" << endl;
+        kWarning(299) << "error while contacting knotify server";
     }
     else
     {
@@ -149,7 +146,7 @@ void KNotificationManager::update(KNotification * n, int id)
 {
 	if(id <= 0)
 		return;
-	
+
 	QByteArray pixmapData;
 	QDataStream arg(&pixmapData, QIODevice::WriteOnly);
 	arg << n->pixmap();
@@ -163,12 +160,12 @@ void KNotificationManager::reemit(KNotification * n, int id)
 	typedef QPair<QString,QString> Context;
 	foreach (const Context& ctx, n->contexts())
 	{
-//		kDebug(299) << k_funcinfo << "add context " << ctx.first << "-" << ctx.second  << endl;
+//		kDebug(299) << "add context " << ctx.first << "-" << ctx.second;
 		QVariantList vl;
 		vl << ctx.first << ctx.second;
 		contextList << vl;
 	}
-    
+
 	d->knotify->call(/*QDBus::NoWaitForReply,*/"reemit", id, contextList);
 }
 
