@@ -4,8 +4,24 @@
  *   License              : This file is released under the terms of the LGPL, version 2.
  *   email                : rich@kde.org
  *   email                : sascha.cunz@tiscali.de
+ *
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Library General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2 of the License, or (at your option) any later version.
+ *
+ *   This library is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Library General Public License for more details.
+ *
+ *   You should have received a copy of the GNU Library General Public License
+ *   along with this library; see the file COPYING.LIB.  If not, write to
+ *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  */
 
+#include "kpassivepopup.h"
+#include "kpassivepopup.moc"
 
 // Qt
 #include <QApplication>
@@ -18,11 +34,11 @@
 #include <QPolygonF>
 #include <QTimer>
 #include <QToolTip>
+#include <QSystemTrayIcon>
 
 #include <kvbox.h>
 #include <kdebug.h>
 #include <kdialog.h>
-#include <kpixmapeffect.h>
 #include <kglobalsettings.h>
 
 #include <kconfig.h>
@@ -32,9 +48,7 @@
 #include <netwm.h>
 #endif
 
-#include "config.h"
-#include "kpassivepopup.h"
-#include "kpassivepopup.moc"
+#include <config.h>
 
 static const int DEFAULT_POPUP_TYPE = KPassivePopup::Boxed;
 static const int DEFAULT_POPUP_TIME = 6*1000;
@@ -166,7 +180,7 @@ void KPassivePopup::setView( QWidget *child )
 void KPassivePopup::setView( const QString &caption, const QString &text,
                              const QPixmap &icon )
 {
-    // kDebug() << "KPassivePopup::setView " << caption << ", " << text << endl;
+    // kDebug() << "KPassivePopup::setView " << caption << ", " << text;
     setView( standardView( caption, text, icon, this ) );
 }
 
@@ -258,20 +272,25 @@ void KPassivePopup::mouseReleaseEvent( QMouseEvent *e )
 // Main Implementation
 //
 
-void KPassivePopup::show()
+void KPassivePopup::setVisible( bool visible )
 {
+    if (! visible ) {
+        QFrame::setVisible( visible );
+        return;
+    }
+
     if ( size() != sizeHint() )
-	resize( sizeHint() );
+        resize( sizeHint() );
 
     if ( d->fixedPosition.isNull() )
-	positionSelf();
+        positionSelf();
     else {
-	if( d->popupStyle == Balloon )
-	    setAnchor( d->fixedPosition );
-	else
-	    move( d->fixedPosition );
+        if( d->popupStyle == Balloon )
+            setAnchor( d->fixedPosition );
+        else
+            move( d->fixedPosition );
     }
-    QFrame::show();
+    QFrame::setVisible( /*visible=*/ true );
 
     int delay = d->hideDelay;
     if ( delay < 0 ) {
@@ -283,6 +302,11 @@ void KPassivePopup::show()
     }
 }
 
+void KPassivePopup::show()
+{
+    QFrame::show();
+}
+
 void KPassivePopup::show(const QPoint &p)
 {
     d->fixedPosition = p;
@@ -327,17 +351,11 @@ void KPassivePopup::positionSelf()
 
     else {
         NETWinInfo ni( QX11Info::display(), d->window, QX11Info::appRootWindow(),
-                       NET::WMIconGeometry | NET::WMKDESystemTrayWinFor );
+                       NET::WMIconGeometry );
 
         // Figure out where to put the popup. Note that we must handle
         // windows that skip the taskbar cleanly
-        if ( ni.kdeSystemTrayWinFor() ) {
-            NETRect frame, win;
-            ni.kdeGeometry( frame, win );
-            target.setRect( win.pos.x, win.pos.y,
-                            win.size.width, win.size.height );
-        }
-        else if ( ni.state() & NET::SkipTaskbar ) {
+        if ( ni.state() & NET::SkipTaskbar ) {
             target = defaultArea();
         }
         else {
@@ -359,11 +377,19 @@ void KPassivePopup::positionSelf()
 
 void KPassivePopup::moveNear( const QRect &target )
 {
+    QPoint pos = calculateNearbyPoint(target);
+    if( d->popupStyle == Balloon )
+        setAnchor( pos );
+    else
+        move( pos.x(), pos.y() );
+}
+
+QPoint KPassivePopup::calculateNearbyPoint( const QRect &target) {
     QPoint pos = target.topLeft();
     int x = pos.x();
     int y = pos.y();
-    int w = width();
-    int h = height();
+    int w = minimumSizeHint().width();
+    int h = minimumSizeHint().height();
 
     QRect r = KGlobalSettings::desktopGeometry(QPoint(x+w/2,y+h/2));
 
@@ -397,10 +423,7 @@ void KPassivePopup::moveNear( const QRect &target )
     if ( x < r.left() )
         x = r.left();
 
-    if( d->popupStyle == Balloon )
-        setAnchor( QPoint( x, y ) );
-    else
-        move( x, y );
+    return QPoint( x, y );
 }
 
 QPoint KPassivePopup::anchor() const
@@ -450,31 +473,32 @@ void KPassivePopup::updateMask()
     QBitmap mask( width(), height() );
     mask.clear();
     QPainter p( &mask );
-    QBrush brush( Qt::white, Qt::SolidPattern );
+    QBrush brush( Qt::color1, Qt::SolidPattern );
     p.setBrush( brush );
 
     int i = 0, z = 0;
     for (; i < 4; ++i) {
         QPainterPath path;
-        path.arcTo(corners[i].x(),corners[i].y(),40,40, i * 16 * 90 , 16 * 90);
+        path.moveTo(corners[i].x(),corners[i].y());
+        path.arcTo(corners[i].x(),corners[i].y(),40,40, i * 90 , 90);
         QPolygon corner = path.toFillPolygon().toPolygon();
 
-        d->surround.resize( z + corner.count() );
-        for (int s = 0; s < corner.count() - 1; s++) {
-            d->surround.setPoint( z++, corner[s] );
+        d->surround.resize( z + corner.count() - 1 );
+        for (int s = 1; s < corner.count() - 1; s++, z++) {
+            d->surround.setPoint( z, corner[s] );
         }
 
         if (bottom && i == 2) {
             if (right) {
                 d->surround.resize( z + 3 );
-                d->surround.setPoint( z++, QPoint( width() - xh, height() - 11 ) );
+                d->surround.setPoint( z++, QPoint( width() - xh, height() - 10 ) );
                 d->surround.setPoint( z++, QPoint( width() - 20, height() ) );
-                d->surround.setPoint( z++, QPoint( width() - xl, height() - 11 ) );
+                d->surround.setPoint( z++, QPoint( width() - xl, height() - 10 ) );
             } else {
                 d->surround.resize( z + 3 );
-                d->surround.setPoint( z++, QPoint( xl, height() - 11 ) );
+                d->surround.setPoint( z++, QPoint( xl, height() - 10 ) );
                 d->surround.setPoint( z++, QPoint( 20, height() ) );
-                d->surround.setPoint( z++, QPoint( xh, height() - 11 ) );
+                d->surround.setPoint( z++, QPoint( xh, height() - 10 ) );
             }
         } else if (!bottom && i == 0) {
             if (right) {
@@ -530,6 +554,25 @@ KPassivePopup *KPassivePopup::message( const QString &caption, const QString &te
     return message( DEFAULT_POPUP_TYPE, caption, text, icon, parent, timeout );
 }
 
+KPassivePopup *KPassivePopup::message( const QString &caption, const QString &text,
+                       const QPixmap &icon,
+                       QSystemTrayIcon *parent, int timeout )
+{
+    return message( DEFAULT_POPUP_TYPE, caption, text, icon, parent, timeout );
+}
+
+KPassivePopup *KPassivePopup::message( const QString &text, QSystemTrayIcon *parent )
+{
+    return message( DEFAULT_POPUP_TYPE, QString(), text, QPixmap(), parent );
+}
+
+KPassivePopup *KPassivePopup::message( const QString &caption, const QString &text,
+                       QSystemTrayIcon *parent )
+{
+    return message( DEFAULT_POPUP_TYPE, caption, text, QPixmap(), parent );
+}
+
+
 KPassivePopup *KPassivePopup::message( int popupStyle, const QString &caption, const QString &text,
 				       const QPixmap &icon,
 				       QWidget *parent, int timeout )
@@ -568,6 +611,34 @@ KPassivePopup *KPassivePopup::message( int popupStyle, const QString &caption, c
     return pop;
 }
 
+KPassivePopup *KPassivePopup::message( int popupStyle, const QString &caption, const QString &text,
+                       const QPixmap &icon,
+                       QSystemTrayIcon *parent, int timeout )
+{
+    KPassivePopup *pop = new KPassivePopup( );
+    pop->setPopupStyle( popupStyle );
+    pop->setAutoDelete( true );
+    pop->setView( caption, text, icon );
+    pop->d->hideDelay = timeout;
+    QPoint pos = pop->calculateNearbyPoint(parent->geometry());
+    pop->show(pos);
+    pop->moveNear(parent->geometry());
+
+    return pop;
+}
+
+KPassivePopup *KPassivePopup::message( int popupStyle, const QString &text, QSystemTrayIcon *parent )
+{
+    return message( popupStyle, QString(), text, QPixmap(), parent );
+}
+
+KPassivePopup *KPassivePopup::message( int popupStyle, const QString &caption, const QString &text,
+                       QSystemTrayIcon *parent )
+{
+    return message( popupStyle, caption, text, QPixmap(), parent );
+}
+
+
 // Local Variables:
 // c-basic-offset: 4
 // End:
