@@ -6,16 +6,31 @@
  *   License              : This file is released under the terms of the LGPL, version 2.
  *   Email                : rich@kde.org
  *   Email                : sascha.cunz@tiscali.de
+ *
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2 of the License, or (at your option) any later version.
+ *
+ *   This library is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
+ *
+ *   You should have received a copy of the GNU Lesser General Public
+ *   License along with this library; if not, write to the Free Software
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifndef KPASSIVEPOPUP_H
 #define KPASSIVEPOPUP_H
 
+#include <kdeui_export.h>
+
 #include <QtGui/QFrame>
 
-#include <kdelibs_export.h>
-
 class KVBox;
+class QSystemTrayIcon;
 
 /**
  * @short A dialog-like popup that displays messages without interupting the user.
@@ -54,8 +69,8 @@ class KVBox;
  *    (void) new QLabel( vb, "<b>Isn't this great?</b>" );
  *
  *    KHBox *box = new KHBox( vb );
- *    (void) new QPushButton( box, "Yes" );
- *    (void) new QPushButton( box, "No" );
+ *    (void) new QPushButton( "Yes", box );
+ *    (void) new QPushButton( "No", box );
  *
  *    pop->setView( vb );
  *    pop->show();
@@ -176,7 +191,7 @@ public:
     /**
      * If no relative window (eg taskbar button, system tray window) is
      * available, use this rectangle (pass it to moveNear()).
-     * Basically KWinModule::workArea() with width and height set to 0
+     * Basically KWindowSystem::workArea() with width and height set to 0
      * so that moveNear uses the upper-left position.
      * @return The QRect to be passed to moveNear() if no other is
      * available.
@@ -205,6 +220,14 @@ public:
      */
     static KPassivePopup *message( const QString &text, QWidget *parent );
 
+    /**
+     * Convenience method that displays popup with the specified  message  beside the
+     * icon of the specified QSystemTrayIcon.
+     * Note that the returned object is destroyed when it is hidden.
+     * @see setAutoDelete
+     */
+    static KPassivePopup *message( const QString &text, QSystemTrayIcon *parent );
+
     /**
      * Convenience method that displays popup with the specified caption and message
      * beside the icon of the specified widget.
@@ -214,6 +237,15 @@ public:
     static KPassivePopup *message( const QString &caption, const QString &text,
 				   QWidget *parent );
 
+    /**
+     * Convenience method that displays popup with the specified caption and message
+     * beside the icon of the specified QSystemTrayIcon.
+     * Note that the returned object is destroyed when it is hidden.
+     * @see setAutoDelete
+     */
+    static KPassivePopup *message( const QString &caption, const QString &text,
+                   QSystemTrayIcon *parent );
+
     /**
      * Convenience method that displays popup with the specified icon, caption and
      * message beside the icon of the specified widget.
@@ -224,6 +256,16 @@ public:
 				   const QPixmap &icon,
 				   QWidget *parent, int timeout = -1 );
 
+    /**
+     * Convenience method that displays popup with the specified icon, caption and
+     * message beside the icon of the specified QSystemTrayIcon.
+     * Note that the returned object is destroyed when it is hidden.
+     * @see setAutoDelete
+     */
+    static KPassivePopup *message( const QString &caption, const QString &text,
+                   const QPixmap &icon,
+                   QSystemTrayIcon *parent, int timeout = -1 );
+
     /**
      * Convenience method that displays popup with the specified icon, caption and
      * message beside the icon of the specified window.
@@ -242,6 +284,23 @@ public:
      */
     static KPassivePopup *message( int popupStyle, const QString &text, QWidget *parent );
 
+    /**
+     * Convenience method that displays popup with the specified popup-style and message beside the
+     * icon of the specified QSystemTrayIcon.
+     * Note that the returned object is destroyed when it is hidden.
+     * @see setAutoDelete
+     */
+    static KPassivePopup *message( int popupStyle, const QString &text, QSystemTrayIcon *parent );
+
+    /**
+     * Convenience method that displays popup with the specified popup-style, caption and message
+     * beside the icon of the specified QSystemTrayIcon.
+     * Note that the returned object is destroyed when it is hidden.
+     * @see setAutoDelete
+     */
+    static KPassivePopup *message( int popupStyle, const QString &caption, const QString &text,
+				   QSystemTrayIcon *parent );
+
     /**
      * Convenience method that displays popup with the specified popup-style, caption and message
      * beside the icon of the specified widget.
@@ -249,7 +308,7 @@ public:
      * @see setAutoDelete
      */
     static KPassivePopup *message( int popupStyle, const QString &caption, const QString &text,
-				   QWidget *parent );
+                   QWidget *parent );
 
     /**
      * Convenience method that displays popup with the specified popup-style, icon, caption and
@@ -261,6 +320,16 @@ public:
 				   const QPixmap &icon,
 				   QWidget *parent, int timeout = -1 );
 
+    /**
+     * Convenience method that displays popup with the specified popup-style, icon, caption and
+     * message beside the icon of the specified QSystemTrayIcon.
+     * Note that the returned object is destroyed when it is hidden.
+     * @see setAutoDelete
+     */
+    static KPassivePopup *message( int popupStyle, const QString &caption, const QString &text,
+                   const QPixmap &icon,
+                   QSystemTrayIcon *parent, int timeout = -1 );
+
     /**
      * Convenience method that displays popup with the specified popup-style, icon, caption and
      * message beside the icon of the specified window.
@@ -292,13 +361,15 @@ public Q_SLOTS:
     /**
      * Reimplemented to reposition the popup.
      */
-    virtual void show();
+    void show();
 
     /**
      * Shows the popup in the given point
      */
     void show(const QPoint &p);
 
+    virtual void setVisible(bool visible);
+
 Q_SIGNALS:
     /**
      * Emitted when the popup is clicked.
@@ -327,6 +398,11 @@ protected:
      */
     void moveNear( const QRect &target );
 
+    /**
+     * Calculates the position to place the popup near the specified rectangle.
+     */
+    QPoint calculateNearbyPoint( const QRect &target);  
+
     /**
      * Reimplemented to detect mouse clicks.
      */
