@@ -18,7 +18,7 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include "config.h"
+#include "ksystemtrayicon.h"
 #include "kaboutdata.h"
 #include "kaction.h"
 #include "kcomponentdata.h"
@@ -26,20 +26,20 @@
 #include "kmenu.h"
 #include "kmessagebox.h"
 #include "kshortcut.h"
-#include "ksystemtrayicon.h"
 #include "kactioncollection.h"
 #include "kstandardaction.h"
 
+#include <config.h>
+
 #ifdef Q_WS_X11
-#include <kwin.h>
-#include <kwinmodule.h>
+#include <kwindowsystem.h>
 #include <QX11Info>
 #endif
 
 #include <kconfig.h>
 #include <kiconloader.h>
+#include <kapplication.h>
 
-#include <QApplication>
 #include <QMouseEvent>
 #include <kconfiggroup.h>
 
@@ -69,27 +69,28 @@ public:
 };
 
 KSystemTrayIcon::KSystemTrayIcon( QWidget* parent )
-    : QSystemTrayIcon( parent )
+    : QSystemTrayIcon( parent ),
+      d( new KSystemTrayIconPrivate( this, parent ) )
 {
     init( parent );
 }
 
 KSystemTrayIcon::KSystemTrayIcon( const QString& icon, QWidget* parent )
-    : QSystemTrayIcon( loadIcon( icon ), parent )
+    : QSystemTrayIcon( loadIcon( icon ), parent ),
+      d( new KSystemTrayIconPrivate( this, parent ) )
 {
     init( parent );
 }
 
 KSystemTrayIcon::KSystemTrayIcon( const QIcon& icon, QWidget* parent )
-    : QSystemTrayIcon( icon, parent )
+    : QSystemTrayIcon( icon, parent ),
+      d( new KSystemTrayIconPrivate( this, parent ) )
 {
     init( parent );
 }
 
 void KSystemTrayIcon::init( QWidget* parent )
 {
-    d = new KSystemTrayIconPrivate( this, parent );
-
     d->menu = new KMenu( parent );
     d->menu->addTitle( qApp->windowIcon(), KGlobal::caption() );
     d->menu->setTitle( KGlobal::mainComponent().aboutData()->programName() );
@@ -105,7 +106,7 @@ void KSystemTrayIcon::init( QWidget* parent )
         connect( action, SIGNAL( triggered( bool ) ), this, SLOT( minimizeRestoreAction() ) );
 
 #ifdef Q_WS_X11
-        KWin::WindowInfo info = KWin::windowInfo( parent->winId(), NET::WMDesktop );
+        KWindowInfo info = KWindowSystem::windowInfo( parent->winId(), NET::WMDesktop );
         d->onAllDesktops = info.onAllDesktops();
 #else
         d->onAllDesktops = false;
@@ -188,6 +189,7 @@ void KSystemTrayIcon::maybeQuit()
     if (KMessageBox::warningContinueCancel(d->window, query,
                                      i18n("Confirm Quit From System Tray"),
                                      KStandardGuiItem::quit(),
+                                     KStandardGuiItem::cancel(),
                                      QString("systemtrayquit%1")
                                             .arg(caption)) !=
         KMessageBox::Continue)
@@ -215,7 +217,7 @@ void KSystemTrayIcon::activateOrHide( QSystemTrayIcon::ActivationReason reasonCa
     }
 
 #ifdef Q_WS_X11
-    KWin::WindowInfo info1 = KWin::windowInfo( pw->winId(), NET::XAWMState | NET::WMState );
+    KWindowInfo info1 = KWindowSystem::windowInfo( pw->winId(), NET::XAWMState | NET::WMState );
     // mapped = visible (but possibly obscured)
     bool mapped = (info1.mappingState() == NET::Visible) && !info1.isMinimized();
 //    - not mapped -> show, raise, focus
@@ -226,15 +228,14 @@ void KSystemTrayIcon::activateOrHide( QSystemTrayIcon::ActivationReason reasonCa
         minimizeRestore( true );
     else
     {
-        KWinModule module;
-        QListIterator< WId > it (module.stackingOrder());
+        QListIterator< WId > it (KWindowSystem::stackingOrder());
         it.toBack();
         while( it.hasPrevious() )
         {
             WId id = it.previous();
             if( id == pw->winId() )
                 break;
-            KWin::WindowInfo info2 = KWin::windowInfo( id,
+            KWindowInfo info2 = KWindowSystem::windowInfo( id,
                 NET::WMGeometry | NET::XAWMState | NET::WMState | NET::WMWindowType );
             if( info2.mappingState() != NET::Visible )
                 continue; // not visible on current desktop -> ignore
@@ -248,7 +249,7 @@ void KSystemTrayIcon::activateOrHide( QSystemTrayIcon::ActivationReason reasonCa
             if( type == NET::Dock || type == NET::TopMenu )
                 continue; // obscured by dock or topmenu -> ignore
             pw->raise();
-            KWin::activateWindow( pw->winId());
+            KWindowSystem::activateWindow( pw->winId());
             return;
         }
         minimizeRestore( false ); // hide
@@ -262,17 +263,17 @@ void KSystemTrayIcon::minimizeRestore( bool restore )
     if( !pw )
 	return;
 #ifdef Q_WS_X11
-    KWin::WindowInfo info = KWin::windowInfo( pw->winId(), NET::WMGeometry | NET::WMDesktop );
+    KWindowInfo info = KWindowSystem::windowInfo( pw->winId(), NET::WMGeometry | NET::WMDesktop );
     if ( restore )
     {
 	if( d->onAllDesktops )
-	    KWin::setOnAllDesktops( pw->winId(), true );
+	    KWindowSystem::setOnAllDesktops( pw->winId(), true );
 	else
-	    KWin::setCurrentDesktop( info.desktop() );
+	    KWindowSystem::setCurrentDesktop( info.desktop() );
         pw->move( info.geometry().topLeft() ); // avoid placement policies
         pw->show();
         pw->raise();
-	KWin::activateWindow( pw->winId() );
+	KWindowSystem::activateWindow( pw->winId() );
     } else {
 	d->onAllDesktops = info.onAllDesktops();
 	pw->hide();
@@ -297,5 +298,12 @@ void KSystemTrayIcon::toggleActive()
     activateOrHide( QSystemTrayIcon::Trigger );
 }
 
+bool KSystemTrayIcon::parentWidgetTrayClose() const
+{
+    if( kapp != NULL && kapp->sessionSaving())
+        return false; // normal close
+    return true;
+}
+
 #include "ksystemtrayicon.moc"
 
