@@ -18,12 +18,12 @@
 #ifndef KSYSTEMTRAY_H
 #define KSYSTEMTRAY_H
 
-#include <QtGui/QSystemTrayIcon>
-
+#include <kdeui_export.h>
 #include <kglobal.h>
 
+#include <QtGui/QSystemTrayIcon>
+
 class KActionCollection;
-class KMenu;
 class KSystemTrayIconPrivate;
 
 /**
@@ -68,13 +68,13 @@ public:
      * Same as above but allows one to define the icon by name that should
      * be used for the system tray icon.
      */
-    KSystemTrayIcon( const QString& icon, QWidget* parent = 0 );
+    explicit KSystemTrayIcon( const QString& icon, QWidget* parent = 0 );
 
     /**
      * Same as above but allows one to define the icon by name that should
      * be used for the system tray icon.
      */
-    KSystemTrayIcon( const QIcon& icon, QWidget* parent = 0 );
+    explicit KSystemTrayIcon( const QIcon& icon, QWidget* parent = 0 );
 
     /*
       Destructor
@@ -92,6 +92,14 @@ public:
     */
     QWidget *parentWidget() const;
 
+    /**
+       Function to be used from function handling closing of the window associated 
+       with the tray icon (i.e. QWidget::closeEvent(), KMainWindow::queryClose() or 
+       similar). When false is returned, the window closing should proceed normally, 
+       when true is returned, special systray-related handling should take place.
+     */
+    bool parentWidgetTrayClose() const;
+
     /**
      * Loads an icon @p icon using the icon loader class of the given componentData @p componentData.
      * The icon is applied the panel effect as it should only be used to be shown in the
@@ -120,7 +128,7 @@ private:
     void init( QWidget* );
     void minimizeRestore( bool restore );
 
-    KSystemTrayIconPrivate* d;
+    KSystemTrayIconPrivate* const d;
 };
 
 #endif
