@@ -21,19 +21,19 @@
 */
 
 
-#include <QApplication>
-#include <QComboBox>
-#include <QEvent>
-#include <QStyle>
-#include <QScrollBar>
-#include <QKeyEvent>
+#include "kcompletionbox.h"
+
+#include <QtCore/QEvent>
+#include <QtGui/QApplication>
+#include <QtGui/QComboBox>
+#include <QtGui/QStyle>
+#include <QtGui/QScrollBar>
+#include <QtGui/QKeyEvent>
 
 #include <kdebug.h>
 #include <kconfig.h>
 #include <kglobalsettings.h>
 
-#include "kcompletionbox.h"
-
 class KCompletionBox::KCompletionBoxPrivate
 {
 public:
@@ -232,8 +232,7 @@ bool KCompletionBox::eventFilter( QObject *o, QEvent *e )
 
             // parent gets a click -> we hide
             else if ( type == QEvent::Resize ||
-                      type == QEvent::Close || type == QEvent::Hide ||
-                      type == QEvent::Move ) {
+                      type == QEvent::Close || type == QEvent::Hide ) {
                 hide();
             }
             
@@ -317,36 +316,35 @@ void KCompletionBox::sizeAndPosition()
     }
 }
 
-void KCompletionBox::show()
+void KCompletionBox::setVisible( bool visible )
 {
-    d->upwardBox = false;
-    if ( d->m_parent ) {
-        sizeAndPosition();
-        qApp->installEventFilter( this );
+    if (visible) {
+        d->upwardBox = false;
+        if ( d->m_parent ) {
+            sizeAndPosition();
+            qApp->installEventFilter( this );
+        }
+
+        // ### we shouldn't need to call this, but without this, the scrollbars
+        // are pretty b0rked.
+        //triggerUpdate( true );
+
+        // Workaround for I'm not sure whose bug - if this KCompletionBox' parent
+        // is in a layout, that layout will detect inserting new child (posted
+        // ChildInserted event), and will trigger relayout (post LayoutHint event).
+        // QWidget::show() sends also posted ChildInserted events for the parent,
+        // and later all LayoutHint events, which causes layout updating.
+        // The problem is, KCompletionBox::eventFilter() detects resizing
+        // of the parent, and calls hide() - and this hide() happen in the middle
+        // of show(), causing inconsistent state. I'll try to submit a Qt patch too.
+        qApp->sendPostedEvents();
+    } else {
+        if ( d->m_parent )
+            qApp->removeEventFilter( this );
+        d->cancelText.clear();
     }
-
-    // ### we shouldn't need to call this, but without this, the scrollbars
-    // are pretty b0rked.
-    //triggerUpdate( true );
-
-    // Workaround for I'm not sure whose bug - if this KCompletionBox' parent
-    // is in a layout, that layout will detect inserting new child (posted
-    // ChildInserted event), and will trigger relayout (post LayoutHint event).
-    // QWidget::show() sends also posted ChildInserted events for the parent,
-    // and later all LayoutHint events, which causes layout updating.
-    // The problem is, KCompletionBox::eventFilter() detects resizing
-    // of the parent, and calls hide() - and this hide() happen in the middle
-    // of show(), causing inconsistent state. I'll try to submit a Qt patch too.
-    qApp->sendPostedEvents();
-    KListWidget::show();
-}
-
-void KCompletionBox::hide()
-{
-    if ( d->m_parent )
-        qApp->removeEventFilter( this );
-    d->cancelText.clear();
-    KListWidget::hide();
+  
+    KListWidget::setVisible(visible);
 }
 
 QRect KCompletionBox::calculateGeometry() const
@@ -562,8 +560,15 @@ void KCompletionBox::setItems( const QStringList& items )
     d->down_workaround = true;
 }
 
+void KCompletionBox::slotSetCurrentItem( QListWidgetItem *i )
+{
+    setCurrentItem( i ); // grrr
+}
+
 void KCompletionBox::slotCurrentChanged()
 {
+    if (currentItem())
+      emit currentTextChanged(currentItem()->text());
     d->down_workaround = false;
 }
 
