@@ -179,12 +179,7 @@ public Q_SLOTS:
     /**
      * Re-implemented for internal reasons.  API is unaffected.
      */
-    virtual void show();
-
-    /**
-     * Re-implemented for internal reasons.  API is unaffected.
-     */
-    virtual void hide();
+    virtual void setVisible( bool visible );
 
 Q_SIGNALS:
     /**
@@ -226,7 +221,7 @@ protected Q_SLOTS:
     virtual void slotActivated( QListWidgetItem * );
 
 private Q_SLOTS:
-    void slotSetCurrentItem( QListWidgetItem *i ) { setCurrentItem( i ); } // grrr
+    void slotSetCurrentItem( QListWidgetItem *i ); // grrr
     void slotCurrentChanged();
     void canceled();
     void slotItemClicked( QListWidgetItem * );
