@@ -28,7 +28,7 @@
 #include "klineedit.h"
 
 #include <kconfig.h>
-#include <qtooltip.h>
+#include <QtGui/QToolTip>
 #include <kcursor.h>
 #include <klocale.h>
 #include <kstandardshortcut.h>
@@ -110,7 +110,6 @@ public:
     bool enableClickMsg:1;
     bool drawClickMsg:1;
 
-    bool bEnableMenu :1; 
     bool possibleTripleClick :1;  // set in mousePressEvent, deleted in tripleClickTimeout
 
     bool clickInClear:1;
@@ -152,7 +151,7 @@ void KLineEdit::init()
     d->bgRole = backgroundRole();
 
     // Enable the context menu by default.
-    KLineEdit::setContextMenuEnabled( true );
+    QLineEdit::setContextMenuPolicy( Qt::DefaultContextMenu );
     KCursor::setAutoHideCursor( this, true, true );
     installEventFilter( this );
 
@@ -186,8 +185,8 @@ void KLineEdit::setClearButtonShown(bool show)
         d->clearButton->setCursor( Qt::ArrowCursor );
         d->clearButton->setToolTip( i18n( "Clear text" ) );
 
-        updateClearButton();
         updateClearButtonIcon(text());
+        updateClearButton();
         d->clearButton->show();
         connect(this, SIGNAL(textChanged(QString)), this, SLOT(updateClearButtonIcon(QString)));
     } else {
@@ -225,9 +224,9 @@ void KLineEdit::updateClearButtonIcon(const QString& text)
     }
 
     if ( qApp->isLeftToRight() ) {
-        d->clearButton->setPixmap( SmallIcon( "clear_left.png", 0, d->clickButtonState ) );
+        d->clearButton->setPixmap( SmallIcon( "clear-left", 0, d->clickButtonState ) );
     } else {
-        d->clearButton->setPixmap( SmallIcon("locationbar_erase.png", 0, d->clickButtonState ) );
+        d->clearButton->setPixmap( SmallIcon("locationbar-erase", 0, d->clickButtonState ) );
     }
 }
 
@@ -244,7 +243,11 @@ void KLineEdit::updateClearButton()
 
     if (newButtonSize != d->clearButton->size()) {
         d->clearButton->resize(newButtonSize);
-        setStyleSheet(QString("QLineEdit { padding-right: %1; }").arg(buttonWidth));
+
+        // we don't need to check for RTL here as Qt does that for us
+        // when it comes to style sheets
+        setStyleSheet( QString( "QLineEdit { padding-right: %1; }" )
+                       .arg( buttonWidth ) );
     }
 
     if (qApp->isLeftToRight()) {
@@ -521,16 +524,17 @@ void KLineEdit::setSqueezedText()
 
 void KLineEdit::copy() const
 {
-    copy(true);
+    if( !copySqueezedText(true))
+        QLineEdit::copy();
 }
 
-void KLineEdit::copy(bool clipboard) const
+bool KLineEdit::copySqueezedText(bool clipboard) const
 {
    if (!d->squeezedText.isEmpty() && d->squeezedStart)
    {
       KLineEdit *that = const_cast<KLineEdit *>(this);
       if (!that->hasSelectedText())
-         return;
+         return false;
       int start = selectionStart(), end = start + selectedText().length();
       if (start >= d->squeezedStart+3)
          start = start - 3 - d->squeezedStart + d->squeezedEnd;
@@ -541,17 +545,16 @@ void KLineEdit::copy(bool clipboard) const
       else if (end > d->squeezedStart)
          end = d->squeezedEnd;
       if (start == end)
-         return;
+         return false;
       QString t = d->squeezedText;
       t = t.mid(start, end - start);
       disconnect( QApplication::clipboard(), SIGNAL(selectionChanged()), this, 0);
       QApplication::clipboard()->setText( t, clipboard ? QClipboard::Clipboard : QClipboard::Selection );
       connect( QApplication::clipboard(), SIGNAL(selectionChanged()), this,
                SLOT(_q_clipboardChanged()) );
-      return;
+      return true;
    }
-
-   QLineEdit::copy();
+   return false;
 }
 
 void KLineEdit::resizeEvent( QResizeEvent * ev )
@@ -982,6 +985,7 @@ void KLineEdit::mouseReleaseEvent( QMouseEvent* e )
                 setText( newText );
             } else {
                 clear();
+                emit clearButtonClicked();
             }
             emit textChanged( newText );
         }
@@ -993,10 +997,10 @@ void KLineEdit::mouseReleaseEvent( QMouseEvent* e )
 
     QLineEdit::mouseReleaseEvent( e );
 
-   // Call our own copy() to fix copying of squeezed text
    if (QApplication::clipboard()->supportsSelection() ) {
        if ( e->button() == Qt::LeftButton ) {
-           copy( FALSE );
+            // Fix copying of squeezed text if needed
+            copySqueezedText( false );
        }
    }
 }
@@ -1016,7 +1020,7 @@ QMenu* KLineEdit::createStandardContextMenu()
     // menu item.
     if ( compObj() && !isReadOnly() && KAuthorized::authorize("lineedit_text_completion") )
     {
-        QMenu *subMenu = popup->addMenu( KIcon("completion"), i18n("Text Completion") );
+        QMenu *subMenu = popup->addMenu( KIcon("text-completion"), i18n("Text Completion") );
         connect( subMenu, SIGNAL( triggered ( QAction* ) ),
                  this, SLOT( completionMenuActivated( QAction* ) ) );
 
@@ -1059,7 +1063,7 @@ QMenu* KLineEdit::createStandardContextMenu()
 
 void KLineEdit::contextMenuEvent( QContextMenuEvent *e )
 {
-    if ( !d->bEnableMenu )
+    if ( QLineEdit::contextMenuPolicy() != Qt::DefaultContextMenu )
       return;
     QMenu *popup = createStandardContextMenu();
 
@@ -1229,7 +1233,7 @@ void KLineEdit::setCompletionBox( KCompletionBox *box )
     d->completionBox = box;
     if ( handleSignals() )
     {
-        connect( d->completionBox, SIGNAL(highlighted( const QString& )),
+        connect( d->completionBox, SIGNAL(currentTextChanged( const QString& )),
                  SLOT(setTextWorkaround( const QString& )) );
         connect( d->completionBox, SIGNAL(userCancelled( const QString& )),
                  SLOT(userCancelled( const QString& )) );
@@ -1377,10 +1381,10 @@ void KLineEdit::setCompletedItems( const QStringList& items, bool autoSuggest )
             }
             if ( matchedItem )
             {
-                d->completionBox->blockSignals( true );
+                bool blocked = d->completionBox->blockSignals( true );
                 d->completionBox->setCurrentItem( matchedItem );
                 matchedItem->setSelected(wasSelected);
-                d->completionBox->blockSignals( false );
+                d->completionBox->blockSignals( blocked );
             }
         }
         else // completion box not visible yet -> show it
@@ -1474,8 +1478,11 @@ void KLineEdit::clear()
 
 void KLineEdit::setTextWorkaround( const QString& text )
 {
-    setText( text );
-    end( false ); // force cursor at end
+    if (!text.isNull())
+    {
+        setText( text );
+        end( false ); // force cursor at end
+    }
 }
 
 QString KLineEdit::originalText() const
@@ -1495,16 +1502,24 @@ void KLineEdit::paintEvent( QPaintEvent *ev )
 {
     QLineEdit::paintEvent( ev );
 
-    if ( d->enableClickMsg && d->drawClickMsg && !hasFocus() ) {
+    if ( d->enableClickMsg && d->drawClickMsg && !hasFocus() && text().isEmpty() ) {
         QPainter p( this );
         QPen tmp = p.pen();
         p.setPen( palette().color( QPalette::Disabled, QPalette::Text ) );
 
-        //FIXME: this rect is not where the text actually starts
+        //FIXME: fugly alert!
         // qlineedit uses an internal qstyleoption set to figure this out
         // and then adds a hardcoded 2 pixel interior to that.
         // probably requires fixes to Qt itself to do this cleanly
-        QRect cr = contentsRect();
+        QStyleOptionFrame opt;
+        opt.init( this );
+        opt.rect = contentsRect();
+        opt.lineWidth = hasFrame() ? style()->pixelMetric( QStyle::PM_DefaultFrameWidth ) : 0;
+        opt.midLineWidth = 0;
+        opt.state |= QStyle::State_Sunken;
+        QRect cr = style()->subElementRect( QStyle::SE_LineEditContents, &opt, this );
+        cr.setLeft( cr.left() + 2 );
+        cr.setRight( cr.right() - 2 );
 
         p.drawText( cr, Qt::AlignLeft|Qt::AlignVCenter, d->clickMessage );
         p.setPen( tmp );
@@ -1541,12 +1556,12 @@ void KLineEdit::setClickMessage( const QString &msg )
 
 void KLineEdit::setContextMenuEnabled( bool showMenu )
 {
-    d->bEnableMenu = showMenu;
+    QLineEdit::setContextMenuPolicy( showMenu ? Qt::DefaultContextMenu : Qt::NoContextMenu );
 }
 
 bool KLineEdit::isContextMenuEnabled() const
 {
-    return  d->bEnableMenu;
+    return  ( contextMenuPolicy() == Qt::DefaultContextMenu );
 }
 
 void KLineEdit::setPasswordMode(bool b)
