@@ -91,6 +91,9 @@ class KUrl;
  * for the read-write mode. This differs from QLineEdit's implementation
  * and is done to give visual distinction between the three different modes:
  * disabled, read-only, and read-write.
+ * 
+ * KLineEdit has also a password mode which depends of globals KDE settings.  Use
+ * KLineEdit::setPasswordMode instead of QLineEdit::echoMode property to have a password field.
  *
  * \b Usage \n
  *
@@ -215,13 +218,15 @@ public:
     * if you do not want this behavior.
     *
     * @param showMenu If @p true, show the context menu.
+    * @deprecated use setContextMenuPolicy 
     */
-    virtual void setContextMenuEnabled( bool showMenu );
+    virtual KDE_DEPRECATED void setContextMenuEnabled( bool showMenu );
 
     /**
      * Returns @p true when the context menu is enabled.
+     * @deprecated use contextMenuPolicy
      */
-    bool isContextMenuEnabled() const;
+    KDE_DEPRECATED bool isContextMenuEnabled() const;
 
     /**
      * Enables/Disables handling of URL drops. If enabled and the user
@@ -406,6 +411,11 @@ Q_SIGNALS:
      */
     void aboutToShowContextMenu( QMenu * p );
 
+    /**
+     * Emitted when the user clicked on the clear button
+     */
+    void clearButtonClicked();
+
 public Q_SLOTS:
 
     /**
@@ -596,7 +606,7 @@ private:
      */
     void init();
 
-    void copy( bool clipboard ) const;
+    bool copySqueezedText( bool clipboard ) const;
 
     /**
      * Checks whether we should/should not consume a key used as
