@@ -23,6 +23,8 @@
  *  Boston, MA 02110-1301, USA.
  */
 
+#include "knuminput.h"
+
 #include <config.h>
 #ifdef HAVE_LIMITS_H
 #include <limits.h>
@@ -30,11 +32,11 @@
 #include <assert.h>
 #include <math.h>
 
-#include <QApplication>
-#include <QLabel>
-#include <QLineEdit>
-#include <QResizeEvent>
-#include <QSlider>
+#include <QtGui/QApplication>
+#include <QtGui/QLabel>
+#include <QtGui/QLineEdit>
+#include <QtGui/QResizeEvent>
+#include <QtGui/QSlider>
 
 #include <kdebug.h>
 #include <kdialog.h>
@@ -42,8 +44,6 @@
 #include <klocale.h>
 #include <knumvalidator.h>
 
-#include "knuminput.h"
-
 static inline int calcDiffByTen( int x, int y ) {
     // calculate ( x - y ) / 10 without overflowing ints:
     return ( x / 10 ) - ( y / 10 )  +  ( x % 10 - y % 10 ) / 10;
@@ -51,60 +51,94 @@ static inline int calcDiffByTen( int x, int y ) {
 
 // ----------------------------------------------------------------------------
 
+class KNumInputPrivate
+{
+public:
+    KNumInputPrivate(KNumInput *q, KNumInput *below = 0):
+        q(q),
+        m_prev(0),
+        m_next(0),
+        m_colw1(0),
+        m_colw2(0),
+        m_label(0),
+        m_slider(0),
+        m_alignment(0)
+    {
+        if(below) {
+            m_next = below->d->m_next;
+            m_prev = below;
+            below->d->m_next = q;
+            if(m_next)
+                m_next->d->m_prev = q;
+        }          
+    }
+
+    static KNumInputPrivate *get(const KNumInput *i)
+    {
+        return i->d;
+    }
+  
+    KNumInput *q;
+    KNumInput* m_prev, *m_next;
+    int m_colw1, m_colw2;
+    
+    QLabel*  m_label;
+    QSlider* m_slider;
+    QSize    m_sizeSlider, m_sizeLabel;
+    
+    Qt::Alignment m_alignment;  
+};
+
+
+#define K_USING_KNUMINPUT_P(_d) KNumInputPrivate *_d = KNumInputPrivate::get(this)
+
 KNumInput::KNumInput(QWidget* parent)
-    : QWidget(parent)
+    : QWidget(parent), d(new KNumInputPrivate(this))
 {
-    init();
 }
 
 KNumInput::KNumInput(QWidget* parent, KNumInput* below)
-    : QWidget(parent)
+    : QWidget(parent), d(new KNumInputPrivate(this, below))
 {
-    init();
-
-    if(below) {
-        m_next = below->m_next;
-        m_prev = below;
-        below->m_next = this;
-        if(m_next)
-            m_next->m_prev = this;
-    }
-}
-
-void KNumInput::init()
-{
-    m_prev = m_next = 0;
-    m_colw1 = m_colw2 = 0;
-    m_label = 0;
-    m_slider = 0;
-    m_alignment = 0;
 }
 
 KNumInput::~KNumInput()
 {
-    if(m_prev)
-        m_prev->m_next = m_next;
+    if(d->m_prev)
+        d->m_prev->d->m_next = d->m_next;
 
-    if(m_next)
-        m_next->m_prev = m_prev;
+    if(d->m_next)
+        d->m_next->d->m_prev = d->m_prev;
+    
+    delete d;
+}
+
+QSlider *KNumInput::slider() const
+{
+  return d->m_slider;
+}
+
+bool KNumInput::showSlider() const
+{
+    return d->m_slider;
 }
 
 void KNumInput::setLabel(const QString & label, Qt::Alignment a)
 {
     if(label.isEmpty()) {
-        delete m_label;
-        m_label = 0;
-        m_alignment = 0;
+        delete d->m_label;
+        d->m_label = 0;
+        d->m_alignment = 0;
     }
     else {
-        if (m_label) m_label->setText(label);
-        else m_label = new QLabel(label, this);
-        m_label->setObjectName("KNumInput::QLabel");
-        m_label->setAlignment(a);
+        if (d->m_label) d->m_label->setText(label);
+        else d->m_label = new QLabel(label, this);
+        d->m_label->setObjectName("KNumInput::QLabel");
+        d->m_label->setAlignment(a);
         // if no vertical alignment set, use Top alignment
         if(!(a & (Qt::AlignTop|Qt::AlignBottom|Qt::AlignVCenter)))
            a |= Qt::AlignTop;
-        m_alignment = a;
+        d->m_alignment = a;
     }
 
     layout(true);
@@ -112,65 +146,65 @@ void KNumInput::setLabel(const QString & label, Qt::Alignment a)
 
 QString KNumInput::label() const
 {
-    if (m_label) return m_label->text();
+    if (d->m_label) return d->m_label->text();
     return QString();
 }
 
 void KNumInput::layout(bool deep)
 {
-    int w1 = m_colw1;
-    int w2 = m_colw2;
+    int w1 = d->m_colw1;
+    int w2 = d->m_colw2;
 
     // label sizeHint
-    m_sizeLabel = (m_label ? m_label->sizeHint() : QSize(0,0));
+    d->m_sizeLabel = (d->m_label ? d->m_label->sizeHint() : QSize(0,0));
 
-    if(m_label && (m_alignment & Qt::AlignVCenter))
-        m_colw1 = m_sizeLabel.width() + 4;
+    if(d->m_label && (d->m_alignment & Qt::AlignVCenter))
+        d->m_colw1 = d->m_sizeLabel.width() + 4;
     else
-        m_colw1 = 0;
+        d->m_colw1 = 0;
 
     // slider sizeHint
-    m_sizeSlider = (m_slider ? m_slider->sizeHint() : QSize(0, 0));
+    d->m_sizeSlider = (d->m_slider ? d->m_slider->sizeHint() : QSize(0, 0));
 
     doLayout();
 
     if(!deep) {
-        m_colw1 = w1;
-        m_colw2 = w2;
+        d->m_colw1 = w1;
+        d->m_colw2 = w2;
         return;
     }
 
     KNumInput* p = this;
     while(p) {
         p->doLayout();
-        w1 = qMax(w1, p->m_colw1);
-        w2 = qMax(w2, p->m_colw2);
-        p = p->m_prev;
+        w1 = qMax(w1, p->d->m_colw1);
+        w2 = qMax(w2, p->d->m_colw2);
+        p = p->d->m_prev;
     }
 
-    p = m_next;
+    p = d->m_next;
     while(p) {
         p->doLayout();
-        w1 = qMax(w1, p->m_colw1);
-        w2 = qMax(w2, p->m_colw2);
-        p = p->m_next;
+        w1 = qMax(w1, p->d->m_colw1);
+        w2 = qMax(w2, p->d->m_colw2);
+        p = p->d->m_next;
     }
 
     p = this;
     while(p) {
-        p->m_colw1 = w1;
-        p->m_colw2 = w2;
-        p = p->m_prev;
+        p->d->m_colw1 = w1;
+        p->d->m_colw2 = w2;
+        p = p->d->m_prev;
     }
 
-    p = m_next;
+    p = d->m_next;
     while(p) {
-        p->m_colw1 = w1;
-        p->m_colw2 = w2;
-        p = p->m_next;
+        p->d->m_colw1 = w1;
+        p->d->m_colw2 = w2;
+        p = p->d->m_next;
     }
 
-//    kDebug() << "w1 " << w1 << " w2 " << w2 << endl;
+//    kDebug() << "w1 " << w1 << " w2 " << w2;
 }
 
 QSizePolicy KNumInput::sizePolicy() const
@@ -185,19 +219,27 @@ QSize KNumInput::sizeHint() const
 
 void KNumInput::setSteps(int minor, int major)
 {
-    if(m_slider)
+    if(d->m_slider)
     {
-        m_slider->setSingleStep( minor );
-        m_slider->setPageStep( major );
+        d->m_slider->setSingleStep( minor );
+        d->m_slider->setPageStep( major );
     }
 }
 
 
 // ----------------------------------------------------------------------------
 
+class KIntSpinBox::KIntSpinBoxPrivate
+{
+public:
+    KIntSpinBoxPrivate(KIntSpinBox *q, int val_base = 10): q(q), val_base(val_base) {}
+  
+    KIntSpinBox *q;
+    int val_base;
+};
+
 KIntSpinBox::KIntSpinBox(QWidget *parent)
-    : QSpinBox(parent),
-      val_base(10)
+    : QSpinBox(parent), d(new KIntSpinBoxPrivate(this))
 {
     setRange(0,99);
     setSingleStep(1);
@@ -207,11 +249,11 @@ KIntSpinBox::KIntSpinBox(QWidget *parent)
 
 KIntSpinBox::~KIntSpinBox()
 {
+    delete d;
 }
 
 KIntSpinBox::KIntSpinBox(int lower, int upper, int step, int value, QWidget *parent,int base)
-    : QSpinBox(parent),
-      val_base(base)
+    : QSpinBox(parent), d(new KIntSpinBoxPrivate(this, base))
 {
     setRange(lower,upper);
     setSingleStep(step);
@@ -221,24 +263,24 @@ KIntSpinBox::KIntSpinBox(int lower, int upper, int step, int value, QWidget *par
 
 void KIntSpinBox::setBase(int base)
 {
-    val_base = base;
+    d->val_base = base;
 }
 
 
 int KIntSpinBox::base() const
 {
-    return val_base;
+    return d->val_base;
 }
 
 QString KIntSpinBox::textFromValue(int v) const
 {
-    return QString::number(v, val_base);
+    return QString::number(v, d->val_base);
 }
 
 int KIntSpinBox::valueFromText(const QString &text) const
 {
     bool ok;
-    return text.toInt(&ok, val_base);
+    return text.toInt(&ok, d->val_base);
 }
 
 void KIntSpinBox::setEditFocus(bool mark)
@@ -253,38 +295,49 @@ void KIntSpinBox::setEditFocus(bool mark)
 
 class KIntNumInput::KIntNumInputPrivate {
 public:
+    KIntNumInput *q; 
     int referencePoint;
     short blockRelative;
-    KIntNumInputPrivate( int r )
-	: referencePoint( r ),
+    KIntSpinBox* m_spin;
+    QSize        m_sizeSpin;
+    
+    KIntNumInputPrivate( KIntNumInput *q, int r )
+	: q(q),
+          referencePoint( r ),
 	  blockRelative( 0 ) {}
 };
 
 
 KIntNumInput::KIntNumInput(KNumInput* below, int val,QWidget *parent,int _base)
     : KNumInput(parent,below)
+    , d( new KIntNumInputPrivate( this, val ) )
 {
     init(val, _base);
 }
 
 KIntNumInput::KIntNumInput(QWidget *parent)
     : KNumInput(parent)
+    , d( new KIntNumInputPrivate( this, 0 ) )
 {
     init(0, 10);
 }
 
 KIntNumInput::KIntNumInput(int val, QWidget *parent,int _base)
     : KNumInput(parent)
+    , d( new KIntNumInputPrivate( this, val ) )
 {
     init(val, _base);
+}
 
+QSpinBox *KIntNumInput::spinBox() const
+{
+    return d->m_spin;
 }
 
 void KIntNumInput::init(int val, int _base)
 {
-    d = new KIntNumInputPrivate( val );
-    m_spin = new KIntSpinBox(INT_MIN, INT_MAX, 1, val, this, _base);
-    m_spin->setObjectName("KIntNumInput::KIntSpinBox");
+    d->m_spin = new KIntSpinBox(INT_MIN, INT_MAX, 1, val, this, _base);
+    d->m_spin->setObjectName("KIntNumInput::KIntSpinBox");
     // the KIntValidator is broken beyond believe for
     // spinboxes which have suffix or prefix texts, so
     // better don't use it unless absolutely necessary
@@ -294,11 +347,11 @@ void KIntNumInput::init(int val, int _base)
 //	if (_base != 10)
 //        m_spin->setValidator(new KIntValidator(this, _base, "KNumInput::KIntValidtr"));
 
-    connect(m_spin, SIGNAL(valueChanged(int)), SLOT(spinValueChanged(int)));
+    connect(d->m_spin, SIGNAL(valueChanged(int)), SLOT(spinValueChanged(int)));
     connect(this, SIGNAL(valueChanged(int)),
 	    SLOT(slotEmitRelativeValueChanged(int)));
 
-    setFocusProxy(m_spin);
+    setFocusProxy(d->m_spin);
     layout(true);
 }
 
@@ -314,8 +367,10 @@ int KIntNumInput::referencePoint() const {
 
 void KIntNumInput::spinValueChanged(int val)
 {
-    if(m_slider)
-        m_slider->setValue(val);
+    K_USING_KNUMINPUT_P(priv);
+  
+    if(priv->m_slider)
+        priv->m_slider->setValue(val);
 
     emit valueChanged(val);
 }
@@ -327,39 +382,41 @@ void KIntNumInput::slotEmitRelativeValueChanged( int value ) {
 
 void KIntNumInput::setRange(int lower, int upper, int step, bool slider)
 {
+    K_USING_KNUMINPUT_P(priv);
+  
     upper = qMax(upper, lower);
     lower = qMin(upper, lower);
-    m_spin->setMinimum(lower);
-    m_spin->setMaximum(upper);
-    m_spin->setSingleStep(step);
+    d->m_spin->setMinimum(lower);
+    d->m_spin->setMaximum(upper);
+    d->m_spin->setSingleStep(step);
 
-    step = m_spin->singleStep(); // maybe QRangeControl didn't like out lineStep?
+    step = d->m_spin->singleStep(); // maybe QRangeControl didn't like out lineStep?
 
     if(slider) {
-	if (m_slider)
-	    m_slider->setRange(lower, upper);
+	if (priv->m_slider)
+	    priv->m_slider->setRange(lower, upper);
 	else {
-	    m_slider = new QSlider(Qt::Horizontal, this);
-	    m_slider->setMinimum(lower);
-	    m_slider->setMaximum(upper);
-	    m_slider->setPageStep(step);
-	    m_slider->setValue(m_spin->value());
-	    m_slider->setTickPosition(QSlider::TicksBelow);
-	    connect(m_slider, SIGNAL(valueChanged(int)),
-		    m_spin, SLOT(setValue(int)));
+	    priv->m_slider = new QSlider(Qt::Horizontal, this);
+	    priv->m_slider->setMinimum(lower);
+	    priv->m_slider->setMaximum(upper);
+	    priv->m_slider->setPageStep(step);
+	    priv->m_slider->setValue(d->m_spin->value());
+	    priv->m_slider->setTickPosition(QSlider::TicksBelow);
+	    connect(priv->m_slider, SIGNAL(valueChanged(int)),
+		    d->m_spin, SLOT(setValue(int)));
 	}
 
 	// calculate (upper-lower)/10 without overflowing int's:
         int major = calcDiffByTen( upper, lower );
 	if ( major==0 ) major = step; // #### workaround Qt bug in 2.1-beta4
 
-        m_slider->setSingleStep(step);
-        m_slider->setPageStep(major);
-        m_slider->setTickInterval(major);
+        priv->m_slider->setSingleStep(step);
+        priv->m_slider->setPageStep(major);
+        priv->m_slider->setTickInterval(major);
     }
     else {
-        delete m_slider;
-        m_slider = 0;
+        delete priv->m_slider;
+        priv->m_slider = 0;
     }
 
     // check that reference point is still inside valid range:
@@ -370,130 +427,137 @@ void KIntNumInput::setRange(int lower, int upper, int step, bool slider)
 
 void KIntNumInput::setMinimum(int min)
 {
-    setRange(min, m_spin->maximum(), m_spin->singleStep(), m_slider);
+    K_USING_KNUMINPUT_P(priv);
+    setRange(min, d->m_spin->maximum(), d->m_spin->singleStep(), priv->m_slider);
 }
 
 int KIntNumInput::minimum() const
 {
-    return m_spin->minimum();
+    return d->m_spin->minimum();
 }
 
 void KIntNumInput::setMaximum(int max)
 {
-    setRange(m_spin->minimum(), max, m_spin->singleStep(), m_slider);
+    K_USING_KNUMINPUT_P(priv);
+    setRange(d->m_spin->minimum(), max, d->m_spin->singleStep(), priv->m_slider);
 }
 
 int KIntNumInput::maximum() const
 {
-    return m_spin->maximum();
+    return d->m_spin->maximum();
 }
 
 void KIntNumInput::setSuffix(const QString &suffix)
 {
-    m_spin->setSuffix(suffix);
+    d->m_spin->setSuffix(suffix);
 
     layout(true);
 }
 
 QString KIntNumInput::suffix() const
 {
-    return m_spin->suffix();
+    return d->m_spin->suffix();
 }
 
 void KIntNumInput::setPrefix(const QString &prefix)
 {
-    m_spin->setPrefix(prefix);
+    d->m_spin->setPrefix(prefix);
 
     layout(true);
 }
 
 QString KIntNumInput::prefix() const
 {
-    return m_spin->prefix();
+    return d->m_spin->prefix();
 }
 
 void KIntNumInput::setEditFocus(bool mark)
 {
-    m_spin->setEditFocus(mark);
+    d->m_spin->setEditFocus(mark);
 }
 
 QSize KIntNumInput::minimumSizeHint() const
 {
+    K_USING_KNUMINPUT_P(priv);
     ensurePolished();
 
     int w;
     int h;
 
-    h = 2 + qMax(m_sizeSpin.height(), m_sizeSlider.height());
+    h = 2 + qMax(d->m_sizeSpin.height(), priv->m_sizeSlider.height());
 
     // if in extra row, then count it here
-    if(m_label && (m_alignment & (Qt::AlignBottom|Qt::AlignTop)))
-        h += 4 + m_sizeLabel.height();
+    if(priv->m_label && (priv->m_alignment & (Qt::AlignBottom|Qt::AlignTop)))
+        h += 4 + priv->m_sizeLabel.height();
     else
         // label is in the same row as the other widgets
-        h = qMax(h, m_sizeLabel.height() + 2);
+        h = qMax(h, priv->m_sizeLabel.height() + 2);
 
-    w = m_slider ? m_slider->sizeHint().width() + 8 : 0;
-    w += m_colw1 + m_colw2;
+    w = priv->m_slider ? priv->m_slider->sizeHint().width() + 8 : 0;
+    w += priv->m_colw1 + priv->m_colw2;
 
-    if(m_alignment & (Qt::AlignTop|Qt::AlignBottom))
-        w = qMax(w, m_sizeLabel.width() + 4);
+    if(priv->m_alignment & (Qt::AlignTop|Qt::AlignBottom))
+        w = qMax(w, priv->m_sizeLabel.width() + 4);
 
     return QSize(w, h);
 }
 
 void KIntNumInput::doLayout()
 {
-    m_sizeSpin = m_spin->sizeHint();
-    m_colw2 = m_sizeSpin.width();
+    K_USING_KNUMINPUT_P(priv);
+  
+    d->m_sizeSpin = d->m_spin->sizeHint();
+    priv->m_colw2 = d->m_sizeSpin.width();
 
-    if (m_label)
-        m_label->setBuddy(m_spin);
+    if (priv->m_label)
+        priv->m_label->setBuddy(d->m_spin);
 }
 
 void KIntNumInput::resizeEvent(QResizeEvent* e)
 {
-    int w = m_colw1;
+    K_USING_KNUMINPUT_P(priv);
+  
+    int w = priv->m_colw1;
     int h = 0;
 
-    if(m_label && (m_alignment & Qt::AlignTop)) {
-        m_label->setGeometry(0, 0, e->size().width(), m_sizeLabel.height());
-        h += m_sizeLabel.height() + KDialog::spacingHint();
+    if(priv->m_label && (priv->m_alignment & Qt::AlignTop)) {
+        priv->m_label->setGeometry(0, 0, e->size().width(), priv->m_sizeLabel.height());
+        h += priv->m_sizeLabel.height() + KDialog::spacingHint();
     }
 
-    if(m_label && (m_alignment & Qt::AlignVCenter))
-        m_label->setGeometry(0, 0, w, m_sizeSpin.height());
+    if(priv->m_label && (priv->m_alignment & Qt::AlignVCenter))
+        priv->m_label->setGeometry(0, 0, w, d->m_sizeSpin.height());
 
     if (qApp->layoutDirection())
     {
-        m_spin->setGeometry(w, h, m_slider ? m_colw2 : qMax(m_colw2, e->size().width() - w), m_sizeSpin.height());
-        w += m_colw2 + 8;
+        d->m_spin->setGeometry(w, h, priv->m_slider ? priv->m_colw2 : qMax(priv->m_colw2, e->size().width() - w), d->m_sizeSpin.height());
+        w += priv->m_colw2 + 8;
 
-        if(m_slider)
-            m_slider->setGeometry(w, h, e->size().width() - w, m_sizeSpin.height());
+        if(priv->m_slider)
+            priv->m_slider->setGeometry(w, h, e->size().width() - w, d->m_sizeSpin.height());
     }
-    else if(m_slider) {
-        m_slider->setGeometry(w, h, e->size().width() - (w + m_colw2 + KDialog::spacingHint()), m_sizeSpin.height());
-        m_spin->setGeometry(w + m_slider->size().width() + KDialog::spacingHint(), h, m_colw2, m_sizeSpin.height());
+    else if(priv->m_slider) {
+        priv->m_slider->setGeometry(w, h, e->size().width() - (w + priv->m_colw2 + KDialog::spacingHint()), d->m_sizeSpin.height());
+        d->m_spin->setGeometry(w + priv->m_slider->size().width() + KDialog::spacingHint(), h, priv->m_colw2, d->m_sizeSpin.height());
     }
     else {
-        m_spin->setGeometry(w, h, qMax(m_colw2, e->size().width() - w), m_sizeSpin.height());
+        d->m_spin->setGeometry(w, h, qMax(priv->m_colw2, e->size().width() - w), d->m_sizeSpin.height());
     }
 
-    h += m_sizeSpin.height() + 2;
+    h += d->m_sizeSpin.height() + 2;
 
-    if(m_label && (m_alignment & Qt::AlignBottom))
-        m_label->setGeometry(0, h, m_sizeLabel.width(), m_sizeLabel.height());
+    if(priv->m_label && (priv->m_alignment & Qt::AlignBottom))
+        priv->m_label->setGeometry(0, h, priv->m_sizeLabel.width(), priv->m_sizeLabel.height());
 }
 
 KIntNumInput::~KIntNumInput()
 {
-	delete d;
+    delete d;
 }
 
 void KIntNumInput::setValue(int val)
 {
-    m_spin->setValue(val);
+    d->m_spin->setValue(val);
     // slider value is changed by spinValueChanged
 }
 
@@ -509,28 +573,30 @@ double KIntNumInput::relativeValue() const {
     return double( value() ) / double ( d->referencePoint );
 }
 
-int  KIntNumInput::value() const
+int KIntNumInput::value() const
 {
-    return m_spin->value();
+    return d->m_spin->value();
 }
 
 void KIntNumInput::setSpecialValueText(const QString& text)
 {
-    m_spin->setSpecialValueText(text);
+    d->m_spin->setSpecialValueText(text);
     layout(true);
 }
 
 QString KIntNumInput::specialValueText() const
 {
-    return m_spin->specialValueText();
+    return d->m_spin->specialValueText();
 }
 
 void KIntNumInput::setLabel(const QString & label, Qt::Alignment a)
 {
+    K_USING_KNUMINPUT_P(priv);
+  
     KNumInput::setLabel(label, a);
 
-    if(m_label)
-        m_label->setBuddy(m_spin);
+    if(priv->m_label)
+        priv->m_label->setBuddy(d->m_spin);
 }
 
 // ----------------------------------------------------------------------------
@@ -544,10 +610,14 @@ public:
     KDoubleSpinBox * spin;
     double referencePoint;
     short blockRelative;
+    QSize m_sizeEdit;
+    QString m_specialvalue;
 };
 
 KDoubleNumInput::KDoubleNumInput(QWidget *parent)
     : KNumInput(parent)
+    , d( new KDoubleNumInputPrivate( 0.0 ) )
+
 {
     init(0.0, 0.0, 9999.0, 0.01, 2);
 }
@@ -555,6 +625,7 @@ KDoubleNumInput::KDoubleNumInput(QWidget *parent)
 KDoubleNumInput::KDoubleNumInput(double lower, double upper, double value, QWidget *parent,
 				 double step, int precision)
     : KNumInput(parent)
+    , d( new KDoubleNumInputPrivate( value ) )
 {
     init(value, lower, upper, step, precision);
 }
@@ -563,21 +634,25 @@ KDoubleNumInput::KDoubleNumInput(KNumInput *below,
 				 double lower, double upper, double value, QWidget *parent,
 				 double step, int precision)
     : KNumInput(parent,below)
+    , d( new KDoubleNumInputPrivate( value ) )
 {
     init(value, lower, upper, step, precision);
 }
 
 KDoubleNumInput::~KDoubleNumInput()
 {
-	delete d;
+    delete d;
+}
+
+QString KDoubleNumInput::specialValueText() const
+{
+    return d->m_specialvalue;
 }
 
 
 void KDoubleNumInput::init(double value, double lower, double upper,
 			   double step, int precision )
 {
-    d = new KDoubleNumInputPrivate( value );
-
     d->spin = new KDoubleSpinBox(lower, upper, step, value, this,precision);
     d->spin->setObjectName("KDoubleNumInput::d->spin" );
     setFocusProxy(d->spin);
@@ -592,17 +667,19 @@ void KDoubleNumInput::init(double value, double lower, double upper,
 }
 
 void KDoubleNumInput::updateLegacyMembers() {
-    m_specialvalue = specialValueText();
+    d->m_specialvalue = specialValueText();
 }
 
 
 double KDoubleNumInput::mapSliderToSpin( int val ) const
 {
+    K_USING_KNUMINPUT_P(priv);
+  
     // map [slidemin,slidemax] to [spinmin,spinmax]
     double spinmin = d->spin->minimum();
     double spinmax = d->spin->maximum();
-    double slidemin = m_slider->minimum(); // cast int to double to avoid
-    double slidemax = m_slider->maximum(); // overflow in rel denominator
+    double slidemin = priv->m_slider->minimum(); // cast int to double to avoid
+    double slidemax = priv->m_slider->maximum(); // overflow in rel denominator
     double rel = ( double(val) - slidemin ) / ( slidemax - slidemin );
     return spinmin + rel * ( spinmax - spinmin );
 }
@@ -620,72 +697,78 @@ void KDoubleNumInput::slotEmitRelativeValueChanged( double value )
 
 QSize KDoubleNumInput::minimumSizeHint() const
 {
+    K_USING_KNUMINPUT_P(priv);
+  
     ensurePolished();
 
     int w;
     int h;
 
-    h = 2 + qMax(m_sizeEdit.height(), m_sizeSlider.height());
+    h = 2 + qMax(d->m_sizeEdit.height(), priv->m_sizeSlider.height());
 
     // if in extra row, then count it here
-    if(m_label && (m_alignment & (Qt::AlignBottom|Qt::AlignTop)))
-        h += 4 + m_sizeLabel.height();
+    if(priv->m_label && (priv->m_alignment & (Qt::AlignBottom|Qt::AlignTop)))
+        h += 4 + priv->m_sizeLabel.height();
     else
         // label is in the same row as the other widgets
-	h = qMax(h, m_sizeLabel.height() + 2);
+	h = qMax(h, priv->m_sizeLabel.height() + 2);
 
-    w = m_slider ? m_slider->sizeHint().width() + 8 : 0;
-    w += m_colw1 + m_colw2;
+    w = priv->m_slider ? priv->m_slider->sizeHint().width() + 8 : 0;
+    w += priv->m_colw1 + priv->m_colw2;
 
-    if(m_alignment & (Qt::AlignTop|Qt::AlignBottom))
-        w = qMax(w, m_sizeLabel.width() + 4);
+    if(priv->m_alignment & (Qt::AlignTop|Qt::AlignBottom))
+        w = qMax(w, priv->m_sizeLabel.width() + 4);
 
     return QSize(w, h);
 }
 
 void KDoubleNumInput::resizeEvent(QResizeEvent* e)
 {
-    int w = m_colw1;
+    K_USING_KNUMINPUT_P(priv);
+
+    int w = priv->m_colw1;
     int h = 0;
 
-    if(m_label && (m_alignment & Qt::AlignTop)) {
-        m_label->setGeometry(0, 0, e->size().width(), m_sizeLabel.height());
-        h += m_sizeLabel.height() + 4;
+    if(priv->m_label && (priv->m_alignment & Qt::AlignTop)) {
+        priv->m_label->setGeometry(0, 0, e->size().width(), priv->m_sizeLabel.height());
+        h += priv->m_sizeLabel.height() + 4;
     }
 
-    if(m_label && (m_alignment & Qt::AlignVCenter))
-        m_label->setGeometry(0, 0, w, m_sizeEdit.height());
+    if(priv->m_label && (priv->m_alignment & Qt::AlignVCenter))
+        priv->m_label->setGeometry(0, 0, w, d->m_sizeEdit.height());
 
     if (qApp->layoutDirection())
     {
-        d->spin->setGeometry(w, h, m_slider ? m_colw2
-                                            : e->size().width() - w, m_sizeEdit.height());
-        w += m_colw2 + KDialog::spacingHint();
+        d->spin->setGeometry(w, h, priv->m_slider ? priv->m_colw2
+                                            : e->size().width() - w, d->m_sizeEdit.height());
+        w += priv->m_colw2 + KDialog::spacingHint();
 
-        if(m_slider)
-            m_slider->setGeometry(w, h, e->size().width() - w, m_sizeEdit.height());
+        if(priv->m_slider)
+            priv->m_slider->setGeometry(w, h, e->size().width() - w, d->m_sizeEdit.height());
     }
-    else if(m_slider) {
-        m_slider->setGeometry(w, h, e->size().width() -
-                                    (m_colw1 + m_colw2 + KDialog::spacingHint()),
-                              m_sizeEdit.height());
-        d->spin->setGeometry(w + m_slider->width() + KDialog::spacingHint(), h,
-                             m_colw2, m_sizeEdit.height());
+    else if(priv->m_slider) {
+        priv->m_slider->setGeometry(w, h, e->size().width() -
+                                    (priv->m_colw1 + priv->m_colw2 + KDialog::spacingHint()),
+                              d->m_sizeEdit.height());
+        d->spin->setGeometry(w + priv->m_slider->width() + KDialog::spacingHint(), h,
+                             priv->m_colw2, d->m_sizeEdit.height());
     }
     else {
-        d->spin->setGeometry(w, h, e->size().width() - w, m_sizeEdit.height());
+        d->spin->setGeometry(w, h, e->size().width() - w, d->m_sizeEdit.height());
     }
 
-    h += m_sizeEdit.height() + 2;
+    h += d->m_sizeEdit.height() + 2;
 
-    if(m_label && (m_alignment & Qt::AlignBottom))
-        m_label->setGeometry(0, h, m_sizeLabel.width(), m_sizeLabel.height());
+    if(priv->m_label && (priv->m_alignment & Qt::AlignBottom))
+        priv->m_label->setGeometry(0, h, priv->m_sizeLabel.width(), priv->m_sizeLabel.height());
 }
 
 void KDoubleNumInput::doLayout()
 {
-    m_sizeEdit = d->spin->sizeHint();
-    m_colw2 = m_sizeEdit.width();
+    K_USING_KNUMINPUT_P(priv);
+  
+    d->m_sizeEdit = d->spin->sizeHint();
+    priv->m_colw2 = d->m_sizeEdit.width();
 }
 
 void KDoubleNumInput::setValue(double val)
@@ -711,11 +794,13 @@ void KDoubleNumInput::setReferencePoint( double ref )
 void KDoubleNumInput::setRange(double lower, double upper, double step,
                                                            bool slider)
 {
-    if( m_slider ) {
+    K_USING_KNUMINPUT_P(priv);
+  
+    if( priv->m_slider ) {
 	// don't update the slider to avoid an endless recursion
 	QSpinBox * spin = d->spin;
 	disconnect(spin, SIGNAL(valueChanged(int)),
-		m_slider, SLOT(setValue(int)) );
+		priv->m_slider, SLOT(setValue(int)) );
     }
     d->spin->setRange( lower, upper, step, d->spin->precision() );
 
@@ -726,30 +811,30 @@ void KDoubleNumInput::setRange(double lower, double upper, double step,
 	int slmin = spin->minimum();
         int slvalue = spin->value();
 	int slstep = spin->singleStep();
-        if (m_slider) {
-            m_slider->setRange(slmin, slmax);
-	    m_slider->setSingleStep(slstep);
-            m_slider->setValue(slvalue);
+        if (priv->m_slider) {
+            priv->m_slider->setRange(slmin, slmax);
+	    priv->m_slider->setSingleStep(slstep);
+            priv->m_slider->setValue(slvalue);
         } else {
-            m_slider = new QSlider(Qt::Horizontal, this);
-            m_slider->setMinimum(slmin);
-            m_slider->setMaximum(slmax);
-            m_slider->setPageStep(slstep);
-            m_slider->setValue(slvalue);
-            m_slider->setTickPosition(QSlider::TicksBelow);
+            priv->m_slider = new QSlider(Qt::Horizontal, this);
+            priv->m_slider->setMinimum(slmin);
+            priv->m_slider->setMaximum(slmax);
+            priv->m_slider->setPageStep(slstep);
+            priv->m_slider->setValue(slvalue);
+            priv->m_slider->setTickPosition(QSlider::TicksBelow);
 	    // feedback line: when one moves, the other moves, too:
-            connect(m_slider, SIGNAL(valueChanged(int)),
+            connect(priv->m_slider, SIGNAL(valueChanged(int)),
                     SLOT(sliderMoved(int)) );
         }
 	connect(spin, SIGNAL(valueChanged(int)),
-			m_slider, SLOT(setValue(int)) );
+			priv->m_slider, SLOT(setValue(int)) );
 	// calculate ( slmax - slmin ) / 10 without overflowing ints:
 	int major = calcDiffByTen( slmax, slmin );
 	if ( !major ) major = slstep; // ### needed?
-        m_slider->setTickInterval(major);
+        priv->m_slider->setTickInterval(major);
     } else {
-        delete m_slider;
-        m_slider = 0;
+        delete priv->m_slider;
+        priv->m_slider = 0;
     }
 
     setReferencePoint( referencePoint() );
@@ -760,7 +845,8 @@ void KDoubleNumInput::setRange(double lower, double upper, double step,
 
 void KDoubleNumInput::setMinimum(double min)
 {
-    setRange(min, maximum(), d->spin->singleStep(), m_slider);
+    K_USING_KNUMINPUT_P(priv);
+    setRange(min, maximum(), d->spin->singleStep(), priv->m_slider);
 }
 
 double KDoubleNumInput::minimum() const
@@ -770,7 +856,8 @@ double KDoubleNumInput::minimum() const
 
 void KDoubleNumInput::setMaximum(double max)
 {
-    setRange(minimum(), max, d->spin->singleStep(), m_slider);
+    K_USING_KNUMINPUT_P(priv);
+    setRange(minimum(), max, d->spin->singleStep(), priv->m_slider);
 }
 
 double KDoubleNumInput::maximum() const
@@ -840,10 +927,12 @@ void KDoubleNumInput::setSpecialValueText(const QString& text)
 
 void KDoubleNumInput::setLabel(const QString & label, Qt::Alignment a)
 {
+    K_USING_KNUMINPUT_P(priv);
+  
     KNumInput::setLabel(label, a);
 
-    if(m_label)
-        m_label->setBuddy(d->spin);
+    if(priv->m_label)
+        priv->m_label->setBuddy(d->spin);
 
 }
 
@@ -980,7 +1069,7 @@ KDoubleSpinBox::KDoubleSpinBox( double lower, double upper, double step,
 }
 
 KDoubleSpinBox::~KDoubleSpinBox() {
-  delete d; d = 0;
+  delete d;
 }
 
 bool KDoubleSpinBox::acceptLocalizedNumbers() const {
