@@ -22,16 +22,17 @@
 #ifndef K_NUMINPUT_H
 #define K_NUMINPUT_H
 
+#include <kdeui_export.h>
+
 #include <QtGui/QWidget>
 #include <QtGui/QSpinBox>
 
-#include <kdelibs_export.h>
-
-class QLabel;
 class QSlider;
+class QSpinBox;
 class QValidator;
 
 class KIntSpinBox;
+class KNumInputPrivate;
 
 /**
  * You need to inherit from this class if you want to implement K*NumInput
@@ -54,8 +55,13 @@ public:
     /**
      * @param below A pointer to another KNumInput.
      * @param parent parent widget
+     * \deprecated - use the version without the below parameter instead
+     */
+    KDE_CONSTRUCTOR_DEPRECATED KNumInput(QWidget *parent, KNumInput* below);
+    
+    /**
+     * Destructor
      */
-    KNumInput(QWidget *parent, KNumInput* below);
     ~KNumInput();
 
     /**
@@ -85,7 +91,7 @@ public:
     /**
      * @return if the num input has a slider.
      */
-    bool showSlider() const { return m_slider; }
+    bool showSlider() const;
 
     /**
      * Sets the spacing of tickmarks for the slider.
@@ -109,6 +115,12 @@ public:
     virtual QSize sizeHint() const;
 
 protected:
+    /**
+     * @return the slider widget.
+     * @internal
+     */
+    QSlider *slider() const;
+      
     /**
      * Call this function whenever you change something in the geometry
      * of your KNumInput child.
@@ -126,21 +138,11 @@ protected:
      */
     virtual void doLayout() = 0;
 
-    KNumInput* m_prev, *m_next;
-    int m_colw1, m_colw2;
-
-    QLabel*  m_label;
-    QSlider* m_slider;
-    QSize    m_sizeSlider, m_sizeLabel;
-
-    Qt::Alignment m_alignment;
-
 private:
-    void init();
-
-private:
-    class KNumInputPrivate;
-    KNumInputPrivate *d;
+    friend class KNumInputPrivate;
+    KNumInputPrivate * const d;
+    
+    Q_DISABLE_COPY(KNumInput)
 };
 
 /* ------------------------------------------------------------------------ */
@@ -216,8 +218,10 @@ public:
      * @param value  initial value for the control
      * @param base   numeric base used for display
      * @param parent parent QWidget
+     * 
+     * \deprecated use the version without the below parameter instead.
      */
-    KIntNumInput(KNumInput* below, int value, QWidget *parent, int base = 10);
+    KDE_CONSTRUCTOR_DEPRECATED KIntNumInput(KNumInput* below, int value, QWidget *parent, int base = 10);
 
     /**
      * Destructor
@@ -299,7 +303,7 @@ public:
      * @return the minimum size necessary to show the control
      */
     virtual QSize minimumSizeHint() const;
-
+    
 public Q_SLOTS:
     /**
      * Sets the value of the control.
@@ -360,18 +364,24 @@ private Q_SLOTS:
     void slotEmitRelativeValueChanged(int);
 
 protected:
+    /**
+     * @return the spin box widget.
+     * @internal
+     */
+    QSpinBox *spinBox() const;
+      
     virtual void doLayout();
     void resizeEvent ( QResizeEvent * );
 
-    KIntSpinBox* m_spin;
-    QSize        m_sizeSpin;
-
 private:
     void init(int value, int _base);
 
 private:
     class KIntNumInputPrivate;
-    KIntNumInputPrivate *d;
+    friend class KIntNumInputPrivate;
+    KIntNumInputPrivate * const d;
+    
+    Q_DISABLE_COPY(KIntNumInput)
 };
 
 
@@ -463,8 +473,10 @@ public:
      * @param step   step size to use for up/down arrow clicks
      * @param precision number of digits after the decimal point
      * @param parent parent QWidget
+     *
+     * \deprecated use the version without below instead
      */
-    KDoubleNumInput(KNumInput* below,
+    KDE_CONSTRUCTOR_DEPRECATED KDoubleNumInput(KNumInput* below,
 		    double lower, double upper, double value, QWidget *parent=0,double step=0.02,
 		    int precision=2);
 
@@ -495,7 +507,7 @@ public:
      * @return the string displayed for a special value.
      * @see setSpecialValueText()
      */
-    QString specialValueText() const { return m_specialvalue; }
+    QString specialValueText() const;
 
      /**
      * @param min  minimum value
@@ -604,22 +616,19 @@ protected:
     virtual void doLayout();
     void resizeEvent ( QResizeEvent * );
 
-
-    QSize    m_sizeEdit;
-
     friend class KDoubleLine;
 private:
     void init(double value, double lower, double upper,
     double step, int precision);
     double mapSliderToSpin(int) const;
     void updateLegacyMembers();
-    // ### no longer used, remove when BIC allowed:
-    QString  m_specialvalue;
-    // ### end remove when BIC allowed
 
 private:
     class KDoubleNumInputPrivate;
-    KDoubleNumInputPrivate *d;
+    friend class KDoubleNumInputPrivate;
+    KDoubleNumInputPrivate * const d;
+
+    Q_DISABLE_COPY(KDoubleNumInput)
 };
 
 
@@ -698,11 +707,12 @@ protected:
      */
     virtual int valueFromText(const QString &text) const;
 
-private:
-    int val_base;
 private:
     class KIntSpinBoxPrivate;
-    KIntSpinBoxPrivate *d;
+    friend class KIntSpinBoxPrivate;
+    KIntSpinBoxPrivate *const d;
+    
+    Q_DISABLE_COPY(KIntSpinBox)
 };
 
 
@@ -876,7 +886,7 @@ private:
   int maxPrecision() const;
 
   class Private;
-  Private * d;
+  Private * const d;
 };
 
 #endif // K_NUMINPUT_H
