@@ -19,9 +19,8 @@
 #ifndef KSQUEEZEDTEXTLABEL_H
 #define KSQUEEZEDTEXTLABEL_H
 
-#include <qlabel.h>
-
-#include <kdelibs_export.h>
+#include <kdeui_export.h>
+#include <QtGui/QLabel>
 
 class KSqueezedTextLabelPrivate;
 
@@ -90,7 +89,7 @@ protected:
   void squeezeTextToLabel();
 
 private:
-  KSqueezedTextLabelPrivate *d;
+  KSqueezedTextLabelPrivate * const d;
 };
 
 #endif // KSQUEEZEDTEXTLABEL_H
