@@ -21,9 +21,9 @@
 #ifndef KTABBAR_H
 #define KTABBAR_H
 
-#include <QtGui/QTabBar>
+#include <kdeui_export.h>
 
-#include <kdelibs_export.h>
+#include <QtGui/QTabBar>
 
 /**
  * A QTabBar with extended features.
@@ -81,6 +81,8 @@ class KDEUI_EXPORT KTabBar: public QTabBar
     /**
      * Selects the tab which has a tab header at
      * given @param position.
+     *
+     * @param position the coordinates of the tab
      */
     int selectTab( const QPoint &position ) const;
 
