@@ -18,6 +18,8 @@
   Boston, MA 02110-1301, USA.
 */
 
+#include "ktabwidget.h"
+
 #include <QtGui/QApplication>
 #include <QtGui/QDragMoveEvent>
 #include <QtGui/QDropEvent>
@@ -27,13 +29,12 @@
 #include <QtGui/QTextDocument>
 #include <QtGui/QWheelEvent>
 
-#include <kconfig.h>
+#include <ksharedconfig.h>
 #include <kiconloader.h>
 #include <kstringhandler.h>
 
 #include <ktabbar.h>
 
-#include "ktabwidget.h"
 #include <kconfiggroup.h>
 
 class KTabWidget::Private
@@ -423,7 +424,7 @@ void KTabWidget::moveTab( int from, int to )
   bool current = ( from == currentIndex() );
   bool enabled = isTabEnabled( from );
 
-  blockSignals( true );
+  bool blocked = blockSignals( true );
   removeTab( from );
 
   // Work-around kmdi brain damage which calls showPage() in insertTab()
@@ -442,7 +443,7 @@ void KTabWidget::moveTab( int from, int to )
   if ( current )
     setCurrentIndex( to );
   setTabEnabled( to, enabled );
-  blockSignals( false );
+  blockSignals( blocked );
 
   emit ( movedTab( from, to ) );
 }
