@@ -25,9 +25,8 @@
 #include <QKeyEvent>
 #include <QScrollBar>
 #include <QTextCursor>
-
-//#include <ksyntaxhighlighter.h>
-//#include <kspell.h>
+#include <dialog.h>
+#include "backgroundchecker.h"
 #include <kcursor.h>
 #include <kglobalsettings.h>
 #include <kstandardshortcut.h>
@@ -37,11 +36,6 @@
 #include <kdialog.h>
 #include <QMenu>
 
-class KSpell;
-
-//TODO: Use kspell2 in the future.
-//Use ksyntaxhighlighter from kspell2
-
 
 class KTextEdit::Private
 {
@@ -49,81 +43,81 @@ class KTextEdit::Private
     Private( KTextEdit *_parent )
       : parent( _parent ),
         customPalette( false ),
-        checkSpellingEnabled( false )
-//      highlighter( 0 ),
-//      spell( 0 )
+        checkSpellingEnabled( false ),
+        highlighter( 0 )
     {
     }
 
     ~Private()
     {
-//      delete highlighter;
-//      delete spell;
+      delete highlighter;
     }
 
-    void slotSpellCheckReady( KSpell *s );
     void slotSpellCheckDone( const QString &s );
-    void spellCheckerMisspelling( const QString &text, const QStringList &, unsigned int pos );
-    void spellCheckerCorrected( const QString &, const QString &, unsigned int );
+
+    void spellCheckerMisspelling( const QString &text, int pos );
+    void spellCheckerCorrected( const QString &, int,const QString &);
+    void spellCheckerAutoCorrect(const QString&,const QString&);
+    void spellCheckerCanceled();
+    
     void spellCheckerFinished();
     void toggleAutoSpellCheck();
     void slotAllowTab();
     void menuActivated( QAction* action );
 
-    void posToRowCol( unsigned int pos, unsigned int &line, unsigned int &col );
-
     KTextEdit *parent;
-    bool customPalette;
     QAction *autoSpellCheckAction;
     QAction *allowTab;
     QAction *spellCheckAction;
+    bool customPalette;
 
     bool checkSpellingEnabled;
-#if 0
-    KDictSpellingHighlighter *highlighter;
-    KSpell *spell;
-#endif
+    QString originalBuffer;
+    QString spellChechingConfigFileName;
+    Sonnet::Highlighter *highlighter;
 };
 
-void KTextEdit::Private::slotSpellCheckReady( KSpell *s )
+void KTextEdit::Private::spellCheckerCanceled()
 {
-// this is for Zack...
-//
-//    s->check( text() ); // TODO: toPlainText()?? (MiB)
-//    connect( s, SIGNAL( done( const QString & ) ), this, SLOT( slotSpellCheckDone( const QString & ) ) );
+    parent->selectAll();
+    parent->setPlainText(originalBuffer);
+    spellCheckerFinished();
+}
+
+void KTextEdit::Private::spellCheckerAutoCorrect(const QString&,const QString&)
+{
+    //TODO
 }
 
 void KTextEdit::Private::slotSpellCheckDone( const QString &s )
 {
+//Necessary ?
 //    if ( s != text() ) // TODO: toPlainText()?? (MiB)
 //        setText( s ); // setPlainText() ?! we'd loose rich text info
 }
 
-void KTextEdit::Private::spellCheckerMisspelling( const QString &text, const QStringList &, unsigned int pos )
+void KTextEdit::Private::spellCheckerMisspelling( const QString &text, int pos )
 {
-//  highlightWord( text.length(), pos );
+    //kDebug()<<"TextEdit::Private::spellCheckerMisspelling :"<<text<<" pos :"<<pos;
+    parent->highlightWord( text.length(), pos );
 }
 
-void KTextEdit::Private::spellCheckerCorrected( const QString &oldWord, const QString &newWord, unsigned int pos )
+void KTextEdit::Private::spellCheckerCorrected( const QString& oldWord, int pos,const QString& newWord)
 {
-// TODO
-/*
-  unsigned int l = 0;
-  unsigned int cnt = 0;
-
-  if ( oldWord != newWord ) {
-    posToRowCol( pos, l, cnt );
-    setSelection( l, cnt, l, cnt + oldWord.length() );
-    removeSelectedText();
-    insert( newWord );
+  //kDebug()<<" oldWord :"<<oldWord<<" newWord :"<<newWord<<" pos : "<<pos;
+  if (oldWord != newWord ) {
+    QTextCursor cursor(parent->document());
+    cursor.setPosition(pos);
+    cursor.setPosition(pos+oldWord.length(),QTextCursor::KeepAnchor);
+    cursor.insertText(newWord);
   }
-*/
 }
 
 void KTextEdit::Private::spellCheckerFinished()
 {
-//    delete d->spell;
-//    d->spell = 0L;
+   QTextCursor cursor(parent->document());
+   cursor.clearSelection();
+   parent->setTextCursor(cursor);
 }
 
 void KTextEdit::Private::toggleAutoSpellCheck()
@@ -146,20 +140,6 @@ void KTextEdit::Private::menuActivated( QAction* action )
     slotAllowTab();
 }
 
-void KTextEdit::Private::posToRowCol( unsigned int pos, unsigned int &line, unsigned int &col )
-{
-// TODO
-/*
-  for ( line = 0; line < static_cast<uint>( lines() ) && col <= pos; line++ )
-    col += paragraphLength( line ) + 1;
-
-  line--;
-  col = pos - col + paragraphLength( line ) + 1;
-*/
-}
-
-
-
 KTextEdit::KTextEdit( const QString& text, QWidget *parent )
   : QTextEdit( text, parent ), d( new Private( this ) )
 {
@@ -177,6 +157,11 @@ KTextEdit::~KTextEdit()
   delete d;
 }
 
+void KTextEdit::setSpellCheckingConfigFileName(const QString &_fileName)
+{
+    d->spellChechingConfigFileName = _fileName;
+}
+
 void KTextEdit::keyPressEvent( QKeyEvent *event )
 {
   int key = event->key() | event->modifiers();
@@ -311,16 +296,18 @@ void KTextEdit::contextMenuEvent( QContextMenuEvent *event )
   if( !isReadOnly() )
   {
       popup->addSeparator();
-      d->spellCheckAction = popup->addAction( KIcon( "spellcheck" ), i18n( "Check Spelling..." ) );
+      if(!acceptRichText())
+      {
+        d->spellCheckAction = popup->addAction( KIcon( "tools-check-spelling" ), i18n( "Check Spelling..." ) );
 
-      if ( document()->isEmpty() )
-          d->spellCheckAction->setEnabled( false );
-
-      d->autoSpellCheckAction = popup->addAction( i18n( "Auto Spell Check" ) );
-      d->autoSpellCheckAction->setCheckable( true );
-      d->autoSpellCheckAction->setChecked( d->checkSpellingEnabled );
-      popup->addSeparator();
+        if ( document()->isEmpty() )
+           d->spellCheckAction->setEnabled( false );
 
+        d->autoSpellCheckAction = popup->addAction( i18n( "Auto Spell Check" ) );
+        d->autoSpellCheckAction->setCheckable( true );
+        d->autoSpellCheckAction->setChecked( d->checkSpellingEnabled );
+        popup->addSeparator();
+      }
       d->allowTab = popup->addAction( i18n("Allow Tabulations") );
       d->allowTab->setCheckable( true );
       d->allowTab->setChecked( !tabChangesFocus() );
@@ -338,9 +325,25 @@ void KTextEdit::wheelEvent( QWheelEvent *event )
     QAbstractScrollArea::wheelEvent( event );
 }
 
+void KTextEdit::createHighlighter()
+{
+    setHightighter(new Sonnet::Highlighter(this, d->spellChechingConfigFileName));
+}
+
+Sonnet::Highlighter* KTextEdit::hightighter() const
+{
+    return d->highlighter;
+}
+
+void KTextEdit::setHightighter(Sonnet::Highlighter *_highLighter)
+{
+    delete d->highlighter;
+    d->highlighter = _highLighter;
+}
+
 void KTextEdit::setCheckSpellingEnabled( bool check )
 {
-  if ( check == d->checkSpellingEnabled )
+  if ( check == d->checkSpellingEnabled || acceptRichText() )
     return;
 
   // From the above statment we know know that if we're turning checking
@@ -348,26 +351,23 @@ void KTextEdit::setCheckSpellingEnabled( bool check )
   // off we should remove the old one.
 
   d->checkSpellingEnabled = check;
-#if 0
     if ( check )
     {
-        if ( hasFocus() )
-            d->highlighter = new KDictSpellingHighlighter( this );
+        if ( hasFocus() ) {
+            createHighlighter();
+        }
     }
     else
     {
         delete d->highlighter;
         d->highlighter = 0;
     }
-#endif
 }
 
 void KTextEdit::focusInEvent( QFocusEvent *event )
 {
-#if 0
-    if ( d->checkSpellingEnabled && !isReadOnly() && !d->highlighter )
-        d->highlighter = new KDictSpellingHighlighter( this );
-#endif
+    if ( d->checkSpellingEnabled && !isReadOnly() && !d->highlighter && !acceptRichText() )
+        createHighlighter();
 
   QTextEdit::focusInEvent( event );
 }
@@ -379,19 +379,15 @@ bool KTextEdit::checkSpellingEnabled() const
 
 void KTextEdit::setReadOnly( bool readOnly )
 {
-#if 0
-  if ( !readOnly && hasFocus() && d->checkSpellingEnabled && !d->highlighter )
-    d->highlighter = new KDictSpellingHighlighter( this );
-#endif
+  if ( !readOnly && hasFocus() && d->checkSpellingEnabled && !d->highlighter  && !acceptRichText())
+    createHighlighter();
 
   if ( readOnly == isReadOnly() )
     return;
 
   if ( readOnly ) {
-#if 0
     delete d->highlighter;
     d->highlighter = 0;
-#endif
 
     d->customPalette = testAttribute( Qt::WA_SetPalette );
     QPalette p = palette();
@@ -415,30 +411,31 @@ void KTextEdit::setReadOnly( bool readOnly )
 
 void KTextEdit::checkSpelling()
 {
-#if 0
-  delete d->spell;
-  d->spell = new KSpell( this, i18n( "Spell Checking" ),
-                         this, SLOT( slotSpellCheckReady( KSpell *) ), 0, true, true);
-
-  connect( d->spell, SIGNAL( death() ),
-           this, SLOT( spellCheckerFinished() ) );
-
-  connect( d->spell, SIGNAL( misspelling( const QString &, const QStringList &, unsigned int ) ),
-           this, SLOT( spellCheckerMisspelling( const QString &, const QStringList &, unsigned int ) ) );
-
-  connect( d->spell, SIGNAL( corrected( const QString &, const QString &, unsigned int ) ),
-           this, SLOT( spellCheckerCorrected( const QString &, const QString &, unsigned int ) ) );
-#endif
+  Sonnet::Dialog *spellDialog = new Sonnet::Dialog(
+      new Sonnet::BackgroundChecker(this), 0);
+  connect(spellDialog, SIGNAL(replace( const QString&, int,const QString&)),
+          this, SLOT(spellCheckerCorrected( const QString&, int,const QString&)));
+  connect(spellDialog, SIGNAL(misspelling( const QString&, int)),
+          this, SLOT(spellCheckerMisspelling(const QString &,int)));
+  connect(spellDialog, SIGNAL(autoCorrect(const QString&, const QString&)),
+          this, SLOT(spellCheckerAutoCorrect(const QString&, const QString&)));
+  connect(spellDialog, SIGNAL(done(const QString&)),
+          this, SLOT(spellCheckerFinished()));
+  connect(spellDialog, SIGNAL(cancel()),
+          this, SLOT(spellCheckerCanceled()));
+  connect(spellDialog, SIGNAL(stop()),
+          this, SLOT(spellCheckerFinished()));
+  d->originalBuffer = toPlainText();
+  spellDialog->setBuffer(toPlainText());
+  spellDialog->show();
 }
 
-void KTextEdit::highlightWord( unsigned int length, unsigned int pos )
+void KTextEdit::highlightWord( int length, int pos )
 {
-/* TODO
-  unsigned int l = 0;
-  unsigned int cnt = 0;
-  posToRowCol( pos, l, cnt );
-  setSelection( l, cnt, l, cnt + length );
-*/
+  QTextCursor cursor(document());
+  cursor.setPosition(pos);
+  cursor.setPosition(pos+length,QTextCursor::KeepAnchor);
+  setTextCursor (cursor);
 }
 
 #include "ktextedit.moc"
