@@ -24,13 +24,16 @@
     Boston, MA 02110-1301, USA.
 */
 
+#include "ktoolbar.h"
+
 #include <config.h>
 
+#include <QtCore/QPointer>
 #include <QtGui/QFrame>
 #include <QtGui/QLayout>
 #include <QtGui/QMouseEvent>
+#include <QtGui/QToolButton>
 #include <QtXml/QDomElement>
-#include <QtCore/QPointer>
 
 #include <kaction.h>
 #include <kactioncollection.h>
@@ -44,13 +47,12 @@
 #include <kicon.h>
 #include <kiconloader.h>
 #include <klocale.h>
-#include <kmainwindow.h>
+#include <kxmlguiwindow.h>
 #include <kmenu.h>
 #include <kstandardaction.h>
 #include <ktoggleaction.h>
 #include <kxmlguifactory.h>
 
-#include "ktoolbar.h"
 #include <kconfiggroup.h>
 
 class KToolBar::Private
@@ -64,9 +66,9 @@ class KToolBar::Private
         unlockedMovable( true ),
         xmlguiClient( 0 ),
         contextLockAction( 0 ),
-        HiddenDefault( false ),
         IconSizeDefault( 22 ),
         ToolButtonStyleDefault( Qt::ToolButtonTextUnderIcon ),
+        HiddenDefault( false ),
         NewLineDefault( false ),
         OffsetDefault( 0 ),
         PositionDefault( "Top" ),
@@ -101,6 +103,7 @@ class KToolBar::Private
 
     static Qt::ToolButtonStyle toolButtonStyleFromString( const QString& style );
     static QString toolButtonStyleToString( Qt::ToolButtonStyle );
+    static Qt::ToolBarArea positionFromString(const QString& position);
 
 
     KToolBar *parent;
@@ -149,9 +152,9 @@ class KToolBar::Private
     QMap<QAction*,int> contextIconSizes;
 
     // Default Values.
-    bool HiddenDefault;
     int IconSizeDefault;
     Qt::ToolButtonStyle ToolButtonStyleDefault;
+    bool HiddenDefault;
     bool NewLineDefault;
     int OffsetDefault;
     QString PositionDefault;
@@ -336,10 +339,9 @@ KMenu *KToolBar::Private::contextMenu()
       unlockedMovable = false;
 
     delete contextLockAction;
-    contextLockAction = new KToggleAction( KIcon( "lock" ), i18n( "Lock Toolbars" ), parent );
+    contextLockAction = new KToggleAction( KIcon( "system-lock-screen" ), i18n( "Lock Toolbars" ), parent );
     context->addAction( contextLockAction );
     contextLockAction->setChecked( parent->toolBarsLocked() );
-    contextLockAction->setCheckedState( KGuiItem( i18n( "Unlock Toolbars" ), KIcon( "unlock" ) ) );
     connect( contextLockAction, SIGNAL( toggled( bool ) ), parent, SLOT( slotLockToolBars( bool ) ) );
 
     connect( context, SIGNAL( aboutToShow() ), parent, SLOT( slotContextAboutToShow() ) );
@@ -425,6 +427,19 @@ QString KToolBar::Private::toolButtonStyleToString( Qt::ToolButtonStyle style )
   }
 }
 
+Qt::ToolBarArea KToolBar::Private::positionFromString(const QString& position)
+{
+    Qt::ToolBarArea newposition = Qt::TopToolBarArea;
+    if (position == QLatin1String("left")) {
+        newposition = Qt::LeftToolBarArea;
+    } else if (position == QLatin1String("bottom")) {
+        newposition = Qt::BottomToolBarArea;
+    } else if (position == QLatin1String("right")) {
+        newposition = Qt::RightToolBarArea;
+    }
+    return newposition;
+}
+
 void KToolBar::Private::slotReadConfig()
 {
   /**
@@ -432,13 +447,15 @@ void KToolBar::Private::slotReadConfig()
    * but a well behaved application will call applyMainWindowSettings
    * anyway, right ?)
    */
-  parent->applyAppearanceSettings(KGlobal::config().data(), QString());
+  KConfigGroup cg( KGlobal::config(), QString());
+  parent->applyAppearanceSettings( cg);
 }
 
 void KToolBar::Private::slotAppearanceChanged()
 {
   // Read appearance settings from global file.
-  parent->applyAppearanceSettings(KGlobal::config().data(), QString(), true /* lose local settings */);
+  KConfigGroup cg(KGlobal::config(), QString());
+  parent->applyAppearanceSettings( cg , true /* lose local settings */);
 
   // And remember to save the new look later
   KMainWindow *kmw = qobject_cast<KMainWindow *>( parent->mainWindow() );
@@ -455,7 +472,7 @@ void KToolBar::Private::slotContextAboutToShow()
    * So we currently plug/unplug the last two actions of the menu.
    * Another way would be to keep around the actions and plug them all into a (new each time) popupmenu.
    */
-  KMainWindow *kmw = qobject_cast<KMainWindow *>( parent->mainWindow() );
+  KXmlGuiWindow *kmw = qobject_cast<KXmlGuiWindow *>( parent->mainWindow() );
   if ( kmw ) {
     kmw->setupToolbarMenuActions();
     // Only allow hiding a toolbar if the action is also plugged somewhere else (e.g. menubar)
@@ -476,7 +493,7 @@ void KToolBar::Private::slotContextAboutToShow()
   if ( configureAction )
     context->addAction( configureAction );
 
-  KEditToolbar::setDefaultToolbar( parent->QObject::objectName().toLatin1().constData() );
+  KEditToolBar::setGlobalDefaultToolBar( parent->QObject::objectName().toLatin1().constData() );
 
   // Check the actions that should be checked
   switch ( parent->toolButtonStyle() ) {
@@ -525,7 +542,7 @@ void KToolBar::Private::slotContextAboutToHide()
 {
   // We have to unplug whatever slotContextAboutToShow plugged into the menu.
   // Unplug the toolbar menu action
-  KMainWindow *kmw = qobject_cast<KMainWindow *>( parent->mainWindow() );
+  KXmlGuiWindow *kmw = qobject_cast<KXmlGuiWindow *>( parent->mainWindow() );
   if ( kmw && kmw->toolBarMenuAction() )
     if ( kmw->toolBarMenuAction()->associatedWidgets().count() > 1 )
       contextMenu()->removeAction( kmw->toolBarMenuAction() );
@@ -658,20 +675,17 @@ QString KToolBar::settingsGroup() const
   return configGroup;
 }
 
-void KToolBar::saveSettings( KConfig *config, const QString &_configGroup )
+void KToolBar::saveSettings( KConfigGroup &_cg )
 {
-  QString configGroup = _configGroup;
-
-  if ( configGroup.isEmpty() )
-    configGroup = settingsGroup();
+  KConfigGroup cg = _cg;
+    if ( cg.group().isEmpty() )
+        cg = KConfigGroup(cg.config(), settingsGroup() );
 
   QString position;
   Qt::ToolButtonStyle ToolButtonStyle;
   int index;
   d->getAttributes( position, ToolButtonStyle, index );
 
-  KConfigGroup cg( config, configGroup );
-
   if ( !cg.hasDefault( "Position" ) && position == d->PositionDefault )
     cg.revertToDefault( "Position" );
   else
@@ -701,7 +715,7 @@ void KToolBar::saveSettings( KConfig *config, const QString &_configGroup )
     // one toolbar, if we only saved the changed indexes, the toolbars wouldn't
     // reappear at the same position the next time.
     // The whole set of indexes has to be saved.
-    //kDebug(220) << name() << "                writing index " << index << endl;
+    //kDebug(220) << name() << "                writing index " << index;
 
     // don't save if there's only one toolbar
 
@@ -856,6 +870,15 @@ void KToolBar::loadState( const QDomElement &element )
       hidden = attrHidden  == "true";
   }
 
+  Qt::ToolBarArea pos = Qt::NoToolBarArea;
+  {
+    QString attrPosition = element.attribute("position").toLower();
+    if (!attrPosition.isEmpty())
+      pos = KToolBar::Private::positionFromString(attrPosition);
+  }
+  if (pos != Qt::NoToolBarArea)
+    mainWindow()->addToolBar(pos, this);
+
   if ( hidden )
     hide();
   else
@@ -879,6 +902,7 @@ void KToolBar::saveState( QDomElement &current ) const
   Qt::ToolButtonStyle ToolButtonStyle;
   int index = -1;
   d->getAttributes( position, ToolButtonStyle, index );
+  position = position.toLower();
 
   current.setAttribute( "noMerge", "1" );
   current.setAttribute( "position", position );
@@ -901,9 +925,11 @@ void KToolBar::saveState( QDomElement &current ) const
   current.setAttribute( "toolButtonStyleDefault", d->toolButtonStyleToString( d->ToolButtonStyleDefault ) );
 }
 
-void KToolBar::applySettings( KConfig *config, const QString &_configGroup, bool force )
+void KToolBar::applySettings( const KConfigGroup &_cg, bool force )
 {
-  QString configGroup = _configGroup.isEmpty() ? settingsGroup() : _configGroup;
+    KConfigGroup cg = _cg;
+    if ( cg.group().isEmpty() )
+        cg = KConfigGroup(cg.config(), settingsGroup() );
 
   /*
     Let's explain this a bit more in details.
@@ -920,12 +946,10 @@ void KToolBar::applySettings( KConfig *config, const QString &_configGroup, bool
   */
 
   // First the appearance stuff - the one which has a global config
-  applyAppearanceSettings( config, configGroup );
+  applyAppearanceSettings( cg );
 
   // ...and now the position stuff
-  if ( config->hasGroup( configGroup ) || force ) {
-    KConfigGroup cg(config, configGroup);
-
+  if ( cg.exists() || force ) {
     QString position = cg.readEntry( "Position", d->PositionDefault );
     int index = cg.readEntry( "Index", int(-1) );
     int offset = cg.readEntry( "Offset", int(d->OffsetDefault) );
@@ -952,9 +976,11 @@ void KToolBar::applySettings( KConfig *config, const QString &_configGroup, bool
   }
 }
 
-void KToolBar::applyAppearanceSettings( KConfig *config, const QString &_configGroup, bool forceGlobal )
+void KToolBar::applyAppearanceSettings( KConfigGroup &_cg, bool forceGlobal )
 {
-  QString configGroup = _configGroup.isEmpty() ? settingsGroup() : _configGroup;
+    KConfigGroup cg = _cg;
+    if ( cg.group().isEmpty() )
+        cg = KConfigGroup(cg.config(), settingsGroup() ); 
 
   // If we have application-specific settings in the XML file,
   // and nothing in the application's config file, then
@@ -993,18 +1019,17 @@ void KToolBar::applyAppearanceSettings( KConfig *config, const QString &_configG
     iconSize = d->IconSizeDefault;
     ToolButtonStyle = d->ToolButtonStyleDefault;
 
-    if ( !forceGlobal && config->hasGroup( configGroup ) ) {
-      config->setGroup( configGroup );
+    if ( !forceGlobal && cg.exists()) {
 
       // read in the ToolButtonStyle property
-      if ( config->hasKey( "ToolButtonStyle" ) ) {
-          ToolButtonStyle = d->toolButtonStyleFromString( config->readEntry( "ToolButtonStyle", QString() ) );
+      if ( cg.hasKey( "ToolButtonStyle" ) ) {
+          ToolButtonStyle = d->toolButtonStyleFromString( cg.readEntry( "ToolButtonStyle", QString() ) );
         applyToolButtonStyle = true;
       }
 
       // now get the size
-      if ( config->hasKey( "IconSize" ) ) {
-          iconSize = config->readEntry( "IconSize", 0 );
+      if ( cg.hasKey( "IconSize" ) ) {
+          iconSize = cg.readEntry( "IconSize", 0 );
           applyIconSize = true;
       }
     }
@@ -1250,6 +1275,25 @@ bool KToolBar::eventFilter( QObject * watched, QEvent * event )
     }
   }
 
+  QToolButton* tb;
+  if ( (tb = qobject_cast<QToolButton*>(watched)) && !tb->actions().isEmpty() ) {
+    QAction* act = tb->actions().first();
+    if ( event->type() == QEvent::MouseButtonPress || event->type() == QEvent::MouseButtonRelease ) {
+      QMouseEvent* me = static_cast<QMouseEvent*>( event );
+      if ( me->button() == Qt::MidButton /*&& 
+           act->receivers(SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)))*/ ) {
+        if ( me->type() == QEvent::MouseButtonPress )  
+          tb->setDown(true); 
+        else {
+          tb->setDown(false);
+          QMetaObject::invokeMethod(act, "triggered", Qt::DirectConnection,
+               Q_ARG(Qt::MouseButtons, me->button()), 
+               Q_ARG(Qt::KeyboardModifiers, QApplication::keyboardModifiers() ));
+        }
+      }
+    }
+  }
+
   found:
 
   // Redirect mouse events to the toolbar when drag + drop editing is enabled
@@ -1290,20 +1334,24 @@ void KToolBar::actionEvent( QActionEvent * event )
 {
   if ( event->type() == QEvent::ActionRemoved ) {
     QWidget* widget = widgetForAction( event->action() );
-    widget->removeEventFilter( this );
+    if (widget) {
+        widget->removeEventFilter( this );
 
-    foreach ( QWidget* child, widget->findChildren<QWidget*>() )
-      child->removeEventFilter( this );
+        foreach ( QWidget* child, widget->findChildren<QWidget*>() )
+            child->removeEventFilter( this );
+    }
   }
 
   QToolBar::actionEvent( event );
 
   if ( event->type() == QEvent::ActionAdded ) {
     QWidget* widget = widgetForAction( event->action() );
-    widget->installEventFilter( this );
+    if (widget) {
+        widget->installEventFilter( this );
 
-    foreach ( QWidget* child, widget->findChildren<QWidget*>() )
-      child->installEventFilter( this );
+        foreach ( QWidget* child, widget->findChildren<QWidget*>() )
+            child->installEventFilter( this );
+    }
   }
 
   d->adjustSeparatorVisibility();
