@@ -27,8 +27,8 @@
 #ifndef   netwm_h
 #define   netwm_h
 
-#include "kdelibs_export.h"
-#include <qwidget.h>
+#include <kdeui_export.h>
+#include <QtGui/QWidget>
 #ifdef Q_WS_X11
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
@@ -53,7 +53,6 @@ template <class Z> class NETRArray;
    @author Bradley T. Hughes <bhughes@trolltech.com>
    @see NET
    @see NETWinInfo
-   @see KWin
  **/
 
 class KDEUI_EXPORT NETRootInfo : public NET {
@@ -219,7 +218,6 @@ public:
        Returns the properties argument passed to the constructor.
        The size is the maximum array size the constructor accepts.
     **/
-    // KDE4 better name?
     const unsigned long* passedProperties() const;
 
     /**
@@ -259,30 +257,16 @@ public:
     **/
     int clientListStackingCount() const;
 
-    /**
-       Returns an array of Window id's, which contain all KDE system tray windows.
-
-       @return the array of Window id's of system tray windows
-
-       @see kdeSystemTrayWindowsCount()
-    **/
-    const Window *kdeSystemTrayWindows() const;
-
-    /**
-       Returns the number of windows in the kdeSystemTrayWindows array.
-
-       @return the number of Window id's in the system tray list
-
-       @see kdeSystemTrayWindows()
-    **/
-    int kdeSystemTrayWindowsCount() const;
-
     /**
        Returns the desktop geometry size.
 
        The desktop argument is ignored. Early drafts of the NET WM
        Specification were unclear about the semantics of this property.
 
+       NOTE: KDE uses virtual desktops and does not directly support
+       viewport in any way. You should use calls for virtual desktops,
+       viewport is mapped to them if needed.
+
        @param desktop the number of the desktop
 
        @return the size of the desktop
@@ -291,6 +275,10 @@ public:
 
     /**
        Returns the viewport of the specified desktop.
+       
+       NOTE: KDE uses virtual desktops and does not directly support
+       viewport in any way. You should use calls for virtual desktops,
+       viewport is mapped to them if needed.
 
        @param desktop the number of the desktop
 
@@ -353,16 +341,28 @@ public:
     /**
        Returns the number of desktops.
 
+       NOTE: KDE uses virtual desktops and does not directly support
+       viewport in any way. They are however mapped to virtual desktops
+       if needed.
+       
+       @param ignore_viewport if false, viewport is mapped to virtual desktops
+
        @return the number of desktops
     **/
-    int numberOfDesktops() const;
+    int numberOfDesktops( bool ignore_viewport = false ) const;
 
     /**
        Returns the current desktop.
 
+       NOTE: KDE uses virtual desktops and does not directly support
+       viewport in any way. They are however mapped to virtual desktops
+       if needed.
+       
+       @param ignore_viewport if false, viewport is mapped to virtual desktops
+
        @return the number of the current desktop
     **/
-    int currentDesktop() const;
+    int currentDesktop( bool ignore_viewport = false ) const;
 
     /**
        Returns the active (focused) window.
@@ -388,8 +388,7 @@ public:
 
        @param count The number of windows in the array
     **/
-    // KDE4 'const Window*', also in the others below
-    void setClientList(Window *windows, unsigned int count);
+    void setClientList(const Window *windows, unsigned int count);
 
     /**
        Sets the list of managed windows in stacking order on the Root/Desktop
@@ -399,23 +398,19 @@ public:
 
        @param count The number of windows in the array.
     **/
-    void setClientListStacking(Window *windows, unsigned int count);
-
-    /**
-       Sets the list of KDE system tray windows on the root window.
-
-       @param windows The array of window id's
-
-       @param count The number of windows in the array.
-    **/
-    void setKDESystemTrayWindows(Window *windows, unsigned int count);
+    void setClientListStacking(const Window *windows, unsigned int count);
 
     /**
        Sets the current desktop to the specified desktop.
 
+       NOTE: KDE uses virtual desktops and does not directly support
+       viewport in any way. It is however mapped to virtual desktops
+       if needed.
+       
        @param desktop the number of the desktop
+       @param ignore_viewport if false, viewport is mapped to virtual desktops
     **/
-    void setCurrentDesktop(int desktop);
+    void setCurrentDesktop(int desktop, bool ignore_viewport = false);
 
     /**
        Sets the desktop geometry to the specified geometry.
@@ -423,6 +418,10 @@ public:
        The desktop argument is ignored. Early drafts of the NET WM
        Specification were unclear about the semantics of this property.
 
+       NOTE: KDE uses virtual desktops and does not directly support
+       viewport in any way. You should use calls for virtual desktops,
+       viewport is mapped to them if needed.
+
        @param desktop the number of the desktop
 
        @param geometry the new size of the desktop
@@ -432,6 +431,10 @@ public:
     /**
        Sets the viewport for the current desktop to the specified point.
 
+       NOTE: KDE uses virtual desktops and does not directly support
+       viewport in any way. You should use calls for virtual desktops,
+       viewport is mapped to them if needed.
+
        @param desktop the number of the desktop
 
        @param viewport the new position of the desktop's viewport
@@ -441,6 +444,10 @@ public:
     /**
        Sets the number of desktops the the specified number.
 
+       NOTE: KDE uses virtual desktops and does not directly support
+       viewport in any way. Viewport is mapped to virtual desktops
+       if needed, but not for this call.
+
        @param numberOfDesktops the number of desktops
     **/
     void setNumberOfDesktops(int numberOfDesktops);
@@ -448,6 +455,10 @@ public:
     /**
        Sets the name of the specified desktop.
 
+       NOTE: KDE uses virtual desktops and does not directly support
+       viewport in any way. Viewport is mapped to virtual desktops
+       if needed, but not for this call.
+
        @param desktop the number of the desktop
 
        @param desktopName the new name of the desktop
@@ -491,7 +502,7 @@ public:
 
        @param count The number of windows in the array.
     **/
-    void setVirtualRoots(Window *windows, unsigned int count);
+    void setVirtualRoots(const Window *windows, unsigned int count);
 
     /**
        Sets the desktop layout. This is set by the pager. When setting, the pager must
@@ -561,10 +572,21 @@ public:
        Sends the _NET_RESTACK_WINDOW request.
     **/
     void restackRequest(Window window, RequestSource source, Window above, int detail, Time timestamp);
+
     /**
-       @obsolete
-    **/
-    void restackRequest(Window window, Window above, int detail);
+      Sends a ping with the given timestamp to the window, using
+      the _NET_WM_PING protocol.
+    */
+    void sendPing( Window window, Time timestamp );
+
+    /**
+       Sends a take activity message with the given timestamp to the window, using
+       the _NET_WM_TAKE_ACTIVITY protocol (see the WM spec for details).
+       @param window the window to which the message should be sent
+       @param timestamp timestamp of the message
+       @param flags arbitrary flags
+    */
+    void takeActivity( Window window, Time timestamp, long flags );
 
     /**
        This function takes the passed XEvent and returns an OR'ed list of
@@ -613,24 +635,6 @@ protected:
     **/
     virtual void removeClient(Window window) { Q_UNUSED(window); }
 
-    /**
-       A Client should subclass NETRootInfo and reimplement this function when
-       it wants to know when a system tray window has been added.  This is a KDE 2.0
-       extension.
-
-       @param window the id of the window to add
-    **/
-    virtual void addSystemTrayWin(Window window) { Q_UNUSED(window); }
-
-    /**
-       A Client should subclass NETRootInfo and reimplement this function when
-       it wants to know when a system tray window has been removed.  This is a KDE 2.0
-       extension.
-
-       @param window the id of the window to remove
-    **/
-    virtual void removeSystemTrayWin(Window window) { Q_UNUSED(window); }
-
     /**
        A Window Manager should subclass NETRootInfo and reimplement this function
        when it wants to know when a Client made a request to change the number
@@ -671,17 +675,6 @@ protected:
     **/
     virtual void changeCurrentDesktop(int desktop) { Q_UNUSED(desktop); }
 
-    /**
-       @deprecated Use NETRootInfo2::changeActiveWindow() instead.
-       A Window Manager should subclass NETRootInfo and reimplement this function
-       when it wants to know when a Client made a request to change the active
-       (focused) window. The changeActiveWindow() method in NETRootInfo2
-       should be used instead.
-
-       @param window the id of the window to activate
-    **/
-    virtual KDE_DEPRECATED void changeActiveWindow(Window window) { Q_UNUSED(window); }
-
     /**
        A Window Manager should subclass NETRootInfo and reimplement this function
        when it wants to know when a Client made a request to close a window.
@@ -706,55 +699,15 @@ protected:
     virtual void moveResize(Window window, int x_root, int y_root,
     			    unsigned long direction) { Q_UNUSED(window); Q_UNUSED(x_root); Q_UNUSED(y_root); Q_UNUSED(direction); }
 
-
-private:
-    void update( const unsigned long[] );
-    void setSupported();
-    void setDefaultProperties();
-    void updateSupportedProperties( Atom atom );
-    Role role;
-
-protected:
-    /** Virtual hook, used to add new "virtual" functions while maintaining
-	binary compatibility. Unused in this class.
-    */
-    virtual void virtual_hook( int id, void* data );
-private:
-    NETRootInfoPrivate *p;
-    friend class NETRootInfo2;
-    friend class NETRootInfo3;
-};
-
-/**
- This class is an extension of the NETRootInfo class, and exists solely
- for binary compatibility reasons (adds new virtual methods). Simply
- use it instead of NETRootInfo and override also the added virtual methods.
-*/
-class KDEUI_EXPORT NETRootInfo2
-    : public NETRootInfo
-{
-public:
-    NETRootInfo2(Display *display, Window supportWindow, const char *wmName,
-		unsigned long properties[], int properties_size,
-                int screen = -1, bool doActivate = true);
-    NETRootInfo2(Display *display, const unsigned long properties[], int properties_size,
-                int screen = -1, bool doActivate = true);
     /**
-      Sends a ping with the given timestamp to the window, using
-      the _NET_WM_PING protocol.
-    */
-    void sendPing( Window window, Time timestamp );
-protected:
-    friend class NETRootInfo;
-    /**
-       A Window Manager should subclass NETRootInfo2 and reimplement this function
+       A Window Manager should subclass NETRootInfo and reimplement this function
        when it wants to receive replies to the _NET_WM_PING protocol.
        @param window the window from which the reply came
        @param timestamp timestamp of the ping
      */
     virtual void gotPing( Window window, Time timestamp ) { Q_UNUSED(window); Q_UNUSED(timestamp); }
     /**
-       A Window Manager should subclass NETRootInfo2 and reimplement this function
+       A Window Manager should subclass NETRootInfo and reimplement this function
        when it wants to know when a Client made a request to change the active
        (focused) window.
 
@@ -765,19 +718,9 @@ protected:
     **/
     virtual void changeActiveWindow(Window window,NET::RequestSource src,
         Time timestamp, Window active_window ) { Q_UNUSED(window); Q_UNUSED(src); Q_UNUSED(timestamp); Q_UNUSED(active_window);}
-    /**
-       A Window Manager should subclass NETRootInfo2 and reimplement this function
-       when it wants to know when a Client made a request to restack a window.
-       See _NET_RESTACK_WINDOW for details.
-
-       @param window the id of the window to restack
-       @param above other window in the restack request
-       @param detail restack detail
-    **/
-    virtual void restackWindow(Window window, Window above, int detail) { Q_UNUSED(window); Q_UNUSED(above); Q_UNUSED(detail); }
 
     /**
-       A Window Manager should subclass NETRootInfo2 and reimplement this function
+       A Window Manager should subclass NETRootInfo and reimplement this function
        when it wants to know when a pager made a request to move/resize a window.
        See _NET_MOVERESIZE_WINDOW for details.
 
@@ -790,35 +733,8 @@ protected:
     **/
     virtual void moveResizeWindow(Window window, int flags, int x, int y, int width, int height) { Q_UNUSED(window); Q_UNUSED(flags); Q_UNUSED(x); Q_UNUSED(y); Q_UNUSED(width); Q_UNUSED(height); }
 
-// no private data, use NETRootInfoPrivate
-};
-
-/**
- This class is an extension of the NETRootInfo class, and exists solely
- for binary compatibility reasons (adds new virtual methods). Simply
- use it instead of NETRootInfo and override also the added virtual methods.
-*/
-class KDEUI_EXPORT NETRootInfo3
-    : public NETRootInfo2
-{
-public:
-    NETRootInfo3(Display *display, Window supportWindow, const char *wmName,
-		unsigned long properties[], int properties_size,
-                int screen = -1, bool doActivate = true);
-    NETRootInfo3(Display *display, const unsigned long properties[], int properties_size,
-                int screen = -1, bool doActivate = true);
     /**
-       Sends a take activity message with the given timestamp to the window, using
-       the _NET_WM_TAKE_ACTIVITY protocol (see the WM spec for details).
-       @param window the window to which the message should be sent
-       @param timestamp timestamp of the message
-       @param flags arbitrary flags
-    */
-    void takeActivity( Window window, Time timestamp, long flags );
-protected:
-    friend class NETRootInfo;
-    /**
-       A Window Manager should subclass NETRootInfo3 and reimplement this function
+       A Window Manager should subclass NETRootInfo and reimplement this function
        when it wants to know when a Client made a request to restack a window.
        See _NET_RESTACK_WINDOW for details.
 
@@ -831,42 +747,36 @@ protected:
     virtual void restackWindow(Window window, RequestSource source,
            Window above, int detail, Time timestamp) { Q_UNUSED(window); Q_UNUSED(source); Q_UNUSED(above); Q_UNUSED(detail); Q_UNUSED(timestamp); }
     /**
-       A Window Manager should subclass NETRootInfo3 and reimplement this function
+       A Window Manager should subclass NETRootInfo and reimplement this function
        when it wants to receive replies to the _NET_WM_TAKE_ACTIVITY protocol.
        @param window the window from which the reply came
        @param timestamp timestamp of the ping
        @param flags flags passed in the original message
      */
     virtual void gotTakeActivity(Window window, Time timestamp, long flags ) { Q_UNUSED(window); Q_UNUSED(timestamp); Q_UNUSED(flags); }
-// no private data, use NETRootInfoPrivate
-};
 
-/**
- This class is an extension of the NETRootInfo class, and exists solely
- for binary compatibility reasons (adds new virtual methods). Simply
- use it instead of NETRootInfo and override also the added virtual methods.
-*/
-class KDEUI_EXPORT NETRootInfo4
-    : public NETRootInfo3
-{
-public:
-    NETRootInfo4(Display *display, Window supportWindow, const char *wmName,
-		unsigned long properties[], int properties_size,
-                int screen = -1, bool doActivate = true);
-    NETRootInfo4(Display *display, const unsigned long properties[], int properties_size,
-                int screen = -1, bool doActivate = true);
-
-protected:
-    friend class NETRootInfo;
     /**
-       A Window Manager should subclass NETRootInfo2 and reimplement this function
+       A Window Manager should subclass NETRootInfo and reimplement this function
        when it wants to know when a pager made a request to change showing the desktop.
        See _NET_SHOWING_DESKTOP for details.
 
        @param showing whether to activate the showing desktop mode
     **/
     virtual void changeShowingDesktop(bool showing) { Q_UNUSED(showing); }
-// no private data, use NETRootInfoPrivate
+
+private:
+    void update( const unsigned long[] );
+    void setSupported();
+    void setDefaultProperties();
+    void updateSupportedProperties( Atom atom );
+
+protected:
+    /** Virtual hook, used to add new "virtual" functions while maintaining
+	binary compatibility. Unused in this class.
+    */
+    virtual void virtual_hook( int id, void* data );
+private:
+    NETRootInfoPrivate *p; // krazy:exclude=dpointer (implicitly shared)
 };
 
 /**
@@ -879,7 +789,6 @@ protected:
    @author Bradley T. Hughes <bhughes@trolltech.com>
    @see NET
    @see NETRootInfo
-   @see KWin
    @see http://www.freedesktop.org/standards/wm-spec/
  **/
 
@@ -958,7 +867,6 @@ public:
        Returns the properties argument passed to the constructor.
        The size is the maximum array size the constructor accepts.
     **/
-    // KDE4 better name?
     const unsigned long* passedProperties() const;
 
     /**
@@ -1044,11 +952,17 @@ public:
     /**
        Returns the desktop where the window is residing.
 
+       NOTE: KDE uses virtual desktops and does not directly support
+       viewport in any way. It is however mapped to virtual desktops
+       if needed.
+       
+       @param ignore_viewport if false, viewport is mapped to virtual desktops
+
        @return the number of the window's desktop
 
        @see OnAllDesktops()
     **/
-    int desktop() const;
+    int desktop( bool ignore_viewport = false ) const;
 
     /**
        Returns the process id for the client window.
@@ -1064,14 +978,6 @@ public:
     **/
     Bool handledIcons() const;
 
-    /**
-       Returns a Window id, telling the window manager which window we are
-       representing.
-
-       @return the window id
-    **/
-    Window kdeSystemTrayWinFor() const;
-
     /**
        Returns the mapping state for the window (see the NET base class
        documentation for a description of mapping state).
@@ -1115,9 +1021,7 @@ public:
 
     /**
        Set the state for the application window (see the NET base class documentation
-       for a description of window state). Note that the constructor needs to be
-       passed NET::WMState in properties even if it's only used for setting the state
-       without reading it.
+       for a description of window state).
 
        @param state the name state
 
@@ -1166,11 +1070,16 @@ public:
     /**
        Set which window the desktop is (should be) on.
 
+       NOTE: KDE uses virtual desktops and does not directly support
+       viewport in any way. It is however mapped to virtual desktops
+       if needed.
+       
        @param desktop the number of the new desktop
+       @param ignore_viewport if false, viewport is mapped to virtual desktops
 
        @see OnAllDesktops()
     **/
-    void setDesktop(int desktop);
+    void setDesktop(int desktop, bool ignore_viewport = false);
 
     /**
        Set the application window's process id.
@@ -1186,13 +1095,6 @@ public:
     **/
     void setHandledIcons(Bool handled);
 
-    /**
-       Set which window we are representing as a system tray window.
-
-       @param window the window that is represented by the system tray icon
-    **/
-    void setKDESystemTrayWinFor(Window window);
-
     /**
        Set the frame decoration strut, i.e. the width of the decoration borders.
 
@@ -1200,14 +1102,6 @@ public:
     **/
     void setFrameExtents(NETStrut strut);
 
-    /**
-       Set the frame decoration strut.  This is a KDE 2.0 extension to aid in
-       writing pager applications.
-
-       @param strut the new strut
-    **/
-    void setKDEFrameStrut(NETStrut strut);
-
     /**
        Returns an icon.  If width and height are passed, the icon returned will be
        the closest it can find (the next biggest).  If width and height are omitted,
@@ -1344,7 +1238,6 @@ public:
     **/
     static const int OnAllDesktops;
 
-
 protected:
     /**
        A Window Manager should subclass NETWinInfo and reimplement this function when
@@ -1371,7 +1264,6 @@ private:
     void updateWMState();
     void setIconInternal(NETRArray<NETIcon>& icons, int& icon_count, Atom property, NETIcon icon, Bool replace);
     NETIcon iconInternal(NETRArray<NETIcon>& icons, int icon_count, int width, int height) const;
-    Role role;
 
 protected:
     /** Virtual hook, used to add new "virtual" functions while maintaining
@@ -1379,7 +1271,7 @@ protected:
     */
     virtual void virtual_hook( int id, void* data );
 private:
-    NETWinInfoPrivate *p;
+    NETWinInfoPrivate *p; // krazy:exclude=dpointer (implicitly shared)
 };
 
 
