@@ -25,8 +25,7 @@
 
 #ifndef   netwm_def_h
 #define   netwm_def_h
-
-#include <kdelibs_export.h>
+#include <kdeui_export.h>
 
 /**
   Simple point class for NET classes.
@@ -349,12 +348,10 @@ public:
         TooltipMask      = 1<<12, ///< @see Tooltip
         NotificationMask = 1<<13, ///< @see Notification
         ComboBoxMask     = 1<<14, ///< @see ComboBox
-        DNDIconMask      = 1<<15  ///< @see DNDIcon
+        DNDIconMask      = 1<<15, ///< @see DNDIcon
+        AllTypesMask     = 0LU-1  ///< All window types.
     };
 
-    // KDE4 move to WindowTypeMask
-    enum { AllTypesMask = 0LU-1 };
-
     /**
      * Returns true if the given window type matches the mask given
      * using WindowTypeMask flags.
@@ -364,6 +361,14 @@ public:
     /**
        Window state.
 
+       To set the state of a window, you'll typically do something like:
+       \code
+         KWindowSystem::setState( winId(), NET::SkipTaskbar | NET::SkipPager );
+       \endcode
+
+       for example to not show the window on the taskbar and pager (alt-tab dialog).
+       winId() is a function of QWidget()
+
        Note that KeepAbove (StaysOnTop) and KeepBelow are meant as user preference and
        applications should avoid setting these states themselves.
     **/
@@ -473,25 +478,24 @@ public:
     /**
        Client window mapping state.  The class automatically watches the mapping
        state of the client windows, and uses the mapping state to determine how
-       to set/change different properties.
+       to set/change different properties. Note that this is very lowlevel
+       and you most probably don't want to use this state.
     **/
-
-    // KDE4 aaarghl, this doesn't map correctly to Xlib #defines
     enum MappingState {
 	/**
 	   indicates the client window is visible to the user.
 	**/
-	Visible, // ie. NormalState
+	Visible = 1, //NormalState,
 	/**
 	   indicates that neither the client window nor its icon is visible.
 	**/
-	Withdrawn,
+	Withdrawn = 0, //WithdrawnState,
 	/**
 	   indicates that the client window is not visible, but its icon is.
 	   This can be when the window is minimized or when it's on a
 	   different virtual desktop. See also NET::Hidden.
 	**/
-	Iconic
+	Iconic = 3 // IconicState
     };
 
     /**
@@ -550,11 +554,6 @@ public:
 
        @li XAWMState
 
-       Extended KDE protocols and properties (NOT STANDARD):
-
-       @li KDESystemTrayWindows
-       @li WMKDESystemTrayWinFor
-       @li WMKDEFrameStrut
     **/
 
     enum Property {
@@ -571,7 +570,7 @@ public:
 	WorkArea              = 1<<9,
 	SupportingWMCheck     = 1<<10,
 	VirtualRoots          = 1<<11,
-	KDESystemTrayWindows  = 1<<12, // NOT STANDARD
+        //
 	CloseWindow           = 1<<13,
 	WMMoveResize          = 1<<14,
 
@@ -587,10 +586,8 @@ public:
 	WMPid                 = 1<<23,
 	WMHandledIcons        = 1<<24,
 	WMPing                = 1<<25,
-	WMKDESystemTrayWinFor = 1<<26, // NOT STANDARD
-	XAWMState             = 1<<27, // NOT STANDARD
+	XAWMState             = 1<<27,
         WMFrameExtents        = 1<<28,
-	WMKDEFrameStrut       = WMFrameExtents, // NOT STANDARD
 
 	// Need to be reordered
 	WMIconName            = 1<<29,
@@ -619,6 +616,7 @@ public:
         @li WM2ShowingDesktop
         @li WM2Opacity _NET_WM_WINDOW_OPACITY
         @li WM2DesktopLayout _NET_DESKTOP_LAYOUT
+        @li WM2FullPlacement _NET_WM_FULL_PLACEMENT
     **/
     enum Property2 {
         WM2UserTime            = 1<<0,
@@ -636,7 +634,8 @@ public:
         WM2ClientMachine       = 1<<12,
         WM2ShowingDesktop      = 1<<13,
         WM2Opacity             = 1<<14,
-        WM2DesktopLayout       = 1<<15        
+        WM2DesktopLayout       = 1<<15,        
+        WM2FullPlacement       = 1<<16
     };
 
     /**
@@ -695,5 +694,4 @@ public:
 
 };
 
-
 #endif // netwm_def_h
