@@ -21,12 +21,12 @@
 #include "kxmlguifactory.h"
 #include "kxmlguibuilder.h"
 
-#include <qdir.h>
-#include <qfile.h>
-#include <qdom.h>
-#include <qtextstream.h>
-#include <qregexp.h>
-#include <qpointer.h>
+#include <QtCore/QDir>
+#include <QtCore/QFile>
+#include <QtXml/QDomDocument>
+#include <QtCore/QTextIStream>
+#include <QtCore/QRegExp>
+#include <QtCore/QPointer>
 
 #include <kcomponentdata.h>
 #include <kstandarddirs.h>
@@ -38,6 +38,14 @@
 
 #include <assert.h>
 
+struct DocStruct
+{
+  QString file;
+  QString data;
+};
+
+typedef QMap<QString, QMap<QString, QString> > ActionPropertiesMap;
+
 class KXMLGUIClientPrivate
 {
 public:
@@ -64,16 +72,169 @@ public:
   KXMLGUIBuilder *m_builder;
   QString m_xmlFile;
   QString m_localXMLFile;
+
+  // Actions to enable/disable on a state change
+  QMap<QString,KXMLGUIClient::StateChange> m_actionsStateMap;
 };
 
+
+static ActionPropertiesMap extractActionProperties( const QDomDocument &doc )
+{
+  ActionPropertiesMap properties;
+
+  QDomElement actionPropElement = doc.documentElement().namedItem( "ActionProperties" ).toElement();
+
+  if ( actionPropElement.isNull() )
+    return properties;
+
+  QDomNode n = actionPropElement.firstChild();
+  while(!n.isNull())
+  {
+    QDomElement e = n.toElement();
+    n = n.nextSibling(); // Advance now so that we can safely delete e
+    if ( e.isNull() )
+      continue;
+
+    if ( e.tagName().toLower() != "action" )
+      continue;
+
+    QString actionName = e.attribute( "name" );
+
+    if ( actionName.isEmpty() )
+      continue;
+
+    QMap<QString, QMap<QString, QString> >::Iterator propIt = properties.find( actionName );
+    if ( propIt == properties.end() )
+      propIt = properties.insert( actionName, QMap<QString, QString>() );
+
+    const QDomNamedNodeMap attributes = e.attributes();
+    const uint attributeslength = attributes.length();
+
+    for ( uint i = 0; i < attributeslength; ++i )
+    {
+      const QDomAttr attr = attributes.item( i ).toAttr();
+
+      if ( attr.isNull() )
+        continue;
+
+      const QString name = attr.name();
+
+      if ( name == "name" || name.isEmpty() )
+        continue;
+
+      (*propIt)[ name ] = attr.value();
+    }
+
+  }
+
+  return properties;
+}
+
+static void storeActionProperties( QDomDocument &doc,
+                            const ActionPropertiesMap &properties )
+{
+  QDomElement actionPropElement = doc.documentElement().namedItem( "ActionProperties" ).toElement();
+
+  if ( actionPropElement.isNull() )
+  {
+    actionPropElement = doc.createElement( "ActionProperties" );
+    doc.documentElement().appendChild( actionPropElement );
+  }
+
+  while ( !actionPropElement.firstChild().isNull() )
+    actionPropElement.removeChild( actionPropElement.firstChild() );
+
+  ActionPropertiesMap::ConstIterator it = properties.begin();
+  ActionPropertiesMap::ConstIterator end = properties.end();
+  for (; it != end; ++it )
+  {
+    QDomElement action = doc.createElement( "Action" );
+    action.setAttribute( "name", it.key() );
+    actionPropElement.appendChild( action );
+
+    QMap<QString, QString> attributes = (*it);
+    QMap<QString, QString>::ConstIterator attrIt = attributes.begin();
+    QMap<QString, QString>::ConstIterator attrEnd = attributes.end();
+    for (; attrIt != attrEnd; ++attrIt )
+      action.setAttribute( attrIt.key(), attrIt.value() );
+  }
+}
+
+static QString findVersionNumber( const QString &xml )
+{
+  enum { ST_START, ST_AFTER_OPEN, ST_AFTER_GUI,
+               ST_EXPECT_VERSION, ST_VERSION_NUM} state = ST_START;
+  for (int pos = 0; pos < xml.length(); pos++)
+  {
+    switch (state)
+    {
+      case ST_START:
+        if (xml[pos] == '<')
+          state = ST_AFTER_OPEN;
+        break;
+      case ST_AFTER_OPEN:
+      {
+        //Jump to gui..
+        int guipos = xml.indexOf("gui", pos, Qt::CaseInsensitive/*case-insensitive*/);
+        if (guipos == -1)
+          return QString(); //Reject
+
+        pos = guipos + 2; //Position at i, so we're moved ahead to the next character by the ++;
+        state = ST_AFTER_GUI;
+        break;
+      }
+      case ST_AFTER_GUI:
+        state = ST_EXPECT_VERSION;
+        break;
+      case ST_EXPECT_VERSION:
+      {
+        int verpos =  xml.indexOf("version=\"", pos, Qt::CaseInsensitive /*case-insensitive*/);
+        if (verpos == -1)
+          return QString(); //Reject
+
+        pos = verpos +  8; //v = 0, e = +1, r = +2, s = +3 , i = +4, o = +5, n = +6, = = +7, " = + 8
+        state = ST_VERSION_NUM;
+        break;
+      }
+      case ST_VERSION_NUM:
+      {
+        int endpos;
+        for (endpos = pos; endpos <  xml.length(); endpos++)
+        {
+          if (xml[endpos].unicode() >= '0' && xml[endpos].unicode() <= '9')
+            continue; //Number..
+          if (xml[endpos].unicode() == '"') //End of parameter
+            break;
+          else //This shouldn't be here..
+          {
+            endpos = xml.length();
+          }
+        }
+
+        if (endpos != pos && endpos < xml.length() )
+        {
+          QString matchCandidate = xml.mid(pos, endpos - pos); //Don't include " ".
+          return matchCandidate;
+        }
+
+        state = ST_EXPECT_VERSION; //Try to match a well-formed version..
+        break;
+      } //case..
+    } //switch
+  } //for
+
+  return QString();
+}
+
+
 KXMLGUIClient::KXMLGUIClient()
+    : d( new KXMLGUIClientPrivate )
 {
-  d = new KXMLGUIClientPrivate;
 }
 
 KXMLGUIClient::KXMLGUIClient( KXMLGUIClient *parent )
+    : d( new KXMLGUIClientPrivate )
 {
-  d = new KXMLGUIClientPrivate;
   parent->insertChildClient( this );
 }
 
@@ -143,7 +304,7 @@ QString KXMLGUIClient::localXMLFile() const
   if ( !QDir::isRelativePath(d->m_xmlFile) )
       return QString(); // can't save anything here
 
-  return KStandardDirs::locateLocal( "data", QLatin1String( componentData().componentName() + '/' ) + d->m_xmlFile );
+  return KStandardDirs::locateLocal( "data", componentData().componentName() + '/' + d->m_xmlFile );
 }
 
 
@@ -176,7 +337,7 @@ void KXMLGUIClient::setXMLFile( const QString& _file, bool merge, bool setXMLDoc
   {
     QString doc;
 
-    QString filter = QLatin1String(componentData().componentName() + '/') + _file;
+    QString filter = componentData().componentName() + '/' + _file;
 
     QStringList allFiles = componentData().dirs()->findAllResources("data", filter) + componentData().dirs()->findAllResources("data", _file);
 
@@ -191,7 +352,7 @@ void KXMLGUIClient::setXMLFile( const QString& _file, bool merge, bool setXMLDoc
       // however if a non-empty file gets passed and we can't find it we might
       // inform the developer using some debug output
       if ( !_file.isEmpty() )
-          kWarning() << "KXMLGUIClient::setXMLFile: cannot find .rc file " << _file << endl;
+          kWarning() << "KXMLGUIClient::setXMLFile: cannot find .rc file " << _file;
 
       setXML( QString(), true );
       return;
@@ -289,7 +450,7 @@ bool KXMLGUIClient::mergeXML( QDomElement &base, const QDomElement &additive, KA
     if ( tag == tagAction )
     {
       QByteArray name =  e.attribute( attrName ).toUtf8(); // WABA
-      if ( !actionCollection->action( name.data() ) ||
+      if ( !actionCollection->action( name.constData() ) ||
            (!KAuthorized::authorizeKAction(name)))
       {
         // remove this child as we aren't using it
@@ -450,7 +611,7 @@ bool KXMLGUIClient::mergeXML( QDomElement &base, const QDomElement &additive, KA
       // if base contains an implemented action, then we must not get
       // deleted (note that the actionCollection contains both,
       // "global" and "local" actions
-      if ( actionCollection->action( e.attribute( attrName ).toUtf8().data() ) )
+      if ( actionCollection->action( e.attribute( attrName ).toUtf8().constData() ) )
       {
         deleteMe = false;
         break;
@@ -577,7 +738,7 @@ void KXMLGUIClient::removeChildClient( KXMLGUIClient *child )
   return true;
 }*/
 
-const QList<KXMLGUIClient*>& KXMLGUIClient::childClients()
+QList<KXMLGUIClient*> KXMLGUIClient::childClients()
 {
   return d->m_children;
 }
@@ -616,7 +777,7 @@ QString KXMLGUIClient::findMostRecentXMLFile( const QStringList &files, QString
 
   foreach (const QString &file, files)
   {
-    //kDebug() << "KXMLGUIClient::findMostRecentXMLFile " << *it << endl;
+    //kDebug() << "KXMLGUIClient::findMostRecentXMLFile " << *it;
     QString data = KXMLGUIFactory::readConfigFile( file );
     DocStruct d;
     d.file = file;
@@ -639,12 +800,12 @@ QString KXMLGUIClient::findMostRecentXMLFile( const QStringList &files, QString
     uint version = versionStr.toUInt( &ok );
     if ( !ok )
       continue;
-    //kDebug() << "FOUND VERSION " << version << endl;
+    //kDebug() << "FOUND VERSION " << version;
 
     if ( version > bestVersion )
     {
       best = docIt;
-      //kDebug() << "best version is now " << version << endl;
+      //kDebug() << "best version is now " << version;
       bestVersion = version;
     }
   }
@@ -681,7 +842,7 @@ QString KXMLGUIClient::findMostRecentXMLFile( const QStringList &files, QString
           if ( f.open( QIODevice::WriteOnly ) )
           {
             QByteArray utf8data = (*local).data.toUtf8();
-            f.write( utf8data.data(), utf8data.length() );
+            f.write( utf8data.constData(), utf8data.length() );
             f.close();
           }
       }
@@ -698,7 +859,7 @@ QString KXMLGUIClient::findMostRecentXMLFile( const QStringList &files, QString
   }
   else if ( files.count() > 0 )
   {
-    //kDebug() << "returning first one..." << endl;
+    //kDebug() << "returning first one...";
     doc = (*allDocuments.begin()).data;
     return (*allDocuments.begin()).file;
   }
@@ -708,162 +869,15 @@ QString KXMLGUIClient::findMostRecentXMLFile( const QStringList &files, QString
 
 
 
-QString KXMLGUIClient::findVersionNumber( const QString &xml )
-{
-  enum { ST_START, ST_AFTER_OPEN, ST_AFTER_GUI,
-               ST_EXPECT_VERSION, ST_VERSION_NUM} state = ST_START;
-  for (int pos = 0; pos < xml.length(); pos++)
-  {
-    switch (state)
-    {
-      case ST_START:
-        if (xml[pos] == '<')
-          state = ST_AFTER_OPEN;
-        break;
-      case ST_AFTER_OPEN:
-      {
-        //Jump to gui..
-        int guipos = xml.indexOf("gui", pos, Qt::CaseInsensitive/*case-insensitive*/);
-        if (guipos == -1)
-          return QString(); //Reject
-
-        pos = guipos + 2; //Position at i, so we're moved ahead to the next character by the ++;
-        state = ST_AFTER_GUI;
-        break;
-      }
-      case ST_AFTER_GUI:
-        state = ST_EXPECT_VERSION;
-        break;
-      case ST_EXPECT_VERSION:
-      {
-        int verpos =  xml.indexOf("version=\"", pos, Qt::CaseInsensitive /*case-insensitive*/);
-        if (verpos == -1)
-          return QString(); //Reject
-
-        pos = verpos +  8; //v = 0, e = +1, r = +2, s = +3 , i = +4, o = +5, n = +6, = = +7, " = + 8
-        state = ST_VERSION_NUM;
-        break;
-      }
-      case ST_VERSION_NUM:
-      {
-        int endpos;
-        for (endpos = pos; endpos <  xml.length(); endpos++)
-        {
-          if (xml[endpos].unicode() >= '0' && xml[endpos].unicode() <= '9')
-            continue; //Number..
-          if (xml[endpos].unicode() == '"') //End of parameter
-            break;
-          else //This shouldn't be here..
-          {
-            endpos = xml.length();
-          }
-        }
-
-        if (endpos != pos && endpos < xml.length() )
-        {
-          QString matchCandidate = xml.mid(pos, endpos - pos); //Don't include " ".
-          return matchCandidate;
-        }
-
-        state = ST_EXPECT_VERSION; //Try to match a well-formed version..
-        break;
-      } //case..
-    } //switch
-  } //for
-
-  return QString();
-}
-
-KXMLGUIClient::ActionPropertiesMap KXMLGUIClient::extractActionProperties( const QDomDocument &doc )
-{
-  ActionPropertiesMap properties;
-
-  QDomElement actionPropElement = doc.documentElement().namedItem( "ActionProperties" ).toElement();
-
-  if ( actionPropElement.isNull() )
-    return properties;
-
-  QDomNode n = actionPropElement.firstChild();
-  while(!n.isNull())
-  {
-    QDomElement e = n.toElement();
-    n = n.nextSibling(); // Advance now so that we can safely delete e
-    if ( e.isNull() )
-      continue;
-
-    if ( e.tagName().toLower() != "action" )
-      continue;
-
-    QString actionName = e.attribute( "name" );
-
-    if ( actionName.isEmpty() )
-      continue;
-
-    QMap<QString, QMap<QString, QString> >::Iterator propIt = properties.find( actionName );
-    if ( propIt == properties.end() )
-      propIt = properties.insert( actionName, QMap<QString, QString>() );
-
-    const QDomNamedNodeMap attributes = e.attributes();
-    const uint attributeslength = attributes.length();
-
-    for ( uint i = 0; i < attributeslength; ++i )
-    {
-      const QDomAttr attr = attributes.item( i ).toAttr();
-
-      if ( attr.isNull() )
-        continue;
-
-      const QString name = attr.name();
-
-      if ( name == "name" || name.isEmpty() )
-        continue;
-
-      (*propIt)[ name ] = attr.value();
-    }
-
-  }
-
-  return properties;
-}
-
-void KXMLGUIClient::storeActionProperties( QDomDocument &doc, const ActionPropertiesMap &properties )
-{
-  QDomElement actionPropElement = doc.documentElement().namedItem( "ActionProperties" ).toElement();
-
-  if ( actionPropElement.isNull() )
-  {
-    actionPropElement = doc.createElement( "ActionProperties" );
-    doc.documentElement().appendChild( actionPropElement );
-  }
-
-  while ( !actionPropElement.firstChild().isNull() )
-    actionPropElement.removeChild( actionPropElement.firstChild() );
-
-  ActionPropertiesMap::ConstIterator it = properties.begin();
-  ActionPropertiesMap::ConstIterator end = properties.end();
-  for (; it != end; ++it )
-  {
-    QDomElement action = doc.createElement( "Action" );
-    action.setAttribute( "name", it.key() );
-    actionPropElement.appendChild( action );
-
-    QMap<QString, QString> attributes = (*it);
-    QMap<QString, QString>::ConstIterator attrIt = attributes.begin();
-    QMap<QString, QString>::ConstIterator attrEnd = attributes.end();
-    for (; attrIt != attrEnd; ++attrIt )
-      action.setAttribute( attrIt.key(), attrIt.value() );
-  }
-}
-
 void KXMLGUIClient::addStateActionEnabled(const QString& state,
                                           const QString& action)
 {
   StateChange stateChange = getActionsToChangeForState(state);
 
   stateChange.actionsToEnable.append( action );
-  //kDebug() << "KXMLGUIClient::addStateActionEnabled( " << state << ", " << action << ")" << endl;
+  //kDebug() << "KXMLGUIClient::addStateActionEnabled( " << state << ", " << action << ")";
 
-  m_actionsStateMap.insert( state, stateChange );
+  d->m_actionsStateMap.insert( state, stateChange );
 }
 
 
@@ -873,15 +887,15 @@ void KXMLGUIClient::addStateActionDisabled(const QString& state,
   StateChange stateChange = getActionsToChangeForState(state);
 
   stateChange.actionsToDisable.append( action );
-  //kDebug() << "KXMLGUIClient::addStateActionDisabled( " << state << ", " << action << ")" << endl;
+  //kDebug() << "KXMLGUIClient::addStateActionDisabled( " << state << ", " << action << ")";
 
-  m_actionsStateMap.insert( state, stateChange );
+  d->m_actionsStateMap.insert( state, stateChange );
 }
 
 
 KXMLGUIClient::StateChange KXMLGUIClient::getActionsToChangeForState(const QString& state)
 {
-  return m_actionsStateMap[state];
+  return d->m_actionsStateMap[state];
 }
 
 
