@@ -25,13 +25,13 @@
 
 #include <assert.h>
 
-#include <qdir.h>
-#include <qdom.h>
-#include <qfile.h>
-#include <qtextstream.h>
-#include <qwidget.h>
-#include <qdatetime.h>
-#include <qvariant.h>
+#include <QtCore/QDir>
+#include <QtXml/QDomDocument>
+#include <QtCore/QFile>
+#include <QtCore/QTextIStream>
+#include <QtGui/QWidget>
+#include <QtCore/QDate>
+#include <QtCore/QVariant>
 #include <QTextCodec>
 
 #include <kdebug.h>
@@ -41,7 +41,7 @@
 #include <kstandarddirs.h>
 
 #include "kaction.h"
-#include "kkeydialog.h"
+#include "kshortcutsdialog.h"
 #include "kactioncollection.h"
 
 using namespace KXMLGUI;
@@ -110,7 +110,7 @@ QString KXMLGUIFactory::readConfigFile( const QString &filename, bool never_null
         xml_file = filename;
     else
     {
-        xml_file = KStandardDirs::locate("data", QLatin1String(componentData.componentName() + '/' ) + filename);
+        xml_file = KStandardDirs::locate("data", componentData.componentName() + '/' + filename);
         if ( !QFile::exists( xml_file ) )
           xml_file = KStandardDirs::locate( "data", filename );
     }
@@ -126,7 +126,7 @@ QString KXMLGUIFactory::readConfigFile( const QString &filename, bool never_null
     }
 
     QByteArray buffer(file.readAll());
-    return QString::fromUtf8(buffer.data(), buffer.size());
+    return QString::fromUtf8(buffer.constData(), buffer.size());
 }
 
 bool KXMLGUIFactory::saveConfigFile( const QDomDocument& doc,
@@ -136,8 +136,7 @@ bool KXMLGUIFactory::saveConfigFile( const QDomDocument& doc,
     QString xml_file(filename);
 
     if (QDir::isRelativePath(xml_file))
-        xml_file = KStandardDirs::locateLocal("data", QLatin1String( componentData.componentName() + '/' )
-                                              + filename);
+        xml_file = KStandardDirs::locateLocal("data", componentData.componentName() + '/' + filename);
 
     QFile file( xml_file );
     if ( !file.open( QIODevice::WriteOnly ) )
@@ -212,7 +211,7 @@ KXMLGUIFactory::~KXMLGUIFactory()
 
 void KXMLGUIFactory::addClient( KXMLGUIClient *client )
 {
-    kDebug(1002) << "KXMLGUIFactory::addClient( " << client << " )" << endl; // ellis
+    kDebug(1002) << "KXMLGUIFactory::addClient( " << client << " )"; // ellis
     static const QString &actionPropElementName = KGlobal::staticQString( "ActionProperties" );
 
     if ( client->factory() ) {
@@ -232,7 +231,7 @@ void KXMLGUIFactory::addClient( KXMLGUIClient *client )
     if ( !d->m_clients.contains( client ) )
         d->m_clients.append( client );
     else
-        kDebug(1002) << "XMLGUI client already added " << client << endl;
+        kDebug(1002) << "XMLGUI client already added " << client;
 
     // Tell the client that plugging in is process and
     //  let it know what builder widget its mainwindow shortcuts
@@ -307,15 +306,15 @@ void KXMLGUIFactory::addClient( KXMLGUIClient *client )
           unaddedActions += action->objectName() + ' ';
 
     if (!unaddedActions.isEmpty())
-      kWarning() << k_funcinfo << "The following actions are not plugged into the gui (shortcuts will not work): " << unaddedActions << endl;
+      kWarning() << "The following actions are not plugged into the gui (shortcuts will not work): " << unaddedActions;
 */
 
-//    kDebug() << "addClient took " << dt.elapsed() << endl;
+//    kDebug() << "addClient took " << dt.elapsed();
 }
 
 void KXMLGUIFactory::removeClient( KXMLGUIClient *client )
 {
-    kDebug(1002) << "KXMLGUIFactory::removeClient( " << client << " )" << endl; // ellis
+    kDebug(1002) << "KXMLGUIFactory::removeClient( " << client << " )"; // ellis
 
     // don't try to remove the client's GUI if we didn't build it
     if ( !client || client->factory() != this )
@@ -330,7 +329,7 @@ void KXMLGUIFactory::removeClient( KXMLGUIClient *client )
     foreach (KXMLGUIClient *child, childClients)
         removeClient(child);
 
-    kDebug(1002) << "KXMLGUIFactory::removeServant, calling removeRecursive" << endl;
+    kDebug(1002) << "KXMLGUIFactory::removeServant, calling removeRecursive";
 
     d->pushState();
 
@@ -354,8 +353,6 @@ void KXMLGUIFactory::removeClient( KXMLGUIClient *client )
 
     d->m_rootNode->destruct( doc.documentElement(), *d );
 
-    d->builder->finalizeGUI( d->guiClient ); //JoWenn
-
     // reset some variables
     d->BuildState::reset();
 
@@ -367,7 +364,7 @@ void KXMLGUIFactory::removeClient( KXMLGUIClient *client )
     emit clientRemoved( client );
 }
 
-const QList<KXMLGUIClient*>& KXMLGUIFactory::clients() const
+QList<KXMLGUIClient*> KXMLGUIFactory::clients() const
 {
     return d->m_clients;
 }
@@ -523,6 +520,12 @@ void KXMLGUIFactory::configureAction( QAction *action, const QDomAttr &attribute
     if ( attrName.toLower() == QLatin1String("name") )
         return;
 
+    if ( attrName.toLower() == QLatin1String("icon") )
+    {
+        action->setIcon( KIcon( attribute.value() ) );
+        return;
+    }
+
     QVariant propertyValue;
 
     QVariant::Type propertyType = action->property( attrName.toLatin1() ).type();
@@ -531,20 +534,23 @@ void KXMLGUIFactory::configureAction( QAction *action, const QDomAttr &attribute
         propertyValue = QVariant( attribute.value().toInt() );
     else if ( propertyType == QVariant::UInt )
         propertyValue = QVariant( attribute.value().toUInt() );
+    else if ( propertyType == QVariant::UserType && action->property( attrName.toLatin1() ).userType() == qMetaTypeId<KShortcut>() )
+	propertyValue =  KShortcut( attribute.value() )  ;
     else
         propertyValue = QVariant( attribute.value() );
-
     action->setProperty( attrName.toLatin1(), propertyValue );
 }
 
 
-int KXMLGUIFactory::configureShortcuts(bool bAllowLetterShortcuts , bool bSaveSettings )
+int KXMLGUIFactory::configureShortcuts(bool letterCutsOk , bool bSaveSettings )
 {
-	KKeyDialog dlg( KKeyChooser::AllActions, bAllowLetterShortcuts ? KKeyChooser::LetterShortcutsAllowed : KKeyChooser::LetterShortcutsDisallowed, qobject_cast<QWidget*>(parent()) );
+	KShortcutsDialog dlg(KShortcutsEditor::AllActions,
+         letterCutsOk ? KShortcutsEditor::LetterShortcutsAllowed : KShortcutsEditor::LetterShortcutsDisallowed,
+         qobject_cast<QWidget*>(parent()));
 	foreach (KXMLGUIClient *client, d->m_clients)
 	{
 		if(!client->xmlFile().isEmpty())
-			dlg.insert( client->actionCollection() );
+			dlg.addCollection( client->actionCollection() );
 	}
 	return dlg.configure(bSaveSettings);
 }
