@@ -21,7 +21,7 @@
 #include "kxmlguiclient.h"
 #include "kxmlguibuilder.h"
 
-#include <qwidget.h>
+#include <QtGui/QWidget>
 
 #include <kglobal.h>
 #include <kdebug.h>
@@ -33,15 +33,16 @@ using namespace KXMLGUI;
 
 void ActionList::plug( QWidget *container, int index ) const
 {
-    QAction* before = 0L;
-    if (index && index <= container->actions().count())
-        before = container->actions().at(index - 1);
-    else if (index)
-        kWarning() << k_funcinfo << "Index " << index << " is not within range (0 - " << container->actions().count() << endl;
+    QAction* before = 0L; // Insert after end of widget's current actions (default).
+
+    if ((index < 0) || (index > container->actions().count()))
+        kWarning() << "Index " << index << " is not within range (0 - " << container->actions().count();
+    else if (index != container->actions().count())
+        before = container->actions().at(index); // Insert before indexed action.
 
     foreach (QAction* action, *this) {
         container->insertAction(before, action);
-        before = action;
+        // before = action; // BUG FIX: do not insert actions in reverse order.
     }
 }
 
@@ -318,7 +319,7 @@ void ContainerNode::adjustMergingIndices( int offset,
     index += offset;
 }
 
-bool ContainerNode::destruct( QDomElement element, BuildState &state )
+bool ContainerNode::destruct( QDomElement element, BuildState &state ) //krazy:exclude=passbyvalue (we need a copy for removeContainer)
 {
     destructChildren( element, state );
 
@@ -618,7 +619,7 @@ bool BuildHelper::processActionElement( const QDomElement &e, int idx )
     // look up the action and plug it in
     QAction *action = m_state.guiClient->action( e );
 
-    //kDebug() << "BuildHelper::processActionElement " << e.attribute( "name" ) << " -> " << action << " (in " << m_state.guiClient->actionCollection() << ")" << endl;
+    //kDebug() << "BuildHelper::processActionElement " << e.attribute( "name" ) << " -> " << action << " (in " << m_state.guiClient->actionCollection() << ")";
     if ( !action )
         return false;
 
