@@ -21,29 +21,29 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include "dom/css_value.h"
-#include "dom/dom_exception.h"
-#include "dom/dom_string.h"
+#include "css_valueimpl.h"
+#include "css_ruleimpl.h"
+#include "css_stylesheetimpl.h"
+#include "cssparser.h"
+#include "cssproperties.h"
+#include "cssvalues.h"
 
-#include "css/css_valueimpl.h"
-#include "css/css_ruleimpl.h"
-#include "css/css_stylesheetimpl.h"
-#include "css/cssparser.h"
-#include "css/cssproperties.h"
-#include "css/cssvalues.h"
+#include <dom/css_value.h>
+#include <dom/dom_exception.h>
+#include <dom/dom_string.h>
 
-#include "xml/dom_stringimpl.h"
-#include "xml/dom_docimpl.h"
+#include <xml/dom_stringimpl.h>
+#include <xml/dom_docimpl.h>
 
-#include "misc/loader.h"
+#include <misc/loader.h>
 
-#include "rendering/font.h"
-#include "rendering/render_style.h"
+#include <rendering/font.h>
+#include <rendering/render_style.h>
 
 #include <kdebug.h>
-#include <qregexp.h>
-#include <qpaintdevice.h>
-#include <q3paintdevicemetrics.h>
+#include <QtCore/QRegExp>
+#include <QtGui/QPaintDevice>
+#include <Qt3Support/Q3PaintDeviceMetrics>
 
 // Hack for debugging purposes
 extern DOM::DOMString getPropertyName(unsigned short id);
@@ -255,7 +255,7 @@ DOMString CSSStyleDeclarationImpl::getPropertyValue( int propertyID ) const
         return getShortHandValue( properties, 3 );
     }
     }
-    //kDebug() << k_funcinfo << "property not found:" << propertyID << endl;
+    //kDebug() << "property not found:" << propertyID;
     return DOMString();
 }
 
@@ -268,7 +268,7 @@ DOMString CSSStyleDeclarationImpl::get4Values( const int* properties ) const
             return DOMString();
         }
         if ( i > 0 )
-            res += " ";
+            res += " ";	//krazy:exclude=doublequote_chars DOM demands chars
         res += value->cssText();
     }
     return res;
@@ -281,7 +281,7 @@ DOMString CSSStyleDeclarationImpl::getShortHandValue( const int* properties, int
         CSSValueImpl* value = getPropertyCSSValue( properties[i] );
         if ( value ) { // TODO provide default value if !value
             if ( !res.isNull() )
-                res += " ";
+                res += " ";	//krazy:exclude=doublequote_chars DOM demands chars
             res += value->cssText();
         }
     }
@@ -459,7 +459,7 @@ void CSSStyleDeclarationImpl::setCssText(DOM::DOMString text)
 
 bool CSSStyleDeclarationImpl::parseString( const DOMString &/*string*/, bool )
 {
-    kDebug() << "WARNING: CSSStyleDeclarationImpl::parseString, unimplemented, was called" << endl;
+    kDebug() << "WARNING: CSSStyleDeclarationImpl::parseString, unimplemented, was called";
     return false;
     // ###
 }
@@ -608,22 +608,22 @@ void CSSPrimitiveValueImpl::cleanup()
     m_type = 0;
 }
 
-int CSSPrimitiveValueImpl::computeLength( khtml::RenderStyle *style, Q3PaintDeviceMetrics *devMetrics )
+int CSSPrimitiveValueImpl::computeLength( khtml::RenderStyle *style, int logicalDpiY)
 {
-    double result = computeLengthFloat( style, devMetrics );
+    double result = computeLengthFloat( style, logicalDpiY );
     // This conversion is imprecise, often resulting in values of, e.g., 44.99998.  We
     // need to go ahead and round if we're really close to the next integer value.
     int intResult = (int)(result + (result < 0 ? -0.01 : +0.01));
     return intResult;
 }
 
-double CSSPrimitiveValueImpl::computeLengthFloat( khtml::RenderStyle *style, Q3PaintDeviceMetrics *devMetrics )
+double CSSPrimitiveValueImpl::computeLengthFloat( khtml::RenderStyle *style, int logicalDpiY)
 {
     unsigned short type = primitiveType();
 
     double dpiY = 72.; // fallback
-    if ( devMetrics )
-        dpiY = devMetrics->logicalDpiY();
+    if ( logicalDpiY )
+        dpiY = logicalDpiY;
     if ( !khtml::printpainter && dpiY < 96 )
         dpiY = 96.;
 
@@ -705,7 +705,7 @@ unsigned short CSSPrimitiveValueImpl::cssValueType() const
 bool CSSPrimitiveValueImpl::parseString( const DOMString &/*string*/, bool )
 {
     // ###
-    kDebug() << "WARNING: CSSPrimitiveValueImpl::parseString, unimplemented, was called" << endl;
+    kDebug() << "WARNING: CSSPrimitiveValueImpl::parseString, unimplemented, was called";
     return false;
 }
 
@@ -728,7 +728,7 @@ DOM::DOMString CSSPrimitiveValueImpl::cssText() const
 	    text = DOMString(QString::number( (int)m_value.num ));
 	    break;
 	case CSSPrimitiveValue::CSS_PERCENTAGE:
-	    text = DOMString(QString::number( m_value.num ) + "%");
+	    text = DOMString(QString::number( m_value.num ) + "%");	//krazy:exclude=doublequote_chars DOM demands chars
 	    break;
 	case CSSPrimitiveValue::CSS_EMS:
 	    text = DOMString(QString::number( m_value.num ) + "em");
@@ -767,7 +767,7 @@ DOM::DOMString CSSPrimitiveValueImpl::cssText() const
 	    text = DOMString(QString::number( m_value.num ) + "ms");
 	    break;
 	case CSSPrimitiveValue::CSS_S:
-	    text = DOMString(QString::number( m_value.num ) + "s");
+	    text = DOMString(QString::number( m_value.num ) + "s");	//krazy:exclude=doublequote_chars DOM demands chars
 	    break;
 	case CSSPrimitiveValue::CSS_HZ:
 	    text = DOMString(QString::number( m_value.num ) + "hz");
@@ -784,7 +784,7 @@ DOM::DOMString CSSPrimitiveValueImpl::cssText() const
 	case CSSPrimitiveValue::CSS_URI:
             text  = "url(";
 	    text += DOMString( m_value.string );
-            text += ")";
+            text += ")";	//krazy:exclude=doublequote_chars DOM demands chars
 	    break;
 	case CSSPrimitiveValue::CSS_IDENT:
 	    text = getValueName(m_value.ident);
@@ -795,17 +795,17 @@ DOM::DOMString CSSPrimitiveValueImpl::cssText() const
 	case CSSPrimitiveValue::CSS_COUNTER:
             text = "counter(";
             text += m_value.counter->m_identifier;
-            text += ")";
+            text += ")";	//krazy:exclude=doublequote_chars DOM demands chars
             // ### add list-style and separator
 	    break;
 	case CSSPrimitiveValue::CSS_RECT:
         {
             RectImpl* rectVal = getRectValue();
             text = "rect(";
-            text += rectVal->top()->cssText() + " ";
-            text += rectVal->right()->cssText() + " ";
-            text += rectVal->bottom()->cssText() + " ";
-            text += rectVal->left()->cssText() + ")";
+            text += rectVal->top()->cssText() + " ";	//krazy:exclude=doublequote_chars DOM demands chars
+            text += rectVal->right()->cssText() + " ";	//krazy:exclude=doublequote_chars DOM demands chars
+            text += rectVal->bottom()->cssText() + " ";	//krazy:exclude=doublequote_chars DOM demands chars
+            text += rectVal->left()->cssText() + ")";	//krazy:exclude=doublequote_chars DOM demands chars
             break;
         }
 	case CSSPrimitiveValue::CSS_RGBCOLOR:
@@ -813,17 +813,17 @@ DOM::DOMString CSSPrimitiveValueImpl::cssText() const
 		if (m_value.rgbcolor == khtml::transparentColor)
 		    text = "transparent";
 		else
-		    text = "rgba(" + QString::number(qRed  (m_value.rgbcolor)) + "," 
-				   + QString::number(qBlue (m_value.rgbcolor)) + "," 
-				   + QString::number(qGreen(m_value.rgbcolor)) + "," 
-				   + QString::number(qAlpha(m_value.rgbcolor)/255.0) + ")";
+		    text = "rgba(" + QString::number(qRed  (m_value.rgbcolor)) + ","	//krazy:exclude=doublequote_chars DOM demands chars
+				   + QString::number(qBlue (m_value.rgbcolor)) + ","	//krazy:exclude=doublequote_chars DOM demands chars
+				   + QString::number(qGreen(m_value.rgbcolor)) + ","	//krazy:exclude=doublequote_chars DOM demands chars
+				   + QString::number(qAlpha(m_value.rgbcolor)/255.0) + ")";	//krazy:exclude=doublequote_chars DOM demands chars
 	    } else {
 		text = QColor(m_value.rgbcolor).name();
 	    }
 	    break;
         case CSSPrimitiveValue::CSS_PAIR:
             text = m_value.pair->first()->cssText();
-            text += " ";
+            text += " ";	//krazy:exclude=doublequote_chars DOM demands chars
             text += m_value.pair->second()->cssText();
             break;
 	default:
@@ -946,7 +946,7 @@ FontFamilyValueImpl::FontFamilyValueImpl( const QString &string)
     const QString &available = KHTMLSettings::availableFamilies();
 
     parsedFontName = parsedFontName.toLower();
-    // kDebug(0) << "searching for face '" << parsedFontName << "'" << endl;
+    // kDebug(0) << "searching for face '" << parsedFontName << "'";
 
     int pos = available.indexOf( ',' + parsedFontName + ',', 0, Qt::CaseInsensitive );
     if ( pos == -1 ) {
@@ -965,7 +965,7 @@ FontFamilyValueImpl::FontFamilyValueImpl( const QString &string)
        int p = available.indexOf(',', pos);
        assert( p != -1 ); // available is supposed to start and end with ,
        parsedFontName = available.mid( pos, p - pos);
-       // kDebug(0) << "going for '" << parsedFontName << "'" << endl;
+       // kDebug(0) << "going for '" << parsedFontName << "'";
     } else
         parsedFontName.clear();
 
@@ -998,32 +998,32 @@ DOMString FontValueImpl::cssText() const
     }
     if (variant) {
 	if (result.length() > 0) {
-	    result += " ";
+	    result += " ";	//krazy:exclude=doublequote_chars DOM demands chars
 	}
 	result += variant->cssText();
     }
     if (weight) {
 	if (result.length() > 0) {
-	    result += " ";
+	    result += " ";	//krazy:exclude=doublequote_chars DOM demands chars
 	}
 	result += weight->cssText();
     }
     if (size) {
 	if (result.length() > 0) {
-	    result += " ";
+	    result += " ";	//krazy:exclude=doublequote_chars DOM demands chars
 	}
 	result += size->cssText();
     }
     if (lineHeight) {
 	if (!size) {
-	    result += " ";
+	    result += " ";	//krazy:exclude=doublequote_chars DOM demands chars
 	}
-	result += "/";
+	result += "/";	//krazy:exclude=doublequote_chars DOM demands chars
 	result += lineHeight->cssText();
     }
     if (family) {
 	if (result.length() > 0) {
-	    result += " ";
+	    result += " ";	//krazy:exclude=doublequote_chars DOM demands chars
 	}
 	result += family->cssText();
     }
@@ -1052,7 +1052,7 @@ QString QuotesValueImpl::openQuote(int level) const
 {
     if (levels == 0) return "";
     level--; // increments are calculated before openQuote is called
-//     kDebug( 6080 ) << "Open quote level:" << level << endl;
+//     kDebug( 6080 ) << "Open quote level:" << level;
     if (level < 0) level = 0;
     else
     if (level >= (int) levels) level = (int) (levels-1);
@@ -1062,7 +1062,7 @@ QString QuotesValueImpl::openQuote(int level) const
 QString QuotesValueImpl::closeQuote(int level) const
 {
     if (levels == 0) return "";
-//     kDebug( 6080 ) << "Close quote level:" << level << endl;
+//     kDebug( 6080 ) << "Close quote level:" << level;
     if (level < 0) level = 0;
     else
     if (level >= (int) levels) level = (int) (levels-1);
@@ -1091,19 +1091,19 @@ DOMString ShadowValueImpl::cssText() const
     }
     if (x) {
         if (text.length() > 0) {
-            text += " ";
+            text += " ";	//krazy:exclude=doublequote_chars DOM demands chars
         }
         text += x->cssText();
     }
     if (y) {
         if (text.length() > 0) {
-            text += " ";
+            text += " ";	//krazy:exclude=doublequote_chars DOM demands chars
         }
         text += y->cssText();
     }
     if (blur) {
         if (text.length() > 0) {
-            text += " ";
+            text += " ";	//krazy:exclude=doublequote_chars DOM demands chars
         }
         text += blur->cssText();
     }
