@@ -30,8 +30,7 @@
 #include "misc/loader_client.h"
 #include "misc/shared.h"
 
-#include <q3intdict.h>
-#include <Q3PaintDeviceMetrics>
+#include <Qt3Support/Q3IntDict>
 
 namespace khtml {
     class RenderStyle;
@@ -190,9 +189,9 @@ public:
      * this is screen/printer dependent, so we probably need a config option for this,
      * and some tool to calibrate.
      */
-    int computeLength( khtml::RenderStyle *style, Q3PaintDeviceMetrics *devMetrics );
+    int computeLength( khtml::RenderStyle *style, int logicalDpiY);
 
-    double computeLengthFloat( khtml::RenderStyle *style, Q3PaintDeviceMetrics *devMetrics );
+    double computeLengthFloat( khtml::RenderStyle *style, int logicalDpiY);
 
     // use with care!!!
     void setPrimitiveType(unsigned short type) { m_type = type; }
