@@ -25,23 +25,25 @@
 // #define TOKEN_DEBUG
 #define YYDEBUG 0
 
+#include "cssparser.h"
+
 #include <kdebug.h>
 #include <kglobal.h>
 #include <kurl.h>
 
-#include "cssparser.h"
 #include "css_valueimpl.h"
 #include "css_ruleimpl.h"
 #include "css_stylesheetimpl.h"
 #include "cssproperties.h"
 #include "cssvalues.h"
-#include "misc/helper.h"
 #include "csshelper.h"
-using namespace DOM;
+#include <misc/helper.h>
 
 #include <stdlib.h>
 #include <assert.h>
 
+using namespace DOM;
+
 // used to promote background: left to left center
 #define BACKGROUND_SKIP_CENTER( num ) \
     if ( !pos_ok[ num ] && expected != 1 ) {    \
@@ -90,7 +92,7 @@ CSSParser *CSSParser::currentParser = 0;
 CSSParser::CSSParser( bool strictParsing )
 {
 #ifdef CSS_DEBUG
-    kDebug( 6080 ) << "CSSParser::CSSParser this=" << this << endl;
+    kDebug( 6080 ) << "CSSParser::CSSParser this=" << this;
 #endif
     strict = strictParsing;
 
@@ -126,7 +128,7 @@ CSSParser::~CSSParser()
     delete valueList;
 
 #ifdef CSS_DEBUG
-    kDebug( 6080 ) << "CSSParser::~CSSParser this=" << this << endl;
+    kDebug( 6080 ) << "CSSParser::~CSSParser this=" << this;
 #endif
 
     free( data );
@@ -169,11 +171,11 @@ void CSSParser::parseSheet( CSSStyleSheetImpl *sheet, const DOMString &string )
     memcpy( data, string.unicode(), string.length()*sizeof( unsigned short) );
 
 #ifdef CSS_DEBUG
-    kDebug( 6080 ) << ">>>>>>> start parsing style sheet" << endl;
+    kDebug( 6080 ) << ">>>>>>> start parsing style sheet";
 #endif
     runParser(length);
 #ifdef CSS_DEBUG
-    kDebug( 6080 ) << "<<<<<<< done parsing style sheet" << endl;
+    kDebug( 6080 ) << "<<<<<<< done parsing style sheet";
 #endif
 
     delete rule;
@@ -191,7 +193,7 @@ CSSRuleImpl *CSSParser::parseRule( DOM::CSSStyleSheetImpl *sheet, const DOM::DOM
     for ( unsigned int i = 0; i < strlen(khtml_rule); i++ )
         data[i] = khtml_rule[i];
     memcpy( data + strlen( khtml_rule ), string.unicode(), string.length()*sizeof( unsigned short) );
-    // qDebug("parse string = '%s'", QConstString( (const QChar *)data, length ).string().toLatin1().constData() );
+    // qDebug("parse string = '%s'", QString::fromRawData( (const QChar *)data, length ).toLatin1().constData() );
     data[length-4] = '}';
 
     runParser(length);
@@ -220,7 +222,7 @@ bool CSSParser::parseValue( DOM::CSSStyleDeclarationImpl *declaration, int _id,
         data[i] = khtml_value[i];
     memcpy( data + strlen( khtml_value ), string.unicode(), string.length()*sizeof( unsigned short) );
     data[length-4] = '}';
-    // qDebug("parse string = '%s'", QConstString( (const QChar *)data, length ).string().toLatin1().constData() );
+    // qDebug("parse string = '%s'", QString::fromRawData( (const QChar *)data, length ).toLatin1().constData() );
 
     id = _id;
     important = _important;
@@ -881,7 +883,7 @@ bool CSSParser::parseValue( int propId, bool important )
                 }
                 value = valueList->next();
             }
-            //kDebug( 6080 ) << "got " << list->length() << "d decorations" << endl;
+            //kDebug( 6080 ) << "got " << list->length() << "d decorations";
             if(list->length() && is_valid) {
                 parsedValue = list;
                 valueList->next();
@@ -921,7 +923,7 @@ bool CSSParser::parseValue( int propId, bool important )
     case CSS_PROP__KHTML_USER_INPUT:        // none | enabled | disabled | inherit
         if ( id == CSS_VAL_NONE || id == CSS_VAL_ENABLED || id == CSS_VAL_DISABLED )
             valid_primitive = true;
-//        kDebug(6080) << "CSS_PROP__KHTML_USER_INPUT: " << valid_primitive << endl;
+//        kDebug(6080) << "CSS_PROP__KHTML_USER_INPUT: " << valid_primitive;
         break;
     case CSS_PROP__KHTML_MARQUEE: {
         const int properties[5] = { CSS_PROP__KHTML_MARQUEE_DIRECTION, CSS_PROP__KHTML_MARQUEE_INCREMENT,
@@ -1062,7 +1064,7 @@ bool CSSParser::parseValue( int propId, bool important )
     }
     default:
 // #ifdef CSS_DEBUG
-//         kDebug( 6080 ) << "illegal or CSS2 Aural property: " << val << endl;
+//         kDebug( 6080 ) << "illegal or CSS2 Aural property: " << val;
 // #endif
         break;
     }
@@ -1317,7 +1319,7 @@ bool CSSParser::parseContent( int propId, bool important )
             parsedValue = new CSSImageValueImpl(
                 DOMString(KUrl( styleElement->baseURL(), value.string()).url() ), styleElement );
 #ifdef CSS_DEBUG
-            kDebug( 6080 ) << "content, url=" << value.string() << " base=" << styleElement->baseURL().url( ) << endl;
+            kDebug( 6080 ) << "content, url=" << value.string() << " base=" << styleElement->baseURL().url( );
 #endif
         } else if ( val->unit == Value::Function ) {
             // attr( X ) | counter( X [,Y] ) | counters( X, Y, [,Z] )
@@ -1541,8 +1543,8 @@ bool CSSParser::parseBackgroundProperty(int propId, int& propId1, int& propId2,
                                         CSSValueImpl*& retValue1, CSSValueImpl*& retValue2)
 {
 #ifdef CSS_DEBUG
-    kdDebug(6080) << "parseBackgroundProperty()" << endl;
-    kdDebug(6080) << "LOOKING FOR: " << getPropertyName(propId).string() << endl;
+    kDebug(6080) << "parseBackgroundProperty()";
+    kDebug(6080) << "LOOKING FOR: " << getPropertyName(propId).string();
 #endif
     CSSValueListImpl *values = 0, *values2 = 0;
     Value* val;
@@ -1726,7 +1728,7 @@ bool CSSParser::parseShape( int propId, bool important )
 // [ 'font-style' || 'font-variant' || 'font-weight' ]? 'font-size' [ / 'line-height' ]? 'font-family'
 bool CSSParser::parseFont( bool important )
 {
-//     kDebug(6080) << "parsing font property current=" << valueList->currentValue << endl;
+//     kDebug(6080) << "parsing font property current=" << valueList->currentValue;
     bool valid = true;
     Value *value = valueList->current();
     CSSValueListImpl* family = 0;
@@ -1807,7 +1809,7 @@ bool CSSParser::parseFont( bool important )
     if ( !weight )
         weight = new CSSPrimitiveValueImpl( CSS_VAL_NORMAL );
 
-//     kDebug( 6080 ) << "  got style, variant and weight current=" << valueList->currentValue << endl;
+//     kDebug( 6080 ) << "  got style, variant and weight current=" << valueList->currentValue;
 
     // now a font size _must_ come
     // <absolute-size> | <relative-size> | <length> | <percentage> | inherit
@@ -1820,7 +1822,7 @@ bool CSSParser::parseFont( bool important )
     if ( !size || !value )
         goto invalid;
 
-    // kDebug( 6080 ) << "  got size" << endl;
+    // kDebug( 6080 ) << "  got size";
 
     if ( value->unit == Value::Operator && value->iValue == '/' ) {
         // line-height
@@ -1841,13 +1843,13 @@ bool CSSParser::parseFont( bool important )
     if ( !lineHeight )
         lineHeight = new CSSPrimitiveValueImpl( CSS_VAL_NORMAL );
 
-//     kDebug( 6080 ) << "  got line height current=" << valueList->currentValue << endl;
+//     kDebug( 6080 ) << "  got line height current=" << valueList->currentValue;
     // font family must come now
     family = parseFontFamily();
 
     if ( valueList->current() || !family )
         goto invalid;
-    //kDebug( 6080 ) << "  got family, parsing ok!" << endl;
+    //kDebug( 6080 ) << "  got family, parsing ok!";
 
     addProperty( CSS_PROP_FONT_FAMILY,  family,     important );
     addProperty( CSS_PROP_FONT_STYLE,   style,      important );
@@ -1858,7 +1860,7 @@ bool CSSParser::parseFont( bool important )
     return true;
 
  invalid:
-    //kDebug(6080) << "   -> invalid" << endl;
+    //kDebug(6080) << "   -> invalid";
     delete family;
     delete style;
     delete variant;
@@ -1871,7 +1873,7 @@ bool CSSParser::parseFont( bool important )
 
 CSSValueListImpl *CSSParser::parseFontFamily()
 {
-//     kDebug( 6080 ) << "CSSParser::parseFontFamily current=" << valueList->currentValue << endl;
+//     kDebug( 6080 ) << "CSSParser::parseFontFamily current=" << valueList->currentValue;
     CSSValueListImpl *list = new CSSValueListImpl;
     Value *value = valueList->current();
     QString currFace;
@@ -1927,7 +1929,7 @@ CSSValueListImpl *CSSParser::parseFontFamily()
         }
         }
 	else {
- 	    //kDebug( 6080 ) << "invalid family part" << endl;
+ 	    //kDebug( 6080 ) << "invalid family part";
             break;
         }
 
@@ -2328,7 +2330,7 @@ bool CSSParser::parseCounter(int propId, bool increment, bool important)
 static inline int yyerror( const char *str ) {
 //    assert( 0 );
 #ifdef CSS_DEBUG
-    kDebug( 6080 ) << "CSS parse error " << str << endl;
+    kDebug( 6080 ) << "CSS parse error " << str;
 #else
     Q_UNUSED( str );
 #endif
