@@ -22,9 +22,9 @@
 #ifndef _CSS_cssparser_h_
 #define _CSS_cssparser_h_
 
-#include <qstring.h>
-#include <qcolor.h>
-#include <QVector>
+#include <QtCore/QString>
+#include <QtGui/QColor>
+#include <QtCore/QVector>
 #include <dom/dom_string.h>
 
 namespace DOM {
@@ -38,8 +38,7 @@ namespace DOM {
     class CSSPrimitiveValueImpl;
     class CSSStyleDeclarationImpl;
     class CSSProperty;
-    class CSSRuleListImpl;
-
+    
 
     struct ParseString {
 	unsigned short *string;
@@ -82,14 +81,14 @@ namespace DOM {
     class ValueList {
     public:
         ValueList() : m_current(0) { }
-	~ValueList();
+        ~ValueList();
         void addValue(const Value& v) { m_values.append(v); }
         unsigned int size() const { return m_values.size(); }
         Value* current() { return m_current < m_values.size() ? &m_values[m_current] : 0; }
         Value* next() { ++m_current; return current(); }
     private:
         QVector<Value> m_values;
-	unsigned int m_current;
+        int m_current;
     };
 
     class CSSParser
