@@ -23,8 +23,8 @@
 #ifndef _CSS_cssstyleselector_h_
 #define _CSS_cssstyleselector_h_
 
-#include <q3ptrlist.h>
-#include <Q3MemArray>
+#include <Qt3Support/Q3PtrList>
+#include <Qt3Support/Q3MemArray>
 
 #include "rendering/render_style.h"
 #include "dom/dom_string.h"
@@ -33,7 +33,6 @@
 class KHTMLSettings;
 class KHTMLView;
 class KHTMLPart;
-class KHTMLFactory;
 class KUrl;
 
 namespace DOM {
@@ -141,8 +140,9 @@ namespace khtml
 	    QString file;
 	} encodedurl;
 
-        void computeFontSizes(Q3PaintDeviceMetrics* paintDeviceMetrics, int zoomFactor);
-	void computeFontSizesFor(Q3PaintDeviceMetrics* paintDeviceMetrics, int zoomFactor, QVector<int>& fontSizes, bool isFixed);
+        // called from KHTMLView::print()
+	void computeFontSizes(int logicalDpiY, int zoomFactor);
+	void computeFontSizesFor(int logicalDpiY, int zoomFactor, QVector<int>& fontSizes, bool isFixed);
 
 	static void precomputeAttributeDependencies(DOM::DocumentImpl* doc, DOM::CSSSelector* sel);
     protected:
@@ -248,7 +248,7 @@ public:
 	KHTMLView *view;
 	KHTMLPart *part;
 	const KHTMLSettings *settings;
-	Q3PaintDeviceMetrics *paintDeviceMetrics;
+	int logicalDpiY;
         QVector<int>     m_fontSizes;
 	QVector<int>     m_fixedFontSizes;
 
