@@ -27,7 +27,7 @@
 #include "xml/dom_elementimpl.h"
 #include "xml/dom2_eventsimpl.h"
 
-#include <qrect.h>
+#include <QtCore/QRect>
 
 using namespace DOM;
 
@@ -379,6 +379,20 @@ bool Node::dispatchEvent(const Event &evt)
     return !evt.handle()->defaultPrevented();
 }
 
+DOMString Node::textContent() const
+{
+    if (!impl) return DOMString();
+    return impl->textContent();
+}
+
+void Node::setTextContent(const DOMString& content)
+{
+    if (!impl) throw DOMException(DOMException::NOT_FOUND_ERR);
+    int exceptioncode = 0;
+    impl->setTextContent(content, exceptioncode);
+    if (exceptioncode)
+        throw DOMException(exceptioncode);
+}
 
 unsigned int Node::elementId() const
 {
