@@ -23,7 +23,7 @@
 #define KJS_DEBUGGER
 
 #include <kcomponentdata.h>
-#include <kmainwindow.h>
+#include <kxmlguiwindow.h>
 
 #include <kjs/debugger.h>
 #include <kjs/completion.h>
@@ -38,10 +38,8 @@
 
 #include "khtml_pagecache.h"
 #include "khtml_part.h"
-#include "misc/decoder.h"
 #include "dom/dom_misc.h"
 
-class KActionCollection;
 class KAction;
 class WatchesDock;
 class LocalVariablesDock;
@@ -51,7 +49,6 @@ class BreakpointsDock;
 class ConsoleDock;
 class QTabWidget;
 class QFrame;
-class QEventLoop;
 
 namespace KJS
 {
@@ -65,7 +62,7 @@ namespace KJS
 *
 * There is only one debug window per program. This can be obtained by calling #instance
 */
-class DebugWindow : public KMainWindow, public KJS::Debugger, public KComponentData
+class DebugWindow : public KXmlGuiWindow, public KJS::Debugger, public KComponentData
 {
     Q_OBJECT
 public:
