@@ -1,3 +1,25 @@
+/*
+ *  This file is part of the KDE libraries
+ *  Copyright (C) 2006 Matt Broadstone (mbroadst@gmail.com)
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "execstatemodel.h"
+#include "execstatemodel.moc"
+
 #include <kdebug.h>
 
 #include <kjs/context.h>
@@ -6,9 +28,6 @@
 #include <kjs/ExecState.h>
 #include <kjs/PropertyNameArray.h>
 
-#include "execstatemodel.h"
-#include "execstatemodel.moc"
-
 // NODE
 Node::Node(const QString &name, KJS::JSValue *value, KJS::ExecState *exec, int row, Node *parent)
 {
@@ -85,14 +104,14 @@ ExecStateModel::ExecStateModel(KJS::ExecState *exec, QObject *parent)
 {
     if (!m_exec)
     {
-        kDebug() << "exec is null!" << endl;
+        kDebug() << "exec is null!";
         return;
     }
 
     KJS::Context* context = m_exec->context();
     if (!context)
     {
-        kDebug() << "nothing running!" << endl;
+        kDebug() << "nothing running!";
         return;
     }
 
