@@ -1,3 +1,25 @@
+/*
+ *  This file is part of the KDE libraries
+ *  Copyright (C) 2006 Matt Broadstone (mbroadst@gmail.com)
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "objectmodel.h"
+#include "objectmodel.moc"
+
 #include <kjs/context.h>
 #include <kjs/object.h>
 #include <kjs/interpreter.h>
@@ -5,9 +27,6 @@
 
 #include <kdebug.h>
 
-#include "objectmodel.h"
-#include "objectmodel.moc"
-
 //////////// Item
 ObjectNode::ObjectNode(ObjectNode *parent)
 {
@@ -175,7 +194,7 @@ void ObjectModel::update(KJS::ExecState *exec)
     KJS::Context* context = exec->context();
     if (!context)
     {
-        kDebug() << "nothing running!" << endl;
+        kDebug() << "nothing running!";
         return;
     }
 
@@ -250,7 +269,7 @@ void ObjectModel::setupModelData(KJS::ExecState *exec, KJS::JSObject *scope, Obj
             data << "[object data]";
             // then scroll through the object and add children
 /*
-            kDebug() << "Object!" << endl << endl << endl << endl << endl << endl;
+            kDebug() << "Object!" << endl << endl << endl << endl << endl;
             KJS::JSObject *tmpObject = value->toObject(exec);
             if(tmpObject->implementsConstruct())
             {
