@@ -22,14 +22,14 @@
 #ifndef _KJS_BINDING_H_
 #define _KJS_BINDING_H_
 
-#include <kdelibs_export.h>
+#include <khtml_export.h>
 #include <kjs/interpreter.h>
-#include <kxmlcore/HashMap.h>
+#include <wtf/HashMap.h>
 
 #include <dom/dom_node.h>
-#include <qvariant.h>
-#include <qhash.h>
-#include <qstring.h>
+#include <QtCore/QVariant>
+#include <QtCore/QHash>
+#include <QtCore/QString>
 #include <kurl.h>
 #include <kjs/lookup.h>
 #include <kjs/function.h>
@@ -118,7 +118,7 @@ namespace KJS {
      * "Smart" window.open policy
      */
     bool isWindowOpenAllowed() const;
-    
+
     /**
      * CPU guard API. This should be used instead of Interpreter
      * methods as it manages the timeouts, including VG support
@@ -126,7 +126,7 @@ namespace KJS {
     virtual bool shouldInterruptScript() const;
     void startCPUGuard();
     void stopCPUGuard();
-    
+
     static void turnOffCPUGuard() {
         s_disableCPUGuard = true;
     }
@@ -147,7 +147,7 @@ namespace KJS {
   {
     if (entry->attr & Function)
       slot.setStaticEntry(thisObj, entry, staticFunctionGetter<FuncImp>);
-    else 
+    else
       slot.setStaticEntry(thisObj, entry, staticValueGetter<ThisImp>);
   }
 
@@ -167,7 +167,7 @@ namespace KJS {
 
     if (entry->attr & Function)
       slot.setStaticEntry(thisObj, entry, staticFunctionGetter<FuncImp>);
-    else 
+    else
       slot.setStaticEntry(thisObj, entry, staticValueGetter<ThisImp>);
 
     return true;
@@ -281,6 +281,11 @@ namespace KJS {
    */
   ValueImp* getStringOrNull(DOM::DOMString s);
 
+  /**
+   * Null string if the value is null
+   */
+  DOM::DOMString valueToStringWithNullCheck(ExecState* exec, JSValue* v);
+
   /**
    * Convert a KJS value into a QVariant
    */
@@ -327,7 +332,7 @@ namespace KJS {
     const ClassInfo Class::info = { ClassName, 0, 0, 0 }; \
     Class::Class(ExecState* exec): DOMObject(ParentProto) {\
         ObjectImp* proto = ProtoClass::self(exec); \
-        putDirect(prototypePropertyName, proto, DontDelete|ReadOnly); \
+        putDirect(exec->propertyNames().prototype, proto, DontDelete|ReadOnly); \
     }\
     ObjectImp* Class::self(ExecState *exec) { \
         return cacheGlobalObject<Class>(exec, "[[" ClassName ".constructor]]"); \
@@ -342,7 +347,7 @@ namespace KJS {
 #define IMPLEMENT_PSEUDO_CONSTRUCTOR_WITH_PARENT(Class,ClassName,ProtoClass,ParentProtoClass) \
     IMPLEMENT_PSEUDO_CONSTRUCTOR_IMP(Class,ClassName,ProtoClass,ParentProtoClass::self(exec))
 
-// This declares a constant table, which merely maps everything in its 
+// This declares a constant table, which merely maps everything in its
 // table to its token value. Can be used as a prototype
 #define DEFINE_CONSTANT_TABLE(Class) \
    class Class : public DOMObject { \
@@ -356,9 +361,9 @@ namespace KJS {
      static ObjectImp* self(ExecState *exec);\
      static Identifier* s_name; \
      static Identifier* name(); \
-   }; 
+   };
 
-// Emits an implementation of a constant table 
+// Emits an implementation of a constant table
 #define IMPLEMENT_CONSTANT_TABLE(Class,ClassName) \
      bool Class::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot) \
      { \
