@@ -65,7 +65,7 @@ using DOM::StyleSheetImpl;
 using DOM::StyleSheetListImpl;
 
 #include <kdebug.h>
-#include <QList>
+#include <QtCore/QList>
 
 namespace KJS {
 
@@ -170,7 +170,7 @@ ValueImp *DOMCSSStyleDeclaration::indexGetter(ExecState* , unsigned index)
   return String(m_impl->item(index));
 }
 
-ValueImp *DOMCSSStyleDeclaration::cssPropertyGetter(ExecState *exec, JSObject*, const Identifier& propertyName, const PropertySlot& slot)
+ValueImp *DOMCSSStyleDeclaration::cssPropertyGetter(ExecState*, JSObject*, const Identifier& propertyName, const PropertySlot& slot)
 {
   DOMCSSStyleDeclaration *thisObj = static_cast<DOMCSSStyleDeclaration *>(slot.slotBase());
 
@@ -201,7 +201,7 @@ ValueImp *DOMCSSStyleDeclaration::cssPropertyGetter(ExecState *exec, JSObject*,
 bool DOMCSSStyleDeclaration::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "DOMCSSStyleDeclaration::getOwnPropertySlot " << propertyName.qstring() << endl;
+  kDebug(6070) << "DOMCSSStyleDeclaration::getOwnPropertySlot " << propertyName.qstring();
 #endif
 
   if (getStaticOwnValueSlot(&DOMCSSStyleDeclarationTable, this, propertyName, slot))
@@ -223,7 +223,7 @@ bool DOMCSSStyleDeclaration::getOwnPropertySlot(ExecState *exec, const Identifie
 void DOMCSSStyleDeclaration::put(ExecState *exec, const Identifier &propertyName, ValueImp *value, int attr )
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "DOMCSSStyleDeclaration::put " << propertyName.qstring() << endl;
+  kDebug(6070) << "DOMCSSStyleDeclaration::put " << propertyName.qstring();
 #endif
   DOMExceptionTranslator exception(exec);
   CSSStyleDeclarationImpl &styleDecl = *m_impl;
@@ -239,7 +239,7 @@ void DOMCSSStyleDeclaration::put(ExecState *exec, const Identifier &propertyName
     if (pxSuffix)
       propvalue += "px";
 #ifdef KJS_VERBOSE
-    kDebug(6070) << "DOMCSSStyleDeclaration: prop=" << prop << " propvalue=" << propvalue << endl;
+    kDebug(6070) << "DOMCSSStyleDeclaration: prop=" << prop << " propvalue=" << propvalue;
 #endif
     // Look whether the property is known.d In that case add it as a CSS property.
     if (int pId = cssPropertyId(prop)) {
@@ -399,7 +399,7 @@ DOMStyleSheetList::~DOMStyleSheetList()
   ScriptInterpreter::forgetDOMObject(m_impl.get());
 }
 
-ValueImp *DOMStyleSheetList::getValueProperty(ExecState *exec, int token) const
+ValueImp *DOMStyleSheetList::getValueProperty(ExecState*, int token) const
 {
     switch(token) {
     case Length:
@@ -426,7 +426,7 @@ ValueImp *DOMStyleSheetList::nameGetter(ExecState *exec, JSObject*, const Identi
 bool DOMStyleSheetList::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "DOMStyleSheetList::getOwnPropertySlot " << propertyName.qstring() << endl;
+  kDebug(6070) << "DOMStyleSheetList::getOwnPropertySlot " << propertyName.qstring();
 #endif
   if (getStaticOwnPropertySlot<DOMStyleSheetListFunc, DOMStyleSheetList>(&DOMStyleSheetTable, this, propertyName, slot))
     return true;
@@ -515,7 +515,7 @@ DOMMediaList::~DOMMediaList()
   ScriptInterpreter::forgetDOMObject(m_impl.get());
 }
 
-ValueImp* DOMMediaList::getValueProperty(ExecState *exec, int token) const
+ValueImp* DOMMediaList::getValueProperty(ExecState*, int token) const
 {
   const MediaListImpl& mediaList = *m_impl;
   switch (token)
@@ -530,7 +530,7 @@ ValueImp* DOMMediaList::getValueProperty(ExecState *exec, int token) const
   }
 }
 
-ValueImp *DOMMediaList::indexGetter(ExecState* exec, unsigned index)
+ValueImp *DOMMediaList::indexGetter(ExecState*, unsigned index)
 {
   return String(m_impl->item(index));
 }
@@ -688,7 +688,7 @@ DOMCSSRuleList::~DOMCSSRuleList()
   ScriptInterpreter::forgetDOMObject(m_impl.get());
 }
 
-ValueImp *DOMCSSRuleList::getValueProperty(ExecState *exec, int token) const
+ValueImp *DOMCSSRuleList::getValueProperty(ExecState*, int token) const
 {
   switch (token) {
   case Length:
@@ -814,7 +814,7 @@ const ClassInfo* DOMCSSRule::classInfo() const
 bool DOMCSSRule::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "DOMCSSRule::tryGet " << propertyName.qstring() << endl;
+  kDebug(6070) << "DOMCSSRule::tryGet " << propertyName.qstring();
 #endif
   //First do the rule-type-specific stuff
   const HashTable* table = classInfo()->propHashTable; // get the right hashtable
@@ -916,7 +916,7 @@ void DOMCSSRule::putValueProperty(ExecState *exec, int token, ValueImp *value, i
     return;
 
   default:
-    kDebug(6070) << "DOMCSSRule::putValueProperty unhandled token " << token << endl;
+    kDebug(6070) << "DOMCSSRule::putValueProperty unhandled token " << token;
   }
 }
 
@@ -1014,7 +1014,7 @@ DOMCSSValue::~DOMCSSValue()
   ScriptInterpreter::forgetDOMObject(m_impl.get());
 }
 
-ValueImp *DOMCSSValue::getValueProperty(ExecState *exec, int token) const
+ValueImp *DOMCSSValue::getValueProperty(ExecState*, int token) const
 {
   CSSValueImpl &cssValue = *m_impl;
   switch (token) {
@@ -1133,7 +1133,7 @@ DOMCSSPrimitiveValue::DOMCSSPrimitiveValue(ExecState *exec, DOM::CSSPrimitiveVal
   setPrototype(DOMCSSPrimitiveValueProto::self(exec));
 }
 
-ValueImp *DOMCSSPrimitiveValue::getValueProperty(ExecState *exec, int token)
+ValueImp *DOMCSSPrimitiveValue::getValueProperty(ExecState*, int token)
 {
   assert(token == PrimitiveType);
   return Number(static_cast<CSSPrimitiveValueImpl *>(impl())->primitiveType());
