@@ -28,7 +28,7 @@
 #include <qlayout.h>
 #include <qpushbutton.h>
 #include <q3textedit.h>
-#include <q3listbox.h>
+#include <qlistwidget.h>
 #include <q3multilineedit.h>
 #include <qapplication.h>
 #include <ktoolbar.h>
@@ -65,7 +65,7 @@
 #include "khtml_pagecache.h"
 #include "khtml_settings.h"
 #include "khtml_factory.h"
-#include "misc/decoder.h"
+#include <kencodingdetector.h>
 #include <kjs/ustring.h>
 #include <kjs/object.h>
 #include <kjs/function.h>
@@ -84,7 +84,7 @@ SourceDisplay::SourceDisplay(KJSDebugWin *debugWin, QWidget *parent, const char
 {
   verticalScrollBar()->setSingleStep(QFontMetrics(m_font).height());
   viewport()->setAttribute(Qt::WA_NoSystemBackground);
-  m_breakpointIcon = KIconLoader::global()->loadIcon("stop",K3Icon::Small);
+  m_breakpointIcon = KIconLoader::global()->loadIcon("process-stop",K3Icon::Small);
 }
 
 SourceDisplay::~SourceDisplay()
@@ -255,7 +255,7 @@ QString SourceFile::getCode()
   if (interpreter) {
     KHTMLPart *part = qobject_cast<KHTMLPart*>(static_cast<ScriptInterpreter*>(interpreter)->part());
     if (part && url == part->url().url() && KHTMLPageCache::self()->isValid(part->cacheId())) {
-      Decoder *decoder = part->createDecoder();
+      KEncodingDetector *decoder = part->createDecoder();
       QByteArray data;
       QDataStream stream(&data,QIODevice::WriteOnly);
       KHTMLPageCache::self()->saveData(part->cacheId(),&stream);
@@ -263,7 +263,9 @@ QString SourceFile::getCode()
       if (data.size() == 0)
         str = "";
       else
-        str = decoder->decode(data.data(),data.size()) + decoder->flush();
+      {
+        str = decoder->decode(data);
+      }
       delete decoder;
       return str;
     }
@@ -305,7 +307,7 @@ KJSErrorDialog::KJSErrorDialog(QWidget *parent, const QString& errorMessage, boo
   setMainWidget(page);
 
   QLabel *iconLabel = new QLabel("",page);
-  iconLabel->setPixmap(KIconLoader::global()->loadIcon("messagebox_critical",
+  iconLabel->setPixmap(KIconLoader::global()->loadIcon("dialog-error",
                                                     K3Icon::NoGroup,K3Icon::SizeMedium,
                                                     K3Icon::DefaultState,0,true));
 
@@ -375,7 +377,7 @@ KJSDebugWin::KJSDebugWin(QWidget *parent, const char *name)
   m_execsAlloc = 0;
   m_steppingDepth = 0;
 
-  m_stopIcon = KIconLoader::global()->loadIcon("stop",K3Icon::Small);
+  m_stopIcon = KIconLoader::global()->loadIcon("process-stop",K3Icon::Small);
   m_emptyIcon = QPixmap(m_stopIcon.width(),m_stopIcon.height());
   QBitmap emptyMask(m_stopIcon.width(),m_stopIcon.height());
   emptyMask.clear();
@@ -398,9 +400,9 @@ KJSDebugWin::KJSDebugWin(QWidget *parent, const char *name)
 
   QLabel *contextLabel = new QLabel(i18n("Call stack"),contextContainer);
   QWidget *contextListContainer = new QWidget(contextContainer);
-  m_contextList = new Q3ListBox(contextListContainer);
+  m_contextList = new QListWidget(contextListContainer);
   m_contextList->setMinimumSize(100,200);
-  connect(m_contextList,SIGNAL(highlighted(int)),this,SLOT(slotShowFrame(int)));
+  connect(m_contextList,SIGNAL(currentRowChanged(int)),this,SLOT(slotShowFrame(int)));
 
   QHBoxLayout *clistLayout = new QHBoxLayout(contextListContainer);
   clistLayout->addWidget(m_contextList);
@@ -612,8 +614,8 @@ void KJSDebugWin::slotSourceSelected(int sourceSelIndex)
 
   // If the currently selected context is in the current source file, then hilight
   // the line it's on.
-  if (m_contextList->currentItem() >= 0) {
-    Context ctx = m_execs[m_contextList->currentItem()]->context();
+  if (m_contextList->currentRow() >= 0) {
+    Context ctx = m_execs[m_contextList->currentRow()]->context();
     abort();
     //if (m_sourceFragments[ctx.sourceId()]->sourceFile == m_sourceSelFiles.at(sourceSelIndex))
     //  setSourceLine(ctx.sourceId(),ctx.curStmtFirstLine());
@@ -669,7 +671,7 @@ void KJSDebugWin::slotEval()
     msg = retval->toString(interp->globalExec()).qstring();
   }
 
-  m_evalEdit->insert(msg+"\n");
+  m_evalEdit->insert(msg+'\n');
   updateContextList();
 }
 
@@ -1076,20 +1078,20 @@ void KJSDebugWin::leaveSession()
 
 void KJSDebugWin::updateContextList()
 {
-  disconnect(m_contextList,SIGNAL(highlighted(int)),this,SLOT(slotShowFrame(int)));
+  disconnect(m_contextList,SIGNAL(currentRowChanged(int)),this,SLOT(slotShowFrame(int)));
 
   m_contextList->clear();
   for (int i = 0; i < m_execsCount; i++)
-    m_contextList->insertItem(contextStr(m_execs[i]->context()));
+    m_contextList->addItem(contextStr(m_execs[i]->context()));
 
   if (m_execsCount > 0) {
-    m_contextList->setSelected(m_execsCount-1, true);
+    m_contextList->setCurrentRow(m_execsCount-1);
     Context ctx = m_execs[m_execsCount-1]->context();
     abort();
     //setSourceLine(ctx.sourceId(),ctx.curStmtFirstLine());
   }
 
-  connect(m_contextList,SIGNAL(highlighted(int)),this,SLOT(slotShowFrame(int)));
+  connect(m_contextList,SIGNAL(currentRowChanged(int)),this,SLOT(slotShowFrame(int)));
 }
 
 QString KJSDebugWin::contextStr(const Context &ctx)
