@@ -19,22 +19,24 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#include "kjs_dom.h"
+#include "kjs_dom.lut.h"
+
 #include <khtmlview.h>
-#include "xml/dom2_eventsimpl.h"
-#include "rendering/render_canvas.h"
-#include "rendering/render_layer.h"
-#include "xml/dom_nodeimpl.h"
-#include "xml/dom_docimpl.h"
-#include "misc/htmltags.h" // ID_*
-#include "misc/htmlattrs.h" // ATTR_*
-#include "html/html_baseimpl.h"
-#include "html/html_documentimpl.h"
-#include "html/html_miscimpl.h"
+#include <xml/dom2_eventsimpl.h>
+#include <rendering/render_canvas.h>
+#include <rendering/render_layer.h>
+#include <xml/dom_nodeimpl.h>
+#include <xml/dom_docimpl.h>
+#include <misc/htmltags.h> // ID_*
+#include <misc/htmlattrs.h> // ATTR_*
+#include <html/html_baseimpl.h>
+#include <html/html_documentimpl.h>
+#include <html/html_miscimpl.h>
 #include <kdebug.h>
 #include <khtml_part.h>
-#include <QList>
+#include <QtCore/QList>
 
-#include "kjs_dom.h"
 #include "kjs_html.h"
 #include "kjs_css.h"
 #include "kjs_range.h"
@@ -43,9 +45,9 @@
 #include "kjs_views.h"
 #include "kjs_window.h"
 #include <kjs/PropertyNameArray.h>
-#include "dom/dom_exception.h"
-#include "kjs_dom.lut.h"
-#include "khtmlpart_p.h"
+#include <dom/dom_exception.h>
+#include <dom/html_document.h>
+#include <khtmlpart_p.h>
 
 using namespace KJS;
 
@@ -134,6 +136,8 @@ bool DOMNode::toBoolean(ExecState *) const
   prefix	DOMNode::Prefix		DontDelete
   localName	DOMNode::LocalName	DontDelete|ReadOnly
   ownerDocument	DOMNode::OwnerDocument	DontDelete|ReadOnly
+# DOM3
+  textContent   DOMNode::TextContent    DontDelete
 # Event handlers
 # IE also has: onactivate, onbefore*, oncontextmenu, oncontrolselect, oncut,
 # ondeactivate, ondrag*, ondrop, onfocusin, onfocusout, onhelp, onmousewheel,
@@ -181,19 +185,19 @@ bool DOMNode::toBoolean(ExecState *) const
 bool DOMNode::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "DOMNode::getOwnPropertySlot " << propertyName.qstring() << endl;
+  kDebug(6070) << "DOMNode::getOwnPropertySlot " << propertyName.qstring();
 #endif
   return getStaticValueSlot<DOMNode, DOMObject>(exec, &DOMNodeTable, this, propertyName, slot);
 }
 
 static khtml::RenderObject* handleBodyRootQuirk(const DOM::NodeImpl* node, khtml::RenderObject* rend, int token)
 {
-  //This emulates the quirks of various height/width properties on the viewport and root. Note that it 
+  //This emulates the quirks of various height/width properties on the viewport and root. Note that it
   //is (mostly) IE-compatible in quirks, and mozilla-compatible in strict.
   if (!rend) return 0;
 
   bool quirksMode = rend->style() && rend->style()->htmlHacks();
-  
+
   //There are a couple quirks here. One is that in quirks mode body is always forwarded to root...
   //This is relevant for even the scrollTop/scrollLeft type properties.
   if (quirksMode && node->id() == ID_BODY) {
@@ -202,7 +206,7 @@ static khtml::RenderObject* handleBodyRootQuirk(const DOM::NodeImpl* node, khtml
   }
 
   //Also, some properties of the root are really done in terms of the viewport.
-  //These are  {offset/client}{Height/Width}. The offset versions do it only in 
+  //These are  {offset/client}{Height/Width}. The offset versions do it only in
   //quirks mode, the client always.
   if (!rend->isRoot()) return rend; //Don't care about non-root things here!
   bool needViewport = false;
@@ -217,7 +221,7 @@ static khtml::RenderObject* handleBodyRootQuirk(const DOM::NodeImpl* node, khtml
       needViewport = true;
       break;
   }
-  
+
   if (needViewport) {
     //Scan up to find the new target
     while (rend->parent())
@@ -266,6 +270,8 @@ ValueImp* DOMNode::getValueProperty(ExecState *exec, int token) const
     return ::getStringOrNull(node.localName());  // Moz returns null if not set (dom/namespaces.html)
   case OwnerDocument:
     return getDOMNode(exec,node.ownerDocument());
+  case TextContent:
+    return ::getStringOrNull(node.textContent());
   case OnAbort:
     return getListener(DOM::EventImpl::ABORT_EVENT);
   case OnBlur:
@@ -379,7 +385,7 @@ ValueImp* DOMNode::getValueProperty(ExecState *exec, int token) const
       }
       return Number( 0 );
     default:
-      kDebug(6070) << "WARNING: Unhandled token in DOMNode::getValueProperty : " << token << endl;
+      kDebug(6070) << "WARNING: Unhandled token in DOMNode::getValueProperty : " << token;
       break;
     }
   }
@@ -390,7 +396,7 @@ ValueImp* DOMNode::getValueProperty(ExecState *exec, int token) const
 void DOMNode::put(ExecState *exec, const Identifier& propertyName, ValueImp* value, int attr)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "DOMNode::tryPut " << propertyName.qstring() << endl;
+  kDebug(6070) << "DOMNode::tryPut " << propertyName.qstring();
 #endif
   lookupPut<DOMNode,DOMObject>(exec, propertyName, value, attr,
                                         &DOMNodeTable, this );
@@ -400,7 +406,7 @@ void DOMNode::putValueProperty(ExecState *exec, int token, ValueImp* value, int
 {
   DOMExceptionTranslator exception(exec);
   NodeImpl& node = *impl();
-  
+
   switch (token) {
   case NodeValue:
     node.setNodeValue(value->toString(exec).domString(), exception);
@@ -408,6 +414,9 @@ void DOMNode::putValueProperty(ExecState *exec, int token, ValueImp* value, int
   case Prefix:
     node.setPrefix(value->toString(exec).domString(), exception);
     break;
+  case TextContent:
+    node.setTextContent(valueToStringWithNullCheck(exec, value), exception);
+    break;
   case OnAbort:
     setListener(exec,DOM::EventImpl::ABORT_EVENT,value);
     break;
@@ -478,7 +487,7 @@ void DOMNode::putValueProperty(ExecState *exec, int token, ValueImp* value, int
     setListener(exec,DOM::EventImpl::UNLOAD_EVENT,value);
     break;
   default:
-    // Make sure our layout is up to date 
+    // Make sure our layout is up to date
     DOM::DocumentImpl* docimpl = node.getDocument();
     if (docimpl)
       docimpl->updateLayout();
@@ -512,7 +521,7 @@ void DOMNode::putValueProperty(ExecState *exec, int token, ValueImp* value, int
         }
         break;
       default:
-      kDebug(6070) << "WARNING: DOMNode::putValueProperty unhandled token " << token << endl;
+      kDebug(6070) << "WARNING: DOMNode::putValueProperty unhandled token " << token;
     }
   }
 }
@@ -531,14 +540,14 @@ UString DOMNode::toString(ExecState *) const
     return "null";
   UString s;
 
-  
+
   if ( m_impl->isElementNode() ) {
     DOM::ElementImpl* e = static_cast<DOM::ElementImpl*>(impl());
     s = DOMString(e->nodeName().string());
   } else
     s = className(); // fallback
 
-  return "[object " + s + "]";
+  return "[object " + s + "]";	//krazy:exclude=doublequote_chars DOM demands chars
 }
 
 void DOMNode::setListener(ExecState *exec, int eventId, ValueImp* func) const
@@ -718,7 +727,7 @@ DOM::NodeImpl* DOMNodeList::getByName(const Identifier& name)
 
 bool DOMNodeList::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
-  if (propertyName == lengthPropertyName) {
+  if (propertyName == exec->propertyNames().length) {
     slot.setCustom(this, lengthGetter);
     return true;
   }
@@ -750,7 +759,7 @@ void DOMNodeList::getPropertyNames(ExecState* exec, PropertyNameArray& propertyN
   for (unsigned i = 0; i < m_impl->length(); ++i)
       propertyNames.add(Identifier::from(i));
 
-  propertyNames.add(lengthPropertyName);
+  propertyNames.add(exec->propertyNames().length);
 
   JSObject::getPropertyNames(exec, propertyNames);
 }
@@ -809,7 +818,7 @@ const ClassInfo DOMAttr::info = { "Attr", &DOMNode::info, &DOMAttrTable, 0 };
 bool DOMAttr::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "DOMAttr::tryGet " << propertyName.qstring() << endl;
+  kDebug(6070) << "DOMAttr::tryGet " << propertyName.qstring();
 #endif
   return getStaticValueSlot<DOMAttr, DOMNode>(exec, &DOMAttrTable, this, propertyName, slot);
 }
@@ -833,7 +842,7 @@ ValueImp* DOMAttr::getValueProperty(ExecState *exec, int token) const
 void DOMAttr::put(ExecState *exec, const Identifier &propertyName, ValueImp* value, int attr)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "DOMAttr::tryPut " << propertyName.qstring() << endl;
+  kDebug(6070) << "DOMAttr::tryPut " << propertyName.qstring();
 #endif
   lookupPut<DOMAttr,DOMNode>(exec, propertyName, value, attr,
                                       &DOMAttrTable, this );
@@ -847,7 +856,7 @@ void DOMAttr::putValueProperty(ExecState *exec, int token, ValueImp* value, int
     static_cast<AttrImpl *>(impl())->setValue(value->toString(exec).domString(), exception);
     return;
   default:
-    kWarning() << "DOMAttr::putValueProperty unhandled token " << token << endl;
+    kWarning() << "DOMAttr::putValueProperty unhandled token " << token;
   }
 }
 
@@ -922,7 +931,7 @@ DOMDocument::DOMDocument(ObjectImp *proto, DOM::DocumentImpl* d)
 bool DOMDocument::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "DOMDocument::tryGet " << propertyName.qstring() << endl;
+  kDebug(6070) << "DOMDocument::tryGet " << propertyName.qstring();
 #endif
   return getStaticValueSlot<DOMDocument, DOMNode>(
     exec, &DOMDocumentTable, this, propertyName, slot);
@@ -946,7 +955,7 @@ ValueImp* DOMDocument::getValueProperty(ExecState *exec, int token) const
       return Undefined();
   }
   case StyleSheets:
-    //kDebug() << "DOMDocument::StyleSheets, returning " << doc.styleSheets().length() << " stylesheets" << endl;
+    //kDebug() << "DOMDocument::StyleSheets, returning " << doc.styleSheets().length() << " stylesheets";
     return getDOMStyleSheetList(exec, doc.styleSheets(), &doc);
   case DOMDocument::DefaultView: // DOM2
     {
@@ -977,7 +986,7 @@ ValueImp* DOMDocument::getValueProperty(ExecState *exec, int token) const
   case Async:
     return Boolean(doc.async());
   default:
-    kDebug(6070) << "WARNING: DOMDocument::getValueProperty unhandled token " << token << endl;
+    kDebug(6070) << "WARNING: DOMDocument::getValueProperty unhandled token " << token;
     return Null();
   }
 }
@@ -985,7 +994,7 @@ ValueImp* DOMDocument::getValueProperty(ExecState *exec, int token) const
 void DOMDocument::put(ExecState *exec, const Identifier& propertyName, ValueImp* value, int attr)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "DOMDocument::tryPut " << propertyName.qstring() << endl;
+  kDebug(6070) << "DOMDocument::tryPut " << propertyName.qstring();
 #endif
   lookupPut<DOMDocument,DOMNode>(exec, propertyName, value, attr, &DOMDocumentTable, this );
 }
@@ -1011,7 +1020,7 @@ ValueImp* DOMDocumentProtoFunc::callAsFunction(ExecState *exec, ObjectImp *thisO
   DOMExceptionTranslator exception(exec);
   DOM::NodeImpl&     node = *static_cast<DOMNode *>( thisObj )->impl();
   DOM::DocumentImpl& doc  = static_cast<DOM::DocumentImpl&>(node);
-  
+
   KJS::UString str = args[0]->toString(exec);
   DOM::DOMString s = str.domString();
 
@@ -1046,7 +1055,7 @@ ValueImp* DOMDocumentProtoFunc::callAsFunction(ExecState *exec, ObjectImp *thisO
                                                           args[1]->toString(exec).domString()));
   case DOMDocument::GetElementById:
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "DOMDocument::GetElementById looking for " << args[0]->toString(exec).qstring() << endl;
+  kDebug(6070) << "DOMDocument::GetElementById looking for " << args[0]->toString(exec).qstring();
 #endif
     return getDOMNode(exec,doc.getElementById(args[0]->toString(exec).domString()));
   case DOMDocument::CreateRange:
@@ -1095,11 +1104,11 @@ ValueImp* DOMDocumentProtoFunc::callAsFunction(ExecState *exec, ObjectImp *thisO
       QString dstUrl = khtmlpart->htmlDocument().completeURL(s).string();
       KParts::ReadOnlyPart *part = static_cast<KJS::ScriptInterpreter*>(exec->dynamicInterpreter())->part();
       if (part->url().host() == KUrl(dstUrl).host()) {
-	kDebug(6070) << "JavaScript: access granted for document.load() of " << dstUrl << endl;
+	kDebug(6070) << "JavaScript: access granted for document.load() of " << dstUrl;
 	doc.load(dstUrl);
       }
       else {
-	kDebug(6070) << "JavaScript: access denied for document.load() of " << dstUrl << endl;
+	kDebug(6070) << "JavaScript: access denied for document.load() of " << dstUrl;
       }
     }
     break;
@@ -1148,7 +1157,7 @@ const ClassInfo DOMElement::info = { "Element", &DOMNode::info, &DOMElementTable
 @end
 */
 DOMElement::DOMElement(ExecState *exec, DOM::ElementImpl* e)
-  : DOMNode(exec, e) 
+  : DOMNode(exec, e)
 {
     setPrototype(DOMElementProto::self(exec));
 }
@@ -1166,7 +1175,7 @@ ValueImp* DOMElement::getValueProperty(ExecState *exec, int token) const
     case Style:
       return getDOMCSSStyleDeclaration(exec,element.styleRules());
     default:
-      kDebug(6070) << "WARNING: Unhandled token in DOMElement::getValueProperty : " << token << endl;
+      kDebug(6070) << "WARNING: Unhandled token in DOMElement::getValueProperty : " << token;
       return Undefined();
   }
 }
@@ -1174,13 +1183,13 @@ ValueImp* DOMElement::getValueProperty(ExecState *exec, int token) const
 bool DOMElement::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "DOMElement::getOwnPropertySlot " << propertyName.qstring() << endl;
+  kDebug(6070) << "DOMElement::getOwnPropertySlot " << propertyName.qstring();
 #endif
 
   //DOM::Element element = static_cast<DOM::Element>(node);
   if (getStaticOwnValueSlot(&DOMElementTable, this, propertyName, slot))
     return true;
-  
+
   // We have to check in DOMNode before giving access to attributes, otherwise
   // onload="..." would make onload return the string (attribute value) instead of
   // the listener object (function).
@@ -1220,7 +1229,7 @@ ValueImp* DOMElementProtoFunc::callAsFunction(ExecState *exec, ObjectImp *thisOb
 
   switch(id) {
     case DOMElement::GetAttribute:
-      /** In theory, we should not return null here, as per DOM. In practice, that 
+      /** In theory, we should not return null here, as per DOM. In practice, that
        breaks websites */
       return getStringOrNull(element.getAttribute(args[0]->toString(exec).domString()));
     case DOMElement::SetAttribute:
@@ -1251,7 +1260,7 @@ ValueImp* DOMElementProtoFunc::callAsFunction(ExecState *exec, ObjectImp *thisOb
     case DOMElement::RemoveAttributeNS: // DOM2
       element.removeAttributeNS(args[0]->toString(exec).domString(),args[1]->toString(exec).domString(), exception);
       return Undefined();
-   case DOMElement::GetAttributeNodeNS: // DOM2 
+   case DOMElement::GetAttributeNodeNS: // DOM2
       return getDOMNode(exec,element.getAttributeNodeNS(args[0]->toString(exec).domString(),args[1]->toString(exec).domString(),exception));
     case DOMElement::SetAttributeNodeNS: {
       DOM::Attr toRet = element.setAttributeNodeNS(KJS::toAttr(args[0]), exception);
@@ -1331,7 +1340,7 @@ ValueImp* DOMDOMImplementationProtoFunc::callAsFunction(ExecState *exec, ObjectI
         setDOMException(exec, DOMException::NOT_FOUND_ERR);
         return Null();
       }
-        
+
       DOM::DocumentTypeImpl* docType = static_cast<DOM::DocumentTypeImpl*>(supposedDocType);
 
       DOM::DocumentImpl* doc = implementation.createDocument(args[0]->toString(exec).domString(),args[1]->toString(exec).domString(),docType,exception);
@@ -1376,7 +1385,7 @@ DOMDocumentType::DOMDocumentType(ExecState *exec, DOM::DocumentTypeImpl* dt)
 bool DOMDocumentType::getOwnPropertySlot(ExecState *exec, const Identifier &propertyName, KJS::PropertySlot& slot)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "DOMDocumentType::getOwnPropertySlot " << propertyName.qstring() << endl;
+  kDebug(6070) << "DOMDocumentType::getOwnPropertySlot " << propertyName.qstring();
 #endif
   return getStaticValueSlot<DOMDocumentType, DOMNode>(exec, &DOMDocumentTypeTable, this, propertyName, slot);
 }
@@ -1398,7 +1407,7 @@ ValueImp* DOMDocumentType::getValueProperty(ExecState *exec, int token) const
   case InternalSubset: // DOM2
     return ::getStringOrNull(type.internalSubset()); // can be null, see domts/level2/core/internalSubset01.html
   default:
-    kDebug(6070) << "WARNING: DOMDocumentType::getValueProperty unhandled token " << token << endl;
+    kDebug(6070) << "WARNING: DOMDocumentType::getValueProperty unhandled token " << token;
     return Null();
   }
 }
@@ -1446,7 +1455,7 @@ ValueImp *DOMNamedNodeMap::lengthGetter(ExecState *, JSObject*, const Identifier
 }
 
 bool DOMNamedNodeMap::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot) {
-  if (propertyName == lengthPropertyName) {
+  if (propertyName == exec->propertyNames().length) {
     slot.setCustom(this, lengthGetter);
     return true;
   }
@@ -1523,7 +1532,7 @@ ValueImp* DOMProcessingInstruction::getValueProperty(ExecState *exec, int token)
   case Sheet:
     return getDOMStyleSheet(exec,pi.sheet());
   default:
-    kDebug(6070) << "WARNING: DOMProcessingInstruction::getValueProperty unhandled token " << token << endl;
+    kDebug(6070) << "WARNING: DOMProcessingInstruction::getValueProperty unhandled token " << token;
     return Null();
   }
 }
@@ -1563,7 +1572,7 @@ ValueImp* DOMNotation::getValueProperty(ExecState *, int token) const
   case SystemId:
     return String(nota.systemId());
   default:
-    kDebug(6070) << "WARNING: DOMNotation::getValueProperty unhandled token " << token << endl;
+    kDebug(6070) << "WARNING: DOMNotation::getValueProperty unhandled token " << token;
     return Null();
   }
 }
@@ -1595,7 +1604,7 @@ ValueImp* DOMEntity::getValueProperty(ExecState *, int token) const
   case NotationName:
     return String(entity.notationName());
   default:
-    kDebug(6070) << "WARNING: DOMEntity::getValueProperty unhandled token " << token << endl;
+    kDebug(6070) << "WARNING: DOMEntity::getValueProperty unhandled token " << token;
     return Null();
   }
 }
@@ -1761,7 +1770,7 @@ ValueImp* DOMExceptionConstructor::getValueProperty(ExecState *, int token) cons
   case INVALID_ACCESS_ERR:
     return Number((unsigned int)DOM::DOMException::INVALID_ACCESS_ERR);
   default:
-    kDebug(6070) << "WARNING: DOMExceptionConstructor::getValueProperty unhandled token " << token << endl;
+    kDebug(6070) << "WARNING: DOMExceptionConstructor::getValueProperty unhandled token " << token;
     return Null();
   }
 #endif
@@ -1805,9 +1814,9 @@ ValueImp *DOMNamedNodesCollection::lengthGetter(ExecState *, JSObject*, const Id
 
 bool DOMNamedNodesCollection::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
-  kDebug(6070) << k_funcinfo << propertyName.ascii() << endl;
+  kDebug(6070) << propertyName.ascii();
 
-  if (propertyName == lengthPropertyName) {
+  if (propertyName == exec->propertyNames().length) {
     slot.setCustom(this, lengthGetter);
     return true;
   }
@@ -1815,7 +1824,7 @@ bool DOMNamedNodesCollection::getOwnPropertySlot(ExecState *exec, const Identifi
   //May be it's an index?
   if (getIndexSlot(this, m_nodes.size(), propertyName, slot))
     return true;
-  
+
   return DOMObject::getOwnPropertySlot(exec,propertyName,slot);
 }
 
@@ -1849,7 +1858,7 @@ DOMCharacterData::DOMCharacterData(ExecState *exec, DOM::CharacterDataImpl* d)
 bool DOMCharacterData::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070)<<"DOMCharacterData::tryGet "<<propertyName.qstring()<<endl;
+  kDebug(6070)<<"DOMCharacterData::tryGet "<<propertyName.qstring();
 #endif
   return getStaticValueSlot<DOMCharacterData, DOMNode>(exec, &DOMCharacterDataTable, this, propertyName, slot);
 }
@@ -1863,7 +1872,7 @@ ValueImp* DOMCharacterData::getValueProperty(ExecState *, int token) const
   case Length:
     return Number(data.length());
  default:
-   kDebug(6070) << "WARNING: Unhandled token in DOMCharacterData::getValueProperty : " << token << endl;
+   kDebug(6070) << "WARNING: Unhandled token in DOMCharacterData::getValueProperty : " << token;
    return Null();
   }
 }
