@@ -65,7 +65,7 @@ namespace KJS {
            OnResize, OnSelect, OnSubmit, OnUnload,
            OffsetLeft, OffsetTop, OffsetWidth, OffsetHeight, OffsetParent,
            ClientWidth, ClientHeight, ScrollLeft, ScrollTop,
-	   ScrollWidth, ScrollHeight, SourceIndex };
+	   ScrollWidth, ScrollHeight, SourceIndex, TextContent };
 
     //### toNode? virtual
     DOM::NodeImpl* impl() const { return m_impl.get(); }
