@@ -19,17 +19,19 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "kjs_window.h"
 #include "kjs_events.h"
 #include "kjs_events.lut.h"
+
+#include "kjs_window.h"
 #include "kjs_views.h"
 #include "kjs_proxy.h"
-#include "xml/dom_nodeimpl.h"
-#include "xml/dom_docimpl.h"
-#include "xml/dom2_eventsimpl.h"
-#include "rendering/render_object.h"
-#include "rendering/render_canvas.h"
-#include "khtml_part.h"
+#include <xml/dom_nodeimpl.h>
+#include <xml/dom_docimpl.h>
+#include <xml/dom2_eventsimpl.h>
+#include <rendering/render_object.h>
+#include <rendering/render_canvas.h>
+#include <khtml_part.h>
+#include <kjs/scriptfunction.h> // private API
 
 #include <kdebug.h>
 
@@ -261,7 +263,7 @@ DOMEvent::~DOMEvent()
 bool DOMEvent::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
 #ifdef KJS_VERBOSE
-  kDebug() << "KJS::DOMEvent::getOwnPropertySlot " << propertyName.qstring() << endl;
+  kDebug() << "KJS::DOMEvent::getOwnPropertySlot " << propertyName.qstring();
 #endif
 
   return getStaticValueSlot<DOMEvent, DOMObject>(exec,&DOMEventTable,this,propertyName,slot);
@@ -291,7 +293,7 @@ ValueImp *DOMEvent::getValueProperty(ExecState *exec, int token) const
   case CancelBubble: // MSIE extension
     return Boolean(event.propagationStopped());
   default:
-    kDebug(6070) << "WARNING: Unhandled token in DOMEvent::getValueProperty : " << token << endl;
+    kDebug(6070) << "WARNING: Unhandled token in DOMEvent::getValueProperty : " << token;
     return 0;
   }
 }
@@ -509,7 +511,7 @@ ValueImp *DOMUIEvent::getValueProperty(ExecState *exec, int token) const
     // NS-compatibility
     return Number(event.which());
   default:
-    kDebug(6070) << "WARNING: Unhandled token in DOMUIEvent::getValueProperty : " << token << endl;
+    kDebug(6070) << "WARNING: Unhandled token in DOMUIEvent::getValueProperty : " << token;
     return Undefined();
   }
 }
@@ -573,7 +575,7 @@ DOMMouseEvent::~DOMMouseEvent()
 bool DOMMouseEvent::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "DOMMouseEvent::getOwnPropertySlot " << propertyName.qstring() << endl;
+  kDebug(6070) << "DOMMouseEvent::getOwnPropertySlot " << propertyName.qstring();
 #endif
 
   return getStaticValueSlot<DOMMouseEvent, DOMUIEvent>(exec,&DOMMouseEventTable,this,propertyName,slot);
@@ -607,7 +609,7 @@ ValueImp *DOMMouseEvent::getValueProperty(ExecState *exec, int token) const
     if ( rend ) {
       int xPos, yPos;
       if ( rend->absolutePosition( xPos, yPos ) ) {
-        //kDebug() << "DOMMouseEvent::getValueProperty rend=" << rend << "  xPos=" << xPos << "  yPos=" << yPos << endl;
+        //kDebug() << "DOMMouseEvent::getValueProperty rend=" << rend << "  xPos=" << xPos << "  yPos=" << yPos;
         x -= xPos;
         y -= yPos;
       }
@@ -653,7 +655,7 @@ ValueImp *DOMMouseEvent::getValueProperty(ExecState *exec, int token) const
   case RelatedTarget:
     return getDOMNode(exec,event.relatedTarget());
   default:
-    kDebug(6070) << "WARNING: Unhandled token in DOMMouseEvent::getValueProperty : " << token << endl;
+    kDebug(6070) << "WARNING: Unhandled token in DOMMouseEvent::getValueProperty : " << token;
     return 0;
   }
 }
@@ -708,7 +710,7 @@ DOMKeyEventBase::~DOMKeyEventBase()
 bool DOMKeyEventBase::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "DOMKeyEventBase::getOwnPropertySlot " << propertyName.qstring() << endl;
+  kDebug(6070) << "DOMKeyEventBase::getOwnPropertySlot " << propertyName.qstring();
 #endif
   return getStaticValueSlot<DOMKeyEventBase, DOMUIEvent>(exec,&DOMKeyEventBaseTable,this,propertyName,slot);
 }
@@ -732,7 +734,7 @@ ValueImp* DOMKeyEventBase::getValueProperty(ExecState *, int token) const
   case MetaKey:
     return Boolean(tevent->metaKey());
   default:
-    kDebug(6070) << "WARNING: Unhandled token in DOMKeyEventBase::getValueProperty : " << token << endl;
+    kDebug(6070) << "WARNING: Unhandled token in DOMKeyEventBase::getValueProperty : " << token;
     return KJS::Undefined();
   }
 }
@@ -751,7 +753,7 @@ const ClassInfo DOMTextEvent::info = { "TextEvent", &DOMKeyEventBase::info, &DOM
 */
 KJS_DEFINE_PROTOTYPE_WITH_PROTOTYPE(DOMTextEventProto,DOMUIEventProto)//Note: no proto in KeyBase
 KJS_IMPLEMENT_PROTOFUNC(DOMTextEventProtoFunc)
-KJS_IMPLEMENT_PROTOTYPE("DOMTextEvent", DOMTextEventProto,DOMTextEventProtoFunc) 
+KJS_IMPLEMENT_PROTOTYPE("DOMTextEvent", DOMTextEventProto,DOMTextEventProtoFunc)
 
 DOMTextEvent::DOMTextEvent(ExecState *exec, DOM::TextEventImpl* ke) :
   DOMKeyEventBase(DOMTextEventProto::self(exec), ke) {}
@@ -763,7 +765,7 @@ DOMTextEvent::~DOMTextEvent()
 bool DOMTextEvent::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "DOMTextEvent::getOwnPropertySlot " << propertyName.qstring() << endl;
+  kDebug(6070) << "DOMTextEvent::getOwnPropertySlot " << propertyName.qstring();
 #endif
   return getStaticValueSlot<DOMTextEvent, DOMKeyEventBase>(exec,&DOMTextEventTable,this,propertyName,slot);
 }
@@ -776,7 +778,7 @@ ValueImp *DOMTextEvent::getValueProperty(ExecState *, int token) const
   case Data:
     return String(tevent.data());
   default:
-    kDebug(6070) << "WARNING: Unhandled token in DOMTextEvent::getValueProperty : " << token << endl;
+    kDebug(6070) << "WARNING: Unhandled token in DOMTextEvent::getValueProperty : " << token;
     return KJS::Undefined();
   }
 }
@@ -824,7 +826,7 @@ DOMKeyboardEvent::~DOMKeyboardEvent()
 bool DOMKeyboardEvent::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "DOMKeyboardEvent::getOwnPropertySlot " << propertyName.qstring() << endl;
+  kDebug(6070) << "DOMKeyboardEvent::getOwnPropertySlot " << propertyName.qstring();
 #endif
   return getStaticValueSlot<DOMKeyboardEvent, DOMKeyEventBase>(exec,&DOMKeyboardEventTable,this,propertyName,slot);
 }
@@ -838,7 +840,7 @@ ValueImp* DOMKeyboardEvent::getValueProperty(ExecState *, int token) const
   case KeyLocation:
     return Number(tevent->keyLocation());
   default:
-    kDebug(6070) << "WARNING: Unhandled token in DOMKeyboardEvent::getValueProperty : " << token << endl;
+    kDebug(6070) << "WARNING: Unhandled token in DOMKeyboardEvent::getValueProperty : " << token;
     return KJS::Undefined();
   }
 }
@@ -881,7 +883,7 @@ KeyboardEventConstructor::KeyboardEventConstructor(ExecState* exec)
 bool KeyboardEventConstructor::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "DOMKeyboardEvent::getOwnPropertySlot " << propertyName.qstring() << endl;
+  kDebug(6070) << "DOMKeyboardEvent::getOwnPropertySlot " << propertyName.qstring();
 #endif
   return getStaticValueSlot<KeyboardEventConstructor, DOMObject>(exec,&KeyboardEventConstructorTable,this,propertyName,slot);
 }
@@ -976,7 +978,7 @@ ValueImp *DOMMutationEvent::getValueProperty(ExecState *exec, int token) const
   case AttrChange:
     return Number((unsigned int)event.attrChange());
   default:
-    kDebug(6070) << "WARNING: Unhandled token in DOMMutationEvent::getValueProperty : " << token << endl;
+    kDebug(6070) << "WARNING: Unhandled token in DOMMutationEvent::getValueProperty : " << token;
     return 0;
   }
 }
