@@ -21,6 +21,9 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#include "kjs_navigator.h"
+#include "kjs_navigator.lut.h"
+
 #include <klocale.h>
 
 #include <kstandarddirs.h>
@@ -28,17 +31,15 @@
 #include <kdebug.h>
 
 #include <kio/kprotocolmanager.h>
-#include <kio/kmimetype.h>
+#include <kmimetype.h>
 #include <kservice.h>
 #include <kservicetypetrader.h>
-#include "kjs_navigator.h"
-#include "kjs/lookup.h"
-#include "kjs_binding.h"
-#include "khtml_part.h"
+#include <kjs/lookup.h>
+#include <kjs_binding.h>
+#include <khtml_part.h>
 #include <sys/utsname.h>
-#include "kjs_navigator.lut.h"
 
-#include <q3ptrlist.h>
+#include <Qt3Support/Q3PtrList>
 
 using namespace KJS;
 
@@ -80,14 +81,14 @@ namespace KJS {
     public:
         Plugins(ExecState *exec, bool pluginsEnabled)
           : PluginBase(exec, pluginsEnabled),
-            m_pluginsEnabled(pluginsEnabled) {};
+            m_pluginsEnabled(pluginsEnabled) {}
 
         virtual bool getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot);
         ValueImp *getValueProperty(ExecState *exec, int token) const;
         virtual const ClassInfo* classInfo() const { return &info; }
         static const ClassInfo info;
         static ValueImp *pluginByName( ExecState* exec, const QString& name );
-        bool pluginsEnabled() const { return m_pluginsEnabled; };
+        bool pluginsEnabled() const { return m_pluginsEnabled; }
     private:
         static ValueImp *indexGetter(ExecState *, JSObject*, const Identifier&, const PropertySlot&);
         static ValueImp *nameGetter(ExecState *, JSObject*, const Identifier&, const PropertySlot&);
@@ -99,13 +100,13 @@ namespace KJS {
     public:
         MimeTypes(ExecState *exec, bool pluginsEnabled)
           : PluginBase(exec, pluginsEnabled),
-            m_pluginsEnabled(pluginsEnabled) {};
+            m_pluginsEnabled(pluginsEnabled) {}
         virtual bool getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot);
         virtual const ClassInfo* classInfo() const { return &info; }
         static const ClassInfo info;
         ValueImp *getValueProperty(ExecState *exec, int token) const;
         static ValueImp *mimeTypeByName( ExecState* exec, const QString& name );
-        bool pluginsEnabled() const { return m_pluginsEnabled; };
+        bool pluginsEnabled() const { return m_pluginsEnabled; }
     private:
         static ValueImp *indexGetter(ExecState *, JSObject*, const Identifier&, const PropertySlot&);
         static ValueImp *nameGetter(ExecState *, JSObject*, const Identifier&, const PropertySlot&);
@@ -117,7 +118,7 @@ namespace KJS {
     public:
         Plugin( ExecState *exec, PluginBase::PluginInfo *info )
           : PluginBase( exec, true )
-        { m_info = info; };
+        { m_info = info; }
         virtual bool getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot);
         virtual const ClassInfo* classInfo() const { return &info; }
         static const ClassInfo info;
@@ -135,7 +136,7 @@ namespace KJS {
     public:
         MimeType( ExecState *exec, PluginBase::MimeClassInfo *info )
           : PluginBase( exec, true )
-        { m_info = info; };
+        { m_info = info; }
         virtual bool getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot);
         virtual const ClassInfo* classInfo() const { return &info; }
         static const ClassInfo info;
@@ -180,7 +181,7 @@ Navigator::Navigator(ExecState *exec, KHTMLPart *p)
 bool Navigator::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "Navigator::getOwnPropertySlot " << propertyName.toAscii().constData() << endl;
+  kDebug(6070) << "Navigator::getOwnPropertySlot " << propertyName.toAscii().constData();
 #endif
   return getStaticPropertySlot<NavigatorFunc, Navigator, ObjectImp>(exec, &NavigatorTable, this, propertyName, slot);
 }
@@ -200,16 +201,16 @@ ValueImp *Navigator::getValueProperty(ExecState *exec, int token) const
     if (userAgent.indexOf(QLatin1String("Mozilla")) >= 0 &&
         userAgent.indexOf(QLatin1String("compatible")) == -1)
     {
-      //kDebug() << "appName -> Mozilla" << endl;
+      //kDebug() << "appName -> Mozilla";
       return String("Netscape");
     }
     if (userAgent.indexOf(QLatin1String("Microsoft")) >= 0 ||
         userAgent.indexOf(QLatin1String("MSIE")) >= 0)
     {
-      //kDebug() << "appName -> IE" << endl;
+      //kDebug() << "appName -> IE";
       return String("Microsoft Internet Explorer");
     }
-    //kDebug() << "appName -> Konqueror" << endl;
+    //kDebug() << "appName -> Konqueror";
     return String("Konqueror");
   case AppVersion:
     // We assume the string is something like Mozilla/version (properties)
@@ -284,7 +285,7 @@ ValueImp *Navigator::getValueProperty(ExecState *exec, int token) const
   case CookieEnabled:
     return Boolean(true); /// ##### FIXME
   default:
-    kDebug(6070) << "WARNING: Unhandled token in DOMEvent::getValueProperty : " << token << endl;
+    kDebug(6070) << "WARNING: Unhandled token in DOMEvent::getValueProperty : " << token;
     return Null();
   }
 }
@@ -308,17 +309,17 @@ PluginBase::PluginBase(ExecState *exec, bool loadPluginInfo)
             QVariant pluginsinfo = (**it).property( "X-KDE-BrowserView-PluginsInfo" );
             if ( !pluginsinfo.isValid() ) {
                 // <backwards compatible>
-                if ((**it).library() == QString("libnsplugin"))
+                if ((**it).library() == QLatin1String("libnsplugin"))
                     pluginsinfo = QVariant("nsplugins/pluginsinfo");
                 else
                 // </backwards compatible>
                     continue;
             }
             // read configuration
-            KConfig kc( KStandardDirs::locate ("data", pluginsinfo.toString()) );
+            KConfigGroup kc = KSharedConfig::openConfig( KStandardDirs::locate ("data", pluginsinfo.toString()) )->group( "0" );
             const int num = kc.readEntry("number", 0);
             for ( int n = 0; n < num; n++ ) {
-                kc.setGroup( QString::number(n) );
+                kc.changeGroup( QString::number(n) );
                 PluginInfo *plugin = new PluginInfo;
 
                 plugin->name = kc.readEntry("name");
@@ -339,7 +340,7 @@ PluginBase::PluginBase(ExecState *exec, bool loadPluginInfo)
                     MimeClassInfo *mime = new MimeClassInfo;
                     QStringList::Iterator token = tokens.begin();
                     mime->type = (*token).toLower();
-                    //kDebug(6070) << "mime->type=" << mime->type << endl;
+                    //kDebug(6070) << "mime->type=" << mime->type;
                     ++token;
 
                     mime->suffixes = *token;
@@ -408,7 +409,7 @@ ValueImp *Plugins::nameGetter(ExecState *exec, JSObject*, const Identifier& prop
 bool Plugins::getOwnPropertySlot(ExecState *exec, const Identifier &propertyName, PropertySlot& slot)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "Plugins::getOwnPropertySlot " << propertyName.qstring() << endl;
+  kDebug(6070) << "Plugins::getOwnPropertySlot " << propertyName.qstring();
 #endif
   if (getStaticOwnPropertySlot<PluginsFunc, Plugins>(&PluginsTable, this, propertyName, slot))
       return true;
@@ -467,7 +468,7 @@ ValueImp *PluginsFunc::callAsFunction(ExecState *exec, ObjectImp *thisObj, const
     return base->pluginByName( exec, s.qstring() );
   }
   default:
-    kDebug(6070) << "WARNING: Unhandled token in PluginsFunc::callAsFunction : " << id << endl;
+    kDebug(6070) << "WARNING: Unhandled token in PluginsFunc::callAsFunction : " << id;
     return Undefined();
   }
 }
@@ -497,7 +498,7 @@ ValueImp *MimeTypes::nameGetter(ExecState *exec, JSObject*, const Identifier& pr
 bool MimeTypes::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "MimeTypes::getOwnPropertySlot " << propertyName.qstring() << endl;
+  kDebug(6070) << "MimeTypes::getOwnPropertySlot " << propertyName.qstring();
 #endif
   if (getStaticOwnPropertySlot<MimeTypesFunc, MimeTypes>(&MimeTypesTable, this, propertyName, slot))
       return true;
@@ -525,7 +526,7 @@ bool MimeTypes::getOwnPropertySlot(ExecState *exec, const Identifier& propertyNa
 
 ValueImp *MimeTypes::mimeTypeByName( ExecState* exec, const QString& name )
 {
-  //kDebug(6070) << "MimeTypes[" << name << "]" << endl;
+  //kDebug(6070) << "MimeTypes[" << name << "]";
   for ( MimeClassInfo *m = mimes->first(); m!=0; m = mimes->next() ) {
     if ( m->type == name )
       return new MimeType( exec, m );
@@ -548,7 +549,7 @@ ValueImp *MimeTypesFunc::callAsFunction(ExecState *exec, ObjectImp *thisObj, con
   KJS::MimeTypes* base = static_cast<KJS::MimeTypes *>(thisObj);
 
   if (!base->pluginsEnabled()) return jsUndefined();
-  
+
   switch( id ) {
   case MimeTypes_Item:
   {
@@ -564,7 +565,7 @@ ValueImp *MimeTypesFunc::callAsFunction(ExecState *exec, ObjectImp *thisObj, con
     return base->mimeTypeByName( exec, s.qstring() );
   }
   default:
-    kDebug(6070) << "WARNING: Unhandled token in MimeTypesFunc::callAsFunction : " << id << endl;
+    kDebug(6070) << "WARNING: Unhandled token in MimeTypesFunc::callAsFunction : " << id;
     return Undefined();
   }
 }
@@ -598,7 +599,7 @@ ValueImp *Plugin::nameGetter(ExecState *exec, JSObject*, const Identifier& prope
 bool Plugin::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "Plugin::getOwnPropertySlot " << propertyName.qstring() << endl;
+  kDebug(6070) << "Plugin::getOwnPropertySlot " << propertyName.qstring();
 #endif
   if (getStaticOwnPropertySlot<PluginFunc, Plugin>(&PluginsTable, this, propertyName, slot))
       return true;
@@ -644,7 +645,7 @@ ValueImp *Plugin::getValueProperty(ExecState* /*exec*/, int token) const
   case Plugin_Length:
     return Number( m_info->mimes.count() );
   default:
-    kDebug(6070) << "WARNING: Unhandled token in Plugin::getValueProperty : " << token << endl;
+    kDebug(6070) << "WARNING: Unhandled token in Plugin::getValueProperty : " << token;
     return Undefined();
   }
 }
@@ -668,7 +669,7 @@ ValueImp *PluginFunc::callAsFunction(ExecState *exec, ObjectImp *thisObj, const
     return plugin->mimeByName( exec, s.qstring() );
   }
   default:
-    kDebug(6070) << "WARNING: Unhandled token in PluginFunc::callAsFunction : " << id << endl;
+    kDebug(6070) << "WARNING: Unhandled token in PluginFunc::callAsFunction : " << id;
     return Undefined();
   }
 }
@@ -688,7 +689,7 @@ const ClassInfo MimeType::info = { "MimeType", 0, &MimeTypesTable, 0 };
 bool MimeType::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
 #ifdef KJS_VERBOSE
-  kDebug(6070) << "MimeType::get " << propertyName.qstring() << endl;
+  kDebug(6070) << "MimeType::get " << propertyName.qstring();
 #endif
   return getStaticValueSlot<MimeType, ObjectImp>(exec, &MimeTypesTable, this, propertyName, slot);
 }
@@ -705,7 +706,7 @@ ValueImp *MimeType::getValueProperty(ExecState* exec, int token) const
   case MimeType_EnabledPlugin:
     return new Plugin(exec, m_info->plugin);
   default:
-    kDebug(6070) << "WARNING: Unhandled token in MimeType::getValueProperty : " << token << endl;
+    kDebug(6070) << "WARNING: Unhandled token in MimeType::getValueProperty : " << token;
     return Undefined();
   }
 }
