@@ -22,11 +22,11 @@
 #ifndef _KJS_WINDOW_H_
 #define _KJS_WINDOW_H_
 
-#include <qobject.h>
-#include <qpointer.h>
-#include <qmap.h>
-#include <QList>
-#include <qdatetime.h>
+#include <QtCore/QObject>
+#include <QtCore/QPointer>
+#include <QtCore/QMap>
+#include <QtCore/QList>
+#include <QtCore/QDate>
 
 #include "khtmlpart_p.h"
 #include "kjs_binding.h"
@@ -134,7 +134,7 @@ namespace KJS {
     // Set the current "event" object
     void setCurrentEvent( DOM::EventImpl *evt );
 
-    Q3PtrDict<JSEventListener> jsEventListeners;
+    QHash<void*, JSEventListener*> jsEventListeners;
     virtual const ClassInfo* classInfo() const { return &info; }
     static const ClassInfo info;
     enum { Closed, Crypto, DefaultStatus, Status, Document, Node, EventCtor, Range,
@@ -307,20 +307,6 @@ namespace KJS {
     QPointer<khtml::ChildFrame> m_frame;
   };
 
-#ifdef Q_WS_QWS
-  class Konqueror : public ObjectImp {
-    friend class KonquerorFunc;
-  public:
-    Konqueror(KHTMLPart *p) : part(p) { }
-    virtual bool getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot);
-    virtual UString toString(ExecState *exec) const;
-    virtual const ClassInfo* classInfo() const { return &info; }
-    static const ClassInfo info;
-  private:
-    KHTMLPart *part;
-  };
-#endif
-
 } // namespace
 
 #endif
