@@ -36,7 +36,8 @@
 
 #include <kio/scheduler.h>
 #include <kio/job.h>
-#include <qobject.h>
+#include <QtCore/QObject>
+#include <QtCore/QHash>
 #include <kdebug.h>
 
 #ifdef APPLE_CHANGES
@@ -46,14 +47,9 @@
 using KIO::NetAccess;
 #endif
 
-#define BANNED_HTTP_HEADERS "authorization,proxy-authorization,"\
-                            "content-length,host,connect,copy,move,"\
-                            "delete,head,trace,put,propfind,proppatch,"\
-                            "mkcol,lock,unlock,options,via"
-
 using namespace KJS;
-using khtml::Decoder;
-
+using namespace DOM;
+// 
 ////////////////////// XMLHttpRequest Object ////////////////////////
 
 /* Source for XMLHttpRequestProtoTable.
@@ -62,6 +58,7 @@ using khtml::Decoder;
   getAllResponseHeaders	XMLHttpRequest::GetAllResponseHeaders	DontDelete|Function 0
   getResponseHeader	XMLHttpRequest::GetResponseHeader	DontDelete|Function 1
   open			XMLHttpRequest::Open			DontDelete|Function 5
+  overrideMimeType	XMLHttpRequest::OverrideMIMEType	DontDelete|Function 1
   send			XMLHttpRequest::Send			DontDelete|Function 1
   setRequestHeader	XMLHttpRequest::SetRequestHeader	DontDelete|Function 2
 @end
@@ -140,19 +137,22 @@ ValueImp *XMLHttpRequest::getValueProperty(ExecState *exec, int token) const
 {
   switch (token) {
   case ReadyState:
-    return Number(state);
+    return Number(m_state);
   case ResponseText:
     return ::getStringOrNull(DOM::DOMString(response));
   case ResponseXML:
-    if (state != XHRS_Loaded) {
-      return Undefined();
+    if (m_state != XHRS_Loaded) {
+      return jsNull();
     }
     if (!createdDocument) {
       QString mimeType = "text/xml";
 
-      ValueImp *header = getResponseHeader("Content-Type");
-      if (header->type() != UndefinedType) {
-	mimeType = header->toString(exec).qstring().split(";")[0].trimmed();
+      if (!m_mimeTypeOverride.isEmpty()) {
+	  mimeType = m_mimeTypeOverride;
+      } else {
+	  ValueImp *header = getResponseHeader("Content-Type");
+	  if (header->type() != UndefinedType)
+	      mimeType = header->toString(exec).qstring().split(";")[0].trimmed();
       }
 
       if (mimeType == "text/xml" || mimeType == "application/xml" || mimeType == "application/xhtml+xml") {
@@ -193,7 +193,7 @@ ValueImp *XMLHttpRequest::getValueProperty(ExecState *exec, int token) const
      return Null();
    }
   default:
-    kWarning() << "XMLHttpRequest::getValueProperty unhandled token " << token << endl;
+    kWarning() << "XMLHttpRequest::getValueProperty unhandled token " << token;
     return 0;
   }
 }
@@ -217,17 +217,90 @@ void XMLHttpRequest::putValueProperty(ExecState *exec, int token, ValueImp *valu
     if (onLoadListener) onLoadListener->ref();
     break;
   default:
-    kWarning() << "XMLHttpRequest::putValue unhandled token " << token << endl;
+    kWarning() << "XMLHttpRequest::putValue unhandled token " << token;
   }
 }
 
+// Token according to RFC 2616
+static bool isValidFieldName(const QString& name)
+{
+    const QChar* c = name.constData();
+    int l = name.length();
+    if (l == 0)
+        return false;
+    for (int i = 0; i < l; ++i, ++c) {
+        int u = c->unicode();
+        if (u < 32 || u > 126)
+            return false;
+        switch (u) {
+        case '(': case ')': case '<': case '>':
+        case '@': case ',': case ';': case ':':
+        case '\\': case '"': case '/':
+        case '[': case ']': case '?': case '=':
+        case '{': case '}': case '\t': case ' ':
+	    return false;
+        default:
+            break;
+        }
+    }
+    return true;
+}
+
+static bool isValidFieldValue(const QString& name)
+{
+    // ### what is invalid?
+    return true;
+}
+
+static bool canSetRequestHeader(const QString& name)
+{
+    static QSet<CaseInsensitiveString> forbiddenHeaders;
+    
+    if (forbiddenHeaders.isEmpty()) {
+	static const char* hdrs[] = {
+	    "accept-charset",
+	    "accept-encoding",
+	    "authorization",
+	    "content-length",
+	    "connect",
+	    "copy",
+	    "date",
+	    "delete",
+	    "expect",
+	    "head",
+	    "host",
+	    "keep-alive",
+	    "lock",
+	    "mkcol",
+	    "move",
+	    "options",
+	    "put",
+	    "propfind",
+	    "proppatch",
+	    "proxy-authorization",
+	    "referer",
+	    "te",
+	    "trace",
+	    "trailer",
+	    "transfer-encoding",
+	    "unlock",
+	    "upgrade",
+	    "via" 
+	};
+	for (size_t i = 0; i < sizeof(hdrs)/sizeof(char*); ++i)
+	    forbiddenHeaders.insert(CaseInsensitiveString(hdrs[i]));
+    }
+    
+    return !forbiddenHeaders.contains(name);
+}
+
 XMLHttpRequest::XMLHttpRequest(ExecState *exec, DOM::DocumentImpl* d)
   : qObject(new XMLHttpRequestQObject(this)),
     doc(d),
     async(true),
     contentType(QString()),
     job(0),
-    state(XHRS_Uninitialized),
+    m_state(XHRS_Uninitialized),
     onReadyStateChangeListener(0),
     onLoadListener(0),
     decoder(0),
@@ -252,8 +325,8 @@ XMLHttpRequest::~XMLHttpRequest()
 
 void XMLHttpRequest::changeState(XMLHttpRequestState newState)
 {
-  if (state != newState) {
-    state = newState;
+  if (m_state != newState) {
+    m_state = newState;
     ProtectedPtr<ObjectImp> ref(this);
 
     if (onReadyStateChangeListener != 0 && doc->view() && doc->view()->part()) {
@@ -262,7 +335,7 @@ void XMLHttpRequest::changeState(XMLHttpRequestState newState)
       onReadyStateChangeListener->handleEvent(ev);
     }
 
-    if (state == XHRS_Loaded && onLoadListener != 0 && doc->view() && doc->view()->part()) {
+    if (m_state == XHRS_Loaded && onLoadListener != 0 && doc->view() && doc->view()->part()) {
       DOM::Event ev = doc->view()->part()->document().createEvent("HTMLEvents");
       ev.initEvent("load", true, true);
       onLoadListener->handleEvent(ev);
@@ -299,7 +372,7 @@ void XMLHttpRequest::open(const QString& _method, const KUrl& _url, bool _async)
   aborted = false;
 
   // clear stuff from possible previous load
-  requestHeaders.clear();
+  m_requestHeaders.clear();
   responseHeaders.clear();
   response = QString::fromLatin1("");
   createdDocument = false;
@@ -316,10 +389,15 @@ void XMLHttpRequest::open(const QString& _method, const KUrl& _url, bool _async)
   changeState(XHRS_Open);
 }
 
-void XMLHttpRequest::send(const QString& _body)
+void XMLHttpRequest::send(const QString& _body, int& ec)
 {
   aborted = false;
 
+  if (m_state != XHRS_Open) {
+      ec =  DOMException::INVALID_STATE_ERR;
+      return;
+  }
+
   if (method == "post") {
     QString protocol = url.protocol().toLower();
 
@@ -346,14 +424,21 @@ void XMLHttpRequest::send(const QString& _body)
     job = KIO::get( url, false, false );
   }
 
-  if (!requestHeaders.isEmpty()) {
+  if (!m_requestHeaders.isEmpty()) {
     QString rh;
-    QMap<QString, QString>::ConstIterator begin = requestHeaders.begin();
-    QMap<QString, QString>::ConstIterator end = requestHeaders.end();
-    for (QMap<QString, QString>::ConstIterator i = begin; i != end; ++i) {
-      if (i != begin)
-        rh += "\r\n";
-      rh += i.key() + ": " + i.value();
+    HTTPHeaderMap::ConstIterator begin = m_requestHeaders.begin();
+    HTTPHeaderMap::ConstIterator end = m_requestHeaders.end();
+    for (HTTPHeaderMap::ConstIterator i = begin; i != end; ++i) {
+      QString key = i.key().original();
+      QString value = i.value();
+      if (key.toLower() == "accept") {
+        // The HTTP KIO slave supports an override this way
+        job->addMetaData("accept", value);
+      } else {
+        if (!rh.isEmpty())
+          rh += "\r\n";
+        rh += key + ": " + value;
+      }
     }
 
     job->addMetaData("customHTTPHeader", rh);
@@ -361,16 +446,13 @@ void XMLHttpRequest::send(const QString& _body)
 
   job->addMetaData("PropagateHttpHeader", "true");
 
-  // Set the default referrer if one is not already supplied
-  // through setRequestHeader. NOTE: the user can still disable
+  // Set the default referrer. NOTE: the user can still disable
   // this feature at the protocol level (kio_http).
-  if (requestHeaders.find("Referer") == requestHeaders.end()) {
-    KUrl documentURL(doc->URL());
-    documentURL.setPass(QString());
-    documentURL.setUser(QString());
-    job->addMetaData("referrer", documentURL.url());
-    // kDebug() << "Adding referrer: " << documentURL << endl;
-  }
+  KUrl documentURL(doc->URL());
+  documentURL.setPass(QString());
+  documentURL.setUser(QString());
+  job->addMetaData("referrer", documentURL.url());
+  // kDebug() << "Adding referrer: " << documentURL;
 
   if (!async) {
     QByteArray data;
@@ -421,9 +503,27 @@ void XMLHttpRequest::abort()
   changeState(XHRS_Uninitialized);
 }
 
-void XMLHttpRequest::setRequestHeader(const QString& _name, const QString &value)
+void XMLHttpRequest::overrideMIMEType(const QString& override)
 {
-  QString name = _name.toLower().trimmed();
+    m_mimeTypeOverride = override;
+}
+
+void XMLHttpRequest::setRequestHeader(const QString& _name, const QString& _value, int& ec)
+{
+  // throw exception if connection is not open or the send flag is set
+  if (m_state != XHRS_Open || job != 0) {
+      ec = DOMException::INVALID_STATE_ERR;
+      return;
+  }
+
+  if (!isValidFieldName(_name) || !isValidFieldValue(_value)) {
+      ec = DOMException::SYNTAX_ERR;
+      return;
+  }
+  QString name = _name.toLower();
+  QString value = _value.trimmed();
+  if (value.isEmpty())
+      return;
 
   // Content-type needs to be set separately from the other headers
   if(name == "content-type") {
@@ -435,7 +535,7 @@ void XMLHttpRequest::setRequestHeader(const QString& _name, const QString &value
   if(name == "referer") {
     KUrl referrerURL(value);
     if (urlMatchesDocumentDomain(referrerURL))
-      requestHeaders[name] = referrerURL.url();
+      m_requestHeaders[name] = referrerURL.url();
     return;
   }
 
@@ -449,14 +549,14 @@ void XMLHttpRequest::setRequestHeader(const QString& _name, const QString &value
     return;
   }
 
-  // Reject all banned headers. See BANNED_HTTP_HEADERS above.
-  // kDebug() << "Banned HTTP Headers: " << BANNED_HTTP_HEADERS << endl;
-  QStringList bannedHeaders = QString::fromLatin1(BANNED_HTTP_HEADERS).split(',');
+  // Reject all banned headers.
+  if (!canSetRequestHeader(_name)) {
+      kWarning(6070) << "Refusing to set unsafe XMLHttpRequest header "
+                     << name << endl;
+      return;
+  }
 
-  if (bannedHeaders.contains(name))
-    return;   // Denied
-
-  requestHeaders[name] = value.trimmed();
+  m_requestHeaders[_name] = value;
 }
 
 ValueImp *XMLHttpRequest::getAllResponseHeaders() const
@@ -471,7 +571,7 @@ ValueImp *XMLHttpRequest::getAllResponseHeaders() const
     return Undefined();
   }
 
-  return String(responseHeaders.mid(endOfLine + 1) + "\n");
+  return String(responseHeaders.mid(endOfLine + 1) + '\n');
 }
 
 ValueImp *XMLHttpRequest::getResponseHeader(const QString& name) const
@@ -480,7 +580,7 @@ ValueImp *XMLHttpRequest::getResponseHeader(const QString& name) const
     return Undefined();
   }
 
-  QRegExp headerLinePattern(name + ":", Qt::CaseInsensitive);
+  QRegExp headerLinePattern(name + ':', Qt::CaseInsensitive);
 
   int matchLength;
   int headerLinePos = headerLinePattern.indexIn(responseHeaders, 0);
@@ -602,7 +702,7 @@ void XMLHttpRequest::slotData( KIO::Job*, const char *data, int len )
 void XMLHttpRequest::slotData(KIO::Job*, const QByteArray &_data)
 #endif
 {
-  if (state < XHRS_Sent ) {
+  if (m_state < XHRS_Sent ) {
     responseHeaders = job->queryMetaData("HTTP-Headers");
 
     // NOTE: Replace a 304 response with a 200! Both IE and Mozilla do this.
@@ -634,9 +734,9 @@ void XMLHttpRequest::slotData(KIO::Job*, const QByteArray &_data)
         encoding = type.mid( index+1 ).remove(QRegExp("charset[ ]*=[ ]*", Qt::CaseInsensitive)).trimmed();
     }
 
-    decoder = new Decoder;
+    decoder = new KEncodingDetector;
     if (!encoding.isNull())
-      decoder->setEncoding(encoding.toLatin1().constData(), Decoder::EncodingFromHTTPHeader);
+      decoder->setEncoding(encoding.toLatin1().constData(), KEncodingDetector::EncodingFromHTTPHeader);
     else {
       // FIXME: Inherit the default encoding from the parent document?
     }
@@ -647,7 +747,7 @@ void XMLHttpRequest::slotData(KIO::Job*, const QByteArray &_data)
   if (len == -1)
     len = strlen(data);
 
-  QString decoded = decoder->decode(data, len);
+  QString decoded = decoder->decodeWithBuffering(data, len);
 
   response += decoded;
 
@@ -663,27 +763,24 @@ ValueImp *XMLHttpRequestProtoFunc::callAsFunction(ExecState *exec, ObjectImp *th
   }
 
   XMLHttpRequest *request = static_cast<XMLHttpRequest *>(thisObj);
+
+  int ec = 0;
+
   switch (id) {
   case XMLHttpRequest::Abort:
     request->abort();
     return Undefined();
   case XMLHttpRequest::GetAllResponseHeaders:
-    if (args.size() != 0) {
-    return Undefined();
-    }
-
     return request->getAllResponseHeaders();
   case XMLHttpRequest::GetResponseHeader:
-    if (args.size() != 1) {
-    return Undefined();
-    }
+    if (args.size() < 1)
+        return throwError(exec, SyntaxError, "Not enough arguments");
 
     return request->getResponseHeader(args[0]->toString(exec).qstring());
   case XMLHttpRequest::Open:
     {
-      if (args.size() < 2 || args.size() > 5) {
-        return Undefined();
-      }
+      if (args.size() < 2)
+          return throwError(exec, SyntaxError, "Not enough arguments");
 
       QString method = args[0]->toString(exec).qstring();
       KHTMLPart *part = qobject_cast<KHTMLPart*>(Window::retrieveActive(exec)->part());
@@ -710,14 +807,6 @@ ValueImp *XMLHttpRequestProtoFunc::callAsFunction(ExecState *exec, ObjectImp *th
     }
   case XMLHttpRequest::Send:
     {
-      if (args.size() > 1) {
-        return Undefined();
-      }
-
-      if (request->state != XHRS_Open) {
-	return Undefined();
-      }
-
       QString body;
       if (args.size() >= 1) {
         DOM::NodeImpl* docNode = toNode(args[0]);
@@ -736,18 +825,32 @@ ValueImp *XMLHttpRequestProtoFunc::callAsFunction(ExecState *exec, ObjectImp *th
         }
       }
 
-      request->send(body);
-
-      return Undefined();
+      request->send(body, ec);
+      setDOMException(exec, ec);  
+      return jsUndefined();
     }
   case XMLHttpRequest::SetRequestHeader:
-    if (args.size() != 2) {
-      return Undefined();
-    }
+      {
+      if (args.size() < 2)
+          return throwError(exec, SyntaxError, "Not enough arguments");
+      JSValue* keyArgument = args[0];
+      JSValue* valArgument = args[1];
+      QString key, val;
+      if (!keyArgument->isUndefined() && !keyArgument->isNull())
+          key = keyArgument->toString(exec).qstring();
+      if (!valArgument->isUndefined() && !valArgument->isNull())
+          val = valArgument->toString(exec).qstring();
+      request->setRequestHeader(key, val, ec);
+      setDOMException(exec, ec);
+      return jsUndefined();
+      }
 
-    request->setRequestHeader(args[0]->toString(exec).qstring(), args[1]->toString(exec).qstring());
+  case XMLHttpRequest::OverrideMIMEType:
+      if (args.size() < 1)
+          return throwError(exec, SyntaxError, "Not enough arguments");
 
-    return Undefined();
+      request->overrideMIMEType(args[0]->toString(exec).qstring());
+      return jsUndefined();
   }
 
   return Undefined();
