@@ -23,15 +23,42 @@
 
 #include "ecma/kjs_binding.h"
 #include "ecma/kjs_dom.h"
-#include "misc/decoder.h"
+#include <kencodingdetector.h>
 #include "kio/jobclasses.h"
-#include <QPointer>
+#include <QtCore/QPointer>
+#include <QtCore/QHash>
 
 namespace KJS {
 
   class JSEventListener;
   class XMLHttpRequestQObject;
 
+  class CaseInsensitiveString
+  {
+  public:
+    CaseInsensitiveString(const char* s) : str(QLatin1String(s)) { }
+    CaseInsensitiveString(const QString& s) : str(s) { }
+
+    QString original() const { return str; }
+    QString toLower() const { return str.toLower(); }
+
+  private:
+    QString str;
+  };
+
+  inline bool operator==(const CaseInsensitiveString& a,
+                         const CaseInsensitiveString& b)
+  {
+      return a.original().compare(b.original(), Qt::CaseInsensitive) == 0;
+  }
+
+  inline uint qHash(const CaseInsensitiveString& key)
+  {
+    return qHash(key.toLower());
+  }
+
+  typedef QHash<CaseInsensitiveString, QString> HTTPHeaderMap;
+
   // these exact numeric values are important because JS expects them
   enum XMLHttpRequestState {
     XHRS_Uninitialized = 0,
@@ -63,7 +90,8 @@ namespace KJS {
     virtual const ClassInfo* classInfo() const { return &info; }
     static const ClassInfo info;
     enum { Onload, Onreadystatechange, ReadyState, ResponseText, ResponseXML, Status, StatusText, Abort,
-           GetAllResponseHeaders, GetResponseHeader, Open, Send, SetRequestHeader };
+           GetAllResponseHeaders, GetResponseHeader, Open, Send, SetRequestHeader,
+           OverrideMIMEType };
 
   private:
     friend class XMLHttpRequestProtoFunc;
@@ -86,9 +114,10 @@ namespace KJS {
     void processSyncLoadResults(const QByteArray &data, const KUrl &finalURL, const QString &headers);
 
     void open(const QString& _method, const KUrl& _url, bool _async);
-    void send(const QString& _body);
+    void send(const QString& _body, int& ec);
     void abort();
-    void setRequestHeader(const QString& name, const QString &value);
+    void setRequestHeader(const QString& name, const QString& value, int& ec);
+    void overrideMIMEType(const QString& override);
     ValueImp *getAllResponseHeaders() const;
     ValueImp *getResponseHeader(const QString& name) const;
 
@@ -99,16 +128,17 @@ namespace KJS {
     KUrl url;
     QString method;
     bool async;
-    QMap<QString,QString> requestHeaders;
+    HTTPHeaderMap m_requestHeaders;
+    QString m_mimeTypeOverride;
     QString contentType;
 
     KIO::TransferJob * job;
 
-    XMLHttpRequestState state;
+    XMLHttpRequestState m_state;
     JSEventListener *onReadyStateChangeListener;
     JSEventListener *onLoadListener;
 
-    khtml::Decoder *decoder;
+    KEncodingDetector *decoder;
     QString encoding;
     QString responseHeaders;
 
