@@ -30,28 +30,27 @@
 //#define EVENT_DEBUG
 //#define UNSUPPORTED_ATTR
 
-#include "html/dtd.h"
-#include "html/html_elementimpl.h"
-#include "html/html_documentimpl.h"
-#include "html/htmltokenizer.h"
+#include "html_elementimpl.h"
+#include "dtd.h"
+#include "html_documentimpl.h"
+#include "htmltokenizer.h"
 
-#include "misc/htmlhashes.h"
+#include <misc/htmlhashes.h>
 
-#include "khtmlview.h"
-#include "khtml_part.h"
+#include <khtmlview.h>
+#include <khtml_part.h>
 
-#include "rendering/render_object.h"
-#include "rendering/render_replaced.h"
-#include "css/css_valueimpl.h"
-#include "css/css_stylesheetimpl.h"
-#include "css/cssproperties.h"
-#include "css/cssvalues.h"
-#include "xml/dom_textimpl.h"
-#include "xml/dom2_eventsimpl.h"
+#include <rendering/render_object.h>
+#include <rendering/render_replaced.h>
+#include <css/css_valueimpl.h>
+#include <css/css_stylesheetimpl.h>
+#include <css/cssproperties.h>
+#include <css/cssvalues.h>
+#include <xml/dom_textimpl.h>
+#include <xml/dom2_eventsimpl.h>
 
 #include <kdebug.h>
 #include <kglobal.h>
-#include "html_elementimpl.h"
 
 using namespace DOM;
 using namespace khtml;
@@ -147,7 +146,7 @@ DOMString HTMLElementImpl::tagName() const
         tn = tn.upper();
 
     if (m_prefix)
-        return DOMString(m_prefix) + ":" + tn;
+        return DOMString(m_prefix) + ":" + tn;	//krazy:exclude=doublequote_chars DOM demands chars
 
     return tn;
 }
@@ -183,7 +182,7 @@ void HTMLElementImpl::parseAttribute(AttributeImpl *attr)
           setHasClassList(l);
           setHasClass(true);
         } else {
-          setHasClassList(false);                 
+          setHasClassList(false);
           setHasClass(false);
         }
         break;
@@ -457,7 +456,7 @@ DOMString HTMLElementImpl::innerHTML() const
     QString result; //Use QString to accumulate since DOMString is poor for appends
     for (NodeImpl *child = firstChild(); child != NULL; child = child->nextSibling()) {
         DOMString kid = child->toString();
-        result += QConstString(kid.unicode(), kid.length()).string();
+        result += QString::fromRawData(kid.unicode(), kid.length());
     }
     return result;
 }
@@ -486,7 +485,7 @@ DOMString HTMLElementImpl::innerText() const
         }
         if(n->isTextNode() ) {
             DOMStringImpl* data = static_cast<const TextImpl *>(n)->string();
-            text += QConstString(data->s, data->l).string();
+            text += QString::fromRawData(data->s, data->l);
         }
     }
  end:
@@ -507,7 +506,6 @@ DocumentFragment HTMLElementImpl::createContextualFragment( const DOMString &htm
         case ID_COLGROUP:
         case ID_FRAMESET:
         case ID_HEAD:
-        case ID_STYLE:
         case ID_TABLE:
         case ID_TBODY:
         case ID_TFOOT:
@@ -653,12 +651,12 @@ DOMString HTMLElementImpl::toString() const
 {
     if (!hasChildNodes()) {
 	DOMString result = openTagStartToString();
-	result += ">";
+	result += ">";	//krazy:exclude=doublequote_chars DOM demands chars
 
 	if (endTag[id()] == REQUIRED) {
 	    result += "</";
 	    result += tagName();
-	    result += ">";
+	    result += ">";	//krazy:exclude=doublequote_chars DOM demands chars
 	}
 
 	return result;
