@@ -59,12 +59,12 @@
 #endif
 #include <netaccess.h>
 #include <kfileitem.h>
-#include <qfile.h>
-#include <qdir.h>
-#include <qtextcodec.h>
+#include <QtCore/QFile>
+#include <QtCore/QDir>
+#include <QtCore/QTextCodec>
 
 // for keygen
-#include <qstring.h>
+#include <QtCore/QCharRef>
 #include <ksslkeygen.h>
 
 #include <assert.h>
@@ -225,7 +225,7 @@ inline static QByteArray fixUpfromUnicode(const QTextCodec* codec, const QString
 QByteArray HTMLFormElementImpl::formData(bool& ok)
 {
 #ifdef FORMS_DEBUG
-    kDebug( 6030 ) << "form: formData()" << endl;
+    kDebug( 6030 ) << "form: formData()";
 #endif
 
     QByteArray form_data;
@@ -280,7 +280,7 @@ QByteArray HTMLFormElementImpl::formData(bool& ok)
 
         if (!current->disabled() && current->encoding(codec, lst, m_multipart))
         {
-            //kDebug(6030) << "adding name '" << current->name().string() << "'" << endl;
+            //kDebug(6030) << "adding name '" << current->name().string() << "'";
             khtml::encodingList::ConstIterator it = lst.begin();
             const khtml::encodingList::ConstIterator itEnd = lst.end();
             for( it = lst.begin(); it != itEnd; ++it )
@@ -298,7 +298,7 @@ QByteArray HTMLFormElementImpl::formData(bool& ok)
                             enc_string += '&';
 
                         enc_string += encodeCString(*it);
-                        enc_string += "=";
+                        enc_string += '=';
                         ++it;
                         enc_string += encodeCString(*it);
                     }
@@ -582,7 +582,7 @@ void HTMLFormElementImpl::submit(  )
     m_insubmit = true;
 
 #ifdef FORMS_DEBUG
-    kDebug( 6030 ) << "submitting!" << endl;
+    kDebug( 6030 ) << "submitting!";
 #endif
 
     bool ok;
@@ -691,7 +691,7 @@ void HTMLFormElementImpl::reset(  )
     m_inreset = true;
 
 #ifdef FORMS_DEBUG
-    kDebug( 6030 ) << "reset pressed!" << endl;
+    kDebug( 6030 ) << "reset pressed!";
 #endif
 
     // ### DOM2 labels this event as not cancelable, however
@@ -921,8 +921,8 @@ HTMLFormElementImpl *HTMLGenericFormElementImpl::getForm() const
         p = p->parentNode();
     }
 #ifdef FORMS_DEBUG
-    kDebug( 6030 ) << "couldn't find form!" << endl;
-    kDebug( 6030 ) << kBacktrace() << endl;
+    kDebug( 6030 ) << "couldn't find form!";
+    kDebug( 6030 ) << kBacktrace();
 #endif
     return 0;
 }
@@ -1380,7 +1380,7 @@ void HTMLInputElementImpl::restoreState(const QString &state)
         break;
     default:
         setValue(DOMString(state.left(state.length()-1)));
-        m_unsubmittedFormChange = state.endsWith("M");
+        m_unsubmittedFormChange = state.endsWith('M');
         break;
     }
 }
@@ -1590,7 +1590,7 @@ bool HTMLInputElementImpl::encoding(const QTextCodec* codec, khtml::encodingList
 
         case BUTTON:
         case RESET:
-            // those buttons are never successful
+            // these types of buttons are never successful
             return false;
 
         case IMAGE:
@@ -1742,14 +1742,11 @@ DOMString HTMLInputElementImpl::value() const
 {
     if (m_type == CHECKBOX || m_type == RADIO) {
         const DOMString val = getAttribute(ATTR_VALUE);
-        // If no attribute exists, then just use "on" or "" based off the checked() state
-        // of the control.
-        if (val.isNull()) {
-            if (checked())
-                return DOMString("on");
-            else
-                return DOMString("");
-        }
+        // If no attribute exists, then we'll just return "on" as
+        // other browsers strangely seem to do without respecting the
+        // checked() state of the control.
+        if (val.isNull())
+	    return DOMString("on");
         return val;
     }
 
@@ -1769,6 +1766,10 @@ void HTMLInputElementImpl::setValue(DOMString val)
     if (m_type == FILE) return;
 
     m_value = (val.isNull() ? DOMString("") : val);
+    // ### set attribute for other types, too. no need for m_value
+    // ### in those cases.
+    if (m_type == RADIO || m_type == CHECKBOX)
+	setAttribute(ATTR_VALUE, m_value);
     if (m_type == TEXT && m_render)
         m_render->updateFromElement();
     setChanged();
@@ -2378,7 +2379,7 @@ int HTMLSelectElementImpl::optionToListIndex(int optionIndex) const
 
     //See if we're asked for the very last item, and check whether it's an <option>
     //to fastpath clear
-    if ((uint)optionIndex == (m_length - 1) && items[itemsSize - 1]->id() == ID_OPTION)
+    if (optionIndex == (m_length - 1) && items[itemsSize - 1]->id() == ID_OPTION)
         return itemsSize - 1;
 
     int listIndex = 0;
@@ -2612,13 +2613,13 @@ long HTMLOptionElementImpl::index() const
             ++optionIndex;
         }
     }
-    kWarning() << "HTMLOptionElementImpl::index(): option not found!" << endl;
+    kWarning() << "HTMLOptionElementImpl::index(): option not found!";
     return 0;
 }
 
 void HTMLOptionElementImpl::setIndex( long  )
 {
-    kWarning() << "Unimplemented HTMLOptionElementImpl::setIndex(long) called" << endl;
+    kWarning() << "Unimplemented HTMLOptionElementImpl::setIndex(long) called";
     // ###
 }
 
@@ -2711,7 +2712,7 @@ QString HTMLTextAreaElementImpl::state( )
 void HTMLTextAreaElementImpl::restoreState(const QString &state)
 {
     setDefaultValue(state.left(state.length()-1));
-    m_unsubmittedFormChange = state.endsWith("M");
+    m_unsubmittedFormChange = state.endsWith('M');
     // the close() in the rendertree will take care of transferring defaultvalue to 'value'
 }
 
