@@ -29,9 +29,8 @@
 #include "html/html_imageimpl.h"
 #include "dom/html_element.h"
 
-#include <q3ptrlist.h>
+#include <Qt3Support/Q3PtrList>
 
-class KHTMLView;
 class QTextCodec;
 
 namespace khtml
@@ -355,8 +354,8 @@ public:
     virtual Id id() const;
     virtual void attach();
     virtual void defaultEventHandler(EventImpl *evt);
-    virtual bool isFocusable() const { return true; };
-    virtual bool isTabFocusable() const { return false; };
+    virtual bool isFocusable() const { return true; }
+    virtual bool isTabFocusable() const { return false; }
     NodeImpl* getFormElement();
 
  private:
@@ -486,7 +485,7 @@ class HTMLOptGroupElementImpl : public HTMLGenericFormElementImpl
 {
 public:
     HTMLOptGroupElementImpl(DocumentImpl *doc, HTMLFormElementImpl *f = 0)
-        : HTMLGenericFormElementImpl(doc, f) {}
+		: HTMLGenericFormElementImpl(doc, f) {}
 
     virtual Id id() const;
 };
