@@ -40,11 +40,11 @@
 #include "css/csshelper.h"
 #include "xml/dom2_eventsimpl.h"
 
-#include <qstring.h>
-#include <qpoint.h>
-#include <qregion.h>
-#include <q3ptrstack.h>
-#include <qimage.h>
+#include <QtCore/QCharRef>
+#include <QtCore/QPoint>
+#include <QtCore/QStack>
+#include <QtGui/QRegion>
+#include <QtGui/QImage>
 
 using namespace DOM;
 using namespace khtml;
@@ -387,7 +387,7 @@ HTMLMapElementImpl::mapMouseEvent(int x_, int y_, int width_, int height_,
 {
     //cout << "map:mapMouseEvent " << endl;
     //cout << x_ << " " << y_ <<" "<< width_ <<" "<< height_ << endl;
-    Q3PtrStack<NodeImpl> nodeStack;
+    QStack<NodeImpl*> nodeStack;
 
     NodeImpl *current = firstChild();
     while(1)
