@@ -25,16 +25,14 @@
 
 #include "html_elementimpl.h"
 #include "xml/dom_stringimpl.h"
-#include <qobject.h>
-#include <qstringlist.h>
+#include <QtCore/QObject>
+#include <QtCore/QStringList>
 
-class KHTMLView;
 
 // -------------------------------------------------------------------------
 namespace DOM {
 
 class HTMLFormElementImpl;
-class DOMStringImpl;
 
 class HTMLObjectBaseElementImpl : public QObject, public HTMLElementImpl
 {
