@@ -25,22 +25,23 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include "html/html_documentimpl.h"
-#include "html/html_tableimpl.h"
+#include "html_tableimpl.h"
 
-#include "dom/dom_exception.h"
-#include "dom/dom_node.h"
+#include "html_documentimpl.h"
 
-#include "misc/htmlhashes.h"
-#include "khtmlview.h"
-#include "khtml_part.h"
+#include <dom/dom_exception.h>
+#include <dom/dom_node.h>
 
-#include "css/cssstyleselector.h"
-#include "css/cssproperties.h"
-#include "css/cssvalues.h"
-#include "css/csshelper.h"
+#include <misc/htmlhashes.h>
+#include <khtmlview.h>
+#include <khtml_part.h>
 
-#include "rendering/render_table.h"
+#include <css/cssstyleselector.h>
+#include <css/cssproperties.h>
+#include <css/cssvalues.h>
+#include <css/csshelper.h>
+
+#include <rendering/render_table.h>
 
 #include <kdebug.h>
 #include <kglobal.h>
@@ -276,7 +277,7 @@ HTMLElementImpl *HTMLTableElementImpl::insertRow( long index, int &exceptioncode
     if(!tFirstBody() && !foot && !head)
         setTBody( new HTMLTableSectionElementImpl(docPtr(), ID_TBODY, true /* implicit */) );
 
-    //kdDebug(6030) << k_funcinfo << index << endl;
+    //kDebug(6030) << index;
 
     long sectionIndex;
     HTMLTableSectionElementImpl* section;
@@ -370,7 +371,7 @@ void HTMLTableElementImpl::handleChildRemove( NodeImpl *child )
 NodeImpl *HTMLTableElementImpl::addChild(NodeImpl *child)
 {
 #ifdef DEBUG_LAYOUT
-    kDebug( 6030 ) << nodeName().string() << "(Table)::addChild( " << child->nodeName().string() << " )" << endl;
+    kDebug( 6030 ) << nodeName().string() << "(Table)::addChild( " << child->nodeName().string() << " )";
 #endif
 
     NodeImpl *retval = HTMLElementImpl::addChild( child );
@@ -685,7 +686,7 @@ HTMLElementImpl *HTMLTableSectionElementImpl::insertRow( long index, int& except
     HTMLTableRowElementImpl *r = 0L;
     HTMLCollectionImpl rows(const_cast<HTMLTableSectionElementImpl*>(this), HTMLCollectionImpl::TSECTION_ROWS);
     int numRows = rows.length();
-    //kDebug(6030) << k_funcinfo << "index=" << index << " numRows=" << numRows << endl;
+    //kDebug(6030) << "index=" << index << " numRows=" << numRows;
     if ( index < -1 || index > numRows ) {
         exceptioncode = DOMException::INDEX_SIZE_ERR; // per the DOM
     }
