@@ -144,7 +144,7 @@ private:
         if (imFrm.type == ImageFormat::Image_RGB_32)
         {
             //Need fillers, plus perhaps BGR swapping for non-alpha
-#if defined(WORDS_BIGENDIAN) || defined(__BIG_ENDIAN__)
+#if Q_BYTE_ORDER == Q_BIG_ENDIAN || defined(__BIG_ENDIAN__)
             png_set_filler(pngReadStruct, 0xff, PNG_FILLER_BEFORE);
 #else
             png_set_filler(pngReadStruct, 0xff, PNG_FILLER_AFTER);
@@ -153,7 +153,7 @@ private:
         }
         else if (imFrm.type == ImageFormat::Image_RGBA_32)
         {
-#if defined(WORDS_BIGENDIAN) || defined(__BIG_ENDIAN__)
+#if Q_BYTE_ORDER == Q_BIG_ENDIAN || defined(__BIG_ENDIAN__)
             png_set_swap_alpha(pngReadStruct); //ARGB, not RGBA
 #else
             png_set_bgr   (pngReadStruct);     //BGRA
@@ -238,8 +238,6 @@ public:
             return Error;
         }
 
-        qDebug("pushing:%d bytes",length);
-        
         //OK, now we can actually do work.... Push data to libPNG,
         //it will use callbacks
         //### time limiting?
