@@ -17,23 +17,28 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
+
+#include "kjavaappletviewer.h"
+
+#include "kjavaappletwidget.h"
+#include "kjavaappletserver.h"
+
 #include <stdio.h>
 
 #ifdef KDE_USE_FINAL
 #undef Always
 #endif
-#include <qdir.h>
-#include <q3table.h>
-#include <qpair.h>
-#include <qtimer.h>
-#include <qpointer.h>
-#include <qlabel.h>
+#include <QtCore/QDir>
+#include <Qt3Support/Q3Table>
+#include <QtCore/QPair>
+#include <QtCore/QTimer>
+#include <QtCore/QPointer>
+#include <QtGui/QLabel>
 #include <QtDBus/QtDBus>
 
 #include <kauthorized.h>
 #include <klibloader.h>
 #include <kaboutdata.h>
-#include <kstaticdeleter.h>
 #include <klocale.h>
 #include <kstatusbar.h>
 #include <kiconloader.h>
@@ -42,10 +47,6 @@
 #include <kconfig.h>
 #include <kio/authinfo.h>
 
-#include "kjavaappletwidget.h"
-#include "kjavaappletviewer.h"
-#include "kjavaappletserver.h"
-
 
 K_EXPORT_COMPONENT_FACTORY (kjavaappletviewer, KJavaAppletViewerFactory)
 
@@ -71,7 +72,6 @@ KParts::Part *KJavaAppletViewerFactory::createPartObject
 //-----------------------------------------------------------------------------
 
 class KJavaServerMaintainer;
-static KJavaServerMaintainer * serverMaintainer = 0;
 
 class KJavaServerMaintainer {
 public:
@@ -87,6 +87,7 @@ private:
             ContextMap;
     ContextMap m_contextmap;
 };
+K_GLOBAL_STATIC(KJavaServerMaintainer, serverMaintainer)
 
 KJavaServerMaintainer::~KJavaServerMaintainer () {
     delete server;
@@ -107,7 +108,7 @@ KJavaAppletContext * KJavaServerMaintainer::getContext (QObject * w, const QStri
 void KJavaServerMaintainer::releaseContext (QObject * w, const QString & doc) {
     ContextMap::iterator it = m_contextmap.find (qMakePair (w, doc));
     if (it != m_contextmap.end () && --(*it).second <= 0) {
-        kDebug(6100) << "KJavaServerMaintainer::releaseContext" << endl;
+        kDebug(6100) << "KJavaServerMaintainer::releaseContext";
         (*it).first->deleteLater ();
         m_contextmap.erase (it);
     }
@@ -118,8 +119,6 @@ inline void KJavaServerMaintainer::setServer (KJavaAppletServer * s) {
         server = s;
 }
 
-static KStaticDeleter <KJavaServerMaintainer> serverMaintainerDeleter;
-
 //-----------------------------------------------------------------------------
 
 AppletParameterDialog::AppletParameterDialog (KJavaAppletWidget * parent)
@@ -230,10 +229,6 @@ KJavaAppletViewer::KJavaAppletViewer (QWidget * wparent,
    m_statusbar_icon (0L),
    m_closed (true)
 {
-    if (!serverMaintainer) {
-        serverMaintainerDeleter.setObject (serverMaintainer,
-                                           new KJavaServerMaintainer);
-    }
     m_view = new CoverWidget (wparent);
     QString classname, classid, codebase, khtml_codebase, src_param;
     int width = -1;
@@ -250,7 +245,7 @@ KJavaAppletViewer::KJavaAppletViewer (QWidget * wparent,
                 value = value.right (value.length () - 1);
             if (value.at (value.length () - 1) == '\"')
                 value.truncate (value.length () - 1);
-            kDebug(6100) << "name=" << name << " value=" << value << endl;
+            kDebug(6100) << "name=" << name << " value=" << value;
             if (!name.isEmpty()) {
                 const QString name_lower = name.toLower ();
                 if (name == "__KHTML__PLUGINBASEURL") {
@@ -287,7 +282,7 @@ KJavaAppletViewer::KJavaAppletViewer (QWidget * wparent,
     }
     if (!classid.isEmpty ()) {
         applet->setParameter ("CLSID", classid);
-        kDebug(6100) << "classid=" << classid << classid.startsWith("clsid:")<< endl;
+        kDebug(6100) << "classid=" << classid << classid.startsWith("clsid:");
         if (classid.startsWith ("clsid:"))
             // codeBase contains the URL to the plugin page
             khtml_codebase = baseurl;
@@ -339,7 +334,7 @@ KJavaAppletViewer::KJavaAppletViewer (QWidget * wparent,
             call ("checkAuthInfo", params, qlonglong(m_view->topLevelWidget()->winId()));
 
         if (!reply.isValid()) {
-            kWarning() << "Can't communicate with kded_kpasswdserver!" << endl;
+            kWarning() << "Can't communicate with kded_kpasswdserver!";
         } else {
             KIO::AuthInfo authResult;
             QDataStream stream2(reply.value());
@@ -427,7 +422,7 @@ bool KJavaAppletViewer::openUrl (const KUrl & url) {
 }
 
 bool KJavaAppletViewer::closeUrl () {
-    kDebug(6100) << "closeUrl" << endl;
+    kDebug(6100) << "closeUrl";
     m_closed = true;
     KJavaApplet* const applet = m_view->appletWidget ()->applet ();
     if (applet->isCreated ())
@@ -464,7 +459,7 @@ void KJavaAppletViewer::infoMessage (const QString & msg) {
 }
 
 KAboutData* KJavaAppletViewer::createAboutData () {
-    return new KAboutData("KJavaAppletViewer", I18N_NOOP("KDE Java Applet Plugin"), "1.0");
+    return new KAboutData("KJavaAppletViewer", 0, ki18n("KDE Java Applet Plugin"), "1.0");
 }
 
 //---------------------------------------------------------------------
@@ -483,7 +478,7 @@ void KJavaAppletViewerBrowserExtension::setLoadingProgress (int percentage) {
     emit loadingProgress (percentage);
 }
 
-void KJavaAppletViewerBrowserExtension::setURLArgs (const KParts::URLArgs & /*args*/) {
+void KJavaAppletViewerBrowserExtension::setBrowserArguments (const KParts::BrowserArguments & /*args*/) {
 }
 
 void KJavaAppletViewerBrowserExtension::saveState (QDataStream & stream) {
@@ -516,7 +511,7 @@ void KJavaAppletViewerBrowserExtension::restoreState (QDataStream & stream) {
         stream >> key;
         stream >> val;
         applet->setParameter (key, val);
-        kDebug(6100) << "restoreState key:" << key << " val:" << val << endl;
+        kDebug(6100) << "restoreState key:" << key << " val:" << val;
     }
     applet->setSize (w->sizeHint ());
     if (w->isVisible())
@@ -526,9 +521,9 @@ void KJavaAppletViewerBrowserExtension::restoreState (QDataStream & stream) {
 void KJavaAppletViewerBrowserExtension::showDocument (const QString & doc,
                                                       const QString & frame) {
     const KUrl url (doc);
-    KParts::URLArgs args;
-    args.frameName = frame;
-    emit openUrlRequest (url, args);
+    KParts::BrowserArguments browserArgs;
+    browserArgs.frameName = frame;
+    emit openUrlRequest(url, KParts::OpenUrlArguments(), browserArgs);
 }
 
 //-----------------------------------------------------------------------------
