@@ -1,4 +1,3 @@
-// -*- c-basic-offset: 2 -*-
 /* This file is part of the KDE project
  *
  * Copyright (C) 2000-2003 Simon Hausmann <hausmann@kde.org>
@@ -25,7 +24,6 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include <assert.h>
 #include "khtml_ext.h"
 #include "khtmlview.h"
 #include "khtml_pagecache.h"
@@ -35,18 +33,19 @@
 #include "misc/loader.h"
 #include "dom/html_form.h"
 #include "dom/html_image.h"
-#include <qclipboard.h>
-#include <qfileinfo.h>
-#include <qmenu.h>
-#include <qurl.h>
-#include <qmetaobject.h>
+#include <QtGui/QClipboard>
+#include <QtCore/QFileInfo>
+#include <QtGui/QMenu>
+#include <QtCore/QUrl>
+#include <QtCore/QMetaEnum>
+#include <assert.h>
 
 #include <kdebug.h>
 #include <klocale.h>
 #include <kfiledialog.h>
 #include <kjobuidelegate.h>
 #include <kio/job.h>
-#include <kprocess.h>
+#include <kshell.h>
 #include <ktoolbar.h>
 #include <ksavefile.h>
 #include <kstringhandler.h>
@@ -95,13 +94,13 @@ int KHTMLPartBrowserExtension::yOffset()
 
 void KHTMLPartBrowserExtension::saveState( QDataStream &stream )
 {
-  //kDebug( 6050 ) << "saveState!" << endl;
+  //kDebug( 6050 ) << "saveState!";
   m_part->saveState( stream );
 }
 
 void KHTMLPartBrowserExtension::restoreState( QDataStream &stream )
 {
-  //kDebug( 6050 ) << "restoreState!" << endl;
+  //kDebug( 6050 ) << "restoreState!";
   m_part->restoreState( stream );
 }
 
@@ -215,7 +214,7 @@ void KHTMLPartBrowserExtension::copy()
         return;
     }
 
-    kDebug( 6050 ) << "************! KHTMLPartBrowserExtension::copy()" << endl;
+    kDebug( 6050 ) << "************! KHTMLPartBrowserExtension::copy()";
     if ( !m_editableFormWidget )
     {
         // get selected text and paste to the clipboard
@@ -270,23 +269,24 @@ void KHTMLPartBrowserExtension::searchProvider()
 
     if( !KUriFilter::self()->filterUri(data, list) )
     {
-        KDesktopFile file("searchproviders/google.desktop", true, "services");
+        KDesktopFile file("services", "searchproviders/google.desktop");
         QString encodedSearchTerm = QUrl::toPercentEncoding(m_part->selectedText());
-	data.setData(file.readEntry("Query").replace("\\{@}", encodedSearchTerm));
+        KConfigGroup cg(file.desktopGroup());
+        data.setData(cg.readEntry("Query").replace("\\{@}", encodedSearchTerm));
     }
 
-    KParts::URLArgs args;
-    args.frameName = "_blank";
+    KParts::BrowserArguments browserArgs;
+    browserArgs.frameName = "_blank";
 
-    emit m_part->browserExtension()->openUrlRequest( data.uri(), args );
+    emit m_part->browserExtension()->openUrlRequest( data.uri(), KParts::OpenUrlArguments(), browserArgs );
 }
 
 void KHTMLPartBrowserExtension::openSelection()
 {
-    KParts::URLArgs args;
-    args.frameName = "_blank";
+    KParts::BrowserArguments browserArgs;
+    browserArgs.frameName = "_blank";
 
-    emit m_part->browserExtension()->openUrlRequest( m_part->selectedText(), args );
+    emit m_part->browserExtension()->openUrlRequest( m_part->selectedText(), KParts::OpenUrlArguments(), browserArgs );
 }
 
 void KHTMLPartBrowserExtension::paste()
@@ -342,7 +342,7 @@ void KHTMLPartBrowserExtension::updateEditActions()
         if ( qobject_cast<QLineEdit*>(m_editableFormWidget))
             hasSelection = static_cast<QLineEdit *>( &(*m_editableFormWidget) )->hasSelectedText();
         else if(qobject_cast<QTextEdit*>(m_editableFormWidget))
-            hasSelection = static_cast<QTextEdit *>( &(*m_editableFormWidget) )->hasSelectedText();
+            hasSelection = static_cast<QTextEdit *>( &(*m_editableFormWidget) )->textCursor().hasSelection();
     }
 
     enableAction( "copy", hasSelection );
@@ -434,9 +434,9 @@ KHTMLPopupGUIClient::KHTMLPopupGUIClient( KHTMLPart *khtml, const QString &doc,
 
       // Fill search provider entries
       KConfig config("kuriikwsfilterrc");
-      config.setGroup("General");
-      const QString defaultEngine = config.readEntry("DefaultSearchEngine", "google");
-      const char keywordDelimiter = config.readEntry("KeywordDelimiter", static_cast<int>(':'));
+      KConfigGroup cg = config.group("General");
+      const QString defaultEngine = cg.readEntry("DefaultSearchEngine", "google");
+      const char keywordDelimiter = cg.readEntry("KeywordDelimiter", static_cast<int>(':'));
 
       // search text
       QString selectedText = khtml->selectedText();
@@ -461,7 +461,7 @@ KHTMLPopupGUIClient::KHTMLPopupGUIClient( KHTMLPart *khtml, const QString &doc,
       {
         QString iconPath = KStandardDirs::locate("cache", KMimeType::favIconForUrl(data.uri()) + ".png");
         if ( iconPath.isEmpty() )
-          icon = SmallIcon("find");
+          icon = SmallIcon("edit-find");
         else
           icon = QPixmap( iconPath );
         name = service->name();
@@ -480,7 +480,7 @@ KHTMLPopupGUIClient::KHTMLPopupGUIClient( KHTMLPart *khtml, const QString &doc,
       // favorite search providers
       QStringList favoriteEngines;
       favoriteEngines << "google" << "google_groups" << "google_news" << "webster" << "dmoz" << "wikipedia";
-      favoriteEngines = config.readEntry("FavoriteSearchEngines", favoriteEngines);
+      favoriteEngines = cg.readEntry("FavoriteSearchEngines", favoriteEngines);
 
       if ( !favoriteEngines.isEmpty()) {
         KActionMenu* providerList = new KActionMenu( i18n( "Search for '%1' with" ,  selectedText ), this );
@@ -500,7 +500,7 @@ KHTMLPopupGUIClient::KHTMLPopupGUIClient( KHTMLPart *khtml, const QString &doc,
           {
             QString iconPath = KStandardDirs::locate("cache", KMimeType::favIconForUrl(data.uri()) + ".png");
             if ( iconPath.isEmpty() )
-              icon = SmallIcon("find");
+              icon = SmallIcon("edit-find");
             else
               icon = QPixmap( iconPath );
             name = service->name();
@@ -519,7 +519,7 @@ KHTMLPopupGUIClient::KHTMLPopupGUIClient( KHTMLPart *khtml, const QString &doc,
       if ( selectedText.contains("://") && KUrl(selectedText).isValid() ) {
          KAction *action = new KAction( i18n( "Open '%1'" ,  selectedText ), this );
          actionCollection()->addAction( "openSelection", action );
-         action->setIcon( KIcon( "window_new" ) );
+         action->setIcon( KIcon( "window-new" ) );
          connect( action, SIGNAL( triggered( bool ) ), d->m_khtml->browserExtension(), SLOT( openSelection() ) );
       }
   }
@@ -559,7 +559,7 @@ KHTMLPopupGUIClient::KHTMLPopupGUIClient( KHTMLPart *khtml, const QString &doc,
     {
       KAction *action = new KAction( i18n( "Open in New &Window" ), this );
       actionCollection()->addAction( "frameinwindow", action );
-      action->setIcon( KIcon( "window_new" ) );
+      action->setIcon( KIcon( "window-new" ) );
       connect( action, SIGNAL( triggered( bool ) ), this, SLOT( slotFrameInWindow() ) );
 
       action = new KAction( i18n( "Open in &This Window" ), this );
@@ -568,7 +568,7 @@ KHTMLPopupGUIClient::KHTMLPopupGUIClient( KHTMLPart *khtml, const QString &doc,
 
       action = new KAction( i18n( "Open in &New Tab" ), this );
       actionCollection()->addAction( "frameintab", action );
-      action->setIcon( KIcon( "tab_new" ) );
+      action->setIcon( KIcon( "tab-new" ) );
       connect( action, SIGNAL( triggered( bool ) ), this, SLOT( slotFrameInTab() ) );
 
       action = new KAction( i18n( "Reload Frame" ), this );
@@ -596,7 +596,7 @@ KHTMLPopupGUIClient::KHTMLPopupGUIClient( KHTMLPart *khtml, const QString &doc,
       // But leave this here, so that it's easy to read it.
       action = new KAction( i18n( "Print Frame..." ), this );
       actionCollection()->addAction( "printFrame", action );
-      action->setIcon( KIcon( "frameprint" ) );
+      action->setIcon( KIcon( "print-frame" ) );
       connect( action, SIGNAL( triggered( bool ) ), d->m_khtml->browserExtension(), SLOT( print() ) );
       action = new KAction( i18n( "Save &Frame As..." ), this );
       actionCollection()->addAction( "saveFrame", action );
@@ -727,7 +727,7 @@ void KHTMLPopupGUIClient::slotBlockImage()
     bool ok = false;
 
     QString url = KInputDialog::getText( i18n("Add URL to Filter"),
-                                         "Enter the URL:",
+                                         i18n("Enter the URL:"),
                                          d->m_imageURL.url(),
                                          &ok);
     if ( ok ) {
@@ -740,7 +740,7 @@ void KHTMLPopupGUIClient::slotBlockIFrame()
 {
     bool ok = false;
     QString url = KInputDialog::getText( i18n( "Add URL to Filter"),
-                                               "Enter the URL:",
+                                               i18n("Enter the URL:"),
                                                d->m_khtml->url().url(),
                                                &ok );
     if ( ok ) {
@@ -790,7 +790,7 @@ void KHTMLPopupGUIClient::slotCopyImage()
   safeURL.populateMimeData( mimeData );
   QApplication::clipboard()->setMimeData( mimeData, QClipboard::Selection );
 #else
-  kDebug() << "slotCopyImage called when the clipboard does not support this.  This should not be possible." << endl;
+  kDebug() << "slotCopyImage called when the clipboard does not support this.  This should not be possible.";
 #endif
 }
 
@@ -818,18 +818,18 @@ void KHTMLPopupGUIClient::slotViewImage()
 
 void KHTMLPopupGUIClient::slotReloadFrame()
 {
-  KParts::URLArgs args( d->m_khtml->browserExtension()->urlArgs() );
-  args.reload = true;
+  KParts::OpenUrlArguments args = d->m_khtml->arguments();
+  args.setReload( true );
   args.metaData()["referrer"] = d->m_khtml->pageReferrer();
   // reload document
   d->m_khtml->closeUrl();
-  d->m_khtml->browserExtension()->setUrlArgs( args );
+  d->m_khtml->setArguments( args );
   d->m_khtml->openUrl( d->m_khtml->url() );
 }
 
 void KHTMLPopupGUIClient::slotFrameInWindow()
 {
-  KParts::URLArgs args( d->m_khtml->browserExtension()->urlArgs() );
+  KParts::OpenUrlArguments args = d->m_khtml->arguments();
   args.metaData()["referrer"] = d->m_khtml->pageReferrer();
   args.metaData()["forcenewwindow"] = "true";
   emit d->m_khtml->browserExtension()->createNewWindow( d->m_khtml->url(), args );
@@ -837,18 +837,20 @@ void KHTMLPopupGUIClient::slotFrameInWindow()
 
 void KHTMLPopupGUIClient::slotFrameInTop()
 {
-  KParts::URLArgs args( d->m_khtml->browserExtension()->urlArgs() );
+  KParts::OpenUrlArguments args = d->m_khtml->arguments();
   args.metaData()["referrer"] = d->m_khtml->pageReferrer();
-  args.frameName = "_top";
-  emit d->m_khtml->browserExtension()->openUrlRequest( d->m_khtml->url(), args );
+  KParts::BrowserArguments browserArgs( d->m_khtml->browserExtension()->browserArguments() );
+  browserArgs.frameName = "_top";
+  emit d->m_khtml->browserExtension()->openUrlRequest( d->m_khtml->url(), args, browserArgs );
 }
 
 void KHTMLPopupGUIClient::slotFrameInTab()
 {
-  KParts::URLArgs args( d->m_khtml->browserExtension()->urlArgs() );
+  KParts::OpenUrlArguments args = d->m_khtml->arguments();
   args.metaData()["referrer"] = d->m_khtml->pageReferrer();
-  args.setNewTab(true);
-  emit d->m_khtml->browserExtension()->createNewWindow( d->m_khtml->url(), args );
+  KParts::BrowserArguments browserArgs( d->m_khtml->browserExtension()->browserArguments() );
+  browserArgs.setNewTab(true);
+  emit d->m_khtml->browserExtension()->createNewWindow( d->m_khtml->url(), args, browserArgs );
 }
 
 void KHTMLPopupGUIClient::saveURL( QWidget *parent, const QString &caption,
@@ -879,10 +881,10 @@ void KHTMLPopupGUIClient::saveURL( QWidget *parent, const QString &caption,
    } while ( query == KMessageBox::Cancel );
 
   if ( destURL.isValid() )
-    saveURL(url, destURL, metadata, cacheId);
+    saveURL(parent, url, destURL, metadata, cacheId);
 }
 
-void KHTMLPopupGUIClient::saveURL( const KUrl &url, const KUrl &destURL,
+void KHTMLPopupGUIClient::saveURL( QWidget* parent, const KUrl &url, const KUrl &destURL,
                                    const QMap<QString, QString> &metadata,
                                    long cacheId )
 {
@@ -925,13 +927,12 @@ void KHTMLPopupGUIClient::saveURL( const KUrl &url, const KUrl &destURL,
           bool downloadViaKIO = true;
           if ( !url.isLocalFile() )
           {
-            KConfig cfg("konquerorrc", false, false);
-            cfg.setGroup("HTML Settings");
+            KConfigGroup cfg = KSharedConfig::openConfig("konquerorrc", KConfig::NoGlobals)->group("HTML Settings");
             QString downloadManger = cfg.readPathEntry("DownloadManager");
             if (!downloadManger.isEmpty())
             {
                 // then find the download manager location
-                kDebug(1000) << "Using: "<<downloadManger <<" as Download Manager" <<endl;
+                kDebug(1000) << "Using: "<<downloadManger <<" as Download Manager";
                 QString cmd = KStandardDirs::findExe(downloadManger);
                 if (cmd.isEmpty())
                 {
@@ -946,10 +947,10 @@ void KHTMLPopupGUIClient::saveURL( const KUrl &url, const KUrl &destURL,
                     downloadViaKIO = false;
                     KUrl cleanDest = destURL;
                     cleanDest.setPass( QString() ); // don't put password into commandline
-                    cmd += " " + KProcess::quote(url.url()) + " " +
-                           KProcess::quote(cleanDest.url());
-                    kDebug(1000) << "Calling command  "<<cmd<<endl;
-                    KRun::runCommand(cmd);
+                    cmd += ' ' + KShell::quoteArg(url.url()) + ' ' +
+                           KShell::quoteArg(cleanDest.url());
+                    kDebug(1000) << "Calling command  "<<cmd;
+                    KRun::runCommand(cmd, parent->topLevelWidget());
                 }
             }
           }
@@ -986,9 +987,9 @@ const QList<KParts::ReadOnlyPart*> KHTMLPartBrowserHostExtension::frames() const
   return m_part->frames();
 }
 
-bool KHTMLPartBrowserHostExtension::openURLInFrame( const KUrl &url, const KParts::URLArgs &urlArgs )
+bool KHTMLPartBrowserHostExtension::openUrlInFrame(const KUrl &url, const KParts::OpenUrlArguments& arguments, const KParts::BrowserArguments &browserArguments)
 {
-  return m_part->openURLInFrame( url, urlArgs );
+  return m_part->openUrlInFrame( url, arguments, browserArguments );
 }
 
 KParts::BrowserHostExtension* KHTMLPartBrowserHostExtension::findFrameParent( KParts::ReadOnlyPart
