@@ -29,7 +29,7 @@
 
 #include "khtml_part.h"
 
-#include <qpointer.h>
+#include <QtCore/QPointer>
 
 #include <kselectaction.h>
 #include <kio/global.h>
@@ -102,7 +102,7 @@ public:
 
   virtual BrowserHostExtension* findFrameParent( KParts::ReadOnlyPart *callingPart, const QString &frame );
 
-  virtual bool openURLInFrame( const KUrl &url, const KParts::URLArgs &urlArgs );
+    virtual bool openUrlInFrame(const KUrl &url, const KParts::OpenUrlArguments& arguments, const KParts::BrowserArguments &browserArguments);
 
 private:
   KHTMLPart *m_part;
@@ -124,7 +124,7 @@ public:
                        const QString &filter = QString(), long cacheId = 0,
                        const QString &suggestedFilename = QString() );
 
-  static void saveURL( const KUrl &url, const KUrl &destination,
+  static void saveURL( QWidget* parent, const KUrl &url, const KUrl &destination,
                        const QMap<QString, QString> &metaData = KIO::MetaData(),
                        long cacheId = 0 );
 private Q_SLOTS:
