@@ -1,6 +1,7 @@
 /* This file is part of the KDE project
  *
  * Copyright (C) 2000 Waldo Bastian <bastian@kde.org>
+ * Copyright (C) 2007 Nick Shaforostoff <shafff@ukr.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -20,14 +21,15 @@
 
 #include "khtml_pagecache.h"
 
-#include <kstaticdeleter.h>
-#include <ktemporaryfile.h>
+#include <kfilterdev.h>
+#include <QTemporaryFile>
 #include <kstandarddirs.h>
 
-#include <q3intdict.h>
-#include <Q3PtrList>
-#include <qtimer.h>
-#include <qfile.h>
+#include <QQueue>
+#include <Qt3Support/Q3IntDict>
+#include <Qt3Support/Q3PtrList>
+#include <QtCore/QTimer>
+#include <QtCore/QFile>
 #include <errno.h>
 #include <sys/types.h>
 #include <unistd.h>
@@ -48,59 +50,65 @@ public:
   ~KHTMLPageCacheEntry();
 
   void addData(const QByteArray &data);
-
   void endData();
 
-  bool isComplete()
-   { return m_complete; }
+  bool isComplete() {return m_complete;}
+  QString fileName() {return m_fileName;}
 
   KHTMLPageCacheDelivery *fetchData(QObject *recvObj, const char *recvSlot);
 private:
   long m_id;
   bool m_complete;
-  QList<QByteArray> m_data;
-  KTemporaryFile *m_file;
+  QByteArray m_buffer;
+  QIODevice* m_file;
+  QString m_fileName;
 };
 
 class KHTMLPageCachePrivate
 {
 public:
   long newId;
+  bool deliveryActive;
   Q3IntDict<KHTMLPageCacheEntry> dict;
   Q3PtrList<KHTMLPageCacheDelivery> delivery;
-  Q3PtrList<KHTMLPageCacheEntry> expireQueue;
-  bool deliveryActive;
+  QQueue<long> expireQueue;
 };
 
-KHTMLPageCacheEntry::KHTMLPageCacheEntry(long id) : m_id(id), m_complete(false)
+KHTMLPageCacheEntry::KHTMLPageCacheEntry(long id)
+    : m_id(id)
+    , m_complete(false)
 {
-  m_file = new KTemporaryFile();
-  m_file->setPrefix("khtmlcache");
-  m_file->open();
+  //get tmp file name
+  QTemporaryFile* f=new QTemporaryFile(KStandardDirs::locateLocal("tmp", "")+"khtmlcacheXXXXXX.tmp");
+  f->open();
+  m_fileName=f->fileName();
+  f->setAutoRemove(false);
+  delete f;
+
+  m_file = KFilterDev::deviceForFile(m_fileName, "application/x-gzip"/*,false*/);
+  m_file->open(QIODevice::WriteOnly);
 }
 
 KHTMLPageCacheEntry::~KHTMLPageCacheEntry()
 {
   delete m_file;
+  QFile::remove(m_fileName);
 }
 
 
 void
 KHTMLPageCacheEntry::addData(const QByteArray &data)
 {
-  if (m_file->error() == QFile::NoError) {
-    m_file->write(data.data(), data.size());
-  }
+    m_buffer+=data;
 }
 
 void
 KHTMLPageCacheEntry::endData()
 {
   m_complete = true;
-  if (m_file->error() == QFile::NoError) {
-    m_file->flush();
-    m_file->seek(0);
-  }
+ m_file->write(m_buffer);
+ m_buffer.clear();
+ m_file->close();
 }
 
 
@@ -108,23 +116,20 @@ KHTMLPageCacheDelivery *
 KHTMLPageCacheEntry::fetchData(QObject *recvObj, const char *recvSlot)
 {
   // Duplicate fd so that entry can be safely deleted while delivering the data.
-  int fd = dup(m_file->handle());
-  lseek(fd, 0, SEEK_SET);
-  KHTMLPageCacheDelivery *delivery = new KHTMLPageCacheDelivery(fd);
+  KHTMLPageCacheDelivery *delivery=new KHTMLPageCacheDelivery(
+                                                              KFilterDev::deviceForFile (m_fileName, "application/x-gzip")
+                                                             );
+  delivery->file->open(QIODevice::ReadOnly);
+
   recvObj->connect(delivery, SIGNAL(emitData(const QByteArray&)), recvSlot);
   delivery->recvObj = recvObj;
   return delivery;
 }
 
-static KStaticDeleter<KHTMLPageCache> pageCacheDeleter;
-
-KHTMLPageCache *KHTMLPageCache::_self = 0;
-
 KHTMLPageCache *
 KHTMLPageCache::self()
 {
-  if (!_self)
-     _self = pageCacheDeleter.setObject(_self, new KHTMLPageCache);
+  K_GLOBAL_STATIC(KHTMLPageCache, _self)
   return _self;
 }
 
@@ -145,21 +150,19 @@ KHTMLPageCache::~KHTMLPageCache()
 long
 KHTMLPageCache::createCacheEntry()
 {
+
   KHTMLPageCacheEntry *entry = new KHTMLPageCacheEntry(d->newId);
   d->dict.insert(d->newId, entry);
-  d->expireQueue.append(entry);
+  d->expireQueue.append(d->newId);
   if (d->expireQueue.count() > KHTML_PAGE_CACHE_SIZE)
-  {
-     KHTMLPageCacheEntry *entry = d->expireQueue.take(0);
-     d->dict.remove(entry->m_id);
-     delete entry;
-  }
+     delete d->dict.take(d->expireQueue.dequeue());
   return (d->newId++);
 }
 
 void
 KHTMLPageCache::addData(long id, const QByteArray &data)
 {
+
   KHTMLPageCacheEntry *entry = d->dict.find(id);
   if (entry)
      entry->addData(data);
@@ -179,7 +182,7 @@ KHTMLPageCache::cancelEntry(long id)
   KHTMLPageCacheEntry *entry = d->dict.take(id);
   if (entry)
   {
-     d->expireQueue.removeRef(entry);
+     d->expireQueue.removeAll(entry->m_id);
      delete entry;
   }
 }
@@ -206,8 +209,8 @@ KHTMLPageCache::fetchData(long id, QObject *recvObj, const char *recvSlot)
   if (!entry || !entry->isComplete()) return;
 
   // Make this entry the most recent entry.
-  d->expireQueue.removeRef(entry);
-  d->expireQueue.append(entry);
+  d->expireQueue.removeAll(entry->m_id);
+  d->expireQueue.enqueue(entry->m_id);
 
   d->delivery.append( entry->fetchData(recvObj, recvSlot) );
   if (!d->deliveryActive)
@@ -242,31 +245,24 @@ KHTMLPageCache::sendData()
      d->deliveryActive = false;
      return;
   }
+
   KHTMLPageCacheDelivery *delivery = d->delivery.take(0);
   assert(delivery);
 
-  char buf[8192];
-  QByteArray byteArray;
+  QByteArray byteArray(delivery->file->read(64*1024));
+  delivery->emitData(byteArray);
 
-  int n = read(delivery->fd, buf, 8192);
-
-  if ((n < 0) && (errno == EINTR))
+  //put back in queue
+  if (delivery->file->atEnd())
   {
-     // try again later
-     d->delivery.append( delivery );
-  }
-  else if (n <= 0)
-  {
-     // done.
-     delivery->emitData(byteArray); // Empty array
-     delete delivery;
+    // done.
+    delivery->file->close();
+    delivery->emitData(QByteArray()); // Empty array
+    delete delivery;
   }
   else
-  {
-     byteArray = QByteArray(buf, n);
-     delivery->emitData(byteArray);
-     d->delivery.append( delivery );
-  }
+    d->delivery.append( delivery );
+
   QTimer::singleShot(0, this, SLOT(sendData()));
 }
 
@@ -276,40 +272,27 @@ KHTMLPageCache::saveData(long id, QDataStream *str)
   KHTMLPageCacheEntry *entry = d->dict.find(id);
   assert(entry);
 
-  int fd = entry->m_file->handle();
-  if ( fd < 0 ) return;
-
-  off_t pos = lseek(fd, 0, SEEK_CUR);
-  lseek(fd, 0, SEEK_SET);
-
-  char buf[8192];
-
-  while(true)
+  if (!entry->isComplete())
   {
-     int n = read(fd, buf, 8192);
-     if ((n < 0) && (errno == EINTR))
-     {
-        // try again
-        continue;
-     }
-     else if (n <= 0)
-     {
-        // done.
-        break;
-     }
-     else
-     {
-        str->writeRawData(buf, n);
-     }
+      QTimer::singleShot(20, this, SLOT(saveData()));
+      return;
   }
 
-  if (pos != (off_t)-1)
-    lseek(fd, pos, SEEK_SET);
+  QIODevice* file = KFilterDev::deviceForFile (entry->fileName(), "application/x-gzip");
+  if (!file->open(QIODevice::ReadOnly))
+    return;
+
+  QByteArray byteArray(file->readAll());
+  file->close();
+
+  str->writeRawData(byteArray.constData(), byteArray.length());
+
 }
 
 KHTMLPageCacheDelivery::~KHTMLPageCacheDelivery()
 {
-  close(fd);
+  file->close();
+  delete file;
 }
 
 #include "khtml_pagecache.moc"
