@@ -26,7 +26,7 @@
 #ifndef __khtml_part_h__
 #define __khtml_part_h__
 
-#include "dom/html_document.h"
+#include "dom/dom_doc.h"
 #include "dom/dom2_range.h"
 
 #include <kparts/part.h>
@@ -35,7 +35,8 @@
 #include <kfind.h>
 #include <kfinddialog.h>
 #include <klocalizedstring.h>
-#include <qregexp.h>
+#include <kencodingdetector.h>
+#include <QtCore/QRegExp>
 
 class KHTMLPartPrivate;
 class KHTMLPartBrowserExtension;
@@ -51,7 +52,6 @@ namespace DOM
   class HTMLDocumentImpl;
   class DocumentImpl;
   class HTMLTitleElementImpl;
-  class HTMLElementImpl;
   class HTMLFrameElementImpl;
   class HTMLIFrameElementImpl;
   class HTMLObjectElementImpl;
@@ -75,8 +75,7 @@ namespace khtml
   class RenderPart;
   class RenderPartObject;
   class ChildFrame;
-  class MouseEvent;
-  class MousePressEvent;
+    class MousePressEvent;
   class MouseDoubleClickEvent;
   class MouseMoveEvent;
   class MouseReleaseEvent;
@@ -85,7 +84,6 @@ namespace khtml
   class RenderWidget;
   class CSSStyleSelector;
   class HTMLTokenizer;
-  class Decoder;
   class XMLTokenizer;
 }
 
@@ -737,8 +735,7 @@ public:
 
   /**
    * Sets the Zoom factor. The value is given in percent, larger values mean a
-   * generally larger font and larger page contents. It is not guaranteed that
-   * all parts of the page are scaled with the same factor though.
+   * generally larger font and larger page contents.
    *
    * The given value should be in the range of 20..300, values outside that
    * range are not guaranteed to work. A value of 100 will disable all zooming
@@ -752,6 +749,22 @@ public:
    */
   int zoomFactor() const;
 
+  /**
+   * Sets the scale factor to be applied to fonts. The value is given in percent, 
+   * larger values mean generally larger fonts.
+   *
+   * The given value should be in the range of 20..300, values outside that
+   * range are not guaranteed to work. A value of 100 will disable all scaling of font sizes
+   * and show the page with the sizes determined via the given lengths in the
+   * stylesheets.
+   */
+  void setFontScaleFactor(int percent);
+
+  /**
+   * Returns the current font scale factor.
+   */
+  int fontScaleFactor() const;
+
   /**
    * Returns the text the user has marked.
    */
@@ -1130,8 +1143,10 @@ protected:
    */
   virtual bool openFile();
 
-  virtual void urlSelected( const QString &url, int button, int state,
-                            const QString &_target, KParts::URLArgs args = KParts::URLArgs());
+  virtual bool urlSelected( const QString &url, int button, int state,
+                            const QString &_target,
+                            const KParts::OpenUrlArguments& args = KParts::OpenUrlArguments(),
+                            const KParts::BrowserArguments& browserArgs = KParts::BrowserArguments() );
 
   /**
    * This method is called when a new embedded object (include html frames) is to be created.
@@ -1340,7 +1355,7 @@ private Q_SLOTS:
   /**
    * @internal
    */
-  virtual void slotSetEncoding();
+  virtual void slotSetEncoding(const QString &);
 
   /**
    * @internal
@@ -1401,7 +1416,7 @@ private Q_SLOTS:
   /**
    * @internal
    */
-  void slotChildURLRequest( const KUrl &url, const KParts::URLArgs &args );
+  void slotChildURLRequest( const KUrl &url, const KParts::OpenUrlArguments&, const KParts::BrowserArguments &args );
   /**
    * @internal
    */
@@ -1466,7 +1481,7 @@ private Q_SLOTS:
   /**
    * @internal
    */
-  void slotAutomaticDetectionLanguage( int _id );
+  void slotAutomaticDetectionLanguage(KEncodingDetector::AutoDetectScript scri);
 
   /**
    * @internal
@@ -1534,9 +1549,7 @@ private:
   void emitSelectionChanged();
   // Returns whether callingHtmlPart may access this part
   bool checkFrameAccess(KHTMLPart *callingHtmlPart);
-  bool openURLInFrame( const KUrl &url, const KParts::URLArgs &urlArgs );
-  bool urlSelectedIntern( const QString &url, int button, int state,
-                          const QString &_target, KParts::URLArgs args = KParts::URLArgs());
+  bool openUrlInFrame(const KUrl &url, const KParts::OpenUrlArguments& arguments, const KParts::BrowserArguments &browserArguments);
   void startAutoScroll();
   void stopAutoScroll();
   void overURL( const QString &url, const QString &target, bool shiftPressed = false );
@@ -1593,7 +1606,9 @@ private:
   bool requestObject( khtml::RenderPart *frame, const QString &url, const QString &serviceType,
                       const QStringList &args = QStringList() );
 
-  bool requestObject( khtml::ChildFrame *child, const KUrl &url, const KParts::URLArgs &args = KParts::URLArgs() );
+  bool requestObject( khtml::ChildFrame *child, const KUrl &url,
+                      const KParts::OpenUrlArguments &args = KParts::OpenUrlArguments(),
+                      const KParts::BrowserArguments& browserArgs = KParts::BrowserArguments() );
 
   DOM::EventListener *createHTMLEventListener( QString code, QString name, DOM::NodeImpl *node );
 
@@ -1601,7 +1616,9 @@ private:
   DOM::DocumentImpl *xmlDocImpl() const;
   khtml::ChildFrame *frame( const QObject *obj );
 
-  khtml::ChildFrame *recursiveFrameRequest( KHTMLPart *callingHtmlPart, const KUrl &url, const KParts::URLArgs &args, bool callParent = true );
+  khtml::ChildFrame *recursiveFrameRequest( KHTMLPart *callingHtmlPart, const KUrl &url,
+                                            const KParts::OpenUrlArguments& args, const KParts::BrowserArguments &browserArgs,
+                                            bool callParent = true );
 
   bool checkLinkSecurity( const KUrl &linkURL,const KLocalizedString &message = KLocalizedString(), const QString &button = QString() );
   QVariant executeScript( const QString& filename, int baseLine, const DOM::Node &n, const QString& script );
@@ -1634,7 +1651,7 @@ private:
    * @return @p true if a selection is extended by the mouse.
    */
   bool isExtendingSelection() const;
-  khtml::Decoder *createDecoder();
+  KEncodingDetector *createDecoder();
   QString defaultEncoding() const;
 
   /** .html, .xhtml or .xml */
