@@ -27,7 +27,7 @@
 #include "misc/loader.h"
 
 
-#include <qtimer.h>
+#include <QtCore/QTimer>
 
 #include <kjobuidelegate.h>
 #include <kio/job.h>
@@ -39,7 +39,7 @@
 
 // Export init_khtmlimagefactory. This way we don't have to export the whole class
 // just for khtmlimagepart. See khtmlimage_init.cpp
-K_EXPORT_COMPONENT_FACTORY( khtmlimagefactory, KHTMLImageFactory )
+K_EXPORT_COMPONENT_FACTORY(khtmlimagepart, KHTMLImageFactory)
 
 KComponentData *KHTMLImageFactory::s_componentData = 0;
 
@@ -95,12 +95,11 @@ KHTMLImage::KHTMLImage( QWidget *parentWidget,
     // forward opening requests to parent frame (if existing)
     KHTMLPart *p = qobject_cast<KHTMLPart*>(parent);
     KParts::BrowserExtension *be = p ? p->browserExtension() : m_ext;
-    connect(m_khtml->browserExtension(), SIGNAL(openUrlRequestDelayed(const KUrl &, const KParts::URLArgs &)),
-    		be, SIGNAL(openUrlRequestDelayed(const KUrl &, const KParts::URLArgs &)));
+    connect(m_khtml->browserExtension(), SIGNAL(openUrlRequestDelayed(const KUrl &, const KParts::OpenUrlArguments&, const KParts::BrowserArguments &)),
+    		be, SIGNAL(openUrlRequestDelayed(const KUrl &, const KParts::OpenUrlArguments&, const KParts::BrowserArguments &)));
 
-    connect( m_khtml->browserExtension(), SIGNAL( popupMenu( KXMLGUIClient *, const QPoint &, const KUrl &,
-             const KParts::URLArgs &, KParts::BrowserExtension::PopupFlags, mode_t) ), m_ext, SIGNAL( popupMenu( KXMLGUIClient *, const QPoint &, const KUrl &,
-             const KParts::URLArgs &, KParts::BrowserExtension::PopupFlags, mode_t) ) );
+    connect( m_khtml->browserExtension(), SIGNAL( popupMenu(KXMLGUIClient *, const QPoint &, const KUrl &, const KParts::OpenUrlArguments &, const KParts::BrowserArguments &, KParts::BrowserExtension::PopupFlags, mode_t) ),
+             m_ext, SIGNAL( popupMenu(KXMLGUIClient *, const QPoint &, const KUrl &, const KParts::OpenUrlArguments &, const KParts::BrowserArguments &, KParts::BrowserExtension::PopupFlags, mode_t) ) );
 
     connect( m_khtml->browserExtension(), SIGNAL( enableAction( const char *, bool ) ),
              m_ext, SIGNAL( enableAction( const char *, bool ) ) );
@@ -129,34 +128,34 @@ bool KHTMLImage::openUrl( const KUrl &url )
 
     disposeImage();
 
-    m_url = url;
+    setUrl(url);
 
     emit started( 0 );
 
-    KParts::URLArgs args = m_ext->urlArgs();
-    m_mimeType = args.serviceType;
+    KParts::OpenUrlArguments args = arguments();
+    m_mimeType = args.mimeType();
 
     emit setWindowCaption( url.prettyUrl() );
 
     // Need to keep a copy of the offsets since they are cleared when emitting completed
-    m_xOffset = args.xOffset;
-    m_yOffset = args.yOffset;
+    m_xOffset = args.xOffset();
+    m_yOffset = args.yOffset();
 
-    m_khtml->begin( m_url );
+    m_khtml->begin( this->url() );
     m_khtml->setAutoloadImages( true );
 
     DOM::DocumentImpl *impl = dynamic_cast<DOM::DocumentImpl *>( m_khtml->document().handle() ); // ### hack ;-)
     if (!impl) return false;
 
-    if ( m_ext->urlArgs().reload )
+    if ( arguments().reload() )
         impl->docLoader()->setCachePolicy( KIO::CC_Reload );
 
     khtml::DocLoader *dl = impl->docLoader();
-    m_image = dl->requestImage( m_url.url() );
+    m_image = dl->requestImage( this->url().url() );
     if ( m_image )
         m_image->ref( this );
 
-    m_khtml->write( html.arg( m_url.url() ) );
+    m_khtml->write( html.arg( this->url().url() ) );
     m_khtml->end();
 
     /*
