@@ -34,11 +34,11 @@
 #include <kparts/statusbarextension.h>
 #include <kparts/browserextension.h>
 
-#include <qdatetime.h>
-#include <qpointer.h>
-#include <qmap.h>
-#include <qtimer.h>
-#include <q3valuelist.h>
+#include <QtCore/QDate>
+#include <QtCore/QPointer>
+#include <QtCore/QMap>
+#include <QtCore/QTimer>
+#include <QtCore/QList>
 
 #include "html/html_formimpl.h"
 #include "khtml_run.h"
@@ -46,17 +46,15 @@
 #include "khtml_events.h"
 #include "khtml_ext.h"
 #include "khtml_settings.h"
-#include "misc/decoder.h"
+#include <kencodingdetector.h>
 #include "ecma/kjs_proxy.h"
 
 class KFind;
 class KFindDialog;
-class KMenu;
-class KSelectAction;
+class KCodecAction;
 class KUrlLabel;
 class KJavaAppletContext;
 class KJSErrorDlg;
-class KActionMenu;
 class KToggleAction;
 
 namespace KIO
@@ -104,12 +102,13 @@ namespace khtml
     KLibrary *m_kjs_lib;
     bool m_bCompleted;
     QString m_name;
-    KParts::URLArgs m_args;
+    KParts::OpenUrlArguments m_args;
+    KParts::BrowserArguments m_browserArgs;
     QPointer<KHTMLRun> m_run;
-    bool m_bPreloaded;
     KUrl m_workingURL;
     Type m_type;
     QStringList m_params;
+    bool m_bPreloaded;
     bool m_bNotify;
     bool m_bPendingRedirection;
   protected Q_SLOTS:
@@ -118,7 +117,7 @@ namespace khtml
 
 }
 
-struct KHTMLFrameList : public Q3ValueList<khtml::ChildFrame*>
+struct KHTMLFrameList : public QList<khtml::ChildFrame*>
 {
     Iterator find( const QString &name ) KDE_NO_EXPORT;
 };
@@ -150,11 +149,12 @@ public:
     m_bClearing = false;
     m_bCleared = false;
     m_zoomFactor = 100;
+    m_fontScaleFactor = 100;
     m_bDnd = true;
     m_startOffset = m_endOffset = 0;
     m_startBeforeEnd = true;
     m_extendAtEnd = true;
-    m_linkCursor = KCursor::handCursor();
+    m_linkCursor = QCursor(Qt::PointingHandCursor);
     m_loadedObjects = 0;
     m_totalObjectCount = 0;
     m_jobPercent = 0;
@@ -195,7 +195,7 @@ public:
     m_bFirstData = true;
     m_submitForm = 0;
     m_delayRedirect = 0;
-    m_autoDetectLanguage = khtml::Decoder::SemiautomaticDetection;
+    m_autoDetectLanguage = KEncodingDetector::SemiautomaticDetection;
 
     // inherit settings from parent
     if(parent && parent->inherits("KHTMLPart"))
@@ -215,6 +215,7 @@ public:
             m_caretMode = part->d->m_caretMode;
             m_designMode = part->d->m_designMode;
             m_zoomFactor = part->d->m_zoomFactor;
+            m_fontScaleFactor = part->d->m_fontScaleFactor;
             m_autoDetectLanguage = part->d->m_autoDetectLanguage;
             m_encoding = part->d->m_encoding;
             m_haveEncoding = part->d->m_haveEncoding;
@@ -264,7 +265,8 @@ public:
   QList<KHTMLPart *> m_suppressedPopupOriginParts;
   int m_openableSuppressedPopups;
   DOM::DocumentImpl *m_doc;
-  khtml::Decoder *m_decoder;
+  KEncodingDetector::AutoDetectScript m_autoDetectLanguage;
+  KEncodingDetector *m_decoder;
   QString m_encoding;
   QString m_sheetUsed;
   qlonglong m_cacheId;
@@ -311,7 +313,6 @@ public:
 
   // QStrings for SSL metadata
   // Note: When adding new variables don't forget to update ::saveState()/::restoreState()!
-  bool m_ssl_in_use;
   QString m_ssl_peer_certificate,
           m_ssl_peer_chain,
           m_ssl_peer_ip,
@@ -323,6 +324,7 @@ public:
           m_ssl_cert_state,
           m_ssl_parent_ip,
           m_ssl_parent_cert;
+  bool m_ssl_in_use;
 
   bool m_bComplete;
   bool m_bLoadEventEmitted;
@@ -344,7 +346,7 @@ public:
   QAction *m_paSaveBackground;
   QAction *m_paSaveDocument;
   QAction *m_paSaveFrame;
-  KActionMenu *m_paSetEncoding;
+  KCodecAction *m_paSetEncoding;
   KSelectAction *m_paUseStylesheet;
   KSelectAction *m_paIncZoomFactor;
   KSelectAction *m_paDecZoomFactor;
@@ -369,6 +371,7 @@ public:
   KHTMLPart::GUIProfile m_guiProfile;
 
   int m_zoomFactor;
+  int m_fontScaleFactor;
 
   QString m_strSelectedURL;
   QString m_strSelectedURLTarget;
@@ -408,9 +411,9 @@ public:
   QString m_overURL;
   QString m_overURLTarget;
 
-  bool m_startBeforeEnd;
-  bool m_extendAtEnd;		// true if selection is to be extended at its end
   enum { ExtendByChar, ExtendByWord, ExtendByLine } m_extendMode;
+  bool m_extendAtEnd;		// true if selection is to be extended at its end
+  bool m_startBeforeEnd;
   bool m_bDnd;
   bool m_bFirstData;
   bool m_bClearing;
@@ -491,10 +494,6 @@ public:
   bool m_openedByJS;
   bool m_newJSInterpreterExists; // set to 1 by setOpenedByJS, for window.open
 
-  khtml::Decoder::AutoDetectLanguage m_autoDetectLanguage;
-  KMenu *m_automaticDetection;
-  KSelectAction *m_manualDetection;
-
   void setFlagRecursively(bool KHTMLPartPrivate::*flag, bool value);
   /** returns the caret node */
   DOM::Node &caretNode() {
