@@ -26,10 +26,10 @@
 #ifndef KHTMLVIEW_H
 #define KHTMLVIEW_H
 
-// qt includes and classes
-#include <QScrollArea>
+#include <khtml_export.h>
 
-#include <kdelibs_export.h>
+// qt includes and classes
+#include <QtGui/QScrollArea>
 
 class QPainter;
 class QRect;
@@ -39,13 +39,11 @@ namespace DOM {
     class HTMLDocumentImpl;
     class DocumentImpl;
     class ElementImpl;
-    class HTMLElementImpl;
     class HTMLTitleElementImpl;
     class HTMLGenericFormElementImpl;
     class HTMLFormElementImpl;
     class HTMLAnchorElementImpl;
     class HTMLInputElementImpl;
-    class Range;
     class NodeImpl;
     class CSSProperty;
 }
@@ -58,8 +56,7 @@ namespace KJS {
 namespace khtml {
     class RenderObject;
     class RenderCanvas;
-    class RenderStyle;
-    class RenderLineEdit;
+        class RenderLineEdit;
     class RenderPartObject;
     class RenderWidget;
     class CSSStyleSelector;
@@ -715,6 +712,8 @@ private:
     // ------------------------------------- member variables ------------------------------------
  private:
 
+    enum LinkCursor { LINK_NORMAL, LINK_MAILTO, LINK_NEWWINDOW };
+
     void setWidgetVisible(::khtml::RenderWidget*, bool visible);
 
 
