@@ -25,7 +25,7 @@
 #include <klocale.h>
 #include <kjobuidelegate.h>
 #include <kio/job.h>
-#include <qfile.h>
+#include <QtCore/QFile>
 #include <ktemporaryfile.h>
 #include <kmessagebox.h>
 #include <kparts/componentfactory.h>
@@ -33,7 +33,7 @@
 #include <khtml_part.h>
 #include <unistd.h>
 #include <kxmlguifactory.h>
-#include <qtimer.h>
+#include <QtCore/QTimer>
 #include <kvbox.h>
 
 typedef KParts::GenericFactory<KMultiPart> KMultiPartFactory; // factory for the part
@@ -108,8 +108,6 @@ KMultiPart::KMultiPart( QWidget *parentWidget,
 
     m_extension = new KParts::BrowserExtension( this );
 
-    // We probably need to use m_extension to get the urlArgs in openUrl...
-
     m_part = 0L;
     m_isHTMLPart = false;
     m_job = 0L;
@@ -155,17 +153,16 @@ void KMultiPart::startHeader()
 
 bool KMultiPart::openUrl( const KUrl &url )
 {
-    m_url = url;
+    setUrl(url);
     m_lineParser->reset();
     startHeader();
 
-    KParts::URLArgs args = m_extension->urlArgs();
-    //m_mimeType = args.serviceType;
+    //m_mimeType = arguments().mimeType();
 
     // Hmm, args.reload is set to true when reloading, but this doesn't seem to be enough...
     // I get "HOLD: Reusing held slave for <url>", and the old data
 
-    m_job = KIO::get( url, args.reload, false );
+    m_job = KIO::get( url, arguments().reload(), false );
 
     emit started( 0 /*m_job*/ ); // don't pass the job, it would interfere with our own infoMessage
 
@@ -191,7 +188,7 @@ void KMultiPart::slotData( KIO::Job *job, const QByteArray &data )
     if (m_boundary.isNull())
     {
        QString tmp = job->queryMetaData("media-boundary");
-       kDebug() << "Got Boundary from kio-http '" << tmp << "'" << endl;
+       kDebug() << "Got Boundary from kio-http '" << tmp << "'";
        if ( !tmp.isEmpty() ) {
            if (tmp.startsWith(QLatin1String("--")))
                m_boundary = tmp.toLatin1();
@@ -209,7 +206,7 @@ void KMultiPart::slotData( KIO::Job *job, const QByteArray &data )
         {
             QByteArray lineData = m_lineParser->currentLine();
 #ifdef DEBUG_PARSING
-            kDebug() << "lineData.size()=" << lineData.size() << endl;
+            kDebug() << "lineData.size()=" << lineData.size();
 #endif
             QByteArray line( lineData.data(), lineData.size()+1 ); // deep copy
             // 0-terminate the data, but only for the line-based tests below
@@ -218,7 +215,7 @@ void KMultiPart::slotData( KIO::Job *job, const QByteArray &data )
             if ( sz > 0 )
                 line[sz-1] = '\0';
 #ifdef DEBUG_PARSING
-            kDebug() << "[" << m_bParsingHeader << "] line='" << line << "'" << endl;
+            kDebug() << "[" << m_bParsingHeader << "] line='" << line << "'";
 #endif
             if ( m_bParsingHeader )
             {
@@ -228,7 +225,7 @@ void KMultiPart::slotData( KIO::Job *job, const QByteArray &data )
                 {
                     if ( !line.isEmpty() ) {
 #ifdef DEBUG_PARSING
-                        kDebug() << "Boundary is " << line << endl;
+                        kDebug() << "Boundary is " << line;
 #endif
                         m_boundary = line;
                         m_boundaryLength = m_boundary.length();
@@ -240,7 +237,7 @@ void KMultiPart::slotData( KIO::Job *job, const QByteArray &data )
                     if (encoding == "gzip" || encoding == "x-gzip") {
                         m_gzip = true;
                     } else {
-                        kDebug() << "FIXME: unhandled encoding type in KMultiPart: " << encoding << endl;
+                        kDebug() << "FIXME: unhandled encoding type in KMultiPart: " << encoding;
                     }
                 }
                 // parse Content-Type
@@ -251,14 +248,14 @@ void KMultiPart::slotData( KIO::Job *job, const QByteArray &data )
                     int semicolon = m_nextMimeType.indexOf( ';' );
                     if ( semicolon != -1 )
                         m_nextMimeType = m_nextMimeType.left( semicolon );
-                    kDebug() << "m_nextMimeType=" << m_nextMimeType << endl;
+                    kDebug() << "m_nextMimeType=" << m_nextMimeType;
                 }
                 // Empty line, end of headers (if we had any header line before)
                 else if ( line.isEmpty() && m_bGotAnyHeader )
                 {
                     m_bParsingHeader = false;
 #ifdef DEBUG_PARSING
-                    kDebug() << "end of headers" << endl;
+                    kDebug() << "end of headers";
 #endif
                     startOfData();
                 }
@@ -266,19 +263,19 @@ void KMultiPart::slotData( KIO::Job *job, const QByteArray &data )
                 else if ( line == m_boundary )
                     ; // nothing to do
                 else if ( !line.isEmpty() ) // this happens with e.g. Set-Cookie:
-                    kDebug() << "Ignoring header " << line << endl;
+                    kDebug() << "Ignoring header " << line;
             } else {
                 if ( !qstrncmp( line, m_boundary, m_boundaryLength ) )
                 {
 #ifdef DEBUG_PARSING
-                    kDebug() << "boundary found!" << endl;
-                    kDebug() << "after it is " << line.data() + m_boundaryLength << endl;
+                    kDebug() << "boundary found!";
+                    kDebug() << "after it is " << line.data() + m_boundaryLength;
 #endif
                     // Was it the very last boundary ?
                     if ( !qstrncmp( line.data() + m_boundaryLength, "--", 2 ) )
                     {
 #ifdef DEBUG_PARSING
-                        kDebug() << "Completed!" << endl;
+                        kDebug() << "Completed!";
 #endif
                         endOfData();
                         emit completed();
@@ -286,7 +283,7 @@ void KMultiPart::slotData( KIO::Job *job, const QByteArray &data )
                     {
                         char nextChar = *(line.data() + m_boundaryLength);
 #ifdef DEBUG_PARSING
-                        kDebug() << "KMultiPart::slotData nextChar='" << nextChar << "'" << endl;
+                        kDebug() << "KMultiPart::slotData nextChar='" << nextChar << "'";
 #endif
                         if ( nextChar == '\n' || nextChar == '\r' ) {
                             endOfData();
@@ -312,7 +309,7 @@ void KMultiPart::setPart( const QString& mimeType )
     KXMLGUIFactory *guiFactory = factory();
     if ( guiFactory ) // seems to be 0 when restoring from SM
         guiFactory->removeClient( this );
-    kDebug() << "KMultiPart::setPart " << mimeType << endl;
+    kDebug() << "KMultiPart::setPart " << mimeType;
     delete m_part;
     // Try to find an appropriate viewer component
     m_part = KParts::ComponentFactory::createPartInstanceFromQuery<KParts::ReadOnlyPart>
@@ -341,27 +338,25 @@ void KMultiPart::setPart( const QString& mimeType )
         connect( childExtension, SIGNAL( openURLNotify() ),
                  m_extension, SIGNAL( openURLNotify() ) );
 
-        connect( childExtension, SIGNAL( openUrlRequestDelayed( const KUrl &, const KParts::URLArgs & ) ),
-                 m_extension, SIGNAL( openUrlRequest( const KUrl &, const KParts::URLArgs & ) ) );
+        connect( childExtension, SIGNAL( openUrlRequestDelayed( const KUrl &, const KParts::OpenUrlArguments&, const KParts::BrowserArguments& ) ),
+                 m_extension, SIGNAL( openUrlRequest( const KUrl &, const KParts::OpenUrlArguments&, const KParts::BrowserArguments & ) ) );
 
-        connect( childExtension, SIGNAL( createNewWindow( const KUrl &, const KParts::URLArgs & ) ),
-                 m_extension, SIGNAL( createNewWindow( const KUrl &, const KParts::URLArgs & ) ) );
-        connect( childExtension, SIGNAL( createNewWindow( const KUrl &, const KParts::URLArgs &, const KParts::WindowArgs &, KParts::ReadOnlyPart *& ) ),
-                 m_extension, SIGNAL( createNewWindow( const KUrl &, const KParts::URLArgs & , const KParts::WindowArgs &, KParts::ReadOnlyPart *&) ) );
+        connect( childExtension, SIGNAL( createNewWindow( const KUrl &, const KParts::OpenUrlArguments&, const KParts::BrowserArguments&, const KParts::WindowArgs &, KParts::ReadOnlyPart** ) ),
+                 m_extension, SIGNAL( createNewWindow( const KUrl &, const KParts::OpenUrlArguments&, const KParts::BrowserArguments& , const KParts::WindowArgs &, KParts::ReadOnlyPart**) ) );
 
         // Keep in sync with khtml_part.cpp
         connect( childExtension, SIGNAL( popupMenu( const QPoint &, const KFileItemList & ) ),
                  m_extension, SIGNAL( popupMenu( const QPoint &, const KFileItemList & ) ) );
         connect( childExtension, SIGNAL( popupMenu( KXMLGUIClient *, const QPoint &, const KFileItemList & ) ),
                  m_extension, SIGNAL( popupMenu( KXMLGUIClient *, const QPoint &, const KFileItemList & ) ) );
-        connect( childExtension, SIGNAL( popupMenu( KXMLGUIClient *, const QPoint &, const KFileItemList &, const KParts::URLArgs &, KParts::BrowserExtension::PopupFlags ) ),
-                 m_extension, SIGNAL( popupMenu( KXMLGUIClient *, const QPoint &, const KFileItemList &, const KParts::URLArgs &, KParts::BrowserExtension::PopupFlags ) ) );
+        connect( childExtension, SIGNAL( popupMenu(KXMLGUIClient *, const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &, const KParts::BrowserArguments &, KParts::BrowserExtension::PopupFlags) ),
+                 m_extension, SIGNAL( popupMenu(KXMLGUIClient *, const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &, const KParts::BrowserArguments &, KParts::BrowserExtension::PopupFlags) ) );
         connect( childExtension, SIGNAL( popupMenu( const QPoint &, const KUrl &, const QString &, mode_t ) ),
                  m_extension, SIGNAL( popupMenu( const QPoint &, const KUrl &, const QString &, mode_t ) ) );
         connect( childExtension, SIGNAL( popupMenu( KXMLGUIClient *, const QPoint &, const KUrl &, const QString &, mode_t ) ),
                  m_extension, SIGNAL( popupMenu( KXMLGUIClient *, const QPoint &, const KUrl &, const QString &, mode_t ) ) );
-        connect( childExtension, SIGNAL( popupMenu( KXMLGUIClient *, const QPoint &, const KUrl &, const KParts::URLArgs &, KParts::BrowserExtension::PopupFlags, mode_t ) ),
-                 m_extension, SIGNAL( popupMenu( KXMLGUIClient *, const QPoint &, const KUrl &, const KParts::URLArgs &, KParts::BrowserExtension::PopupFlags, mode_t ) ) );
+        connect( childExtension, SIGNAL( popupMenu(KXMLGUIClient *, const QPoint &, const KUrl &, const KParts::OpenUrlArguments &, const KParts::BrowserArguments &, KParts::BrowserExtension::PopupFlags, mode_t) ),
+                 m_extension, SIGNAL( popupMenu(KXMLGUIClient *, const QPoint &, const KUrl &, const KParts::OpenUrlArguments &, const KParts::BrowserArguments &, KParts::BrowserExtension::PopupFlags, mode_t) ) );
 
 
         if ( m_isHTMLPart )
@@ -408,7 +403,7 @@ void KMultiPart::setPart( const QString& mimeType )
 
 void KMultiPart::startOfData()
 {
-    kDebug() << "KMultiPart::startOfData" << endl;
+    kDebug() << "KMultiPart::startOfData";
     Q_ASSERT( !m_nextMimeType.isNull() );
     if( m_nextMimeType.isNull() )
         return;
@@ -426,10 +421,11 @@ void KMultiPart::startOfData()
         setPart( m_mimeType );
     }
     Q_ASSERT( m_part );
-    // Pass URLArgs (e.g. reload)
+    // Pass args (e.g. reload)
+    m_part->setArguments( arguments() );
     KParts::BrowserExtension* childExtension = KParts::BrowserExtension::childObject( m_part );
     if ( childExtension )
-        childExtension->setUrlArgs( m_extension->urlArgs() );
+        childExtension->setBrowserArguments( m_extension->browserArguments() );
 
     m_nextMimeType.clear();
     if ( m_tempFile ) {
@@ -489,13 +485,13 @@ void KMultiPart::endOfData()
         {
             // The part is still loading the last data! Let it proceed then
             // Otherwise we'd keep canceling it, and nothing would ever show up...
-            kDebug() << "KMultiPart::endOfData part isn't ready, skipping frame" << endl;
+            kDebug() << "KMultiPart::endOfData part isn't ready, skipping frame";
             ++m_numberOfFramesSkipped;
             m_tempFile->setAutoRemove( true );
         }
         else
         {
-            kDebug() << "KMultiPart::endOfData opening " << m_tempFile->fileName() << endl;
+            kDebug() << "KMultiPart::endOfData opening " << m_tempFile->fileName();
             KUrl url;
             url.setPath( m_tempFile->fileName() );
             m_partIsLoading = true;
@@ -513,7 +509,7 @@ void KMultiPart::slotPartCompleted()
         Q_ASSERT( m_part );
         // Delete temp file used by the part
         Q_ASSERT( m_part->url().isLocalFile() );
-	kDebug() << "slotPartCompleted deleting " << m_part->url().path() << endl;
+	kDebug() << "slotPartCompleted deleting " << m_part->url().path();
         (void) unlink( QFile::encodeName( m_part->url().path() ) );
         m_partIsLoading = false;
         ++m_numberOfFrames;
@@ -548,8 +544,8 @@ void KMultiPart::slotJobFinished( KJob *job )
     {
         /*if ( m_khtml->view()->contentsY() == 0 )
         {
-            KParts::URLArgs args = m_ext->urlArgs();
-            m_khtml->view()->setContentsPos( args.xOffset, args.yOffset );
+            const KParts::OpenUrlArguments args = arguments();
+            m_khtml->view()->setContentsPos( args.xOffset(), args.yOffset() );
         }*/
 
         emit completed();
@@ -565,22 +561,22 @@ void KMultiPart::slotProgressInfo()
     if ( !time ) return;
     if ( m_totalNumberOfFrames == m_numberOfFrames + m_numberOfFramesSkipped )
         return; // No change, don't overwrite statusbar messages if any
-    //kDebug() << m_numberOfFrames << " in " << time << " milliseconds" << endl;
+    //kDebug() << m_numberOfFrames << " in " << time << " milliseconds";
     QString str( "%1 frames per second, %2 frames skipped per second" );
     str = str.arg( 1000.0 * (double)m_numberOfFrames / (double)time );
     str = str.arg( 1000.0 * (double)m_numberOfFramesSkipped / (double)time );
     m_totalNumberOfFrames = m_numberOfFrames + m_numberOfFramesSkipped;
-    //kDebug() << str << endl;
+    //kDebug() << str;
     emit m_extension->infoMessage( str );
 }
 
 KAboutData* KMultiPart::createAboutData()
 {
-    KAboutData* aboutData = new KAboutData( "kmultipart", I18N_NOOP("KMultiPart"),
-                                             "0.1",
-                                            I18N_NOOP( "Embeddable component for multipart/mixed" ),
-                                             KAboutData::License_GPL,
-                                             "(c) 2001, David Faure <david@mandrakesoft.com>");
+    KAboutData* aboutData = new KAboutData( "kmultipart", 0, ki18n("KMultiPart"),
+                                            "0.1",
+                                            ki18n( "Embeddable component for multipart/mixed" ),
+                                            KAboutData::License_GPL,
+                                            ki18n("Copyright 2001, David Faure <email>david@mandrakesoft.com</email>"));
     return aboutData;
 }
 
