@@ -22,15 +22,14 @@
  */
 #include "helper.h"
 #include "khtmllayout.h"
-#include <qmap.h>
-#include <qpainter.h>
+#include <QtCore/QMap>
+#include <QtGui/QPainter>
 #include <dom/dom_string.h>
 #include <xml/dom_stringimpl.h>
 #include <rendering/render_object.h>
-#include <kstaticdeleter.h>
 #include <kapplication.h>
 #include <kconfig.h>
-#include <qtooltip.h>
+#include <QtGui/QToolTip>
 #include "css/cssvalues.h"
 
 using namespace DOM;
@@ -171,10 +170,9 @@ QColor khtml::colorForCSSValue( int css_value )
 	else if ( css_value == CSS_VAL_INFOTEXT )
 	    return QToolTip::palette().color( QPalette::Inactive, QPalette::Foreground );
 	else if ( css_value == CSS_VAL_BACKGROUND ) {
-	    KConfig bckgrConfig("kdesktoprc", true, false); // No multi-screen support
-	    bckgrConfig.setGroup("Desktop0");
+	    KConfig bckgrConfig("kdesktoprc", KConfig::NoGlobals);
 	    // Desktop background.
-	    return bckgrConfig.readEntry("Color1", qApp->palette().color( QPalette::Disabled, QPalette::Background ) );
+	    return bckgrConfig.group( "Desktop0" ).readEntry("Color1", qApp->palette().color( QPalette::Disabled, QPalette::Background ) );
 	}
 	return QColor();
     }
@@ -185,8 +183,7 @@ QColor khtml::colorForCSSValue( int css_value )
 #ifndef APPLE_CHANGES
     if ( uicol->configEntry ) {
 	KSharedConfig::Ptr globalConfig = KGlobal::config();
-	globalConfig->setGroup( uicol->configGroup );
-	c = globalConfig->readEntry( uicol->configEntry, c );
+	c = globalConfig->group( uicol->configGroup ).readEntry( uicol->configEntry, c );
     }
 #endif
 
