@@ -26,10 +26,7 @@
 #ifndef _khtml_loader_h
 #define _khtml_loader_h
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
-
 #include <time.h>
 
 #include "loader_client.h"
@@ -38,14 +35,14 @@
 #endif
 
 #include <stdlib.h>
-#include <qobject.h>
-#include <q3ptrdict.h>
-#include <q3dict.h>
-#include <qpixmap.h>
-#include <qbuffer.h>
-#include <qstringlist.h>
-#include <qtextcodec.h>
-#include <qtimer.h>
+#include <QtCore/QObject>
+#include <Qt3Support/Q3PtrDict>
+#include <Qt3Support/Q3Dict>
+#include <QtGui/QPixmap>
+#include <QtCore/QBuffer>
+#include <QtCore/QStringList>
+#include <QtCore/QTextCodec>
+#include <QtCore/QTimer>
 
 #include <QLinkedList>
 
@@ -57,19 +54,16 @@
 #include "imload/image.h"
 #include "imload/imageowner.h"
 
-class QMovie;
 class KHTMLPart;
 
 class KJob;
 namespace KIO {
   class Job;
-  class TransferJob;
 }
 
 namespace DOM
 {
-    class CSSStyleSheetImpl;
-    class DocumentImpl;
+        class DocumentImpl;
 }
 
 namespace khtml
@@ -514,7 +508,7 @@ namespace khtml
         static void preloadScript(const QString &url, const QString &script_data);
 
 	static void setSize( int bytes );
-	static int size() { return maxSize; };
+	static int size() { return maxSize; }
 	static void statistics();
 	KHTML_EXPORT static void flush(bool force=false);
 
