@@ -22,25 +22,29 @@
  *
  */
 
-#include "config.h"
+#include "font.h"
+
+#include <config.h>
 
 #ifdef HAVE_ALLOCA_H
-#include <alloca.h>
-#endif
-#ifdef HAVE_MALLOC_H
-#include <malloc.h>
+#  include <alloca.h>
+#  else
+#  ifdef HAVE_MALLOC_H
+#    include <malloc.h>
+#  else
+#    include <stdlib.h>
+#  endif
 #endif
 
-#include "font.h"
-#include "khtml_factory.h"
-#include "khtml_settings.h"
+#include <khtml_factory.h>
+#include <khtml_settings.h>
 
 #include <kdebug.h>
 #include <kglobal.h>
 
-#include <qpainter.h>
-#include <qfontdatabase.h>
-#include <q3paintdevicemetrics.h>
+#include <QtGui/QPainter>
+#include <QtGui/QFontDatabase>
+#include <Qt3Support/Q3PaintDeviceMetrics>
 
 using namespace khtml;
 
@@ -425,7 +429,7 @@ bool Font::isFontScalable(QFontDatabase& db, const QFont& font)
     return s->scaleable;
 }
 
-void Font::update( Q3PaintDeviceMetrics* devMetrics ) const
+void Font::update(int logicalDpiY) const
 {
     f.setFamily( fontDef.family.isEmpty() ? KHTMLFactory::defaultHTMLSettings()->stdFontName() : fontDef.family );
     f.setItalic( fontDef.italic );
@@ -434,7 +438,7 @@ void Font::update( Q3PaintDeviceMetrics* devMetrics ) const
     QFontDatabase db;
 
     int size = fontDef.size;
-    const int lDpiY = qMax(devMetrics->logicalDpiY(), 96);
+    const int lDpiY = qMax(logicalDpiY, 96);
 
     // ok, now some magic to get a nice unscaled font
     // all other font properties should be set before this one!!!!
@@ -443,7 +447,7 @@ void Font::update( Q3PaintDeviceMetrics* devMetrics ) const
         const QList<int> pointSizes = scalCache->object(ScalKey(f))->sizes;
         // lets see if we find a nice looking font, which is not too far away
         // from the requested one.
-        // kDebug(6080) << "khtml::setFontSize family = " << f.family() << " size requested=" << size << endl;
+        // kDebug(6080) << "khtml::setFontSize family = " << f.family() << " size requested=" << size;
 
 
         float diff = 1; // ### 100% deviation
@@ -455,7 +459,7 @@ void Font::update( Q3PaintDeviceMetrics* devMetrics ) const
         for( ; it != itEnd; ++it )
         {
             float newDiff = ((*it)*(lDpiY/72.) - float(size))/float(size);
-            //kDebug( 6080 ) << "smooth font size: " << *it << " diff=" << newDiff << endl;
+            //kDebug( 6080 ) << "smooth font size: " << *it << " diff=" << newDiff;
             if(newDiff < 0) newDiff = -newDiff;
             if(newDiff < diff)
             {
@@ -463,7 +467,7 @@ void Font::update( Q3PaintDeviceMetrics* devMetrics ) const
                 bestSize = *it;
             }
         }
-        //kDebug( 6080 ) << "best smooth font size: " << bestSize << " diff=" << diff << endl;
+        //kDebug( 6080 ) << "best smooth font size: " << bestSize << " diff=" << diff;
         if ( bestSize != 0 && diff < 0.2 ) // 20% deviation, otherwise we use a scaled font...
             size = (int)((bestSize*lDpiY) / 72);
     }
