@@ -19,24 +19,26 @@
  * Boston, MA 02110-1301, USA.
  *
  */
+
+#include "render_applet.h"
+
 #include <config.h>
 #include <klocale.h>
 
 #include <kdebug.h>
 
-#include "rendering/render_applet.h"
-#include "rendering/render_canvas.h"
-#include "xml/dom_docimpl.h"
-#include "khtmlview.h"
-#include "khtml_part.h"
+#include "render_canvas.h"
+#include <xml/dom_docimpl.h>
+#include <khtmlview.h>
+#include <khtml_part.h>
 
-#include <qlabel.h>
+#include <QtGui/QLabel>
 
 #ifndef Q_WS_QWS // We don't have Java in Qt Embedded
 
-#include "java/kjavaappletwidget.h"
-#include "misc/htmltags.h"
-#include "html/html_objectimpl.h"
+#include <java/kjavaappletwidget.h>
+#include <misc/htmltags.h>
+#include <html/html_objectimpl.h>
 
 using namespace khtml;
 using namespace DOM;
@@ -55,7 +57,7 @@ RenderApplet::RenderApplet(HTMLElementImpl *applet, const QMap<QString, QString>
     }
 
     if ( context ) {
-        //kDebug(6100) << "RenderApplet::RenderApplet, setting QWidget" << endl;
+        //kDebug(6100) << "RenderApplet::RenderApplet, setting QWidget";
         setQWidget( new KJavaAppletWidget(context, _view->widget()) );
         processArguments(args);
     }
@@ -87,7 +89,7 @@ int RenderApplet::intrinsicHeight() const
 
 void RenderApplet::layout()
 {
-    //kDebug(6100) << "RenderApplet::layout" << endl;
+    //kDebug(6100) << "RenderApplet::layout";
 
     KHTMLAssert( needsLayout() );
     KHTMLAssert( minMaxKnown() );
@@ -108,7 +110,7 @@ void RenderApplet::layout()
             }
             child = child->nextSibling();
         }
-        //kDebug(6100) << "setting applet widget to size: " << m_width << ", " << m_height << endl;
+        //kDebug(6100) << "setting applet widget to size: " << m_width << ", " << m_height;
         m_widget->resize(m_width-borderLeft()-borderRight()-paddingLeft()-paddingRight(),
                          m_height-borderTop()-borderBottom()-paddingTop()-paddingBottom());
         tmp->showApplet();
