@@ -103,17 +103,17 @@ void RenderContainer::addChild(RenderObject *newChild, RenderObject *beforeChild
         case TABLE_HEADER_GROUP:
         case TABLE_FOOTER_GROUP:
 
-            //kDebug( 6040 ) << "adding section" << endl;
+            //kDebug( 6040 ) << "adding section";
             if ( !isTable() )
                 needsTable = true;
             break;
         case TABLE_ROW:
-            //kDebug( 6040 ) << "adding row" << endl;
+            //kDebug( 6040 ) << "adding row";
             if ( !isTableSection() )
                 needsTable = true;
             break;
         case TABLE_CELL:
-            //kDebug( 6040 ) << "adding cell" << endl;
+            //kDebug( 6040 ) << "adding cell";
             if ( !isTableRow() )
                 needsTable = true;
             // I'm not 100% sure this is the best way to fix this, but without this
@@ -136,7 +136,7 @@ void RenderContainer::addChild(RenderObject *newChild, RenderObject *beforeChild
         if ( last && last->isTable() && last->isAnonymous() ) {
             table = static_cast<RenderTable *>(last);
         } else {
-	    //kDebug( 6040 ) << "creating anonymous table, before=" << beforeChild << endl;
+	    //kDebug( 6040 ) << "creating anonymous table, before=" << beforeChild;
             table = new (renderArena()) RenderTable(document() /* is anonymous */);
             RenderStyle *newStyle = new RenderStyle();
             newStyle->inheritFrom(style());
@@ -388,11 +388,13 @@ RenderContainer* RenderContainer::pseudoContainer(RenderStyle::PseudoId type) co
         assert(child->isRenderBlock() || child->isRenderInline());
         return static_cast<RenderContainer*>(child);
     }
-    else
-    {   // check continuations
+    if (type == RenderStyle::AFTER) {
+        // check continuations
         if (continuation())
             return continuation()->pseudoContainer(type);
     }
+    if (child && child->isAnonymousBlock())
+        return static_cast<RenderBlock*>(child)->pseudoContainer(type);
     return 0;
 }
 
@@ -401,22 +403,22 @@ void RenderContainer::addPseudoContainer(RenderObject* child)
     RenderStyle::PseudoId type = child->style()->styleType();
     switch (type) {
         case RenderStyle::AFTER: {
-            RenderObject *l = 0;
-            if (isRenderInline()) {
-                RenderObject *c = continuation();
-                while (c) {
-                    l = c;
-                    c = c->continuation();
-                }
-            }
-            if (l)
-                l->addChild(child, 0);
-            else
-                addChild(child, 0);
+            RenderObject *o = this;
+            while (o->continuation()) o = o->continuation();
+
+            // Coalesce inlines
+            if (child->style()->display() == INLINE && o->lastChild() && o->lastChild()->isAnonymousBlock()) {
+                o->lastChild()->addChild(child, 0);
+            } else
+                o->addChild(child, 0);
             break;
         }
         case RenderStyle::BEFORE:
-            addChild(child, firstChild());
+            // Coalesce inlines
+            if (child->style()->display() == INLINE && firstChild() && firstChild()->isAnonymousBlock()) {
+                firstChild()->addChild(child, firstChild()->firstChild());
+            } else
+                addChild(child, firstChild());
             break;
         case RenderStyle::REPLACED:
             addChild(child, pseudoContainer(RenderStyle::AFTER));
