@@ -23,25 +23,26 @@
  */
 // -------------------------------------------------------------------------
 
+#include "render_flow.h"
+
 #include <kdebug.h>
 #include <assert.h>
-#include <qpainter.h>
+#include <QtGui/QPainter>
 #include <kglobal.h>
 
-#include "rendering/render_flow.h"
-#include "rendering/render_text.h"
-#include "rendering/render_table.h"
-#include "rendering/render_canvas.h"
-#include "rendering/render_inline.h"
-#include "rendering/render_block.h"
-#include "rendering/render_arena.h"
-#include "rendering/render_line.h"
-#include "xml/dom_nodeimpl.h"
-#include "xml/dom_docimpl.h"
-#include "misc/htmltags.h"
-#include "html/html_formimpl.h"
+#include "render_text.h"
+#include "render_table.h"
+#include "render_canvas.h"
+#include "render_inline.h"
+#include "render_block.h"
+#include "render_arena.h"
+#include "render_line.h"
+#include <xml/dom_nodeimpl.h>
+#include <xml/dom_docimpl.h>
+#include <misc/htmltags.h>
+#include <html/html_formimpl.h>
 
-#include "khtmlview.h"
+#include <khtmlview.h>
 
 using namespace DOM;
 using namespace khtml;
@@ -85,7 +86,7 @@ RenderFlow* RenderFlow::continuationBefore(RenderObject* beforeChild)
 void RenderFlow::addChildWithContinuation(RenderObject* newChild, RenderObject* beforeChild)
 {
     RenderFlow* flow = continuationBefore(beforeChild);
-    while(beforeChild && beforeChild->parent() != this && !beforeChild->parent()->isAnonymousBlock()) {
+    while(beforeChild && beforeChild->parent() != flow && !beforeChild->parent()->isAnonymousBlock()) {
         // skip implicit containers around beforeChild
         beforeChild = beforeChild->parent();
     }
@@ -120,7 +121,7 @@ void RenderFlow::addChild(RenderObject *newChild, RenderObject *beforeChild)
 #ifdef DEBUG_LAYOUT
     kDebug( 6040 ) << renderName() << "(RenderFlow)::addChild( " << newChild->renderName() <<
                        ", " << (beforeChild ? beforeChild->renderName() : "0") << " )" << endl;
-    kDebug( 6040 ) << "current height = " << m_height << endl;
+    kDebug( 6040 ) << "current height = " << m_height;
 #endif
 
     if (continuation())
