@@ -24,6 +24,8 @@
  *
  */
 
+#include "render_form.h"
+
 #include <kcompletionbox.h>
 #include <kcursor.h>
 #include <kdebug.h>
@@ -37,39 +39,38 @@
 #include <kreplacedialog.h>
 #include <k3spell.h>
 #include <kurlcompletion.h>
-#include <kwin.h>
+#include <kwindowsystem.h>
 #include <kstandardaction.h>
 #include <kactioncollection.h>
 
 #include <QAbstractItemView>
 #include <QAbstractTextDocumentLayout>
-#include <qstyle.h>
+#include <QtGui/QStyle>
 #include <QStyleOptionButton>
 
-#include "misc/helper.h"
-#include "xml/dom2_eventsimpl.h"
-#include "html/html_formimpl.h"
-#include "misc/htmlhashes.h"
+#include <misc/helper.h>
+#include <xml/dom2_eventsimpl.h>
+#include <html/html_formimpl.h>
+#include <misc/htmlhashes.h>
 
-#include "rendering/render_form.h"
 #include <assert.h>
 
-#include "khtmlview.h"
-#include "khtml_ext.h"
-#include "xml/dom_docimpl.h"
+#include <khtmlview.h>
+#include <khtml_ext.h>
+#include <xml/dom_docimpl.h>
 
-#include <qmenu.h>
-#include <qbitmap.h>
+#include <QtGui/QMenu>
+#include <QtGui/QBitmap>
 
 using namespace khtml;
 
 RenderFormElement::RenderFormElement(HTMLGenericFormElementImpl *element)
     : RenderWidget(element)
+//     , m_state(0)
 {
     // init RenderObject attributes
     setInline(true);   // our object is Inline
 
-    m_state = 0;
 }
 
 RenderFormElement::~RenderFormElement()
@@ -349,6 +350,32 @@ RenderResetButton::RenderResetButton(HTMLInputElementImpl *element)
 
 // -------------------------------------------------------------------------------
 
+class CompletionWidget: public KCompletionBox
+{
+public:
+    CompletionWidget( QWidget *parent = 0 ) : KCompletionBox( parent ) {}
+    virtual void popup() {
+        QWidget* pw = parentWidget();
+        KHTMLWidget* kwp = dynamic_cast<KHTMLWidget*>(pw);
+        if (!kwp) {
+            qDebug() << "CompletionWidget has no KHTMLWidget parent" << endl;
+            KCompletionBox::popup();
+            return;
+        }
+        bool blocked = pw->signalsBlocked();
+        QPoint p = pw->pos();
+        pw->blockSignals(true);
+        pw->move( kwp->m_kwp->absolutePos() );
+        pw->blockSignals(blocked);
+
+        KCompletionBox::popup();
+        
+        pw->blockSignals(true);
+        pw->move( p );
+        pw->blockSignals(blocked);
+    }
+};
+
 LineEditWidget::LineEditWidget(DOM::HTMLInputElementImpl* input, KHTMLView* view, QWidget* parent)
     : KLineEdit(parent), m_input(input), m_view(view), m_spell(0)
 {
@@ -356,6 +383,10 @@ LineEditWidget::LineEditWidget(DOM::HTMLInputElementImpl* input, KHTMLView* view
     setMouseTracking(true);
     KActionCollection *ac = new KActionCollection(this);
     m_spellAction = KStandardAction::spelling( this, SLOT( slotCheckSpelling() ), ac );
+
+    setCompletionBox( new CompletionWidget( this ) );
+    completionBox()->setObjectName("completion box");
+    completionBox()->setFont(font());
 }
 
 LineEditWidget::~LineEditWidget()
@@ -383,6 +414,12 @@ void LineEditWidget::spellCheckerMisspelling( const QString &_text, const QStrin
     highLightWord( _text.length(),pos );
 }
 
+void LineEditWidget::setFocus()
+{
+    KLineEdit::setFocus();
+    end( false );
+}
+
 void LineEditWidget::highLightWord( unsigned int length, unsigned int pos )
 {
     setSelection ( pos, length );
@@ -414,7 +451,6 @@ void LineEditWidget::slotSpellCheckDone( const QString &s )
         setText( s );
 }
 
-
 void LineEditWidget::contextMenuEvent(QContextMenuEvent *e)
 {
     QMenu* popup = createStandardContextMenu();
@@ -424,7 +460,7 @@ void LineEditWidget::contextMenuEvent(QContextMenuEvent *e)
 
     if (m_input->autoComplete()) {
         popup->addSeparator();
-        QAction* act = popup->addAction( KIcon("history_clear"), i18n("Clear &History"));
+        QAction* act = popup->addAction( KIcon("history-clear"), i18n("Clear &History"));
         act->setEnabled(compObj() && !compObj()->isEmpty());
         connect(act, SIGNAL(triggered()),
                 this, SLOT(clearHistoryActivated()));
@@ -514,7 +550,7 @@ RenderLineEdit::RenderLineEdit(HTMLInputElementImpl *element)
         QStringList completions = view()->formCompletionItems(element->name().string());
         if (completions.count()) {
             edit->completionObject()->setItems(completions);
-            edit->setContextMenuEnabled(true);
+            edit->setContextMenuPolicy(Qt::NoContextMenu);
             edit->completionBox()->setTabHandling( false );
         }
     }
@@ -583,7 +619,7 @@ void RenderLineEdit::calcMinMaxWidth()
 
     int margin = static_cast<LineEditWidget*>(widget())->hasFrame() ? 4 : 0;
     s = QSize(w + margin, qMax(h, 14) + margin);
-    s = widget()->style()->sizeFromContents(QStyle::CT_LineEdit, &opt, s);
+    s = widget()->style()->sizeFromContents(QStyle::CT_LineEdit, &opt, s, widget());
     s = s.expandedTo(QApplication::globalStrut());
 
     setIntrinsicWidth( s.width() );
@@ -603,14 +639,14 @@ void RenderLineEdit::updateFromElement()
     }
 
     if (element()->value().string() != widget()->text()) {
-        widget()->blockSignals(true);
+        bool blocked = widget()->blockSignals(true);
         int pos = widget()->cursorPosition();
         widget()->setText(element()->value().string());
 
         widget()->setModified( false );
 
         widget()->setCursorPosition(pos);
-        widget()->blockSignals(false);
+        widget()->blockSignals(blocked);
     }
     widget()->setReadOnly(element()->readOnly());
 
@@ -714,7 +750,7 @@ RenderObject* RenderFieldset::findLegend()
 
 void RenderFieldset::paintBoxDecorations(PaintInfo& pI, int _tx, int _ty)
 {
-    //kDebug( 6040 ) << renderName() << "::paintDecorations()" << endl;
+    //kDebug( 6040 ) << renderName() << "::paintDecorations()";
 
     RenderObject* legend = findLegend();
     if (!legend)
@@ -821,6 +857,7 @@ RenderFileButton::RenderFileButton(HTMLInputElementImpl *element)
     FileButtonWidget* w = new FileButtonWidget( view()->widget() );
 
     w->setMode(KFile::File | KFile::ExistingOnly);
+    w->lineEdit()->setCompletionBox( new CompletionWidget(w) );
     w->completionObject()->setDir(KGlobalSettings::documentPath());
 
     connect(w->lineEdit(), SIGNAL(returnPressed()), this, SLOT(slotReturnPressed()));
@@ -869,10 +906,10 @@ void RenderFileButton::handleFocusOut()
 void RenderFileButton::updateFromElement()
 {
     KLineEdit* edit = widget()->lineEdit();
-    edit->blockSignals(true);
+    bool blocked = edit->blockSignals(true);
     edit->setText(element()->value().string());
     edit->blockSignals(false);
-    edit->setModified( false );
+    edit->setModified(blocked );
 
     RenderFormElement::updateFromElement();
 }
@@ -929,15 +966,15 @@ ComboBoxWidget::ComboBoxWidget(QWidget *parent)
 void ComboBoxWidget::showPopup()
 {
     QPoint p = pos();
-    blockSignals(true);
+    bool blocked = blockSignals(true);
     move( m_kwp->absolutePos() );
-    blockSignals(false);
+    blockSignals(blocked);
 
     KComboBox::showPopup();
 
-    blockSignals(true);
+    blocked = blockSignals(true);
     move( p );
-    blockSignals(false);
+    blockSignals(blocked);
 }
 
 void ComboBoxWidget::hidePopup()
@@ -1411,7 +1448,7 @@ void TextAreaWidget::contextMenuEvent(QContextMenuEvent * e)
 void TextAreaWidget::slotFindHighlight(const QString& text, int matchingIndex, int matchingLength)
 {
     Q_UNUSED(text)
-    //kDebug() << "Highlight: [" << text << "] mi:" << matchingIndex << " ml:" << matchingLength << endl;
+    //kDebug() << "Highlight: [" << text << "] mi:" << matchingIndex << " ml:" << matchingLength;
     QTextCursor tc = textCursor();
     tc.setPosition(matchingIndex);
     tc.movePosition(QTextCursor::NextCharacter, QTextCursor::KeepAnchor, matchingLength);
@@ -1422,7 +1459,7 @@ void TextAreaWidget::slotFindHighlight(const QString& text, int matchingIndex, i
 
 void TextAreaWidget::slotReplaceText(const QString &text, int replacementIndex, int /*replacedLength*/, int matchedLength) {
     Q_UNUSED(text)
-    //kDebug() << "Replace: [" << text << "] ri:" << replacementIndex << " rl:" << replacedLength << " ml:" << matchedLength << endl;
+    //kDebug() << "Replace: [" << text << "] ri:" << replacementIndex << " rl:" << replacedLength << " ml:" << matchedLength;
     QTextCursor tc = textCursor();
     tc.setPosition(replacementIndex);
     tc.movePosition(QTextCursor::NextCharacter, QTextCursor::KeepAnchor, matchedLength);
@@ -1545,13 +1582,14 @@ void TextAreaWidget::slotFind()
         return;
 
     if ( m_findDlg ) {
-#ifdef Q_WS_WIN
-      m_findDlg->activateWindow();
+#ifdef Q_WS_X11
+      KWindowSystem::activateWindow( m_findDlg->winId() );
 #else
-      KWin::activateWindow( m_findDlg->winId() );
+      m_findDlg->activateWindow();
 #endif
     } else {
-      m_findDlg = new KFindDialog(false, this, "KHTML Text Area Find Dialog");
+      m_findDlg = new KFindDialog(this);
+      m_findDlg->setObjectName("KHTML Text Area Find Dialog");
       connect( m_findDlg, SIGNAL(okClicked()), this, SLOT(slotDoFind()) );
     }
     m_findDlg->show();
@@ -1564,14 +1602,15 @@ void TextAreaWidget::slotReplace()
         return;
 
     if ( m_repDlg ) {
-#ifdef Q_WS_WIN
-      m_repDlg->activateWindow();
+#ifdef Q_WS_X11
+      KWindowSystem::activateWindow( m_repDlg->winId() );
 #else
-      KWin::activateWindow( m_repDlg->winId() );
+      m_repDlg->activateWindow();
 #endif
     } else {
-      m_repDlg = new KReplaceDialog(this, "KHTMLText Area Replace Dialog", 0,
+      m_repDlg = new KReplaceDialog(this, 0,
                                     QStringList(), QStringList(), false);
+      m_repDlg->setObjectName("KHTMLText Area Replace Dialog");
       connect( m_repDlg, SIGNAL(okClicked()), this, SLOT(slotDoReplace()) );
     }
     m_repDlg->show();
@@ -1663,9 +1702,9 @@ void RenderTextArea::setStyle(RenderStyle* _style)
 
     RenderFormElement::setStyle(_style);
 
-    widget()->blockSignals(true);
+    bool blocked = widget()->blockSignals(true);
     widget()->setAlignment(textAlignment());
-    widget()->blockSignals(false);
+    widget()->blockSignals(blocked);
 
     scrollbarsStyled = false;
 
@@ -1694,7 +1733,7 @@ void RenderTextArea::updateFromElement()
     QString elementText = element()->value().string();
     if ( elementText != text() )
     {
-        w->blockSignals(true);
+        bool blocked = w->blockSignals(true);
         QTextCursor tc = w->textCursor();
         int cx = w->horizontalScrollBar()->value();
         int cy = w->verticalScrollBar()->value();
@@ -1702,7 +1741,7 @@ void RenderTextArea::updateFromElement()
         w->setTextCursor(tc);
         w->horizontalScrollBar()->setValue( cx );
         w->verticalScrollBar()->setValue( cy );
-        w->blockSignals(false);
+        w->blockSignals(blocked);
     }
     element()->m_dirtyvalue = false;
 
