@@ -32,20 +32,17 @@
 #include "html/html_formimpl.h"
 
 class QWidget;
-class QLineEdit;
-class QListboxItem;
 
 #include <ktextedit.h>
 #include <kurlrequester.h>
 #include <klineedit.h>
-#include <qcheckbox.h>
-#include <qradiobutton.h>
-#include <qpushbutton.h>
+#include <QtGui/QCheckBox>
+#include <QtGui/QRadioButton>
+#include <QtGui/QPushButton>
 #include <klistwidget.h>
 #include <kcombobox.h>
 #include "dom/dom_misc.h"
 
-class KHTMLPartBrowserExtension;
 class K3Spell;
 class KFindDialog;
 class KReplaceDialog;
@@ -55,7 +52,6 @@ class KAction;
 class KUrlRequester;
 
 namespace DOM {
-    class HTMLFormElementImpl;
     class HTMLInputElementImpl;
     class HTMLSelectElementImpl;
     class HTMLGenericFormElementImpl;
@@ -64,7 +60,6 @@ namespace DOM {
 
 namespace khtml {
 
-class DocLoader;
 
 // -------------------------------------------------------------------------
 
@@ -97,8 +92,8 @@ protected:
     virtual bool isEditable() const { return false; }
 	Qt::AlignmentFlag textAlignment() const;
 
-    QPoint m_mousePos;
-    int m_state;
+//     QPoint m_mousePos;
+//     int m_state;
 };
 
 // -------------------------------------------------------------------------
@@ -277,6 +272,7 @@ public:
     LineEditWidget(DOM::HTMLInputElementImpl* input,
                    KHTMLView* view, QWidget* parent);
     ~LineEditWidget();
+    void setFocus();
     void highLightWord( unsigned int length, unsigned int pos );
 
 protected:
@@ -530,8 +526,8 @@ protected:
 class ScrollBarWidget: public QScrollBar, public KHTMLWidget
 {
 public:
-    ScrollBarWidget( QWidget * parent = 0 ): QScrollBar(parent) { m_kwp->setIsRedirected( true ); };
-    ScrollBarWidget( Qt::Orientation orientation, QWidget * parent = 0 ): QScrollBar(orientation, parent) { m_kwp->setIsRedirected( true ); };
+    ScrollBarWidget( QWidget * parent = 0 ): QScrollBar(parent) { m_kwp->setIsRedirected( true ); }
+    ScrollBarWidget( Qt::Orientation orientation, QWidget * parent = 0 ): QScrollBar(orientation, parent) { m_kwp->setIsRedirected( true ); }
 };
 
 } //namespace
