@@ -42,9 +42,9 @@
 #include <kmimetype.h>
 #include <klocale.h>
 #include <kdebug.h>
-#include <qtimer.h>
-#include <qpainter.h>
-#include <qcursor.h>
+#include <QtCore/QTimer>
+#include <QtGui/QPainter>
+#include <QtGui/QCursor>
 
 #include <assert.h>
 
@@ -110,7 +110,7 @@ void RenderFrameSet::layout( )
     }
 
 #ifdef DEBUG_LAYOUT
-    kDebug( 6040 ) << renderName() << "(FrameSet)::layout( ) width=" << width() << ", height=" << height() << endl;
+    kDebug( 6040 ) << renderName() << "(FrameSet)::layout( ) width=" << width() << ", height=" << height();
 #endif
 
     int remainingLen[2];
@@ -161,7 +161,7 @@ void RenderFrameSet::layout( )
                     totalFixed += gridLayout[i];
                     countFixed++;
                 }
-                
+
                 // Count the total percentage of all of the percentage columns/rows -> totalPercent
                 // Count the number of columns/rows which are percentages -> countPercent
                 if (grid[i].isPercent()) {
@@ -175,11 +175,11 @@ void RenderFrameSet::layout( )
                 if (grid[i].isRelative()) {
                     totalRelative += qMax(grid[i].value(), 1);
                     countRelative++;
-                }            
+                }
             }
 
             // Fixed columns/rows are our first priority. If there is not enough space to fit all fixed
-            // columns/rows we need to proportionally adjust their size. 
+            // columns/rows we need to proportionally adjust their size.
             if (totalFixed > remainingLen[k]) {
                 int remainingFixed = remainingLen[k];
 
@@ -193,13 +193,13 @@ void RenderFrameSet::layout( )
                 remainingLen[k] -= totalFixed;
             }
 
-            // Percentage columns/rows are our second priority. Divide the remaining space proportionally 
-            // over all percentage columns/rows. IMPORTANT: the size of each column/row is not relative 
+            // Percentage columns/rows are our second priority. Divide the remaining space proportionally
+            // over all percentage columns/rows. IMPORTANT: the size of each column/row is not relative
             // to 100%, but to the total percentage. For example, if there are three columns, each of 75%,
             // and the available space is 300px, each column will become 100px in width.
             if (totalPercent > remainingLen[k]) {
                 int remainingPercent = remainingLen[k];
- 
+
                 for (int i = 0; i < gridLen; ++i) {
                     if (grid[i].isPercent()) {
                         gridLayout[i] = (gridLayout[i] * remainingPercent) / totalPercent;
@@ -224,7 +224,7 @@ void RenderFrameSet::layout( )
                     }
                 }
 
-                // If we could not evently distribute the available space of all of the relative  
+                // If we could not evently distribute the available space of all of the relative
                 // columns/rows, the remainder will be added to the last column/row.
                 // For example: if we have a space of 100px and three columns (*,*,*), the remainder will
                 // be 1px and will be added to the last column: 33px, 33px, 34px.
@@ -238,9 +238,9 @@ void RenderFrameSet::layout( )
             // columns/rows
             if (remainingLen[k]) {
                 // Our first priority is to spread if over the percentage columns. The remaining
-                // space is spread evenly, for example: if we have a space of 100px, the columns 
-                // definition of 25%,25% used to result in two columns of 25px. After this the 
-                // columns will each be 50px in width. 
+                // space is spread evenly, for example: if we have a space of 100px, the columns
+                // definition of 25%,25% used to result in two columns of 25px. After this the
+                // columns will each be 50px in width.
                 if (countPercent && totalPercent) {
                     int remainingPercent = remainingLen[k];
                     int changePercent = 0;
@@ -264,14 +264,14 @@ void RenderFrameSet::layout( )
                             changeFixed = (remainingFixed * gridLayout[i]) / totalFixed;
                             gridLayout[i] += changeFixed;
                             remainingLen[k] -= changeFixed;
-                        } 
+                        }
                     }
                 }
             }
-            
+
             // If we still have some left over space we probably ended up with a remainder of
-            // a division. We can not spread it evenly anymore. If we have any percentage 
-            // columns/rows simply spread the remainder equally over all available percentage columns, 
+            // a division. We can not spread it evenly anymore. If we have any percentage
+            // columns/rows simply spread the remainder equally over all available percentage columns,
             // regardless of their size.
             if (remainingLen[k] && countPercent) {
                 int remainingPercent = remainingLen[k];
@@ -284,14 +284,14 @@ void RenderFrameSet::layout( )
                         remainingLen[k] -= changePercent;
                     }
                 }
-            } 
-            
+            }
+
             // If we don't have any percentage columns/rows we only have fixed columns. Spread
             // the remainder equally over all fixed columns/rows.
             else if (remainingLen[k] && countFixed) {
                 int remainingFixed = remainingLen[k];
                 int changeFixed = 0;
-                
+
                 for (int i = 0; i < gridLen; ++i) {
                     if (grid[i].isFixed()) {
                         changeFixed = remainingFixed / countFixed;
@@ -334,7 +334,7 @@ void RenderFrameSet::layout( )
     if(!m_hSplitVar && !m_vSplitVar)
     {
 #ifdef DEBUG_LAYOUT
-        kDebug( 6031 ) << "calculationg fixed Splitters" << endl;
+        kDebug( 6031 ) << "calculationg fixed Splitters";
 #endif
         if(!m_vSplitVar && element()->totalCols() > 1)
         {
@@ -361,7 +361,7 @@ void RenderFrameSet::layout( )
                 if(fixed)
                 {
 #ifdef DEBUG_LAYOUT
-                    kDebug( 6031 ) << "found fixed cell " << r << "/" << c << "!" << endl;
+                    kDebug( 6031 ) << "found fixed cell " << r << "/" << c << "!";
 #endif
                     if( element()->totalCols() > 1)
                     {
@@ -378,7 +378,7 @@ void RenderFrameSet::layout( )
                 }
 #ifdef DEBUG_LAYOUT
                 else
-                    kDebug( 6031 ) << "not fixed: " << r << "/" << c << "!" << endl;
+                    kDebug( 6031 ) << "not fixed: " << r << "/" << c << "!";
 #endif
             }
         }
@@ -410,7 +410,7 @@ void RenderFrameSet::positionFrames()
     {
       child->setPos( xPos, yPos );
 #ifdef DEBUG_LAYOUT
-      kDebug(6040) << "child frame at (" << xPos << "/" << yPos << ") size (" << m_gridLayout[1][c] << "/" << m_gridLayout[0][r] << ")" << endl;
+      kDebug(6040) << "child frame at (" << xPos << "/" << yPos << ") size (" << m_gridLayout[1][c] << "/" << m_gridLayout[0][r] << ")";
 #endif
       // has to be resized and itself resize its contents
       if ((m_gridLayout[1][c] != child->width()) || (m_gridLayout[0][r] != child->height())) {
@@ -453,7 +453,7 @@ bool RenderFrameSet::userResize( MouseEventImpl *evt )
   if ( !m_resizing && evt->id() == EventImpl::MOUSEMOVE_EVENT || evt->id() == EventImpl::MOUSEDOWN_EVENT )
   {
 #ifdef DEBUG_LAYOUT
-    kDebug( 6031 ) << "mouseEvent:check" << endl;
+    kDebug( 6031 ) << "mouseEvent:check";
 #endif
 
     m_hSplit = -1;
@@ -468,7 +468,7 @@ bool RenderFrameSet::userResize( MouseEventImpl *evt )
       {
         if(m_vSplitVar && m_vSplitVar[c-1] == true) m_vSplit = c-1;
 #ifdef DEBUG_LAYOUT
-        kDebug( 6031 ) << "vsplit!" << endl;
+        kDebug( 6031 ) << "vsplit!";
 #endif
         res = true;
         break;
@@ -483,8 +483,8 @@ bool RenderFrameSet::userResize( MouseEventImpl *evt )
       {
         if(m_hSplitVar && m_hSplitVar[r-1] == true) m_hSplit = r-1;
 #ifdef DEBUG_LAYOUT
-        kDebug( 6031 ) << "hsplitvar = " << m_hSplitVar << endl;
-        kDebug( 6031 ) << "hsplit!" << endl;
+        kDebug( 6031 ) << "hsplitvar = " << m_hSplitVar;
+        kDebug( 6031 ) << "hsplit!";
 #endif
         res = true;
         break;
@@ -492,7 +492,7 @@ bool RenderFrameSet::userResize( MouseEventImpl *evt )
       pos += m_gridLayout[0][r] + element()->border();
     }
 #ifdef DEBUG_LAYOUT
-    kDebug( 6031 ) << m_hSplit << "/" << m_vSplit << endl;
+    kDebug( 6031 ) << m_hSplit << "/" << m_vSplit;
 #endif
   }
 
@@ -523,7 +523,7 @@ bool RenderFrameSet::userResize( MouseEventImpl *evt )
     if(m_vSplit != -1 )
     {
 #ifdef DEBUG_LAYOUT
-      kDebug( 6031 ) << "split xpos=" << _x << endl;
+      kDebug( 6031 ) << "split xpos=" << _x;
 #endif
       int delta = m_vSplitPos - _x;
       m_gridDelta[1][m_vSplit] -= delta;
@@ -532,7 +532,7 @@ bool RenderFrameSet::userResize( MouseEventImpl *evt )
     if(m_hSplit != -1 )
     {
 #ifdef DEBUG_LAYOUT
-      kDebug( 6031 ) << "split ypos=" << _y << endl;
+      kDebug( 6031 ) << "split ypos=" << _y;
 #endif
       int delta = m_hSplitPos - _y;
       m_gridDelta[0][m_hSplit] -= delta;
@@ -629,7 +629,7 @@ RenderPart::RenderPart(DOM::HTMLElementImpl* node)
 void RenderPart::setWidget( QWidget *widget )
 {
 #ifdef DEBUG_LAYOUT
-    kDebug(6031) << "RenderPart::setWidget()" << endl;
+    kDebug(6031) << "RenderPart::setWidget()";
 #endif
 
     setQWidget( widget );
@@ -675,7 +675,7 @@ void RenderFrame::slotViewCleared()
 {
     if(m_widget->inherits("QScrollArea")) {
 #ifdef DEBUG_LAYOUT
-        kDebug(6031) << "frame is a scrollview!" << endl;
+        kDebug(6031) << "frame is a scrollview!";
 #endif
         QScrollArea *view = static_cast<QScrollArea *>(m_widget);
         if(!element()->frameBorder || !((static_cast<HTMLFrameSetElementImpl *>(element()->parentNode()))->frameBorder()))
@@ -684,7 +684,7 @@ void RenderFrame::slotViewCleared()
 	    view->setHorizontalScrollBarPolicy(element()->scrolling );
         if(view->inherits("KHTMLView")) {
 #ifdef DEBUG_LAYOUT
-            kDebug(6031) << "frame is a KHTMLview!" << endl;
+            kDebug(6031) << "frame is a KHTMLview!";
 #endif
             KHTMLView *htmlView = static_cast<KHTMLView *>(view);
             if(element()->marginWidth != -1) htmlView->setMarginWidth(element()->marginWidth);
@@ -830,7 +830,7 @@ void RenderPartObject::updateWidget()
                   serviceType = "video/x-msvideo";
 
               else
-                  kDebug(6031) << "ActiveX classId " << objbase->classId << endl;
+                  kDebug(6031) << "ActiveX classId " << objbase->classId;
 
               // TODO: add more plugins here
           }
@@ -857,7 +857,7 @@ void RenderPartObject::close()
 bool RenderPartObject::partLoadingErrorNotify( khtml::ChildFrame *childFrame, const KUrl& url, const QString& serviceType )
 {
     KHTMLPart *part = static_cast<KHTMLView *>(m_view)->part();
-    kDebug(6031) << "RenderPartObject::partLoadingErrorNotify serviceType=" << serviceType << endl;
+    kDebug(6031) << "RenderPartObject::partLoadingErrorNotify serviceType=" << serviceType;
     // Check if we just tried with e.g. nsplugin
     // and fallback to the activexhandler if there is a classid
     // and a codebase, where we may download the ocx if it's missing
@@ -876,9 +876,9 @@ bool RenderPartObject::partLoadingErrorNotify( khtml::ChildFrame *childFrame, co
         if( embed && !o->classId.isEmpty() &&
             !( static_cast<ElementImpl *>(o)->getAttribute(ATTR_CODEBASE).string() ).isEmpty() )
         {
-            KParts::URLArgs args;
-            args.serviceType = "application/x-activex-handler";
-            kDebug(6031) << "set to activex" << endl;
+            KParts::OpenUrlArguments args;
+            args.setMimeType("application/x-activex-handler");
+            kDebug(6031) << "set to activex";
             if (part->requestObject( childFrame, url, args ))
                 return true; // success
 
@@ -930,7 +930,7 @@ void RenderPartObject::slotPartLoadingErrorNotify()
         // Prepare the mimetype to show in the question (comment if available, name as fallback)
         QString mimeName = serviceType;
         KMimeType::Ptr mime = KMimeType::mimeType(serviceType);
-        if ( mime->name() != KMimeType::defaultMimeType() )
+        if ( mime && mime->name() != KMimeType::defaultMimeType() )
             mimeName = mime->comment();
 
         // Check if we already asked the user, for this page
@@ -977,7 +977,7 @@ void RenderPartObject::slotViewCleared()
 {
   if(m_widget->inherits("QScrollArea") ) {
 #ifdef DEBUG_LAYOUT
-      kDebug(6031) << "iframe is a scrollview!" << endl;
+      kDebug(6031) << "iframe is a scrollview!";
 #endif
       QScrollArea *view = static_cast<QScrollArea *>(m_widget);
       int frameStyle = QFrame::NoFrame;
@@ -997,7 +997,7 @@ void RenderPartObject::slotViewCleared()
       view->setHorizontalScrollBarPolicy(scroll );
       if(view->inherits("KHTMLView")) {
 #ifdef DEBUG_LAYOUT
-          kDebug(6031) << "frame is a KHTMLview!" << endl;
+          kDebug(6031) << "frame is a KHTMLview!";
 #endif
           KHTMLView *htmlView = static_cast<KHTMLView *>(view);
           htmlView->setIgnoreWheelEvents( element()->id() == ID_IFRAME );
