@@ -28,12 +28,11 @@
 #include "rendering/render_replaced.h"
 #include "dom/dom_string.h"
 
-#include <qmap.h>
-#include <qpixmap.h>
+#include <QtCore/QMap>
+#include <QtGui/QPixmap>
 
 namespace khtml {
 
-class DocLoader;
 class CachedObject;
 
 class RenderImage : public RenderReplaced
