@@ -26,8 +26,8 @@
 #ifndef render_object_h
 #define render_object_h
 
-#include <qcolor.h>
-#include <qrect.h>
+#include <QtGui/QColor>
+#include <QtCore/QRect>
 #include <assert.h>
 #include <QList>
 
@@ -39,12 +39,10 @@
 #include "misc/loader_client.h"
 #include "misc/helper.h"
 #include "rendering/render_style.h"
-#include <qtextstream.h>
+#include <QtCore/QTextIStream>
 
 class QPainter;
 class QTextStream;
-class CSSStyle;
-class KHTMLView;
 
 #ifndef NDEBUG
 #define KHTMLAssert( x ) if( !(x) ) { \
@@ -106,7 +104,6 @@ inline PageBreakLevel operator| (PageBreakLevel a, PageBreakLevel b) {
 
 namespace DOM {
     class HTMLAreaElementImpl;
-    class DOMString;
     class NodeImpl;
     class DocumentImpl;
     class ElementImpl;
@@ -116,7 +113,6 @@ namespace DOM {
 namespace khtml {
     class RenderFlow;
     class RenderStyle;
-    class RenderTable;
     class CachedObject;
     class RenderObject;
     class RenderCanvas;
@@ -318,7 +314,7 @@ public:
     DOM::NodeImpl* element() const { return isAnonymous() ? 0L : m_node; }
     DOM::NodeImpl* node() const { return m_node; }
     
-    virtual bool handleEvent(const DOM::EventImpl&) { return false; };
+    virtual bool handleEvent(const DOM::EventImpl&) { return false; }
 
    /**
      * returns the object containing this one. can be different from parent for
@@ -482,8 +478,8 @@ public:
     virtual bool canClear(RenderObject * /*child*/, PageBreakLevel level)
     { if (parent()) return parent()->canClear(this, level); else return false; }
 
-    void setAfterPageBreak(bool b = true)  { m_afterPageBreak = b; };
-    void setBeforePageBreak(bool b = true) { m_beforePageBreak = b; };
+    void setAfterPageBreak(bool b = true)  { m_afterPageBreak = b; }
+    void setBeforePageBreak(bool b = true) { m_beforePageBreak = b; }
     virtual bool afterPageBreak() const  { return m_afterPageBreak; }
     virtual bool beforePageBreak() const { return m_beforePageBreak; }
 
@@ -692,7 +688,7 @@ public:
     virtual bool isHidden() const { return isFloating() || isPositioned(); }
 
     // Special objects are objects that are neither really inline nor blocklevel
-    bool isFloatingOrPositioned() const { return (isFloating() || isPositioned()); };
+    bool isFloatingOrPositioned() const { return (isFloating() || isPositioned()); }
     virtual bool hasOverhangingFloats() const { return false; }
     virtual bool hasFloats() const { return false; }
     virtual bool containsFloat(RenderObject* /*o*/) const { return false; }
