@@ -30,19 +30,17 @@
 #include "render_arena.h"
 
 #include <assert.h>
-#include <qwidget.h>
-#include <qpainter.h>
-#include <qevent.h>
-#include <qapplication.h>
-#include <qlineedit.h>
+#include <QtGui/QWidget>
+#include <QtGui/QPainter>
+#include <QtGui/QActionEvent>
+#include <QtGui/QApplication>
+#include <QtGui/QLineEdit>
 #include <kglobalsettings.h>
 #include <kurlrequester.h>
-#include <qobject.h>
+#include <QtCore/QObject>
 #include <QVector>
 #include <QMatrix>
-#include <qpaintengine.h>
-#include <Q3ListBox>
-#include <Q3ScrollView>
+#include <QtGui/QPaintEngine>
 
 #include "khtml_ext.h"
 #include "khtmlview.h"
@@ -75,7 +73,7 @@ void RenderReplaced::calcMinMaxWidth()
     KHTMLAssert( !minMaxKnown());
 
 #ifdef DEBUG_LAYOUT
-    kDebug( 6040 ) << "RenderReplaced::calcMinMaxWidth() known=" << minMaxKnown() << endl;
+    kDebug( 6040 ) << "RenderReplaced::calcMinMaxWidth() known=" << minMaxKnown();
 #endif
 
     m_width = calcReplacedWidth();
@@ -569,11 +567,17 @@ static void copyWidget(const QRect& r, QPainter *p, QWidget *widget, int tx, int
         pp.setCompositionMode(QPainter::CompositionMode_Clear);
         pp.eraseRect(r);
         d = pm;
-    }
+    } else
+        p->end();
+
     QPainter::setRedirected(widget, d, buffered ? QPoint(0,0) : -thePoint);
+
     QPaintEvent e( r );
     QApplication::sendEvent(widget, &e);
     QPainter::restoreRedirected(widget);
+
+    if (!p->isActive())
+        p->begin(p->device());
     p->setWorldMatrix( m );
 
     if (buffered) {
@@ -626,7 +630,7 @@ bool RenderWidget::eventFilter(QObject* /*o*/, QEvent* e)
 
     bool filtered = false;
 
-    //kDebug() << "RenderWidget::eventFilter type=" << e->type() << endl;
+    //kDebug() << "RenderWidget::eventFilter type=" << e->type();
     switch(e->type()) {
     case QEvent::FocusOut:
         // First, forward it to the widget, so that Qt gets a precise
@@ -648,7 +652,7 @@ bool RenderWidget::eventFilter(QObject* /*o*/, QEvent* e)
         directToWidget = false;
         filtered       = true; //We already delivered it!
 
-        //kDebug(6000) << "RenderWidget::eventFilter captures FocusIn" << endl;
+        //kDebug(6000) << "RenderWidget::eventFilter captures FocusIn";
         element()->getDocument()->setFocusNode(element());
 //         if ( isEditable() ) {
 //             KHTMLPartBrowserExtension *ext = static_cast<KHTMLPartBrowserExtension *>( element()->view->part()->browserExtension() );
@@ -724,31 +728,6 @@ void RenderWidget::EventPropagator::sendEvent(QEvent *e) {
     }
 }
 
-void RenderWidget::ScrollViewEventPropagator::sendEvent(QEvent *e) {
-    switch(e->type()) {
-    case QEvent::MouseButtonPress:
-        viewportMousePressEvent(static_cast<QMouseEvent *>(e));
-        break;
-    case QEvent::MouseButtonRelease:
-        viewportMouseReleaseEvent(static_cast<QMouseEvent *>(e));
-        break;
-    case QEvent::MouseButtonDblClick:
-        viewportMouseDoubleClickEvent(static_cast<QMouseEvent *>(e));
-        break;
-    case QEvent::MouseMove:
-        viewportMouseMoveEvent(static_cast<QMouseEvent *>(e));
-        break;
-    case QEvent::KeyPress:
-        keyPressEvent(static_cast<QKeyEvent *>(e));
-        break;
-    case QEvent::KeyRelease:
-        keyReleaseEvent(static_cast<QKeyEvent *>(e));
-        break;
-    default:
-        break;
-    }
-}
-
 bool RenderWidget::handleEvent(const DOM::EventImpl& ev)
 {
     bool ret = false;
@@ -856,11 +835,7 @@ bool RenderWidget::handleEvent(const DOM::EventImpl& ev)
         QEvent *e = (ev.id() == EventImpl::KHTML_MOUSEWHEEL_EVENT) ?
                     static_cast<QEvent*>(new QWheelEvent(p, -me.detail()*40, buttons, state, orient)) :
                     static_cast<QEvent*>(new QMouseEvent(type,    p, button, buttons, state));
-        Q3ScrollView * sc = ::qobject_cast<Q3ScrollView*>(target);
-        if (sc && !::qobject_cast<Q3ListBox*>(m_widget))
-            static_cast<ScrollViewEventPropagator *>(sc)->sendEvent(e);
-        else
-            static_cast<EventPropagator *>(target)->sendEvent(e);
+        static_cast<EventPropagator *>(target)->sendEvent(e);
 
         ret = e->isAccepted();
 
