@@ -24,19 +24,13 @@
 #define render_replaced_h
 
 #include "rendering/render_block.h"
-#include <qobject.h>
-#include <q3scrollview.h>
+#include <QtCore/QObject>
 #include <QAbstractScrollArea>
 #include <QScrollBar>
 
 class KHTMLView;
 class QWidget;
 
-namespace DOM
-{
-    class MouseEventImpl;
-}
-
 namespace khtml {
 
 class RenderReplaced : public RenderBox
@@ -92,7 +86,7 @@ public:
 
     virtual void setStyle(RenderStyle *style);
     virtual void paint( PaintInfo& i, int tx, int ty );
-    virtual bool isWidget() const { return true; };
+    virtual bool isWidget() const { return true; }
 
     virtual bool isFrame() const { return false; }
 
@@ -148,7 +142,7 @@ protected:
 
     QWidget *m_widget;
     KHTMLView* m_view;
-    
+
     //Because we mess with normal detach due to ref/deref,
     //we need to keep track of the arena ourselves
     //so it doesn't get yanked from us, etc.
@@ -168,10 +162,6 @@ public:
     public:
         void sendEvent(QEvent *e);
     };
-    class ScrollViewEventPropagator : public Q3ScrollView {
-    public:
-        void sendEvent(QEvent *e);
-    };
 };
 
 class KHTMLWidgetPrivate
