@@ -22,6 +22,8 @@
  *
  */
 
+#include "test_regression.h"
+
 #include <stdlib.h>
 #include <sys/time.h>
 #include <sys/resource.h>
@@ -33,9 +35,8 @@
 #include <kapplication.h>
 #include <kacceleratormanager.h>
 #include <kstandarddirs.h>
-#include <qimage.h>
-#include <qfile.h>
-#include "test_regression.h"
+#include <QtGui/QImage>
+#include <QtCore/QFile>
 #include <stdio.h>
 
 #include "css/cssstyleselector.h"
@@ -43,9 +44,9 @@
 #include "rendering/render_style.h"
 #include "rendering/render_layer.h"
 #include "khtmldefaults.h"
-#include <QProcess>
-#include <QWindowsStyle>
-#include <QStyleOptionSlider>
+#include <QtCore/QProcess>
+#include <QtGui/QWindowsStyle>
+#include <QtGui/QStyleOption>
 
 #include <dom/dom_node.h>
 #include <dom/dom_element.h>
@@ -218,22 +219,21 @@ public:
 #include "khtml_factory.h"
 #include <kio/job.h>
 #include <kmainwindow.h>
-#include <ksimpleconfig.h>
+#include <kconfig.h>
 #include <kglobalsettings.h>
 
-#include <qcolor.h>
-#include <qcursor.h>
-#include <qdir.h>
-#include <qobject.h>
-#include <qpushbutton.h>
-#include <qstring.h>
-#include <qtextstream.h>
-#include <qwidget.h>
-#include <qfileinfo.h>
-#include <qtimer.h>
+#include <QtGui/QColor>
+#include <QtGui/QCursor>
+#include <QtCore/QDir>
+#include <QtCore/QObject>
+#include <QtGui/QPushButton>
+#include <QtCore/QString>
+#include <QtCore/QTextStream>
+#include <QtCore/QFileInfo>
+#include <QtCore/QTimer>
 #include <kstatusbar.h>
 
-#include "misc/decoder.h"
+#include "localization/kencodingdetector.h"
 #include "dom/dom2_range.h"
 #include "dom/dom_exception.h"
 #include "dom/html_document.h"
@@ -369,7 +369,7 @@ ValueImp* RegTestFunction::callAsFunction(ExecState *exec, ObjectImp* /*thisObj*
             if ( str.qstring().toLower().indexOf( "failed!" ) >= 0 )
                 m_regTest->saw_failure = true;
             QString res = str.qstring().replace('\007', "");
-            m_regTest->m_currentOutput += res + "\n";
+            m_regTest->m_currentOutput += res + "\n";	//krazy:exclude=duoblequote_chars DOM demands chars
 	    break;
 	}
 	case ReportResult: {
@@ -389,7 +389,7 @@ ValueImp* RegTestFunction::callAsFunction(ExecState *exec, ObjectImp* /*thisObj*
                 docimpl->updateRendering();
             }
             QString filename = args[0]->toString(exec).qstring();
-            filename = RegressionTest::curr->m_currentCategory+"/"+filename;
+            filename = RegressionTest::curr->m_currentCategory+"/"+filename;	//krazy:exclude=duoblequote_chars DOM demands chars
             int failures = RegressionTest::NoFailure;
             if ( m_regTest->m_genOutput ) {
                 if ( !m_regTest->reportResult( m_regTest->checkOutput(filename+"-dom"),
@@ -483,7 +483,7 @@ ValueImp* KHTMLPartFunction::callAsFunction(ExecState *exec, ObjectImp*/*thisObj
 	    }
 
             QString filename = args[0]->toString(exec).qstring();
-            QString fullFilename = QFileInfo(RegressionTest::curr->m_currentBase+"/"+filename).absoluteFilePath();
+            QString fullFilename = QFileInfo(RegressionTest::curr->m_currentBase+"/"+filename).absoluteFilePath();	//krazy:exclude=duoblequote_chars DOM demands chars
             KUrl url;
             url.setProtocol("file");
             url.setPath(fullFilename);
@@ -505,7 +505,7 @@ ValueImp* KHTMLPartFunction::callAsFunction(ExecState *exec, ObjectImp*/*thisObj
 
             QString filename = args[0]->toString(exec).qstring();
             QString url = args[1]->toString(exec).qstring();
-            QFile file(RegressionTest::curr->m_currentBase+"/"+filename);
+            QFile file(RegressionTest::curr->m_currentBase+"/"+filename);	//krazy:exclude=duoblequote_chars DOM demands chars
 	    if (!file.open(QIODevice::ReadOnly)) {
 		exec->setException(Error::create(exec, GeneralError,
 						 qPrintable(QString("Error reading " + filename))));
@@ -566,28 +566,6 @@ ValueImp* KHTMLPartFunction::callAsFunction(ExecState *exec, ObjectImp*/*thisObj
 
 // -------------------------------------------------------------------------
 
-static KCmdLineOptions options[] =
-{
-    { "b", 0, 0 },
-    { "base <base_dir>", "Directory containing tests, basedir and output directories.", 0},
-    { "d", 0, 0 },
-    { "debug", "Do not suppress debug output", 0},
-    { "g", 0, 0 } ,
-    { "genoutput", "Regenerate baseline (instead of checking)", 0 } ,
-    { "s", 0, 0 } ,
-    { "noshow", "Do not show the window while running tests", 0 } ,
-    { "t", 0, 0 } ,
-    { "test <filename>", "Only run a single test. Multiple options allowed.", 0 } ,
-    { "js",  "Only run .js tests", 0 },
-    { "html", "Only run .html tests", 0},
-    { "noxvfb", "Do not use Xvfb", 0},
-    { "o", 0, 0 },
-    { "output <directory>", "Put output in <directory> instead of <base_dir>/output", 0 } ,
-    { "+[base_dir]", "Directory containing tests,basedir and output directories. Only regarded if -b is not specified.", 0 } ,
-    { "+[testcases]", "Relative path to testcase, or directory of testcases to be run (equivalent to -t).", 0 } ,
-    KCmdLineLastOption
-};
-
 int main(int argc, char *argv[])
 {
     // forget about any settings
@@ -613,13 +591,32 @@ int main(int argc, char *argv[])
     // workaround various Qt crashes by always enforcing a TrueColor visual
     QApplication::setColorSpec( QApplication::ManyColor );
 
-    KCmdLineArgs::init(argc, argv, "testregression", "TestRegression",
-                       "Regression tester for khtml", "1.0");
+    KCmdLineOptions options;
+    options.add("b");
+    options.add("base <base_dir>", ki18n("Directory containing tests, basedir and output directories."));
+    options.add("d");
+    options.add("debug", ki18n("Do not suppress debug output"));
+    options.add("g");
+    options.add("genoutput", ki18n("Regenerate baseline (instead of checking)"));
+    options.add("s");
+    options.add("noshow", ki18n("Do not show the window while running tests"));
+    options.add("t");
+    options.add("test <filename>", ki18n("Only run a single test. Multiple options allowed."));
+    options.add("js", ki18n("Only run .js tests"));
+    options.add("html", ki18n("Only run .html tests"));
+    options.add("noxvfb", ki18n("Do not use Xvfb"));
+    options.add("o");
+    options.add("output <directory>", ki18n("Put output in <directory> instead of <base_dir>/output"));
+    options.add("+[base_dir]", ki18n("Directory containing tests,basedir and output directories. Only regarded if -b is not specified."));
+    options.add("+[testcases]", ki18n("Relative path to testcase, or directory of testcases to be run (equivalent to -t)."));
+
+    KCmdLineArgs::init(argc, argv, "testregression", 0, ki18n("TestRegression"),
+                       "1.0", ki18n("Regression tester for khtml"));
     KCmdLineArgs::addCmdLineOptions(options);
 
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs( );
 
-    QByteArray baseDir = args->getOption("base");
+    QString baseDir = args->getOption("base");
 
     if ( args->count() < 1 && baseDir.isEmpty() ) {
 	KCmdLineArgs::usage();
@@ -634,7 +631,7 @@ int main(int argc, char *argv[])
 
     const char *subdirs[] = {"tests", "baseline", "output", "resources"};
     for ( int i = 0; i < 3; i++ ) {
-        QFileInfo sourceDir(QFile::encodeName( baseDir ) + "/" + subdirs[i]);
+        QFileInfo sourceDir(QFile::encodeName( baseDir ) + "/" + subdirs[i]);	//krazy:exclude=duoblequote_chars DOM demands chars
         if ( !sourceDir.exists() || !sourceDir.isDir() ) {
             fprintf(stderr,"ERROR: Source directory \"%s/%s\": no such directory.\n", (const char *)baseDir, subdirs[i]);
             exit(1);
@@ -678,7 +675,7 @@ int main(int argc, char *argv[])
     KApplication a;
 //    a.disableAutoDcopRegistration();
     a.setStyle( new TestStyle );
-    KSimpleConfig sc1( "cryptodefaults" );
+    KConfig sc1( "cryptodefaults", KConfig::OnlyLocal );
     sc1.setGroup( "Warnings" );
     sc1.writeEntry( "OnUnencrypted",  false );
     KSharedConfigPtr config = KGlobal::mainComponent().config();
@@ -717,7 +714,7 @@ int main(int argc, char *argv[])
     int rv = 1;
 
     if ( args->isSet( "debug" ) ) {
-        KSimpleConfig dc( "kdebugrc" );
+        KConfig dc( "kdebugrc", KConfig::OnlyLocal );
         static int areas[] = { 1000, 6000, 6005, 6010, 6020, 6030,
                                6031, 6035, 6036, 6040, 6041, 6045,
                                6050, 6060, 6061, 7000, 7006, 170,
@@ -771,18 +768,18 @@ int main(int argc, char *argv[])
                                                         args->isSet("genoutput"),
                                                         !args->isSet( "html" ),
                                                         !args->isSet( "js" ));
-    QObject::connect(part->browserExtension(), SIGNAL(openUrlRequest(const KUrl &, const KParts::URLArgs &)),
-		     regressionTest, SLOT(slotOpenURL(const KUrl&, const KParts::URLArgs &)));
+    QObject::connect(part->browserExtension(), SIGNAL(openUrlRequest(const KUrl&, const KParts::OpenUrlArguments&, const KParts::BrowserArguments&)),
+		     regressionTest, SLOT(slotOpenURL(const KUrl&, const KParts::OpenUrlArguments&, const KParts::BrowserArguments&)));
     QObject::connect(part->browserExtension(), SIGNAL(resizeTopLevelWidget( int, int )),
 		     regressionTest, SLOT(resizeTopLevelWidget( int, int )));
 
     bool result = false;
-    QByteArrayList tests = args->getOptionList("test");
+    QStringList tests = args->getOptionList("test");
     // merge testcases specified on command line
     for (; testcase_index < args->count(); testcase_index++)
         tests << args->arg(testcase_index);
     if (tests.count() > 0)
-        foreach (QByteArray test, tests) {
+        foreach (QString test, tests) {
 	    result = regressionTest->runTests(test,true);
             if (!result) break;
         }
@@ -855,12 +852,12 @@ RegressionTest::RegressionTest(KHTMLPart *part, const QString &baseDir, const QS
     m_part = part;
     m_baseDir = baseDir;
     m_baseDir = m_baseDir.replace( "//", "/" );
-    if ( m_baseDir.endsWith( "/" ) )
+    if ( m_baseDir.endsWith( "/" ) )	//krazy:exclude=duoblequote_chars DOM demands chars
         m_baseDir = m_baseDir.left( m_baseDir.length() - 1 );
     if (outputDir.isEmpty())
         m_outputDir = m_baseDir + "/output";
     else {
-        createMissingDirs(outputDir + "/");
+        createMissingDirs(outputDir + "/");	//krazy:exclude=duoblequote_chars DOM demands chars
         m_outputDir = outputDir;
     }
     m_genOutput = _genOutput;
@@ -886,9 +883,9 @@ RegressionTest::RegressionTest(KHTMLPart *part, const QString &baseDir, const QS
     m_paintBuffer = 0;
 
     curr = this;
+    m_part->view()->setFrameStyle(QFrame::StyledPanel | QFrame::Plain);
 }
 
-#include <qobject.h>
 
 static QStringList readListFile( const QString &filename )
 {
@@ -947,7 +944,7 @@ bool RegressionTest::runTests(QString relPath, bool mustExist, QStringList failu
 	QDir sourceDir(m_baseDir + "/tests/"+relPath);
 	for (uint fileno = 0; fileno < sourceDir.count(); fileno++) {
 	    QString filename = sourceDir[fileno];
-	    QString relFilename = relPath.isEmpty() ? filename : relPath+"/"+filename;
+	    QString relFilename = relPath.isEmpty() ? filename : relPath+"/"+filename;	//krazy:exclude=duoblequote_chars DOM demands chars
 
 	    if (filename == "." || filename == ".." ||  ignoreFiles.contains(filename) )
                 continue;
@@ -1171,7 +1168,7 @@ QImage RegressionTest::renderToImage()
 bool RegressionTest::imageEqual( const QImage &lhsi, const QImage &rhsi )
 {
     if ( lhsi.width() != rhsi.width() || lhsi.height() != rhsi.height() ) {
-        kDebug() << "dimensions different " << lhsi.size() << " " << rhsi.size() << endl;
+        kDebug() << "dimensions different " << lhsi.size() << " " << rhsi.size();
         return false;
     }
     int w = lhsi.width();
@@ -1193,7 +1190,7 @@ bool RegressionTest::imageEqual( const QImage &lhsi, const QImage &rhsi )
                      ( abs( qGreen( l ) - qGreen(r ) ) < 20 ) &&
                      ( abs( qBlue( l ) - qBlue(r ) ) < 20 ) )
                     continue;
-                 kDebug() << "pixel (" << x << ", " << y << ") is different " << QColor(  lhsi.pixel (  x, y ) ) << " " << QColor(  rhsi.pixel (  x, y ) ) << endl;
+                 kDebug() << "pixel (" << x << ", " << y << ") is different " << QColor(  lhsi.pixel (  x, y ) ) << " " << QColor(  rhsi.pixel (  x, y ) );
                 return false;
             }
         }
@@ -1204,7 +1201,7 @@ bool RegressionTest::imageEqual( const QImage &lhsi, const QImage &rhsi )
 
 void RegressionTest::createLink( const QString& test, int failures )
 {
-    createMissingDirs( m_outputDir + "/" + test + "-compare.html" );
+    createMissingDirs( m_outputDir + "/" + test + "-compare.html" );	//krazy:exclude=duoblequote_chars DOM demands chars
 
     QFile list( m_outputDir + "/links.html" );
     list.open( QIODevice::WriteOnly|QIODevice::Append );
@@ -1215,11 +1212,11 @@ void RegressionTest::createLink( const QString& test, int failures )
     link += m_currentTest;
     link += "</a> [";
     if ( failures & DomFailure )
-        link += "D";
+        link += "D";	//krazy:exclude=duoblequote_chars DOM demands chars
     if ( failures & RenderFailure )
-        link += "R";
+        link += "R";	//krazy:exclude=duoblequote_chars DOM demands chars
     if ( failures & PaintFailure )
-        link += "P";
+        link += "P";	//krazy:exclude=duoblequote_chars DOM demands chars
     link += "]<br>\n";
     list.write( link.toLatin1(), link.length() );
     list.close();
@@ -1227,13 +1224,13 @@ void RegressionTest::createLink( const QString& test, int failures )
 
 void RegressionTest::doJavascriptReport( const QString &test )
 {
-    QFile compare( m_outputDir + "/" + test + "-compare.html" );
+    QFile compare( m_outputDir + "/" + test + "-compare.html" );	//krazy:exclude=duoblequote_chars DOM demands chars
     if ( !compare.open( QIODevice::WriteOnly|QIODevice::Truncate ) )
-        kDebug() << "failed to open " << m_outputDir + "/" + test + "-compare.html" << endl;
+        kDebug() << "failed to open " << m_outputDir + "/" + test + "-compare.html";	//krazy:exclude=duoblequote_chars DOM demands chars
     QString cl;
     cl = QString( "<html><head><title>%1</title>" ).arg( test );
     cl += "<body><tt>";
-    QString text = "\n" + m_currentOutput;
+    QString text = "\n" + m_currentOutput;	//krazy:exclude=duoblequote_chars DOM demands chars
     text.replace( '<', "&lt;" );
     text.replace( '>', "&gt;" );
     text.replace( QRegExp( "\nFAILED" ), "\n<span style='color: red'>FAILED</span>" );
@@ -1259,8 +1256,8 @@ static QString makeRelativePath(const QString &base, const QString &path)
 {
     QString absBase = QFileInfo(base).absoluteFilePath();
     QString absPath = QFileInfo(path).absoluteFilePath();
-//     kDebug() << "absPath: \"" << absPath << "\"" << endl;
-//     kDebug() << "absBase: \"" << absBase << "\"" << endl;
+//     kDebug() << "absPath: \"" << absPath << "\"";
+//     kDebug() << "absBase: \"" << absBase << "\"";
 
     // walk up to common ancestor directory
     int pos = 0;
@@ -1270,16 +1267,16 @@ static QString makeRelativePath(const QString &base, const QString &path)
         if (newpos == -1) newpos = absBase.length();
         QString cmpPathComp(absPath.unicode() + pos, newpos - pos);
         QString cmpBaseComp(absBase.unicode() + pos, newpos - pos);
-//         kDebug() << "cmpPathComp: \"" << cmpPathComp.string() << "\"" << endl;
-//         kDebug() << "cmpBaseComp: \"" << cmpBaseComp.string() << "\"" << endl;
-//         kDebug() << "pos: " << pos << " newpos: " << newpos << endl;
+//         kDebug() << "cmpPathComp: \"" << cmpPathComp.string() << "\"";
+//         kDebug() << "cmpBaseComp: \"" << cmpBaseComp.string() << "\"";
+//         kDebug() << "pos: " << pos << " newpos: " << newpos;
         if (cmpPathComp != cmpBaseComp) { pos--; break; }
         pos = newpos;
     } while (pos < (int)absBase.length() && pos < (int)absPath.length());
     int basepos = pos < (int)absBase.length() ? pos + 1 : pos;
     int pathpos = pos < (int)absPath.length() ? pos + 1 : pos;
 
-//     kDebug() << "basepos " << basepos << " pathpos " << pathpos << endl;
+//     kDebug() << "basepos " << basepos << " pathpos " << pathpos;
 
     QString rel;
     {
@@ -1290,7 +1287,7 @@ static QString makeRelativePath(const QString &base, const QString &path)
             for (int i = relBase.count('/'); i > 0; --i)
                 rel += "../";
             rel += "..";
-            if (relPath.length() > 0) rel += "/";
+            if (relPath.length() > 0) rel += "/";	//krazy:exclude=duoblequote_chars DOM demands chars
         }
         rel += relPath;
     }
@@ -1311,7 +1308,7 @@ static QString getDiff(QString cmdLine)
 void RegressionTest::doFailureReport( const QString& test, int failures )
 {
     if ( failures == NoFailure ) {
-        ::unlink( QFile::encodeName( m_outputDir + "/" + test + "-compare.html" ) );
+        ::unlink( QFile::encodeName( m_outputDir + "/" + test + "-compare.html" ) );	//krazy:exclude=duoblequote_chars DOM demands chars
         return;
     }
 
@@ -1322,7 +1319,7 @@ void RegressionTest::doFailureReport( const QString& test, int failures )
         return; // no support for both kind
     }
 
-    QFile compare( m_outputDir + "/" + test + "-compare.html" );
+    QFile compare( m_outputDir + "/" + test + "-compare.html" );	//krazy:exclude=duoblequote_chars DOM demands chars
 
     QString testFile = QFileInfo(test).fileName();
 
@@ -1331,7 +1328,7 @@ void RegressionTest::doFailureReport( const QString& test, int failures )
 
     QString relOutputDir = makeRelativePath(m_baseDir, m_outputDir);
 
-    // are blocking reads possible with KProcess?
+    // are blocking reads possible with K3Process?
     QString pwd = QDir::currentPath();
     chdir( QFile::encodeName( m_baseDir ) );
 
@@ -1352,7 +1349,7 @@ void RegressionTest::doFailureReport( const QString& test, int failures )
     chdir( QFile::encodeName( pwd ) );
 
     // create a relative path so that it works via web as well. ugly
-    QString relpath = makeRelativePath(m_outputDir + "/"
+    QString relpath = makeRelativePath(m_outputDir + "/"	//krazy:exclude=duoblequote_chars DOM demands chars
         + QFileInfo(test).path(), m_baseDir);
 
     compare.open( QIODevice::WriteOnly|QIODevice::Truncate );
@@ -1438,11 +1435,11 @@ void RegressionTest::testStaticFile(const QString & filename)
     qApp->mainWidget()->resize( 800, 598 ); // restore size
 
     // Set arguments
-    KParts::URLArgs args;
-    if (filename.endsWith(".html") || filename.endsWith(".htm")) args.serviceType = "text/html";
-    else if (filename.endsWith(".xhtml")) args.serviceType = "application/xhtml+xml";
-    else if (filename.endsWith(".xml")) args.serviceType = "text/xml";
-    m_part->browserExtension()->setUrlArgs(args);
+    KParts::OpenUrlArguments args;
+    if (filename.endsWith(".html") || filename.endsWith(".htm")) args.setMimeType("text/html")
+    else if (filename.endsWith(".xhtml")) args.setMimeType("application/xhtml+xml")
+    else if (filename.endsWith(".xml")) args.setMimeType("text/xml")
+    m_part->setArguments(args);
     // load page
     KUrl url;
     url.setProtocol("file");
@@ -1467,14 +1464,14 @@ void RegressionTest::testStaticFile(const QString & filename)
             {
                 ObjectImp* argArrayObj = comp.value()->toObject(exec);
                 unsigned int length = argArrayObj->
-                                      get(exec,lengthPropertyName)->
+                                      get(exec, "length")->
                                       toUInt32(exec);
                 if ( length == 1 )
                     functionname = argArrayObj->get(exec, 0)->toString(exec).qstring();
             }
         }
         if ( functionname.isNull() ) {
-            kDebug() << "DOM " << filename << " doesn't expose 1 function name - ignoring" << endl;
+            kDebug() << "DOM " << filename << " doesn't expose 1 function name - ignoring";
             return;
         }
 
@@ -1565,14 +1562,14 @@ void RegressionTest::evalJS( ScriptInterpreter &interp, const QString &filename,
                 if (obj)
                     line = obj->get(exec, "line")->toUInt32(exec);
                 printf( "ERROR: %s (%s) at line:%d\n",qPrintable(filename), qPrintable(errmsg), line);
-                doFailureReport( m_currentCategory + "/" + m_currentTest, JSFailure );
+                doFailureReport( m_currentCategory + "/" + m_currentTest, JSFailure );	//krazy:exclude=duoblequote_chars DOM demands chars
                 m_errors++;
             } else {
                 reportResult( true, QString( "Expected Failure: %1" ).arg( errmsg ) );
             }
         } else if ( saw_failure ) {
             if ( !expected_failure )
-                doFailureReport( m_currentCategory + "/" + m_currentTest, JSFailure );
+                doFailureReport( m_currentCategory + "/" + m_currentTest, JSFailure );	//krazy:exclude=duoblequote_chars DOM demands chars
             reportResult( expected_failure, "saw 'failed!'" );
         } else {
             reportResult( !expected_failure, "passed" );
@@ -1611,7 +1608,7 @@ void RegressionTest::testJSFile(const QString & filename )
     {
         if ( ! ::access( QFile::encodeName( basedir + "shell.js" ), R_OK ) )
             evalJS( interp, basedir + "shell.js", false );
-        basedir += *it + "/";
+        basedir += *it + "/";	//krazy:exclude=duoblequote_chars DOM demands chars
     }
     evalJS( interp, m_baseDir + "/tests/"+ filename, true );
 }
@@ -1629,7 +1626,7 @@ RegressionTest::CheckResult RegressionTest::checkPaintdump(const QString &filena
     QImage baseline;
     baseline.load( absFilename, "PNG");
     QImage output = renderToImage();
-    if ( !imageEqual( baseline, output ) ) {
+    if ( !imageEqual( baseline, output ) ) {	//krazy:exclude=duoblequote_chars DOM demands chars
         QString outputFilename = m_outputDir + "/" + againstFilename;
         createMissingDirs(outputFilename );
 
@@ -1644,7 +1641,7 @@ RegressionTest::CheckResult RegressionTest::checkPaintdump(const QString &filena
         output.save(outputFilename, "PNG", 60);
     }
     else {
-        ::unlink( QFile::encodeName( m_outputDir + "/" + againstFilename ) );
+        ::unlink( QFile::encodeName( m_outputDir + "/" + againstFilename ) );	//krazy:exclude=duoblequote_chars DOM demands chars
         result = Success;
     }
     return result;
@@ -1665,7 +1662,7 @@ RegressionTest::CheckResult RegressionTest::checkOutput(const QString &againstFi
     CheckResult result = Success;
 
     // compare result to existing file
-    QString outputFilename = QFileInfo(m_outputDir + "/" + againstFilename).absoluteFilePath();
+    QString outputFilename = QFileInfo(m_outputDir + "/" + againstFilename).absoluteFilePath();	//krazy:exclude=duoblequote_chars DOM demands chars
     bool kf = false;
     if ( m_known_failures & AllFailure )
         kf = true;
@@ -1794,9 +1791,10 @@ void RegressionTest::createMissingDirs(const QString & filename)
     }
 }
 
-void RegressionTest::slotOpenURL(const KUrl &url, const KParts::URLArgs &args)
+void RegressionTest::slotOpenURL(const KUrl &url, const KParts::OpenUrlArguments& args, const KParts::BrowserArguments& browserArgs)
 {
-    m_part->browserExtension()->setUrlArgs( args );
+    m_part->setArguments(args);
+    m_part->browserExtension()->setBrowserArguments(browserArgs);
 
     PartMonitor pm(m_part);
     m_part->openUrl(url);
