@@ -25,13 +25,16 @@
 #define QT_NO_FONTCONFIG 1
 #define QT_NO_FREETYPE   1
 #include <private/qfontengine_p.h>
-#include <qfontdatabase.h>
-#include <qfont.h>
+#ifdef Q_WS_X11
+#  include <private/qfontengine_x11_p.h>
+#endif
+#include <QtGui/QFontDatabase>
+#include <QtGui/QFont>
 #include "khtml_settings.h"
-#include <qwidget.h>
+#include <QtGui/QImage>
 #include <assert.h>
-#include <QX11Info>
-#include <QPainter>
+#include <QtGui/QX11Info>
+#include <QtGui/QPainter>
 #include <fixx11h.h>
 
 struct MetricsInfo {
@@ -560,8 +563,8 @@ void DCOPClient::processSocketData( int )
 {
 }*/
 
-#include <qapplication.h>
-#include <qpalette.h>
+#include <QtGui/QApplication>
+#include <QtGui/QPalette>
 
 #if 0
 KDE_EXPORT void QApplication::setPalette( const QPalette &, bool ,
