@@ -23,17 +23,17 @@
 #include <assert.h>
 #include <signal.h>
 
-#include <QFile>
-#include <QTimer>
-#include <QProcess>
-#include <QFileInfo>
-#include <QTextStream>
-#include <QMainWindow>
+#include <QtCore/QFile>
+#include <QtCore/QTimer>
+#include <QtCore/QProcess>
+#include <QtCore/QFileInfo>
+#include <QtCore/QTextStream>
+#include <QtGui/QMainWindow>
 
 #include <kiconloader.h>
 #include <kmessagebox.h>
-#include <ksimpleconfig.h>
-#include <kdirselectdialog.h>
+#include <kconfig.h>
+#include <kfiledialog.h>
 
 #include "test_regression_gui_window.moc"
 
@@ -76,7 +76,7 @@ TestRegressionWindow::TestRegressionWindow(QWidget *parent)
 	m_ui.treeWidget->headerItem()->setText(0, i18n("Available Tests: 0"));
 
 	// Load default values for tests directory/khtml directory...
-	KSimpleConfig config("testregressiongui");
+	KConfig config("testregressiongui", KConfig::OnlyLocal);
 
 	m_testsUrl = KUrl::fromPath(config.readPathEntry("TestsDirectory"));
 	m_khtmlUrl = KUrl::fromPath(config.readPathEntry("KHTMLDirectory"));
@@ -154,7 +154,7 @@ void TestRegressionWindow::toggleNoXvfbUse(bool checked)
 
 void TestRegressionWindow::setTestsDirectory()
 {
-	m_testsUrl = KDirSelectDialog::selectDirectory(QString(), true /* local only */);
+	m_testsUrl = KFileDialog::getExistingDirectory();
 
 	initTestsDirectory();
 	loadOutputHTML();
@@ -162,7 +162,7 @@ void TestRegressionWindow::setTestsDirectory()
 
 void TestRegressionWindow::setOutputDirectory()
 {
-	m_outputUrl = KDirSelectDialog::selectDirectory(QString(), true /* local only */);
+	m_outputUrl = KFileDialog::getExistingDirectory();
 	loadOutputHTML();
 }
 
@@ -174,7 +174,7 @@ void TestRegressionWindow::initTestsDirectory()
 		const char *subdirs[] = { "tests", "baseline", "output", "resources" };
 		for(int i = 0; i <= 3; i++)
 		{
-			QFileInfo sourceDir(m_testsUrl.path() + "/" + subdirs[i]);
+			QFileInfo sourceDir(m_testsUrl.path() + "/" + subdirs[i]);	//krazy:exclude=duoblequote_chars DOM demands chars
 			if(!sourceDir.exists() || !sourceDir.isDir())
 			{
 				KMessageBox::error(0, i18n("Please choose a valid 'khtmltests/regression/' directory."));
@@ -219,7 +219,7 @@ void TestRegressionWindow::initTestsDirectory()
 			m_failureMap.insert(QString(), failureFileList);
 
 		// Remember directory...
-		KSimpleConfig config("testregressiongui");
+		KConfig config("testregressiongui", KConfig::OnlyLocal);
 		config.writePathEntry("TestsDirectory", m_testsUrl.path());
 
 		// Start listing directory...
@@ -235,14 +235,14 @@ void TestRegressionWindow::initTestsDirectory()
 
 void TestRegressionWindow::setKHTMLDirectory()
 {
-	m_khtmlUrl = KDirSelectDialog::selectDirectory(QString(), true /* local only */);
+	m_khtmlUrl = KFileDialog::getExistingDirectory();
 
 	if(!m_khtmlUrl.isEmpty())
 	{
 		const char *subdirs[] = { "css", "dom", "xml", "html" }; // That's enough ;-)
 		for(int i = 0; i <= 3; i++)
 		{
-			QFileInfo sourceDir(m_khtmlUrl.path() + "/" + subdirs[i]);
+			QFileInfo sourceDir(m_khtmlUrl.path() + "/" + subdirs[i]);	//krazy:exclude=duoblequote_chars DOM demands chars
 			if(!sourceDir.exists() || !sourceDir.isDir())
 			{
 				KMessageBox::error(0, i18n("Please choose a valid 'khtml/' build directory."));
@@ -253,7 +253,7 @@ void TestRegressionWindow::setKHTMLDirectory()
 		}
 
 		// Remember directory...
-		KSimpleConfig config("testregressiongui");
+		KConfig config("testregressiongui", KConfig::OnlyLocal);
 		config.writePathEntry("KHTMLDirectory", m_khtmlUrl.path());
 
 		if(!m_testsUrl.isEmpty() && !m_khtmlUrl.isEmpty())
@@ -270,7 +270,7 @@ void TestRegressionWindow::directoryListingResult(KIO::Job *, const KIO::UDSEntr
 	{
 		const KIO::UDSEntry &entry = *it;
 
-		QString name = entry.stringValue(KIO::UDS_NAME);
+		QString name = entry.stringValue(KIO::UDSEntry::UDS_NAME);
 		if(entry.isDir()) // Create new map entry...
 		{
 			assert(m_directoryMap.constFind(name) == m_directoryMap.constEnd());
@@ -373,7 +373,7 @@ void TestRegressionWindow::directoryListingFinished(KJob *)
 		for(; it2 != end2; ++it2)
 		{
 			QString test = (*it2);
-			QString cacheName = directory + "/" + test;
+			QString cacheName = directory + "/" + test;	//krazy:exclude=duoblequote_chars DOM demands chars
 
 			QTreeWidgetItem *testItem = new QTreeWidgetItem(parent, QStringList(KUrl(test).path()));
 
@@ -399,8 +399,8 @@ void TestRegressionWindow::directoryListingFinished(KJob *)
 				}
 				else
 				{
-					dom[i] = (QFileInfo(baseLinePath + "-" + QString::number(i) + "-dom").exists());
-					render[i] = (QFileInfo(baseLinePath + "-" + QString::number(i) + "-render").exists());
+					dom[i] = (QFileInfo(baseLinePath + "-" + QString::number(i) + "-dom").exists());	//krazy:exclude=duoblequote_chars DOM demands chars
+					render[i] = (QFileInfo(baseLinePath + "-" + QString::number(i) + "-render").exists());	//krazy:exclude=duoblequote_chars DOM demands chars
 				}
 			}
 
@@ -572,7 +572,7 @@ void TestRegressionWindow::pauseContinueButtonClicked()
 void TestRegressionWindow::saveLogButtonClicked()
 {
 	assert(m_activeProcess == 0);
-	m_saveLogUrl = KDirSelectDialog::selectDirectory(QString(), true /* local only */);
+	m_saveLogUrl = KFileDialog::getExistingDirectory();
 
 	QString fileName = m_saveLogUrl.path() + "/logOutput.html";
 	if(QFileInfo(fileName).exists())
@@ -959,7 +959,7 @@ QString TestRegressionWindow::pathFromItem(const QTreeWidgetItem *item) const
 	while(parent != 0)
 	{
 		if(parent->parent() != 0)
-			path.prepend(parent->text(0) + "/");
+			path.prepend(parent->text(0) + "/");	//krazy:exclude=duoblequote_chars DOM demands chars
 
 		parent = parent->parent();
 	}
@@ -974,11 +974,11 @@ QString TestRegressionWindow::extractTestNameFromData(QString &data, TestResult
 		// Name extraction regexps...
 		QString bracesSelector("[0-9a-zA-Z-_<>\\* +-,.:!?$'\"=/\\[\\]\\(\\)]*");
 
-		QRegExp expPass("PASS: (" + bracesSelector + ")");
-		QRegExp expPassUnexpected("PASS \\(unexpected!\\): (" + bracesSelector + ")");
+		QRegExp expPass("PASS: (" + bracesSelector + ")");	//krazy:exclude=duoblequote_chars DOM demands chars
+		QRegExp expPassUnexpected("PASS \\(unexpected!\\): (" + bracesSelector + ")");	//krazy:exclude=duoblequote_chars DOM demands chars
 
-		QRegExp expFail("FAIL: (" + bracesSelector + ")");
-		QRegExp expFailKnown("FAIL \\(known\\): (" + bracesSelector + ")");
+		QRegExp expFail("FAIL: (" + bracesSelector + ")");	//krazy:exclude=duoblequote_chars DOM demands chars
+		QRegExp expFailKnown("FAIL \\(known\\): (" + bracesSelector + ")");	//krazy:exclude=duoblequote_chars DOM demands chars
 
 		// Extract name of test... (while using regexps as rare as possible!)
 		int pos = -1;
@@ -1023,7 +1023,7 @@ QString TestRegressionWindow::extractTestNameFromData(QString &data, TestResult
 
 			assert(m_directoryMap.constFind(cachedDirectory) != m_directoryMap.constEnd());
 
-			QString cacheName = cachedDirectory + "/" + cachedFilename;
+			QString cacheName = cachedDirectory + "/" + cachedFilename;	//krazy:exclude=duoblequote_chars DOM demands chars
 			if(m_itemMap.constFind(cacheName) != m_itemMap.constEnd())
 			{
 				// Highlight test...
@@ -1096,10 +1096,10 @@ void TestRegressionWindow::treeWidgetContextMenuRequested(const QPoint &pos)
 		// Build & show popup menu...
 		QMenu menu(m_ui.treeWidget);
 
-		menu.addAction(SmallIcon("player_play"), i18n("Run test..."), this, SLOT(runSingleTest()));
+		menu.addAction(SmallIcon("media-playback-start"), i18n("Run test..."), this, SLOT(runSingleTest()));
 		menu.addSeparator();
-		menu.addAction(SmallIcon("add"), i18n("Add to ignores..."), this, SLOT(addToIgnores()));
-		menu.addAction(SmallIcon("button_cancel"), i18n("Remove from ignores..."), this, SLOT(removeFromIgnores()));
+		menu.addAction(SmallIcon("list-add"), i18n("Add to ignores..."), this, SLOT(addToIgnores()));
+		menu.addAction(SmallIcon("dialog-cancel"), i18n("Remove from ignores..."), this, SLOT(removeFromIgnores()));
 
 		if(!menu.exec(m_ui.treeWidget->mapToGlobal(pos)))
 			m_activeTreeItem = 0; // Needs reset...
@@ -1148,7 +1148,7 @@ void TestRegressionWindow::updateLogOutput(const QString &data)
 		if(!fileExists)
 			file.write(QString::fromLatin1("<html>\n<body>\n").toAscii());
 
-		file.write((data + "\n").toAscii());
+		file.write((data + "\n").toAscii());	//krazy:exclude=duoblequote_chars DOM demands chars
 		file.close();
 
 		// Reset save log url, if we reached the end...
