@@ -1,7 +1,9 @@
 // program to test the new khtml implementation
 
+#include "testkhtml.h"
+#include "testkhtml.moc"
+
 #include <stdlib.h>
-#include "decoder.h"
 #include "kapplication.h"
 #include "khtmlview.h"
 #include "html_document.h"
@@ -11,10 +13,8 @@
 #define protected public
 #include "khtml_part.h"
 #undef protected
-#include "testkhtml.h"
-#include "testkhtml.moc"
 #include "misc/loader.h"
-#include <qcursor.h>
+#include <QtGui/QCursor>
 #include <dom_string.h>
 #include "dom/dom2_range.h"
 #include "dom/html_document.h"
@@ -26,7 +26,7 @@
 #include "css/cssstyleselector.h"
 #include "html/html_imageimpl.h"
 #include "rendering/render_style.h"
-#include <kmainwindow.h>
+#include <kxmlguiwindow.h>
 #include <kcmdlineargs.h>
 #include <ktoggleaction.h>
 #include <kactioncollection.h>
@@ -34,13 +34,13 @@
 #include "domtreeview.h"
 #include "kxmlguifactory.h"
 
-static KCmdLineOptions options[] = { { "+file", "url to open", 0 } , KCmdLineLastOption };
-
 int main(int argc, char *argv[])
 {
+    KCmdLineOptions options;
+    options.add("+file", ki18n("url to open"));
 
-    KCmdLineArgs::init(argc, argv, "testkhtml", "Testkhtml",
-            "a basic web browser using the KHTML library", "1.0");
+    KCmdLineArgs::init(argc, argv, "testkhtml", 0, ki18n("Testkhtml"),
+            "1.0", ki18n("a basic web browser using the KHTML library"));
     KCmdLineArgs::addCmdLineOptions(options);
 
     KApplication a;
@@ -54,17 +54,17 @@ int main(int argc, char *argv[])
     KHTMLFactory *fac = new KHTMLFactory(true);
 #endif
 
-    KMainWindow *toplevel = new KMainWindow();
+    KXmlGuiWindow *toplevel = new KXmlGuiWindow();
     KHTMLPart *doc = new KHTMLPart( toplevel, toplevel, KHTMLPart::BrowserViewGUI );
 
     Dummy *dummy = new Dummy( doc );
-    QObject::connect( doc->browserExtension(), SIGNAL( openUrlRequest( const KUrl &, const KParts::URLArgs & ) ),
-		      dummy, SLOT( slotOpenURL( const KUrl&, const KParts::URLArgs & ) ) );
+    QObject::connect( doc->browserExtension(), SIGNAL( openUrlRequest(const KUrl&, const KParts::OpenUrlArguments&, const KParts::BrowserArguments &) ),
+		      dummy, SLOT( slotOpenURL( const KUrl&, const KParts::OpenUrlArguments&, const KParts::BrowserArguments& ) ) );
 
     if (args->url(0).url().right(4).toLower() == ".xml") {
-        KParts::URLArgs ags(doc->browserExtension()->urlArgs());
-        ags.serviceType = "text/xml";
-        doc->browserExtension()->setUrlArgs(ags);
+        KParts::OpenUrlArguments args(doc->arguments());
+        args.setMimeType("text/xml");
+        doc->setArguments(args);
     }
 
     doc->openUrl( args->url(0) );
@@ -99,7 +99,7 @@ int main(int argc, char *argv[])
     e.setAttribute( "name", "print" );
     toolBar.insertBefore( e, toolBar.firstChild() );
 
-    KAction *action = new KAction(KIcon("reload"),  "Reload", doc );
+    KAction *action = new KAction(KIcon("view-refresh"),  "Reload", doc );
     doc->actionCollection()->addAction( "reload", action );
     QObject::connect(action, SIGNAL(triggered(bool)), dummy, SLOT( reload() ));
     action->setShortcut(Qt::Key_F5);
@@ -107,7 +107,7 @@ int main(int argc, char *argv[])
     doc->actionCollection()->addAction( "print", kprint );
     QObject::connect(kprint, SIGNAL(triggered(bool)), doc->browserExtension(), SLOT( print() ));
     kprint->setEnabled(true);
-    KToggleAction *ta = new KToggleAction( KIcon("editclear"), "Navigable", doc );
+    KToggleAction *ta = new KToggleAction( KIcon("edit-clear"), "Navigable", doc );
     doc->actionCollection()->addAction( "navigable", ta );
     ta->setShortcuts( KShortcut() );
     ta->setChecked(doc->isCaretMode());
