@@ -23,69 +23,69 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include "dom/dom_exception.h"
+#include "dom_docimpl.h"
 
-#include "xml/dom_textimpl.h"
-#include "xml/dom_xmlimpl.h"
-#include "xml/dom2_rangeimpl.h"
-#include "xml/dom2_eventsimpl.h"
-#include "xml/xml_tokenizer.h"
-#include "html/htmltokenizer.h"
-#include "xml/dom_restyler.h"
+#include <dom/dom_exception.h>
 
-#include "css/csshelper.h"
-#include "css/cssstyleselector.h"
-#include "css/css_stylesheetimpl.h"
-#include "misc/htmlhashes.h"
-#include "misc/helper.h"
-#include "misc/seed.h"
-#include "misc/loader.h"
-#include "ecma/kjs_proxy.h"
-#include "ecma/kjs_binding.h"
+#include "dom_textimpl.h"
+#include "dom_xmlimpl.h"
+#include "dom2_rangeimpl.h"
+#include "dom2_eventsimpl.h"
+#include "xml_tokenizer.h"
+#include <html/htmltokenizer.h>
+#include "dom_restyler.h"
 
-#include <q3ptrstack.h>
-#include <q3paintdevicemetrics.h>
+#include <css/csshelper.h>
+#include <css/cssstyleselector.h>
+#include <css/css_stylesheetimpl.h>
+#include <misc/htmlhashes.h>
+#include <misc/helper.h>
+#include <misc/seed.h>
+#include <misc/loader.h>
+#include <ecma/kjs_proxy.h>
+#include <ecma/kjs_binding.h>
+
+#include <QtCore/QStack>
 //Added by qt3to4:
 #include <QTimerEvent>
 #include <Q3PtrList>
+#include <QtCore/QList>
 #include <kdebug.h>
 #include <klocale.h>
-#include <kstaticdeleter.h>
 
-#include "rendering/counter_tree.h"
-#include "rendering/render_canvas.h"
-#include "rendering/render_replaced.h"
-#include "rendering/render_arena.h"
-#include "rendering/render_layer.h"
-#include "rendering/render_frames.h"
-#include "rendering/render_image.h"
+#include <rendering/counter_tree.h>
+#include <rendering/render_canvas.h>
+#include <rendering/render_replaced.h>
+#include <rendering/render_arena.h>
+#include <rendering/render_layer.h>
+#include <rendering/render_frames.h>
+#include <rendering/render_image.h>
 
-#include "khtmlview.h"
-#include "khtml_part.h"
+#include <khtmlview.h>
+#include <khtml_part.h>
 #include <kauthorized.h>
 #include <kglobalsettings.h>
 #include <kstringhandler.h>
-#include <krfcdate.h>
-#include "khtml_settings.h"
-#include "khtmlpart_p.h"
+#include <kdatetime.h>
+#include <khtml_settings.h>
+#include <khtmlpart_p.h>
 
-#include "html/html_baseimpl.h"
-#include "html/html_blockimpl.h"
-#include "html/html_canvasimpl.h"
-#include "html/html_documentimpl.h"
-#include "html/html_formimpl.h"
-#include "html/html_headimpl.h"
-#include "html/html_imageimpl.h"
-#include "html/html_listimpl.h"
-#include "html/html_miscimpl.h"
-#include "html/html_tableimpl.h"
-#include "html/html_objectimpl.h"
+#include <html/html_baseimpl.h>
+#include <html/html_blockimpl.h>
+#include <html/html_canvasimpl.h>
+#include <html/html_documentimpl.h>
+#include <html/html_formimpl.h>
+#include <html/html_headimpl.h>
+#include <html/html_imageimpl.h>
+#include <html/html_listimpl.h>
+#include <html/html_miscimpl.h>
+#include <html/html_tableimpl.h>
+#include <html/html_objectimpl.h>
 
 #include <kapplication.h>
 #include <kio/job.h>
 
 #include <stdlib.h>
-#include "dom_docimpl.h"
 
 using namespace DOM;
 using namespace khtml;
@@ -299,8 +299,8 @@ ElementMappingCache::ItemInfo* ElementMappingCache::get(const QString& id)
     return m_dict.find(id);
 }
 
-static KStaticDeleter< Q3PtrList<DocumentImpl> > s_changedDocumentsDeleter;
-Q3PtrList<DocumentImpl> * DocumentImpl::changedDocuments;
+typedef QList<DocumentImpl*> ChangedDocuments ;
+K_GLOBAL_STATIC(ChangedDocuments, s_changedDocuments)
 
 // KHTMLView might be 0
 DocumentImpl::DocumentImpl(DOMImplementationImpl *_implementation, KHTMLView *v)
@@ -310,7 +310,6 @@ DocumentImpl::DocumentImpl(DOMImplementationImpl *_implementation, KHTMLView *v)
     m_document.resetSkippingRef(this); //Make getDocument return us..
     m_selfOnlyRefCount = 0;
 
-    m_paintDeviceMetrics = 0;
     m_paintDevice = 0;
     //m_decoderMibEnum = 0;
     m_textColor = Qt::black;
@@ -443,8 +442,8 @@ DocumentImpl::~DocumentImpl()
 
     if (m_loadingXMLDoc)
 	m_loadingXMLDoc->deref(this);
-    if (changedDocuments && m_docChanged)
-        changedDocuments->remove(this);
+    if (s_changedDocuments && m_docChanged)
+        s_changedDocuments->removeAll(this);
     delete m_tokenizer;
     m_document.resetSkippingRef(0);
     delete m_styleSelector;
@@ -453,7 +452,6 @@ DocumentImpl::~DocumentImpl()
     if (m_doctype)
         m_doctype->deref();
     m_implementation->deref();
-    delete m_paintDeviceMetrics;
     delete m_elementMap;
     delete m_attrMap;
     delete m_namespaceMap;
@@ -700,7 +698,7 @@ ElementImpl *DocumentImpl::getElementById( const DOMString &elementId ) const
         return info->nd;
 
     //Now we actually have to walk.
-    Q3PtrStack<NodeImpl> nodeStack;
+    QStack<NodeImpl*> nodeStack;
     NodeImpl *current = _first;
 
     while(1)
@@ -737,7 +735,7 @@ ElementImpl *DocumentImpl::getElementById( const DOMString &elementId ) const
 
     assert(0); //If there is no item with such an ID, we should never get here
 
-    //kDebug() << "WARNING: *DocumentImpl::getElementById not found " << elementId.string() << endl;
+    //kDebug() << "WARNING: *DocumentImpl::getElementById not found " << elementId.string();
 
     return 0;
 }
@@ -1035,7 +1033,7 @@ ElementImpl *DocumentImpl::createHTMLElement( const DOMString &name )
         break;
 // text
     case ID_TEXT:
-        kDebug( 6020 ) << "Use document->createTextNode()" << endl;
+        kDebug( 6020 ) << "Use document->createTextNode()";
         break;
 
     default:
@@ -1103,13 +1101,10 @@ TreeWalkerImpl *DocumentImpl::createTreeWalker(NodeImpl *root, unsigned long wha
 
 void DocumentImpl::setDocumentChanged(bool b)
 {
-    if (!changedDocuments)
-        changedDocuments = s_changedDocumentsDeleter.setObject( changedDocuments, new Q3PtrList<DocumentImpl>() );
-
     if (b && !m_docChanged)
-        changedDocuments->append(this);
+        s_changedDocuments->append(this);
     else if (!b && m_docChanged)
-        changedDocuments->remove(this);
+        s_changedDocuments->removeAll(this);
     m_docChanged = b;
 }
 
@@ -1147,9 +1142,9 @@ void DocumentImpl::recalcStyle( StyleChange change )
             fontDef.size = m_styleSelector->fontSizes()[3];
         }
 
-        //kDebug() << "DocumentImpl::attach: setting to charset " << settings->charset() << endl;
+        //kDebug() << "DocumentImpl::attach: setting to charset " << settings->charset();
         _style->setFontDef(fontDef);
-	_style->htmlFont().update( paintDeviceMetrics() );
+	_style->htmlFont().update( 0 );
         if ( inCompatMode() )
             _style->setHtmlHacks(true); // enable html specific rendering tricks
 
@@ -1167,7 +1162,7 @@ void DocumentImpl::recalcStyle( StyleChange change )
     for (n = _first; n; n = n->nextSibling())
         if ( change>= Inherit || n->hasChangedChild() || n->changed() )
             n->recalcStyle( change );
-    //kDebug( 6020 ) << "TIME: recalcStyle() dt=" << qt.elapsed() << endl;
+    //kDebug( 6020 ) << "TIME: recalcStyle() dt=" << qt.elapsed();
 
     if (changed() && m_view)
 	m_view->layout();
@@ -1186,7 +1181,7 @@ void DocumentImpl::updateRendering()
 
 //     QTime time;
 //     time.start();
-//     kDebug() << "UPDATERENDERING: "<<endl;
+//     kDebug() << "UPDATERENDERING: ";
 
     StyleChange change = NoChange;
 #if 0
@@ -1197,17 +1192,16 @@ void DocumentImpl::updateRendering()
 #endif
     recalcStyle( change );
 
-//    kDebug() << "UPDATERENDERING time used="<<time.elapsed()<<endl;
+//    kDebug() << "UPDATERENDERING time used="<<time.elapsed();
 }
 
 void DocumentImpl::updateDocumentsRendering()
 {
-    if (!changedDocuments)
+    if (!s_changedDocuments)
         return;
 
-    while ( !changedDocuments->isEmpty() ) {
-        changedDocuments->first();
-        DocumentImpl* it = changedDocuments->take();
+    while ( !s_changedDocuments->isEmpty() ) {
+        DocumentImpl* it = s_changedDocuments->takeFirst();
         if (it->isDocumentChanged())
             it->updateRendering();
     }
@@ -1246,7 +1240,7 @@ void DocumentImpl::attach()
     m_styleSelector = new CSSStyleSelector( this, m_usersheet, m_styleSheets, m_url,
                                             !inCompatMode() );
     m_render = new (m_renderArena.get()) RenderCanvas(this, m_view);
-    m_styleSelector->computeFontSizes(paintDeviceMetrics(), m_view ? m_view->part()->zoomFactor() : 100);
+    m_styleSelector->computeFontSizes(m_paintDevice->logicalDpiY(), m_view ? m_view->part()->zoomFactor() : 100);
     recalcStyle( Force );
 
     RenderObject* render = m_render;
@@ -1303,13 +1297,9 @@ khtml::Tokenizer *DocumentImpl::createTokenizer()
     return new khtml::XMLTokenizer(docPtr(),m_view);
 }
 
-void DocumentImpl::setPaintDevice( QPaintDevice *dev )
+int DocumentImpl::logicalDpiY()
 {
-    if (m_paintDevice != dev) {
-        m_paintDevice = dev;
-        delete m_paintDeviceMetrics;
-        m_paintDeviceMetrics = new Q3PaintDeviceMetrics( dev );
-    }
+    return m_paintDevice->logicalDpiY();
 }
 
 void DocumentImpl::open( bool clearEventListeners )
@@ -1431,7 +1421,7 @@ void DocumentImpl::determineParseMode( const QString &/*str*/ )
     // For XML documents, use strict parse mode
     pMode = Strict;
     hMode = XHtml;
-    kDebug(6020) << " using strict parseMode" << endl;
+    kDebug(6020) << " using strict parseMode";
 }
 
 NodeImpl *DocumentImpl::nextFocusNode(NodeImpl *fromNode)
@@ -1706,7 +1696,7 @@ void DocumentImpl::processHttpEquiv(const DOMString &equiv, const DOMString &con
     {
         bool relative = false;
         QString str = content.string().trimmed();
-        time_t expire_date = KRFCDate::parseDate(str);
+        time_t expire_date = KDateTime::fromString(str, KDateTime::RFCDate).toTime_t();
         if (!expire_date)
         {
             expire_date = str.toULong();
@@ -1896,7 +1886,7 @@ NodeImpl::Id DocumentImpl::getId( NodeImpl::IdType _type, DOMStringImpl* _nsURI,
         if (!readonly && id && _prefix && _prefix->l) {
             // we were called in registration mode... check if the alias exists
             const QString px = QString::fromRawData( _prefix->s, _prefix->l );
-            QString qn("aliases: " + (cs ? px : px.toUpper()) + ":" + name);
+            QString qn("aliases: " + (cs ? px : px.toUpper()) + ":" + name);	//krazy:exclude=doublequote_chars DOM demands chars
             if (!map->ids.find( qn )) {
                 map->ids.insert( qn, (void*)id );
             }
@@ -2046,7 +2036,7 @@ void DocumentImpl::removeStyleSheet(StyleSheetImpl *sheet, int *exceptioncode)
 
 void DocumentImpl::updateStyleSelector(bool shallow)
 {
-//    kDebug() << "PENDING " << m_pendingStylesheets << endl;
+//    kDebug() << "PENDING " << m_pendingStylesheets;
 
     // Don't bother updating, since we haven't loaded all our style info yet.
     if (m_pendingStylesheets > 0)
@@ -2512,7 +2502,7 @@ void DocumentImpl::error(int err, const QString &text)
 void DocumentImpl::defaultEventHandler(EventImpl *evt)
 {
     // if any html event listeners are registered on the window, then dispatch them here
-    if (!m_windowEventListeners.listeners)
+    if (!m_windowEventListeners.listeners || evt->propagationStopped())
         return;
 
     QList<RegisteredEventListener>::iterator it;
@@ -2674,12 +2664,21 @@ DOMString DocumentImpl::toString() const
     DOMString result;
 
     for (NodeImpl *child = firstChild(); child != NULL; child = child->nextSibling()) {
-	result += child->toString();
+        result += child->toString();
     }
 
     return result;
 }
 
+void DOM::DocumentImpl::setRestoreState( const QStringList &s)
+{
+    m_state = s;
+}
+
+KHTMLView* DOM::DocumentImpl::view() const
+{
+    return m_view;
+}
 
 KHTMLPart* DOM::DocumentImpl::part() const
 {
@@ -2840,10 +2839,10 @@ DOMString DocumentTypeImpl::toString() const
     if (!m_subset.isEmpty()) {
 	result += " [";
 	result += m_subset;
-	result += "]";
+	result += "]";	//krazy:exclude=doublequote_chars DOM demands chars
     }
 
-    result += ">";
+    result += ">";	//krazy:exclude=doublequote_chars DOM demands chars
 
     return result;
 }
