@@ -34,12 +34,12 @@
 #include "misc/loader.h"
 #include "misc/seed.h"
 
-#include <qstringlist.h>
-#include <q3ptrlist.h>
-#include <qobject.h>
-#include <q3intdict.h>
-#include <q3dict.h>
-#include <qmap.h>
+#include <QtCore/QStringList>
+#include <Qt3Support/Q3PtrList>
+#include <QtCore/QObject>
+#include <Qt3Support/Q3IntDict>
+#include <Qt3Support/Q3Dict>
+#include <QtCore/QMap>
 //Added by qt3to4:
 #include <QTimerEvent>
 
@@ -47,14 +47,12 @@
 
 class QPaintDevice;
 class QTextCodec;
-class Q3PaintDeviceMetrics;
 class KHTMLView;
 
 namespace khtml {
     class Tokenizer;
     class CSSStyleSelector;
     class DocLoader;
-    class CSSStyleSelectorList;
     class RenderArena;
     class RenderObject;
     class CounterNode;
@@ -78,7 +76,6 @@ namespace DOM {
     class EntityReferenceImpl;
     class EventImpl;
     class EventListener;
-    class GenericRONamedNodeMapImpl;
     class HTMLDocumentImpl;
     class HTMLElementImpl;
     class HTMLImageElementImpl;
@@ -88,7 +85,6 @@ namespace DOM {
     class NodeListImpl;
     class ProcessingInstructionImpl;
     class RangeImpl;
-    class RegisteredEventListener;
     class StyleSheetImpl;
     class StyleSheetListImpl;
     class TextImpl;
@@ -278,9 +274,9 @@ public:
     void deregisterMaintainsState(NodeImpl* e) { m_maintainsState.removeRef(e); }
 
     // Set the state the document should restore to
-    void setRestoreState( const QStringList &s) { m_state = s; }
+    void setRestoreState( const QStringList &s);
 
-    KHTMLView *view() const { return m_view; }
+    KHTMLView *view() const;
     KHTMLPart* part() const;
 
     RangeImpl *createRange();
@@ -292,7 +288,6 @@ public:
                             bool entityReferenceExpansion, int &exceptioncode);
 
     virtual void recalcStyle( StyleChange = NoChange );
-    static Q3PtrList<DocumentImpl> * changedDocuments;
     virtual void updateRendering();
     void updateLayout();
     static void updateDocumentsRendering();
@@ -327,7 +322,7 @@ public:
     QString baseTarget() const { return m_baseTarget; }
     void setBaseTarget(const QString& baseTarget) { m_baseTarget = baseTarget; }
 
-    QString completeURL(const QString& url) const { return KUrl(baseURL(),url /*,m_decoderMibEnum*/).url(); };
+    QString completeURL(const QString& url) const { return KUrl(baseURL(),url /*,m_decoderMibEnum*/).url(); }
     DOMString canonURL(const DOMString& url) const { return url.isEmpty() ? url : completeURL(url.string()); }
 
     void setUserStyleSheet(const QString& sheet);
@@ -339,9 +334,9 @@ public:
     virtual khtml::Tokenizer *createTokenizer();
     khtml::Tokenizer *tokenizer() { return m_tokenizer; }
 
-    Q3PaintDeviceMetrics *paintDeviceMetrics() { return m_paintDeviceMetrics; }
-    QPaintDevice *paintDevice() const { return m_paintDevice; }
-    void setPaintDevice( QPaintDevice *dev );
+    void setPaintDevice(QPaintDevice *dev){m_paintDevice = dev;}
+    QPaintDevice *paintDevice() const {return m_paintDevice;}
+    int logicalDpiY();
 
     enum HTMLMode {
         Html3 = 0,
@@ -387,7 +382,7 @@ public:
                                       int *pExceptioncode = 0);
     DOMString getName( NodeImpl::IdType _type, NodeImpl::Id _id ) const;
 
-    StyleSheetListImpl* styleSheets() { return m_styleSheets; };
+    StyleSheetListImpl* styleSheets() { return m_styleSheets; }
 
     DOMString preferredStylesheetSet() const { return m_preferredStylesheetSet; }
     DOMString selectedStylesheetSet() const;
@@ -577,7 +572,6 @@ protected:
     CSSStyleSheetImpl *m_elemSheet;
 
     QPaintDevice *m_paintDevice;
-    Q3PaintDeviceMetrics *m_paintDeviceMetrics;
     ParseMode pMode;
     HTMLMode hMode;
 
@@ -689,7 +683,7 @@ public:
         if (!m_selfOnlyRefCount && !refCount())
             delete this;
     }
-    
+
     // This is called when our last outside reference dies
     virtual void removedLastRef();
 };
