@@ -24,29 +24,31 @@
  */
 
 //#define EVENT_DEBUG
-#include "dom/dom_exception.h"
-#include "dom/dom_node.h"
-#include "dom/html_image.h"
-#include "xml/dom_textimpl.h"
-#include "xml/dom_docimpl.h"
-#include "xml/dom2_eventsimpl.h"
-#include "xml/dom_elementimpl.h"
-#include "xml/dom_restyler.h"
 
-#include "html/dtd.h"
-#include "html/htmlparser.h"
-#include "html/html_imageimpl.h"
+#include "dom_elementimpl.h"
 
-#include "rendering/render_canvas.h"
-#include "misc/htmlhashes.h"
-#include "css/css_valueimpl.h"
-#include "css/css_stylesheetimpl.h"
-#include "css/cssstyleselector.h"
-#include "css/cssvalues.h"
-#include "css/cssproperties.h"
-#include "xml/dom_xmlimpl.h"
+#include <dom/dom_exception.h>
+#include <dom/dom_node.h>
+#include <dom/html_image.h>
+#include "dom_textimpl.h"
+#include "dom_docimpl.h"
+#include "dom2_eventsimpl.h"
+#include "dom_restyler.h"
+#include "dom_xmlimpl.h"
 
-#include <qtextstream.h>
+#include <html/dtd.h>
+#include <html/htmlparser.h>
+#include <html/html_imageimpl.h>
+
+#include <rendering/render_canvas.h>
+#include <misc/htmlhashes.h>
+#include <css/css_valueimpl.h>
+#include <css/css_stylesheetimpl.h>
+#include <css/cssstyleselector.h>
+#include <css/cssvalues.h>
+#include <css/cssproperties.h>
+
+#include <QtCore/QTextIStream>
 #include <QTextDocument>
 #include <kdebug.h>
 #include <stdlib.h>
@@ -141,7 +143,7 @@ DOMString AttrImpl::name() const
         n = n.lower();
 
     if (m_prefix && m_prefix->l)
-        return DOMString(m_prefix) + ":" + n;
+        return DOMString(m_prefix) + ":" + n;	//krazy:exclude=doublequote_chars DOM demands chars
 
     return n;
 }
@@ -852,7 +854,7 @@ bool ElementImpl::childTypeAllowed( unsigned short type )
 void ElementImpl::scrollIntoView(bool /*alignToTop*/)
 {
     // ###
-    kdWarning() << "non-standard scrollIntoView() not implemented" << endl;
+    kWarning() << "non-standard scrollIntoView() not implemented";
 }
 
 void ElementImpl::createDecl( )
@@ -937,7 +939,7 @@ DOMString ElementImpl::openTagStartToString(bool expandurls) const
     if (attrMap) {
 	unsigned long numAttrs = attrMap->length();
 	for (unsigned long i = 0; i < numAttrs; i++) {
-	    result += " ";
+	    result += " ";	//krazy:exclude=doublequote_chars DOM demands chars
 
 	    AttributeImpl *attribute = attrMap->attrAt(i);
 	    AttrImpl *attr = attribute->attr();
@@ -977,7 +979,7 @@ DOMString ElementImpl::selectionToString(NodeImpl *selectionStart, NodeImpl *sel
     DOMString result = openTagStartToString();
 
     if (hasChildNodes()) {
-	result += ">";
+	result += ">";	//krazy:exclude=doublequote_chars DOM demands chars
 
 	for (NodeImpl *child = firstChild(); child != NULL; child = child->nextSibling()) {
 	    result += child->selectionToString(selectionStart, selectionEnd, startOffset, endOffset, found); // this might set found to true
@@ -988,7 +990,7 @@ DOMString ElementImpl::selectionToString(NodeImpl *selectionStart, NodeImpl *sel
 
 	result += "</";
 	result += tagName();
-	result += ">";
+	result += ">";	//krazy:exclude=doublequote_chars DOM demands chars
     } else {
 	result += " />";
     }
@@ -1001,18 +1003,18 @@ DOMString ElementImpl::toString() const
     QString result = openTagStartToString().string(); //Accumulate in QString, since DOMString can't append well.
 
     if (hasChildNodes()) {
-	result += ">";
+	result += ">";	//krazy:exclude=doublequote_chars DOM demands chars
 
 	for (NodeImpl *child = firstChild(); child != NULL; child = child->nextSibling()) {
 	    DOMString kid = child->toString();
-	    result += QConstString(kid.unicode(), kid.length()).string();
+	    result += QString::fromRawData(kid.unicode(), kid.length());
 	}
 
 	result += "</";
 	result += tagName().string();
-	result += ">";
+	result += ">";	//krazy:exclude=doublequote_chars DOM demands chars
     } else if (result.length() == 1) {
-	// ensure we dont get results like < /> can happen when serialize document
+	// ensure we do not get results like < /> can happen when serialize document
         result = "";
     } else {
 	result += " />";
@@ -1026,7 +1028,7 @@ bool ElementImpl::contentEditable() const {
     DOM::CSSPrimitiveValueImpl *val = static_cast<DOM::CSSPrimitiveValueImpl *>
     		(const_cast<ElementImpl *>(this)->styleRules()
 		->getPropertyCSSValue(CSS_PROP__KONQ_USER_INPUT));
-//    kDebug() << "val" << val << endl;
+//    kDebug() << "val" << val;
     return val ? val->getIdent() == CSS_VAL_ENABLED : false;
 #endif
     return NodeImpl::contentEditable();
@@ -1046,7 +1048,7 @@ void ElementImpl::setContentEditable(bool enabled) {
         // FIXME: reset caret if it is in this node or a child
     }/*end if*/
     // FIXME: use addCSSProperty when I get permission to move it here
-//    kDebug(6000) << "CSS_PROP__KHTML_USER_INPUT: "<< value << endl;
+//    kDebug(6000) << "CSS_PROP__KHTML_USER_INPUT: "<< value;
     styleRules()->setProperty(CSS_PROP__KHTML_USER_INPUT, value, false, true);
     setChanged();
 
@@ -1090,7 +1092,7 @@ DOMString XMLElementImpl::tagName() const
         tn = tn.upper();
 
     if (m_prefix)
-        return DOMString(m_prefix) + ":" + tn;
+        return DOMString(m_prefix) + ":" + tn;	//krazy:exclude=doublequote_chars DOM demands chars
 
     return tn;
 }
