@@ -23,27 +23,27 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include "dom/dom_exception.h"
-#include "misc/htmlattrs.h"
-#include "misc/htmltags.h"
-#include "xml/dom_elementimpl.h"
-#include "xml/dom_textimpl.h"
-#include "xml/dom2_eventsimpl.h"
-#include "xml/dom_docimpl.h"
-#include "xml/dom_nodeimpl.h"
-#include "xml/dom_restyler.h"
+#include "dom_nodeimpl.h"
+
+#include <dom/dom_exception.h>
+#include <misc/htmlattrs.h>
+#include <misc/htmltags.h>
+#include "dom_elementimpl.h"
+#include "dom_textimpl.h"
+#include "dom2_eventsimpl.h"
+#include "dom_docimpl.h"
+#include "dom_restyler.h"
 
 #include <kglobal.h>
 #include <kdebug.h>
 
-#include "rendering/render_text.h"
-#include "rendering/render_flow.h"
-#include "rendering/render_line.h"
+#include <rendering/render_text.h>
+#include <rendering/render_flow.h>
+#include <rendering/render_line.h>
 
-#include "ecma/kjs_proxy.h"
-#include "khtmlview.h"
-#include "khtml_part.h"
-#include "dom_nodeimpl.h"
+#include <ecma/kjs_proxy.h>
+#include <khtmlview.h>
+#include <khtml_part.h>
 //Added by qt3to4:
 #include <QMouseEvent>
 #include <QKeyEvent>
@@ -209,6 +209,80 @@ void NodeImpl::setPrefix(const DOMString &/*_prefix*/, int &exceptioncode )
     exceptioncode = DOMException::NAMESPACE_ERR;
 }
 
+DOMString NodeImpl::textContent() const
+{
+    switch (nodeType()) {
+    case Node::TEXT_NODE:
+    case Node::CDATA_SECTION_NODE:
+    case Node::COMMENT_NODE:
+    case Node::PROCESSING_INSTRUCTION_NODE:
+	return nodeValue();
+        
+    case Node::ELEMENT_NODE:
+    case Node::ATTRIBUTE_NODE:
+    case Node::ENTITY_NODE:
+    case Node::ENTITY_REFERENCE_NODE:
+    case Node::DOCUMENT_FRAGMENT_NODE: {
+        DOMString s = "";
+
+        if (nodeType() == Node::ATTRIBUTE_NODE)
+            s += nodeValue();
+
+	for (NodeImpl *child = firstChild(); child; child = child->nextSibling()) {
+            if (child->nodeType() == Node::COMMENT_NODE ||
+                child->nodeType() == Node::PROCESSING_INSTRUCTION_NODE)
+                    continue;
+
+                s += child->textContent();
+            }
+
+            return s;
+        }
+        
+    case Node::DOCUMENT_NODE:
+    case Node::DOCUMENT_TYPE_NODE:
+    case Node::NOTATION_NODE:
+    default:
+	return DOMString();            
+    }
+}
+
+void NodeImpl::setTextContent(const DOMString& text, int& ec)
+{
+    if (isReadOnly()) {
+        ec = DOMException::NO_MODIFICATION_ALLOWED_ERR;
+        return;
+    }
+
+    switch (nodeType()) {
+        case Node::TEXT_NODE:
+        case Node::CDATA_SECTION_NODE:
+        case Node::COMMENT_NODE:
+        case Node::PROCESSING_INSTRUCTION_NODE:
+            setNodeValue(text, ec);
+            break;
+        case Node::ELEMENT_NODE:
+        case Node::ATTRIBUTE_NODE:
+        case Node::ENTITY_NODE:
+        case Node::ENTITY_REFERENCE_NODE:
+        case Node::DOCUMENT_FRAGMENT_NODE: {
+            NodeBaseImpl *container = static_cast<NodeBaseImpl *>(this);
+            
+            container->removeChildren();
+            
+            if (!text.isEmpty())
+                appendChild(getDocument()->createTextNode(text.implementation()), ec);
+            break;
+        }
+        case Node::DOCUMENT_NODE:
+        case Node::DOCUMENT_TYPE_NODE:
+        case Node::NOTATION_NODE:
+        default:
+            // Do nothing
+            break;
+    }
+}
+
 DOMString NodeImpl::localName() const
 {
     return DOMString();
@@ -234,11 +308,11 @@ void NodeImpl::getCaret(int offset, bool override, int &_x, int &_y, int &width,
 	long r_ofs;
 	bool outside, outsideEnd;
 #if 0
-kDebug(6200) << "getCaret: node " << this << " " << nodeName().string() << " offset: " << offset << endl;
+kDebug(6200) << "getCaret: node " << this << " " << nodeName().string() << " offset: " << offset;
 #endif
         mapDOMPosToRenderPos(this, offset, r, r_ofs, outside, outsideEnd);
 #if 0
-kDebug(6200) << "getCaret: r " << r << " " << (r?r->renderName():QString()) << " r_ofs: " << r_ofs << " outside " << outside << " outsideEnd " << outsideEnd << endl;
+kDebug(6200) << "getCaret: r " << r << " " << (r?r->renderName():QString()) << " r_ofs: " << r_ofs << " outside " << outside << " outsideEnd " << outsideEnd;
 #endif
 	if (r) {
             r->caretPos(r_ofs, override*RenderObject::CFOverride
@@ -575,7 +649,7 @@ void NodeImpl::dispatchSubtreeModifiedEvent()
 bool NodeImpl::dispatchKeyEvent(QKeyEvent *key, bool keypress)
 {
     int exceptioncode = 0;
-    //kDebug(6010) << "DOM::NodeImpl: dispatching keyboard event" << endl;
+    //kDebug(6010) << "DOM::NodeImpl: dispatching keyboard event";
     EventImpl* keyEventImpl;
     if (keypress)
         keyEventImpl = new TextEventImpl(key, getDocument()->defaultView());
@@ -625,7 +699,7 @@ void NodeImpl::handleLocalEvents(EventImpl *evt, bool useCapture)
     }
 }
 
-void NodeImpl::defaultEventHandler(EventImpl *e)
+void NodeImpl::defaultEventHandler(EventImpl*)
 {
 }
 
@@ -1036,7 +1110,7 @@ DocumentImpl* NodeImpl::ownerDocument() const
 
 NodeBaseImpl::~NodeBaseImpl()
 {
-    //kDebug( 6020 ) << "NodeBaseImpl destructor" << endl;
+    //kDebug( 6020 ) << "NodeBaseImpl destructor";
     // we have to tell all children, that the parent has died...
     NodeImpl *n;
     NodeImpl *next;
@@ -1383,7 +1457,7 @@ bool NodeBaseImpl::checkSameDocument( NodeImpl *newChild, int &exceptioncode )
     DocumentImpl *ownerDocThis = getDocument();
     DocumentImpl *ownerDocNew = newChild->getDocument();
     if(ownerDocThis != ownerDocNew) {
-        kDebug(6010)<< "not same document, newChild = " << newChild << "document = " << getDocument() << endl;
+        kDebug(6010)<< "not same document, newChild = " << newChild << "document = " << getDocument();
         exceptioncode = DOMException::WRONG_DOCUMENT_ERR;
         return true;
     }
@@ -1407,7 +1481,7 @@ NodeImpl *NodeBaseImpl::addChild(NodeImpl *newChild)
     // short check for consistency with DTD
     if(getDocument()->isHTMLDocument() && !childAllowed(newChild))
     {
-        //kDebug( 6020 ) << "AddChild failed! id=" << id() << ", child->id=" << newChild->id() << endl;
+        //kDebug( 6020 ) << "AddChild failed! id=" << id() << ", child->id=" << newChild->id();
         return 0;
     }
 
@@ -1683,7 +1757,7 @@ NodeImpl *NodeListImpl::item( unsigned long index ) const
     bool usedCache = false;
     if (m_cache->current.node) {
         //Compute distance from the requested index to the cache node
-        unsigned long cacheDist = QABS(long(index) - long(m_cache->position));
+        unsigned long cacheDist = qAbs(long(index) - long(m_cache->position));
 
         if (cacheDist < (unsigned long)index) { //Closer to the cached position
             usedCache = true;
