@@ -34,14 +34,12 @@
 // The namespace used for XHTML elements
 #define XHTML_NAMESPACE "http://www.w3.org/1999/xhtml"
 
-class QPainter;
 template <class type> class Q3PtrList;
 template <class type> class QList;
 class KHTMLView;
 class QRect;
 class QMouseEvent;
 class QKeyEvent;
-class QTextStream;
 
 namespace khtml {
     class RenderStyle;
@@ -54,7 +52,6 @@ namespace DOM {
 class NodeListImpl;
 class NamedNodeMapImpl;
 class DocumentImpl;
-class CSSStyleDeclarationImpl;
 class RegisteredEventListener;
 class EventImpl;
 
@@ -152,6 +149,9 @@ public:
     virtual bool containsOnlyWhitespace() const { return false; }
     virtual bool contentEditable() const;
 
+    DOMString textContent() const;
+    void setTextContent(const DOMString& text, int& ec);
+
     // helper functions not being part of the DOM
     // Attention: they assume that the caller did the consistency checking!
     void setPreviousSibling(NodeImpl *previous) { m_previous = previous; }
@@ -372,8 +372,8 @@ public:
      */
     virtual void close();
 
-    virtual void structureChanged() {};
-    virtual void backwardsStructureChanged() {};
+    virtual void structureChanged() {}
+    virtual void backwardsStructureChanged() {}
 
     void createRendererIfNeeded();
     virtual khtml::RenderStyle *styleForRenderer(khtml::RenderObject *parent);
