@@ -19,13 +19,14 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include "dom/dom_exception.h"
+#include "dom_xmlimpl.h"
 
-#include "xml/dom_xmlimpl.h"
-#include "xml/dom_docimpl.h"
-#include "xml/dom_stringimpl.h"
-#include "css/css_stylesheetimpl.h"
-#include "misc/loader.h"
+#include <dom/dom_exception.h>
+
+#include "dom_docimpl.h"
+#include "dom_stringimpl.h"
+#include <css/css_stylesheetimpl.h>
+#include <misc/loader.h>
 
 using namespace DOM;
 
@@ -128,7 +129,7 @@ DOMString EntityImpl::toString() const
     DOMString result = "<!ENTITY' ";
 
     if (m_name && m_name->l != 0) {
-	result += " ";
+	result += " ";	//krazy:exclude=doublequote_chars DOM demands chars
 	result += m_name;
     }
 
@@ -149,7 +150,7 @@ DOMString EntityImpl::toString() const
 	result += m_notationName;
     }
 
-    result += ">";
+    result += ">";	//krazy:exclude=doublequote_chars DOM demands chars
 
     return result;
 }
@@ -215,7 +216,7 @@ DOMString EntityReferenceImpl::toString() const
 {
     DOMString result = "&";
     result += m_entityName;
-    result += ";";
+    result += ";";	//krazy:exclude=doublequote_chars DOM demands chars
 
     return result;
 }
@@ -458,9 +459,9 @@ DOMString ProcessingInstructionImpl::toString() const
 {
     DOMString result = "<?";
     result += m_target;
-    result += " ";
+    result += " ";	//krazy:exclude=doublequote_chars DOM demands chars
     result += m_data;
-    result += ">";
+    result += ">";	//krazy:exclude=doublequote_chars DOM demands chars
     return result;
 }
 
