@@ -34,7 +34,7 @@
 
 #include "khtmlview.h"
 #include "khtml_part.h"
-#include <qvariant.h>
+#include <QtCore/QVariant>
 #include <kdebug.h>
 #include <klocale.h>
 
@@ -115,7 +115,10 @@ NodeImpl *XMLHandler::popNode()
 
 NodeImpl *XMLHandler::currentNode() const
 {
-    return m_nodes.current();
+    if ( m_nodes.isEmpty() )
+        return 0;
+    else
+        return m_nodes.top();
 }
 
 QString XMLHandler::errorProtocol()
@@ -152,7 +155,7 @@ void XMLHandler::fixUpNSURI(QString& uri, const QString& qname)
 {
     /* QXml does not resolve the namespaces of attributes in the same 
        tag that preceed the xmlns declaration. This fixes up that case */
-    if (uri.isEmpty() && qname.find(':') != -1) {
+    if (uri.isEmpty() && qname.indexOf(':') != -1) {
         QXmlNamespaceSupport ns;
         QString localName, prefix;
         ns.splitName(qname, prefix, localName);
@@ -465,8 +468,8 @@ void XMLTokenizer::finish()
             line = stream.readLine();
 
             for (unsigned long colno = 0; colno < m_handler.errorCol-1; colno++)
-                errorLocPtr += " ";
-            errorLocPtr += "^";
+                errorLocPtr += ' ';
+            errorLocPtr += '^';
         }
 
         // Create elements for display
@@ -483,7 +486,7 @@ void XMLTokenizer::finish()
         if ( !line.isNull() ) {
             hr = doc->createElementNS(XHTML_NAMESPACE,"hr");
             pre = doc->createElementNS(XHTML_NAMESPACE,"pre");
-            lineText = doc->createTextNode(line+"\n");
+            lineText = doc->createTextNode(line+'\n');
             errorLocText = doc->createTextNode(errorLocPtr);
         }
 
