@@ -23,12 +23,11 @@
 #ifndef _XML_Tokenizer_h_
 #define _XML_Tokenizer_h_
 
-#include <qxml.h>
-#include <q3ptrlist.h>
-#include <q3ptrstack.h>
-#include <QStack>
+#include <Qt/qxml.h>
+#include <Qt3Support/Q3PtrList>
+#include <QtCore/QStack>
 #include <QMap>
-#include <qobject.h>
+#include <QtCore/QObject>
 #include "misc/loader_client.h"
 #include "misc/stringit.h"
 
@@ -103,7 +102,7 @@ private:
     QString errorProt;
     DOM::DocumentImpl *m_doc;
     KHTMLView *m_view;
-    Q3PtrStack<DOM::NodeImpl> m_nodes;
+    QStack<DOM::NodeImpl*> m_nodes;
     DOM::NodeImpl *m_rootNode;
 
     enum State {
