@@ -1,18 +1,17 @@
-// Oliver Eiden <o.eiden@pop.ruhr.de>
-// 23.3.99
-// changed the mapping from 3-3-2 decoded pixels to 8-8-8 decoded true-color pixels
-// now it uses the same mapping as xv, this leads to better visual results
-// Patch merged in HEAD by Chris Spiegel <matrix@xirtam.org>
-// This library is distributed under the conditions of the GNU LGPL.
+/**
+* QImageIO Routines to read/write XV images.
+* copyright (c) 1998 Torben Weis <weis@kde.org>
+* copyright (c) 1999 Oliver Eiden <o.eiden@pop.ruhr.de>
+*
+* This library is distributed under the conditions of the GNU LGPL.
+*/
+
+#include "xview.h"
 
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-#include <qimage.h>
-
-#include <kdelibs_export.h>
-
-#include "xview.h"
+#include <QtGui/QImage>
 
 #define BUFSIZE 1024
 
@@ -140,20 +139,19 @@ bool XVHandler::write(const QImage &image)
     f.write( str, strlen( str ) );
 
 
+    QImage tmpImage( image );
     if ( image.depth() == 1 )
-    {
-        image.convertToFormat( QImage::Format_Indexed8, Qt::AutoColor );
-    }
+        tmpImage = image.convertToFormat( QImage::Format_Indexed8, Qt::AutoColor );
 
     uchar* buffer = new uchar[ w ];
 
     for ( int py = 0; py < h; py++ )
     {
-        const uchar *data = image.scanLine( py );
+        const uchar *data = tmpImage.scanLine( py );
         for ( int px = 0; px < w; px++ )
         {
             int r, g, b;
-            if ( image.depth() == 32 )
+            if ( tmpImage.depth() == 32 )
             {
                 const QRgb *data32 = (QRgb*) data;
                 r = qRed( *data32 ) >> 5;
@@ -163,7 +161,7 @@ bool XVHandler::write(const QImage &image)
             }
             else
             {
-                QRgb color = image.color( *data );
+                QRgb color = tmpImage.color( *data );
                 r = qRed( color ) >> 5;
                 g = qGreen( color ) >> 5;
                 b = qBlue( color ) >> 6;
