@@ -19,7 +19,6 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include "config.h"
 #include <config.h>
 
 #include <sys/types.h>
@@ -34,7 +33,7 @@
 
 #include <errno.h>
 #include <fcntl.h>
-#include <setproctitle.h>
+#include "proctitle.h"
 #include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -42,14 +41,14 @@
 #include <unistd.h>
 #include <locale.h>
 
-#include <QLibrary>
-#include <qstring.h>
-#include <qfile.h>
-#include <qdatetime.h>
-#include <qfileinfo.h>
-#include <qtextstream.h>
-#include <qregexp.h>
-#include <qfont.h>
+#include <QtCore/QLibrary>
+#include <QtCore/QString>
+#include <QtCore/QFile>
+#include <QtCore/QDate>
+#include <QtCore/QFileInfo>
+#include <QtCore/QTextStream>
+#include <QtCore/QRegExp>
+#include <QtGui/QFont>
 #include <kcomponentdata.h>
 #include <kstandarddirs.h>
 #include <kglobal.h>
@@ -495,7 +494,7 @@ static pid_t launch(int argc, const char *_name, const char *args,
        QString argvexe = s_instance->dirs()->findExe(QString::fromLatin1(d.argv[0]));
        if (!argvexe.isEmpty()) {
           QByteArray cstr = argvexe.toLocal8Bit();
-          kDebug() << "kdeinit4: launch() setting argv: " << cstr.data() << endl;
+          kDebug(7016) << "kdeinit4: launch() setting argv: " << cstr.data();
           d.argv[0] = strdup(cstr.data());
        }
 #endif
@@ -514,11 +513,11 @@ static pid_t launch(int argc, const char *_name, const char *args,
        /* set the process name, so that killall works like intended */
        r = prctl(PR_SET_NAME, (unsigned long) name.data(), 0, 0, 0);
        if ( r == 0 )
-           kdeinit_setproctitle( "%s [kdeinit]%s", name.data(), procTitle.data() ? procTitle.data() : "" );
+           proctitle_set( "%s [kdeinit]%s", name.data(), procTitle.data() ? procTitle.data() : "" );
        else
-           kdeinit_setproctitle( "kdeinit4: %s%s", name.data(), procTitle.data() ? procTitle.data() : "" );
+           proctitle_set( "kdeinit4: %s%s", name.data(), procTitle.data() ? procTitle.data() : "" );
 #else
-       kdeinit_setproctitle( "kdeinit4: %s%s", name.data(), procTitle.data() ? procTitle.data() : "" );
+       proctitle_set( "kdeinit4: %s%s", name.data(), procTitle.data() ? procTitle.data() : "" );
 #endif
      }
 
@@ -602,7 +601,7 @@ static pid_t launch(int argc, const char *_name, const char *args,
      if (d.debug_wait)
      {
         fprintf(stderr, "kdeinit4: Suspending process\n"
-                        "kdeinit4: 'gdb kdeinit %d' to debug\n"
+                        "kdeinit4: 'gdb kdeinit4 %d' to debug\n"
                         "kdeinit4: 'kill -SIGCONT %d' to continue\n",
                         getpid(), getpid());
         kill(getpid(), SIGSTOP);
@@ -1402,7 +1401,7 @@ static void kdeinit_library_path()
    QStringList candidates = s_instance->dirs()->resourceDirs("lib");
    for (QStringList::ConstIterator it = candidates.begin();
         it != candidates.end();
-        it++)
+        ++it)
    {
       QString d = *it;
       if (ltdl_library_path.contains(d))
@@ -1637,7 +1636,7 @@ int main(int argc, char **argv, char **envp)
          keep_running = 0;
       if (strcmp(safe_argv[i], "--help") == 0)
       {
-        printf("Usage: kdeinit [options]\n");
+        printf("Usage: kdeinit4 [options]\n");
      // printf("    --no-dcop         Do not start dcopserver\n");
      // printf("    --no-klauncher    Do not start klauncher\n");
         printf("    --no-kded         Do not start kded\n");
@@ -1659,7 +1658,8 @@ int main(int argc, char **argv, char **envp)
       d.initpipe[1] = -1;
       // wait till init is complete
       char c;
-      while( read(d.initpipe[0], &c, 1) < 0);
+      while( read(d.initpipe[0], &c, 1) < 0)
+          ;
       // then exit;
       close(d.initpipe[0]);
       d.initpipe[0] = -1;
@@ -1674,17 +1674,16 @@ int main(int argc, char **argv, char **envp)
       setsid();
 
    /** Create our instance **/
-   s_instance = new KComponentData("kdeinit4"); // "kdeinit4" is special cased in KComponentData to not register with KGlobal
+   s_instance = new KComponentData("kdeinit4", QByteArray(), KComponentData::SkipMainComponentRegistration);
 
    /** Prepare to change process name **/
-   kdeinit_initsetproctitle(argc, argv, envp);
-   kdeinit_setproctitle("kdeinit Starting up...");
+   proctitle_init(argc, argv, envp);
    kdeinit_library_path();
    // Don't make our instance the global instance
    // (do it only after kdeinit_library_path, that one indirectly uses KConfig,
-   // which seems to be buggy and always use KGlobal instead of the maching KComponentData)
+   // which seems to be buggy and always use KGlobal instead of the matching KComponentData)
    Q_ASSERT(!KGlobal::hasMainComponent());
-   // don't change envvars before kdeinit_initsetproctitle()
+   // don't change envvars before proctitle_init()
    unsetenv("LD_BIND_NOW");
    unsetenv("DYLD_BIND_AT_LAUNCH");
    KApplication::loadedByKdeinit = true;
@@ -1703,18 +1702,24 @@ int main(int argc, char **argv, char **envp)
    if (keep_running)
    {
       /*
-       * Create ~/.kde/tmp-<hostname>/kdeinit-<display> socket for incoming wrapper
+       * Create ~/.kde/tmp-<hostname>/kdeinit4-<display> socket for incoming wrapper
        * requests.
        */
       init_kdeinit_socket();
    }
-
+#ifdef Q_WS_X11
    if (!d.suicide && !getenv("KDE_IS_PRELINKED"))
    {
-       QLibrary l("konq");
-       l.setLoadHints(QLibrary::ExportExternalSymbolsHint);
-       l.load();
+       QString konq = KStandardDirs::locate("lib", "libkonq.so.5", *s_instance);
+       // can't use KLibLoader here as it would unload the library
+       // again
+       if (!konq.isEmpty()) {
+           QLibrary l(konq);
+           l.setLoadHints(QLibrary::ExportExternalSymbolsHint);
+           l.load();
+       }
    }
+#endif
    if (launch_klauncher)
    {
       pid = launch( 1, "klauncher", 0 );
@@ -1744,7 +1749,7 @@ int main(int argc, char **argv, char **envp)
 
    if (launch_kded)
    {
-      pid = launch( 1, "kded", 0 );
+      pid = launch( 1, KDED_EXENAME, 0 );
 #ifndef NDEBUG
       fprintf(stderr, "kdeinit4: Launched KDED, pid = %ld result = %d\n", (long) pid, d.result);
 #endif
@@ -1781,7 +1786,7 @@ int main(int argc, char **argv, char **envp)
    }
    free (safe_argv);
 
-   kdeinit_setproctitle("kdeinit Running...");
+   proctitle_set("kdeinit4 Running...");
 
    if (!keep_running)
       return 0;
@@ -1796,3 +1801,4 @@ int main(int argc, char **argv, char **envp)
    return 0;
 }
 
+
