@@ -19,19 +19,19 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
 #include <stdlib.h>
 #include <stdio.h>
 #include <errno.h>
 
-#include <qstring.h>
-#include <QLibrary>
-#include <QFile>
+#include <QtCore/QString>
+#include <QtCore/QLibrary>
+#include <QtCore/QFile>
 #ifdef Q_WS_WIN
 #include <QStringList>
+#include <QProcess>
+#include <windows.h>
 #endif
 
 #ifndef Q_WS_WIN
@@ -101,6 +101,28 @@ int main(int argc, char **argv)
         }
      }
 
+#ifdef Q_WS_WIN
+     // enter debugger in case debugging is actived 
+     QString mSlaveDebug = getenv("KDE_SLAVE_DEBUG_WAIT");
+
+     if (mSlaveDebug == argv[2]) 
+#ifdef Q_CC_GNU
+     {
+        // gdb does not support win32 jit debug support, so implement it by ourself
+        QByteArray buf(1024,0);
+        GetModuleFileName(NULL,buf.data(),buf.size());
+        QStringList params;
+        params << buf;
+        params << QString::number(GetCurrentProcessId());
+        QProcess::startDetached("gdb",params);
+        Sleep(1000);
+     }
+#else
+        // msvc: windbg supports jit debugging, require install windbg jit with windbg -i
+        DebugBreak();
+#endif
+#endif
+
      int (*func)(int, char *[]) = (int (*)(int, char *[])) sym;
 
      exit( func(argc-1, argv+1)); /* Launch! */
