@@ -17,6 +17,10 @@
   Boston, MA 02110-1301, USA.
 */
 
+#include "klauncher.h"
+#include "klauncher_cmds.h"
+#include "klauncher_adaptor.h"
+
 #include <config.h>
 
 #include <stdio.h>
@@ -26,7 +30,7 @@
 #include <signal.h>
 #include <sys/time.h>
 
-#include <qfile.h>
+#include <QtCore/QFile>
 
 #include <kconfig.h>
 #include <kdebug.h>
@@ -39,35 +43,37 @@
 #include <ktemporaryfile.h>
 #include <kurl.h>
 
-#include "kio/global.h"
-#include "kio/connection.h"
-#include "kio/slaveinterface.h"
-
-#include "klauncher.h"
-#include "klauncher_cmds.h"
-#include "klauncher_adaptor.h"
+#include <kio/global.h>
+#include <kio/connection.h>
+#include <kio/slaveinterface.h>
 
 #ifdef Q_WS_X11
 #include <kstartupinfo.h>
 #include <X11/Xlib.h>
 #endif
 
+#include <QtCore/QCoreApplication>
+
 // Dispose slaves after being idle for SLAVE_MAX_IDLE seconds
 #define SLAVE_MAX_IDLE	30
 
 using namespace KIO;
-using namespace KNetwork;
 
-IdleSlave::IdleSlave(KStreamSocket *socket)
+IdleSlave::IdleSlave(QObject *parent)
+    : QObject(parent)
 {
-   mConn.init(socket);
-   mConn.connect(this, SLOT(gotInput()));
+   QObject::connect(&mConn, SIGNAL(readyRead()), this, SLOT(gotInput()));
+   // Send it a SLAVE_STATUS command.
    mConn.send( CMD_SLAVE_STATUS );
    mPid = 0;
    mBirthDate = time(0);
    mOnHold = false;
 }
 
+template<int T> struct PIDType { typedef pid_t PID_t; } ;
+template<> struct PIDType<2> { typedef qint16 PID_t; } ;
+template<> struct PIDType<4> { typedef qint32 PID_t; } ;
+
 void
 IdleSlave::gotInput()
 {
@@ -91,11 +97,13 @@ IdleSlave::gotInput()
    else
    {
       QDataStream stream( data );
+      PIDType<sizeof(pid_t)>::PID_t stream_pid;
       pid_t pid;
-      QString protocol;
+      QByteArray protocol;
       QString host;
       qint8 b;
-      stream >> pid >> protocol >> host >> b;
+      stream >> stream_pid >> protocol >> host >> b;
+      pid = stream_pid;
 // Overload with (bool) onHold, (KUrl) url.
       if (!stream.atEnd())
       {
@@ -107,7 +115,7 @@ IdleSlave::gotInput()
 
       mPid = pid;
       mConnected = (b != 0);
-      mProtocol = protocol;
+      mProtocol = QString::fromLatin1(protocol);
       mHost = host;
       emit statusUpdate(this);
    }
@@ -170,28 +178,14 @@ KLauncher::KLauncher(int _kdeinitSocket)
            SIGNAL(serviceOwnerChanged(QString,QString,QString)),
            SLOT(slotNameOwnerChanged(QString,QString,QString)));
 
-   QString prefix = KStandardDirs::locateLocal("socket", "klauncher");
-   KTemporaryFile *domainname = new KTemporaryFile();
-   domainname->setPrefix(prefix);
-   domainname->setSuffix(QLatin1String(".slave-socket"));
-   domainname->setAutoRemove(false);
-   if (!domainname->open())
+   mConnectionServer.listenForRemote();
+   connect(&mConnectionServer, SIGNAL(newConnection()), SLOT(acceptSlave()));
+   if (!mConnectionServer.isListening())
    {
-      // Sever error!
+      // Severe error!
       qDebug("KLauncher: Fatal error, can't create tempfile!");
       ::_exit(1);
    }
-   mPoolSocketName = domainname->fileName();
-#ifdef __CYGWIN__
-   domainname->setAutoRemove(true);
-#endif
-   delete domainname;
-
-   mPoolSocket.setAddress(QFile::encodeName(mPoolSocketName));
-   mPoolSocket.setAcceptBuffered(false); // we use KStreamSockets
-   connect(&mPoolSocket, SIGNAL(readyAccept()),
-           SLOT(acceptSlave()));
-   mPoolSocket.listen();
 
    connect(&mTimer, SIGNAL(timeout()), SLOT(idleTimeout()));
 
@@ -226,11 +220,6 @@ KLauncher::~KLauncher()
 
 void KLauncher::close()
 {
-   if (!mPoolSocketName.isEmpty())
-   {
-      const QByteArray filename = QFile::encodeName(mPoolSocketName);
-      unlink(filename.data());
-   }
 #ifdef Q_WS_X11
    if( mCached_dpy != NULL )
        XCloseDisplay( mCached_dpy );
@@ -240,9 +229,9 @@ void KLauncher::close()
 void
 KLauncher::destruct(int exit_code)
 {
-   if (qApp) ((KLauncher*)qApp)->close();
-   // We don't delete qApp here, that's intentional.
-   ::_exit(exit_code);
+    if (QCoreApplication::instance()) ((KLauncher*)QCoreApplication::instance())->close();
+    // We don't delete the app here, that's intentional.
+    ::_exit(exit_code);
 }
 
 void KLauncher::setLaunchEnv(const QString &name, const QString &value)
@@ -306,7 +295,7 @@ KLauncher::slotKDEInitData(int)
                             sizeof( request_header));
    if (result == -1)
    {
-      kDebug() << "Exiting on read_socket errno: " << errno << endl;
+      kDebug(7016) << "Exiting on read_socket errno:" << errno;
       ::signal( SIGHUP, SIG_IGN);
       ::signal( SIGTERM, SIG_IGN);
       destruct(255); // Exit!
@@ -315,20 +304,26 @@ KLauncher::slotKDEInitData(int)
    result = read_socket(kdeinitSocket, (char *) requestData.data(),
                         request_header.arg_length);
 
-   if (request_header.cmd == LAUNCHER_DIED)
+   processRequestReturn(request_header.cmd,requestData);
+       
+}
+   
+void KLauncher::processRequestReturn(int status, const QByteArray &requestData)
+{   
+   if (status == LAUNCHER_DIED)
    {
      long *request_data;
      request_data = (long *) requestData.data();
      processDied(request_data[0], request_data[1]);
      return;
    }
-   if (lastRequest && (request_header.cmd == LAUNCHER_OK))
+   if (lastRequest && (status == LAUNCHER_OK))
    {
      long *request_data;
      request_data = (long *) requestData.data();
      lastRequest->pid = (pid_t) (*request_data);
-     kDebug(7016) << lastRequest->name << " (pid " << lastRequest->pid <<
-        ") up and running." << endl;
+     kDebug(7016).nospace() << lastRequest->name << " (pid " << lastRequest->pid <<
+        ") up and running.";
      switch(lastRequest->dbus_startup_type)
      {
        case KService::DBUS_None:
@@ -343,17 +338,17 @@ KLauncher::slotKDEInitData(int)
      lastRequest = 0;
      return;
    }
-   if (lastRequest && (request_header.cmd == LAUNCHER_ERROR))
+   if (lastRequest && (status == LAUNCHER_ERROR))
    {
      lastRequest->status = KLaunchRequest::Error;
+     kDebug(7016) << lastRequest->name << " failed." << endl;
      if (!requestData.isEmpty())
         lastRequest->errorMsg = QString::fromUtf8((char *) requestData.data());
      lastRequest = 0;
      return;
    }
 
-   kWarning(7016) << "Unexpected command from KDEInit (" << (unsigned int) request_header.cmd
-                 << ")" << endl;
+   kWarning(7016)<< "Unexpected request return" << (unsigned int) status;
 }
 
 void
@@ -365,7 +360,8 @@ KLauncher::processDied(pid_t pid, long /* exitStatus */)
       {
          if (request->dbus_startup_type == KService::DBUS_Wait)
             request->status = KLaunchRequest::Done;
-         else if ((request->dbus_startup_type == KService::DBUS_Unique) && QDBusConnection::sessionBus().interface()->isServiceRegistered(request->dbus_name))
+         else if ((request->dbus_startup_type == KService::DBUS_Unique)
+                  && QDBusConnection::sessionBus().interface()->isServiceRegistered(request->dbus_name))
             request->status = KLaunchRequest::Running;
          else
             request->status = KLaunchRequest::Error;
@@ -513,10 +509,11 @@ KLauncher::requestDone(KLaunchRequest *request)
       if ( requestResult.dbusName.isNull() ) // null strings can't be sent
           requestResult.dbusName = "";
       Q_ASSERT( !requestResult.error.isNull() );
+      PIDType<sizeof(pid_t)>::PID_t stream_pid = requestResult.pid;
       QDBusConnection::sessionBus().send(request->transaction.createReply(QVariantList() << requestResult.result
                                      << requestResult.dbusName
                                      << requestResult.error
-                                     << requestResult.pid));
+                                     << stream_pid));
    }
    requestList.removeAll( request );
    delete request;
@@ -828,7 +825,7 @@ KLauncher::kdeinit_exec(const QString &app, const QStringList &args,
 
    for(QStringList::ConstIterator it = args.begin();
        it != args.end();
-       it++)
+       ++it)
    {
        QString arg = *it;
        request->arg_list.append(arg.toLocal8Bit());
@@ -845,7 +842,7 @@ KLauncher::kdeinit_exec(const QString &app, const QStringList &args,
    request->startup_id = startup_id;
 #endif
    request->envs = envs;
-   if( app != "kbuildsycoca" ) // avoid stupid loop
+   if( !app.endsWith("kbuildsycoca4") ) // avoid stupid loop
    {
        // Find service, if any - strip path if needed
        KService::Ptr service = KService::serviceByDesktopName( app.mid( app.lastIndexOf( '/' ) + 1 ));
@@ -910,10 +907,13 @@ pid_t
 KLauncher::requestHoldSlave(const KUrl &url, const QString &app_socket)
 {
     IdleSlave *slave = 0;
-    foreach (slave, mSlaveList)
+    foreach (IdleSlave *p, mSlaveList)
     {
-       if (slave->onHold(url))
+       if (p->onHold(url))
+       {
+          slave = p;
           break;
+       }
     }
     if (slave)
     {
@@ -932,25 +932,34 @@ KLauncher::requestSlave(const QString &protocol,
                         QString &error)
 {
     IdleSlave *slave = 0;
-    foreach (slave, mSlaveList)
+    foreach (IdleSlave *p, mSlaveList)
     {
-       if (slave->match(protocol, host, true))
-          break;
-    }
-    if (!slave)
-    {
-       foreach (slave, mSlaveList)
+       if (p->match(protocol, host, true))
        {
-          if (slave->match(protocol, host, false))
-             break;
+          slave = p;
+          break;
        }
     }
     if (!slave)
     {
-       foreach (slave, mSlaveList)
+       foreach (IdleSlave *p, mSlaveList)
        {
-          if (slave->match(protocol, QString(), false))
+          if (p->match(protocol, host, false))
+          {
+             slave = p;
              break;
+          }
+       }
+    }
+    if (!slave)
+    {
+       foreach (IdleSlave *p, mSlaveList)
+       {
+          if (p->match(protocol, QString(), false))
+          {
+             slave = p;
+             break;
+          }
        }
     }
     if (slave)
@@ -968,15 +977,15 @@ KLauncher::requestSlave(const QString &protocol,
     }
 
     QString arg1 = protocol;
-    QString arg2 = QString::fromLocal8Bit(QFile::encodeName(mPoolSocketName));
-    QString arg3 = QString::fromLocal8Bit(QFile::encodeName(app_socket));
+    QString arg2 = mConnectionServer.address();
+    QString arg3 = app_socket;
     QStringList arg_list;
     arg_list.append(arg1);
     arg_list.append(arg2);
     arg_list.append(arg3);
 
-    kDebug(7016) << "KLauncher: launching new slave " << name << " with protocol=" << protocol
-        << " args=" << arg_list << endl;
+    //kDebug(7016) << "KLauncher: launching new slave " << name << " with protocol=" << protocol
+    //    << " args=" << arg_list << endl;
     if (mSlaveDebug == arg1)
     {
        klauncher_header request_header;
@@ -1008,7 +1017,7 @@ KLauncher::requestSlave(const QString &protocol,
     requestStart(request);
     pid_t pid = request->pid;
 
-//    kDebug(7016) << "Slave launched, pid = " << pid << endl;
+//    kDebug(7016) << "Slave launched, pid = " << pid;
 
     // We don't care about this request any longer....
     requestDone(request);
@@ -1037,14 +1046,12 @@ KLauncher::waitForSlave(int pid, const QDBusMessage &msg)
 void
 KLauncher::acceptSlave()
 {
-    // the cast is safe, because KServerSocket promises us so
-    KStreamSocket* slaveSocket = static_cast<KStreamSocket*>(mPoolSocket.accept());
-    IdleSlave *slave = new IdleSlave(slaveSocket);
-    // Send it a SLAVE_STATUS command.
+    IdleSlave *slave = new IdleSlave(this);
+    mConnectionServer.setNextPendingConnection(&slave->mConn);
     mSlaveList.append(slave);
     connect(slave, SIGNAL(destroyed()), this, SLOT(slotSlaveGone()));
     connect(slave, SIGNAL(statusUpdate(IdleSlave *)),
-	    this, SLOT(slotSlaveStatus(IdleSlave *)));
+           this, SLOT(slotSlaveStatus(IdleSlave *)));
     if (!mTimer.isActive())
     {
        mTimer.start(1000*10);
@@ -1102,7 +1109,7 @@ void KLauncher::reparseConfiguration()
       slave->reparseConfiguration();
 }
 
-void 
+void
 KLauncher::slotGotOutput()
 {
 }
