@@ -23,16 +23,13 @@
 #include <sys/types.h>
 #include <unistd.h>
 #include <time.h>
-#include <qstring.h>
-#include <qsocketnotifier.h>
-#include <qtimer.h>
-#include <qlist.h>
-#include <qobject.h>
+#include <QtCore/QString>
+#include <QtCore/QSocketNotifier>
+#include <QtCore/QTimer>
+#include <QtCore/QList>
+#include <QtCore/QObject>
 
 #include <kurl.h>
-#include <kstreamsocket.h>
-#include <kserversocket.h>
-
 #include <kio/connection.h>
 
 #include <kservice.h>
@@ -49,7 +46,7 @@ class IdleSlave : public QObject
 {
    Q_OBJECT
 public:
-   IdleSlave(KNetwork::KStreamSocket *socket);
+   explicit IdleSlave(QObject *parent);
    bool match( const QString &protocol, const QString &host, bool connected);
    void connect( const QString &app_socket);
    pid_t pid() const { return mPid;}
@@ -64,8 +61,9 @@ Q_SIGNALS:
 protected Q_SLOTS:
    void gotInput();
 
-protected:
+public:
    KIO::Connection mConn;
+protected:
    QString mProtocol;
    QString mHost;
    bool mConnected;
@@ -188,10 +186,9 @@ protected:
    QList<KLaunchRequest*> requestQueue; // Requests waiting to being handled
    KLaunchRequest *lastRequest;
    QList<SlaveWaitRequest*> mSlaveWaitRequest;
-   QString mPoolSocketName;
    int kdeinitSocket;
    QSocketNotifier *kdeinitNotifier;
-   KNetwork::KServerSocket mPoolSocket;
+   KIO::ConnectionServer mConnectionServer;
    QList<IdleSlave*> mSlaveList;
    QTimer mTimer;
    QTimer mAutoTimer;
@@ -204,6 +201,7 @@ protected:
 #ifdef Q_WS_X11
    Display *mCached_dpy;
 #endif
+   void processRequestReturn(int status, const QByteArray &requestData);
 
 protected Q_SLOTS:
     void slotGotOutput();
