@@ -17,7 +17,7 @@
   Boston, MA 02110-1301, USA.
 */
 
-#include "config.h"
+#include <config.h>
 
 #include <unistd.h>
 #include <fcntl.h>
@@ -32,7 +32,7 @@
 #include <klocale.h>
 
 #include "klauncher_cmds.h"
-#include <QCoreApplication>
+#include <QtCore/QCoreApplication>
 
 #ifndef Q_WS_WIN
 static void sig_handler(int sig_num)
@@ -52,7 +52,7 @@ extern "C" KDE_EXPORT int kdemain( int argc, char**argv )
    if (fcntl(LAUNCHER_FD, F_GETFD) == -1)
    {
       fprintf(stderr, "%s", i18n("klauncher: This program is not supposed to be started manually.\n"
-                                 "klauncher: It is started automatically by kdeinit.\n").toLocal8Bit().data());
+                                 "klauncher: It is started automatically by kdeinit4.\n").toLocal8Bit().data());
       return 1;
    }
 #endif
@@ -62,24 +62,25 @@ extern "C" KDE_EXPORT int kdemain( int argc, char**argv )
    putenv(strdup("SESSION_MANAGER="));
 
    // Allow the locale to initialize properly
-   KLocale::setMainCatalog("kdelibs");
+   KLocale::setMainCatalog("kdelibs4");
 
    // We need a QCoreApplication to get a DBus event loop
    QCoreApplication app(argc, argv);
+   app.setApplicationName( componentData.componentName() );
 
    int maxTry = 3;
    while(true)
    {
       QString service(QLatin1String("org.kde.klauncher")); // same as ktoolinvocation.cpp
       if (!QDBusConnection::sessionBus().isConnected()) {
-         kWarning() << "No DBUS session-bus found. Check if you have started the DBUS server." << endl;
+         kWarning() << "No DBUS session-bus found. Check if you have started the DBUS server.";
          return 1;
       }
       QDBusReply<QDBusConnectionInterface::RegisterServiceReply> reply =
           QDBusConnection::sessionBus().interface()->registerService(service);
       if (!reply.isValid())
       {
-         kWarning() << "DBUS communication problem!" << endl;
+         kWarning() << "DBUS communication problem!";
          return 1;
       }
       if (reply == QDBusConnectionInterface::ServiceRegistered)
@@ -87,12 +88,12 @@ extern "C" KDE_EXPORT int kdemain( int argc, char**argv )
 
       if (--maxTry == 0)
       {
-         kWarning() << "Another instance of klauncher is already running!" << endl;
+         kWarning() << "Another instance of klauncher is already running!";
          return 1;
       }
 
       // Wait a bit...
-      kWarning() << "Waiting for already running klauncher to exit." << endl;
+      kWarning() << "Waiting for already running klauncher to exit.";
       sleep(1);
 
       // Try again...
