@@ -26,10 +26,10 @@
 #include <errno.h>
 #include <signal.h>
 
-#include <qglobal.h>
-#include <QFile>
-#include <QProcess>
-#include <QCoreApplication>
+#include <QtCore/QBool>
+#include <QtCore/QFile>
+#include <QtCore/QProcess>
+#include <QtCore/QCoreApplication>
 
 #include <kconfig.h>
 #include <kdebug.h>
@@ -56,232 +56,17 @@ QList<QProcess *>processList;
 #define TRACE()
 #endif
 
-#if 0
-/* note:
-   this is an initial version of klauncher for win32
-   by replacing all kdeinit related calls (mywrite/myread) to a local handler
-   handle_request() which is mostly taken from the related parts of kinit.cpp
-
-   The current state is, that klauncher is registrated in dbus, request are processed
-   but process fails to start because of missing shared libraries.
-
-   @TODO: fix indention
-   @TODO: remove TRACE, when debugging is over
-   @TODO: implement kio slave starting
-   @TODO: added env support
-
-*/
-klauncher_header response_header;
-char response_data[1024];
-
-/*
-  @TODO: need some cleanup
-*/
-int handle_request(klauncher_header request_header, char *request_data)
-{
-   TRACE();
-   if (request_header.cmd == LAUNCHER_OK)
-   {
-      return true;
-   }
-   else if (request_header.arg_length &&
-      ((request_header.cmd == LAUNCHER_EXEC) ||
-       (request_header.cmd == LAUNCHER_EXT_EXEC) ||
-       (request_header.cmd == LAUNCHER_SHELL ) ||
-       (request_header.cmd == LAUNCHER_KWRAPPER) ||
-       (request_header.cmd == LAUNCHER_EXEC_NEW)))
-   {
-      QStringList arglist;
-      QStringList envlist;
-      pid_t pid;
-      long l;
-      memcpy( &l, request_data, sizeof( long ));
-      int argc = l;
-      char *name = request_data + sizeof(long);
-      char *args = name + strlen(name) + 1;
-      const char *cwd = 0;
-      int envc = 0;
-      const char *envs = 0;
-      const char *tty = 0;
-      int avoid_loops = 0;
-      const char *startup_id_str = "0";
-
-//#ifndef NTRACE
-    int launcher;
-     fprintf(stderr, "kdeinit4: Got %s '%s' from %s.\n",
-        (request_header.cmd == LAUNCHER_EXEC ? "EXEC" :
-        (request_header.cmd == LAUNCHER_EXT_EXEC ? "EXT_EXEC" :
-        (request_header.cmd == LAUNCHER_EXEC_NEW ? "EXEC_NEW" :
-        (request_header.cmd == LAUNCHER_SHELL ? "SHELL" : "KWRAPPER" )))),
-         name, launcher ? "launcher" : "socket" );
-//#endif
-
-      char *arg_n = args;
-      for(int i = 1; i < argc; i++)
-      {
-        arglist << arg_n;
-        arg_n = arg_n + strlen(arg_n) + 1;
-      }
-
-      if( request_header.cmd == LAUNCHER_SHELL || request_header.cmd == LAUNCHER_KWRAPPER )
-      {
-         // Shell or kwrapper
-         cwd = arg_n; arg_n += strlen(cwd) + 1;
-      }
-      if( request_header.cmd == LAUNCHER_SHELL || request_header.cmd == LAUNCHER_KWRAPPER
-          || request_header.cmd == LAUNCHER_EXT_EXEC || request_header.cmd == LAUNCHER_EXEC_NEW )
-      {
-         memcpy( &l, arg_n, sizeof( long ));
-         envc = l;
-         arg_n += sizeof(long);
-         envs = arg_n;
-         for(int i = 0; i < envc; i++)
-         {
-           envlist << arg_n;
-           arg_n = arg_n + strlen(arg_n) + 1;
-         }
-         if( request_header.cmd == LAUNCHER_KWRAPPER )
-         {
-             tty = arg_n;
-             arg_n += strlen( tty ) + 1;
-         }
-      }
-
-     if( request_header.cmd == LAUNCHER_SHELL || request_header.cmd == LAUNCHER_KWRAPPER
-         || request_header.cmd == LAUNCHER_EXT_EXEC || request_header.cmd == LAUNCHER_EXEC_NEW )
-     {
-         memcpy( &l, arg_n, sizeof( long ));
-         avoid_loops = l;
-         arg_n += sizeof( long );
-     }
-
-     if( request_header.cmd == LAUNCHER_SHELL || request_header.cmd == LAUNCHER_KWRAPPER
-         || request_header.cmd == LAUNCHER_EXT_EXEC )
-     {
-         startup_id_str = arg_n;
-         arg_n += strlen( startup_id_str ) + 1;
-     }
-
-     if ((request_header.arg_length > (arg_n - request_data)) &&
-         (request_header.cmd == LAUNCHER_EXT_EXEC || request_header.cmd == LAUNCHER_EXEC_NEW ))
-     {
-         // Optional cwd
-         cwd = arg_n; arg_n += strlen(cwd) + 1;
-     }
-
-     if ((arg_n - request_data) != request_header.arg_length)
-     {
-//#ifndef NTRACE
-       fprintf(stderr, "kdeinit4: EXEC request has invalid format.\n");
-//#endif
-       return false;
-     }
-    fprintf(stderr,"argc %d, name %s, args %s, cwd %s, envc %s, envs %s\n",
-      argc, name, args, cwd, envc, envs);
-
-    QProcess *process  = new QProcess;
-//      process.setEnvironment(envlist);
-    process->start(name,arglist);
-    QByteArray _stderr = process->readAllStandardError();
-    QByteArray _stdout = process->readAllStandardOutput();
-    fprintf(stderr,"%s",_stdout.data());
-    fprintf(stderr,"%s",_stderr.data());
-
-    _PROCESS_INFORMATION* _pid = process->pid();
-    pid = _pid ? _pid->dwProcessId : 0;
-
-    fprintf(stderr,"pid = %d\n",pid);
-
-    if (pid) {
-      response_header.cmd = LAUNCHER_OK;
-      response_header.arg_length = sizeof(long);
-      *((long*)response_data) = pid;
-      fprintf(stderr,"return pid\n");
-    }
-    else {
-      char *error = "error occured";
-      response_header.cmd = LAUNCHER_ERROR;
-      response_header.arg_length = strlen(error)+1;
-      strcpy(response_data,error);
-      fprintf(stderr,"return error\n");
-    }
-    return 0;
-  }
-  return true;     
-}
-
-
-int mywrite(int sock, void *p, int len)
-{
-   TRACE();
-  char *buf = (char *)p;
-  fprintf(stderr,"write len:%d data:\n",len);
-  for (int i = 0; i < len; i++)
-    fprintf(stderr,"%02x '%c'\n",buf[i],buf[i] >= 0x20 ? buf[i] : ' ');
-  fprintf(stderr,"\n");
-
-  char *request_data = 0;
-  static klauncher_header request_header;
-  static int waitforData = 0;
-  if (!waitforData) {
-    request_header = *(klauncher_header*)p;
-    if ( request_header.arg_length != 0 )
-      waitforData = 1;
-    else {
-      char *data = "";
-      handle_request(request_header,data);
-      return 0;
-    }
-  }
-  else {
-    waitforData = 0;
-    handle_request(request_header,buf);
-  }
-  return len;
-}
-int myread(int sock, void *buf, int len)
-{
-   TRACE();
-  static int sendData = 0;
-  klauncher_header *request_header = (klauncher_header*)buf;
-  fprintf(stderr,"cmd=%d",response_header.cmd);
-
-  if (response_header.cmd && sendData) {
-    memcpy(buf,response_data,response_header.arg_length);
-    sendData = 0;
-    response_header.cmd = 0;
-    fprintf(stderr,"read data len=%d return len=%d\n",len,response_header.arg_length);
-    return sizeof(response_header.arg_length);
-  }
-  else if (response_header.cmd) {
-    fprintf(stderr,"return header\n");
-    request_header->cmd = response_header.cmd;
-    request_header->arg_length = response_header.arg_length;
-    if (response_header.arg_length)
-      sendData = 1;
-    fprintf(stderr,"read header len=%d return len=%d\n",len,sizeof(*request_header));
-    return sizeof(*request_header);
-  }
-  else {
-    request_header->cmd = LAUNCHER_OK;
-    request_header->arg_length = 0;
-    fprintf(stderr,"read default len=%d return len=%d\n",len,sizeof(*request_header));
-    return sizeof(*request_header);
-  }
-}
-#endif
 
 // Dispose slaves after being idle for SLAVE_MAX_IDLE seconds
 #define SLAVE_MAX_IDLE  30
 
 using namespace KIO;
-using namespace KNetwork;
 
-IdleSlave::IdleSlave(KStreamSocket *socket)
+IdleSlave::IdleSlave(QObject *parent)
+    : QObject(parent)
 {
    TRACE();
-   mConn.init(socket);
-   mConn.connect(this, SLOT(gotInput()));
+   QObject::connect(&mConn, SIGNAL(readyRead()), this, SLOT(gotInput()));
    mConn.send( CMD_SLAVE_STATUS );
    mPid = 0;
    mBirthDate = time(0);
@@ -397,32 +182,15 @@ KLauncher::KLauncher(int _kdeinitSocket)
            SIGNAL(serviceOwnerChanged(QString,QString,QString)),
            SLOT(slotNameOwnerChanged(QString,QString,QString)));
 
-#ifndef Q_WS_WIN
-   QString prefix = KStandardDirs::locateLocal("socket", "klauncher");
-   KTemporaryFile *domainname = new KTemporaryFile();
-   domainname->setPrefix(prefix);
-   domainname->setSuffix(QLatin1String(".slave-socket"));
-   domainname->setAutoRemove(false);
-   if (!domainname->open())
+   mConnectionServer.listenForRemote();
+   connect(&mConnectionServer, SIGNAL(newConnection()), SLOT(acceptSlave()));
+   if (!mConnectionServer.isListening())
    {
-      // Sever error!
+      // Severe error!
       qDebug("KLauncher: Fatal error, can't create tempfile!");
       ::_exit(1);
    }
-   mPoolSocketName = domainname->fileName();
-#ifdef __CYGWIN__
-   domainname->setAutoRemove(true);
-#endif
-   delete domainname;
-   mPoolSocket.setAddress(QFile::encodeName(mPoolSocketName));
-#else
-   mPoolSocket.setAddress(QFile::encodeName("4545"));
-#endif
-   mPoolSocket.setAcceptBuffered(false); // we use KStreamSockets
-   connect(&mPoolSocket, SIGNAL(readyAccept()),
-           SLOT(acceptSlave()));
-   mPoolSocket.listen();
-
+   qDebug() << "connection address" << mConnectionServer.address();
    connect(&mTimer, SIGNAL(timeout()), SLOT(idleTimeout()));
 
 #ifndef Q_WS_WIN
@@ -434,7 +202,7 @@ KLauncher::KLauncher(int _kdeinitSocket)
    lastRequest = 0;
    bProcessingQueue = false;
 
-   mSlaveDebug = getenv("KDE_SLAVE_TRACE_WAIT");
+   mSlaveDebug = getenv("KDE_SLAVE_DEBUG_WAIT");
    if (!mSlaveDebug.isEmpty())
    {
       qWarning("Klauncher running in slave-debug mode for slaves of protocol '%s'", qPrintable(mSlaveDebug));
@@ -462,12 +230,6 @@ KLauncher::~KLauncher()
 
 void KLauncher::close()
 {
-   TRACE();
-   if (!mPoolSocketName.isEmpty())
-   {
-      const QByteArray filename = QFile::encodeName(mPoolSocketName);
-      unlink(filename.data());
-   }
 #ifdef Q_WS_X11
    if( mCached_dpy != NULL )
        XCloseDisplay( mCached_dpy );
@@ -478,9 +240,9 @@ void
 KLauncher::destruct(int exit_code)
 {
    TRACE();
-   if (qApp) ((KLauncher*)qApp)->close();
-   // We don't delete qApp here, that's intentional.   
-   ::_exit(exit_code);
+    if (QCoreApplication::instance()) ((KLauncher*)QCoreApplication::instance())->close();
+    // We don't delete the app here, that's intentional.
+    ::_exit(exit_code);
 }
 
 void KLauncher::setLaunchEnv(const QString &name, const QString &value)
@@ -554,7 +316,7 @@ KLauncher::slotKDEInitData(int)
                             sizeof( request_header));
    if (result == -1)
    {
-      kDebug() << "Exiting on read_socket errno: " << errno << endl;
+      kDebug(7016) << "Exiting on read_socket errno: " << errno;
       ::signal( SIGHUP, SIG_IGN);
       ::signal( SIGTERM, SIG_IGN);
       destruct(255); // Exit!
@@ -770,7 +532,7 @@ KLauncher::requestDone(KLaunchRequest *request)
 
    if (request->transaction.type() != QDBusMessage::InvalidMessage)
    {
-      fprintf(stderr,"%s return dbus message\n",__FUNCTION__);
+      qDebug() << __FUNCTION__ << "return dbus message\n";
       if ( requestResult.dbusName.isNull() ) // null strings can't be sent
           requestResult.dbusName = "";
       Q_ASSERT( !requestResult.error.isNull() );
@@ -791,20 +553,6 @@ static void appendLong(QByteArray &ba, long l)
    memcpy(ba.data() + sz, &l, sizeof(long));
 }
 
-// handles all output from launched clients
-void 
-KLauncher::slotGotOutput()
-{
-#ifdef DEBUG
-	qDebug("got output signal");
-#endif
-	QByteArray _stdout;
-  foreach (QProcess *p, processList) {
-    _stdout = p->readAllStandardOutput();
-    fprintf(stderr,"%s",_stdout.data());
-	}
-}
-
 void
 KLauncher::requestStart(KLaunchRequest *request)
 {
@@ -1041,10 +789,9 @@ KLauncher::kdeinit_exec(const QString &app, const QStringList &args,
 
    for(QStringList::ConstIterator it = args.begin();
        it != args.end();
-       it++)
+       ++it)
    {
-       QString arg = *it;
-       request->arg_list.append(arg.toLocal8Bit());
+       request->arg_list.append((*it).toLocal8Bit());
    }
 
    request->name = app.toLocal8Bit();
@@ -1055,7 +802,7 @@ KLauncher::kdeinit_exec(const QString &app, const QStringList &args,
    request->pid = 0;
 
    request->envs = envs;
-   if( app != "kbuildsycoca" ) // avoid stupid loop
+   if( !app.endsWith("kbuildsycoca4") ) // avoid stupid loop
    {
        // Find service, if any - strip path if needed
        KService::Ptr service = KService::serviceByDesktopName( app.mid( app.lastIndexOf( '/' ) + 1 ));
@@ -1147,7 +894,7 @@ KLauncher::requestSlave(const QString &protocol,
                         QString &error)
 {
    TRACE();
-    fprintf(stderr,"%s %s %s\n",protocol.toAscii().data(),host.toAscii().data(),app_socket.toAscii().data());
+    qDebug() << __FUNCTION__ << "protocol="  << protocol << "host=" << host << "app_socket=" << app_socket;
     IdleSlave *slave = 0;
     foreach (slave, mSlaveList)
     {
@@ -1192,8 +939,8 @@ KLauncher::requestSlave(const QString &protocol,
     QStringList arg_list;
     arg_list << name;
     arg_list << protocol;
-    arg_list << "";
-    arg_list << QString::fromLocal8Bit(QFile::encodeName(app_socket));
+    arg_list << mConnectionServer.address();
+    arg_list << app_socket;
     name = "kioslave";
 
     kDebug(7016) << "KLauncher: launching new slave " << name << " with protocol=" << protocol
@@ -1214,7 +961,7 @@ KLauncher::requestSlave(const QString &protocol,
     pid_t pid = request->pid;
 
     TRACE();
-    kDebug(7016) << "Slave launched, pid = " << pid << endl;
+    kDebug(7016) << "Slave launched, pid = " << pid;
 
     // We don't care about this request any longer....
     requestDone(request);
@@ -1244,10 +991,9 @@ KLauncher::waitForSlave(int pid, const QDBusMessage &msg)
 void
 KLauncher::acceptSlave()
 {
-   TRACE();
-    // the cast is safe, because KServerSocket promises us so
-    KStreamSocket* slaveSocket = static_cast<KStreamSocket*>(mPoolSocket.accept());
-    IdleSlave *slave = new IdleSlave(slaveSocket);
+	TRACE();
+    IdleSlave *slave = new IdleSlave(this);
+    mConnectionServer.setNextPendingConnection(&slave->mConn);
     // Send it a SLAVE_STATUS command.
     mSlaveList.append(slave);
     connect(slave, SIGNAL(destroyed()), this, SLOT(slotSlaveGone()));
@@ -1314,4 +1060,18 @@ void KLauncher::reparseConfiguration()
       slave->reparseConfiguration();
 }
 
+// handles all output from launched clients
+void 
+KLauncher::slotGotOutput()
+{
+#ifdef DEBUG
+	qDebug("got output signal");
+#endif
+	QByteArray _stdout;
+  foreach (QProcess *p, processList) {
+    _stdout = p->readAllStandardOutput();
+    fprintf(stderr,"%s",_stdout.data());
+	}
+}
+
 #include "klauncher.moc"
