@@ -28,7 +28,6 @@
 #include <kglobal.h>
 #include <klocale.h>
 #include <assert.h>
-#include <kapplication.h>
 #include <kbookmarkmanager.h>
 
 #include <qdatetime.h>
@@ -39,7 +38,7 @@ KBookmarkGroup::KBookmarkGroup()
 {
 }
 
-KBookmarkGroup::KBookmarkGroup( QDomElement elem )
+KBookmarkGroup::KBookmarkGroup( const QDomElement &elem )
  : KBookmark(elem)
 {
 }
@@ -87,9 +86,19 @@ KBookmark KBookmarkGroup::next( const KBookmark & current ) const
     return KBookmark( nextKnownTag( firstElement(current.element.nextSibling()), true ) );
 }
 
+int KBookmarkGroup::indexOf(const KBookmark& child) const
+{
+    uint counter = 0;
+    for ( KBookmark bk = first(); !bk.isNull(); bk = next(bk), ++counter ) {
+        if ( bk.element == child.element )
+            return counter;
+    }
+    return -1;
+}
+
 // KDE4: Change QDomElement to QDomNode so that we can get rid of
-// firstElement() and lastElement()
-QDomElement KBookmarkGroup::nextKnownTag( QDomElement start, bool goNext ) const
+// firstElement() and lastElement(). Well, no, use firstChildElement :)
+QDomElement KBookmarkGroup::nextKnownTag( const QDomElement &start, bool goNext ) const
 {
     static const QString & bookmark = KGlobal::staticQString("bookmark");
     static const QString & folder = KGlobal::staticQString("folder");
@@ -109,7 +118,7 @@ QDomElement KBookmarkGroup::nextKnownTag( QDomElement start, bool goNext ) const
     return QDomElement();
 }
 
-KBookmarkGroup KBookmarkGroup::createNewFolder( KBookmarkManager* mgr, const QString & text, bool emitSignal )
+KBookmarkGroup KBookmarkGroup::createNewFolder( const QString & text )
 {
     QString txt( text );
     if ( text.isEmpty() )
@@ -131,16 +140,8 @@ KBookmarkGroup KBookmarkGroup::createNewFolder( KBookmarkManager* mgr, const QSt
     element.appendChild( groupElem );
     QDomElement textElem = doc.createElement( "title" );
     groupElem.appendChild( textElem );
-    textElem.appendChild( doc.createTextNode( txt ) );
-
-    KBookmarkGroup grp(groupElem);
-
-    if (emitSignal)
-        KBookmarkNotifier::createdNewFolder(
-                                mgr->path(), grp.fullText(),
-                                grp.address() );
-
-    return grp;
+    textElem.appendChild( doc.createTextNode( txt ) );   
+    return KBookmarkGroup(groupElem);
 
 }
 
@@ -177,26 +178,15 @@ bool KBookmarkGroup::moveItem( const KBookmark & item, const KBookmark & after )
     return (!n.isNull());
 }
 
-KBookmark KBookmarkGroup::addBookmark( KBookmarkManager* mgr, const KBookmark &bm, bool emitSignal )
+KBookmark KBookmarkGroup::addBookmark( const KBookmark &bm )
 {
     element.appendChild( bm.internalElement() );
-
-    if (emitSignal) {
-        if ( bm.hasMetaData() ) {
-            emit mgr->notifyCompleteChange( "" );
-        } else {
-            emit KBookmarkNotifier::addedBookmark(
-                                     mgr->path(), bm.url().url(),
-                                     bm.fullText(), bm.address(), bm.icon() );
-        }
-    }
-
     return bm;
 }
 
-KBookmark KBookmarkGroup::addBookmark( KBookmarkManager* mgr, const QString & text, const KUrl & url, const QString & icon, bool emitSignal )
+KBookmark KBookmarkGroup::addBookmark( const QString & text, const KUrl & url, const QString & icon )
 {
-    //kDebug(7043) << "KBookmarkGroup::addBookmark " << text << " into " << m_address << endl;
+    //kDebug(7043) << "KBookmarkGroup::addBookmark " << text << " into " << m_address;
     QDomDocument doc = element.ownerDocument();
     QDomElement elem = doc.createElement( "bookmark" );
     elem.setAttribute( "href", url.url() ); // gives us utf8
@@ -209,10 +199,10 @@ KBookmark KBookmarkGroup::addBookmark( KBookmarkManager* mgr, const QString & te
     elem.appendChild( textElem );
     textElem.appendChild( doc.createTextNode( text ) );
 
-    return addBookmark( mgr, KBookmark( elem ), emitSignal );
+    return addBookmark( KBookmark( elem ) );
 }
 
-void KBookmarkGroup::deleteBookmark( KBookmark bk )
+void KBookmarkGroup::deleteBookmark( const KBookmark &bk )
 {
     element.removeChild( bk.element );
 }
@@ -257,8 +247,40 @@ QList<KUrl> KBookmarkGroup::groupUrlList() const
     return urlList;
 }
 
+KBookmark KBookmarkGroup::closestBookmark( const KUrl& url ) const
+{
+    KBookmark bookmark = first();
+    KBookmark foundBookmark;
+    int maxLength = 0;
+
+    // Search the bookmark which is equal to the URL or at least is a parent URL.
+    // If there are more than one possible parent URL candidates, choose the bookmark
+    // which covers the bigger range of the URL.
+    while (!bookmark.isNull()) {
+        const KUrl bookmarkUrl = bookmark.url();
+        if (bookmarkUrl.isParentOf(url)) {
+            const int length = bookmarkUrl.prettyUrl().length();
+            if (length > maxLength) {
+                foundBookmark = bookmark;
+                maxLength = length;
+            }
+        }
+        bookmark = next(bookmark);
+    }
+
+    return foundBookmark;
+}
+
 //////
 
+KBookmark::KBookmark()
+{
+}
+
+KBookmark::KBookmark( const QDomElement &elem ) : element(elem)
+{
+}
+
 bool KBookmark::isGroup() const
 {
     QString tag = element.tagName();
@@ -271,6 +293,11 @@ bool KBookmark::isSeparator() const
     return (element.tagName() == "separator");
 }
 
+bool KBookmark::isNull() const
+{
+    return element.isNull();
+}
+
 bool KBookmark::hasParent() const
 {
     QDomElement parent = element.parentNode().toElement();
@@ -290,19 +317,43 @@ QString KBookmark::fullText() const
     return element.namedItem("title").toElement().text();
 }
 
+void KBookmark::setFullText(const QString &fullText)
+{
+    QDomNode titleNode = element.namedItem("title");
+    if (titleNode.isNull()) {
+        titleNode = element.ownerDocument().createElement("title");
+        element.appendChild(titleNode);
+    }
+
+    if (titleNode.firstChild().isNull()) {
+        QDomText domtext = titleNode.ownerDocument().createTextNode("");
+        titleNode.appendChild(domtext);
+    }
+
+    QDomText domtext = titleNode.firstChild().toText();
+    domtext.setData(fullText);
+}
+
 KUrl KBookmark::url() const
 {
     return KUrl(element.attribute("href")); // Decodes it from utf8
 }
 
+void KBookmark::setUrl(const KUrl &url)
+{
+    element.setAttribute("href", url.prettyUrl());
+}
+
 QString KBookmark::icon() const
 {
     QString icon = element.attribute("icon");
+    if(icon == "bookmark_folder")
+      return "bookmark-folder";
     if ( icon.isEmpty() )
         // Default icon depends on URL for bookmarks, and is default directory
         // icon for groups.
         if ( isGroup() )
-            icon = "bookmark_folder";
+            icon = "bookmark-folder";
         else
             if ( isSeparator() )
                 icon = "eraser"; // whatever
@@ -311,6 +362,11 @@ QString KBookmark::icon() const
     return icon;
 }
 
+void KBookmark::setIcon(const QString &icon)
+{
+    element.setAttribute("icon", icon);
+}
+
 KBookmarkGroup KBookmark::parentGroup() const
 {
     return KBookmarkGroup( element.parentNode().toElement() );
@@ -336,42 +392,37 @@ QString KBookmark::address() const
         }
         KBookmarkGroup group = parentGroup();
         QString parentAddress = group.address();
-        uint counter = 0;
-        // Implementation note: we don't use QDomNode's childNode list because we
-        // would have to skip "TEXT", which KBookmarkGroup already does for us.
-        for ( KBookmark bk = group.first() ; !bk.isNull() ; bk = group.next(bk), ++counter )
-        {
-            if ( bk.element == element )
-                return parentAddress + '/' + QString::number(counter);
-        }
-        kWarning() << "KBookmark::address : this can't happen!  " << parentAddress << endl;
-        return "ERROR";
+        int pos = group.indexOf(*this);
+        Q_ASSERT(pos != -1);
+        return parentAddress + '/' + QString::number(pos);
     }
 }
 
+int KBookmark::positionInParent() const
+{
+    return parentGroup().indexOf(*this);
+}
+
+QDomElement KBookmark::internalElement() const
+{
+    return element;
+}
+
 KBookmark KBookmark::standaloneBookmark( const QString & text, const KUrl & url, const QString & icon )
 {
     QDomDocument doc("xbel");
     QDomElement elem = doc.createElement("xbel");
     doc.appendChild( elem );
     KBookmarkGroup grp( elem );
-    grp.addBookmark( 0L, text, url, icon, false );
+    grp.addBookmark( text, url, icon );
     return grp.first();
 }
 
-// For some strange reason QString("").left(0) returns QString();
-// That breaks commonParent()
-QString KBookmark::left(const QString & str, uint len)
-{
-    //kDebug()<<"********"<<QString("").left(0).isNull()<<endl;
-    if(len == 0)
-        return QString("");
-    else
-        return str.left(len);
-}
 
-QString KBookmark::commonParent(QString A, QString B)
+QString KBookmark::commonParent(const QString &first, const QString &second)
 {
+    QString A = first;
+    QString B = second;
     QString error("ERROR");
     if(A == error || B == error)
         return error;
@@ -384,14 +435,14 @@ QString KBookmark::commonParent(QString A, QString B)
     for(uint i=0; i < lastPos; ++i)
     {
         if(A[i] != B[i])
-            return left(A, lastCommonSlash);
+            return A.left(lastCommonSlash);
         if(A[i] == '/')
             lastCommonSlash = i;
     }
-    return left(A, lastCommonSlash);
+    return A.left(lastCommonSlash);
 }
 
-static QDomNode cd_or_create(QDomNode node, QString name)
+static QDomNode cd_or_create(QDomNode node, const QString &name)
 {
     QDomNode subnode = node.namedItem(name);
     if (subnode.isNull())
@@ -447,7 +498,7 @@ bool KBookmark::hasMetaData() const
 
 void KBookmark::updateAccessMetadata()
 {
-    kDebug(7043) << "KBookmark::updateAccessMetadata " << address() << " " << url().prettyUrl() << endl;
+    kDebug(7043) << "KBookmark::updateAccessMetadata " << address() << " " << url().prettyUrl();
 
     const uint timet = QDateTime::currentDateTime().toTime_t();
     setMetaDataItem( "time_added", QString::number( timet ), DontOverwriteMetaData );
@@ -464,6 +515,30 @@ void KBookmark::updateAccessMetadata()
     // TODO - for 4.0 - time_modified
 }
 
+QString KBookmark::parentAddress( const QString & address )
+{
+    return address.left( address.lastIndexOf(QLatin1Char('/')) );
+}
+
+uint KBookmark::positionInParent( const QString & address )
+{
+    return address.mid( address.lastIndexOf(QLatin1Char('/')) + 1 ).toInt();
+}
+
+QString KBookmark::previousAddress( const QString & address )
+{
+    uint pp = positionInParent(address);
+    return pp>0
+        ? parentAddress(address) + QLatin1Char('/') + QString::number(pp-1)
+        : QString();
+}
+
+QString KBookmark::nextAddress( const QString & address )
+{
+    return parentAddress(address) + QLatin1Char('/') +
+        QString::number(positionInParent(address)+1);
+}
+
 QString KBookmark::metaDataItem( const QString &key ) const
 {
     QDomNode infoNode = cd_or_create( internalElement(), "info" );
@@ -494,6 +569,18 @@ void KBookmark::setMetaDataItem( const QString &key, const QString &value, MetaD
     text.setData( value );
 }
 
+
+bool KBookmark::operator==(const KBookmark& rhs) const
+{
+    return element == rhs.element;
+}
+
+////
+
+KBookmarkGroupTraverser::~KBookmarkGroupTraverser()
+{
+}
+
 void KBookmarkGroupTraverser::traverse(const KBookmarkGroup &root)
 {
     // non-recursive bookmark iterator
@@ -539,6 +626,18 @@ void KBookmarkGroupTraverser::traverse(const KBookmarkGroup &root)
     // never reached
 }
 
+void KBookmarkGroupTraverser::visit(const KBookmark &)
+{
+}
+
+void KBookmarkGroupTraverser::visitEnter(const KBookmarkGroup &)
+{
+}
+
+void KBookmarkGroupTraverser::visitLeave(const KBookmarkGroup &)
+{
+}
+
 void KBookmark::populateMimeData( QMimeData* mimeData ) const
 {
     KBookmark::List bookmarkList;
@@ -546,6 +645,10 @@ void KBookmark::populateMimeData( QMimeData* mimeData ) const
     bookmarkList.populateMimeData( mimeData );
 }
 
+KBookmark::List::List() : QList<KBookmark>()
+{
+}
+
 void KBookmark::List::populateMimeData( QMimeData* mimeData ) const
 {
     KUrl::List urls;
@@ -597,7 +700,7 @@ KBookmark::List KBookmark::List::fromMimeData( const QMimeData *mimeData )
         KUrl::List::ConstIterator uEnd = urls.end();
         for ( ; uit != uEnd ; ++uit )
         {
-            //kDebug(7043) << k_funcinfo << "url=" << (*uit) << endl;
+            //kDebug(7043) << "url=" << (*uit);
             bookmarks.append( KBookmark::standaloneBookmark(
                                   (*uit).prettyUrl(), (*uit) ));
         }
