@@ -20,9 +20,11 @@
 #ifndef __kbookmark_h
 #define __kbookmark_h
 
-#include <qstring.h>
+#include <kio/kio_export.h>
+
+#include <QtCore/QString>
 #include <QtCore/QList>
-#include <qdom.h>
+#include <QtXml/QDomElement>
 #include <kurl.h>
 
 class KBookmarkManager;
@@ -36,7 +38,6 @@ public:
         OverwriteMetaData, DontOverwriteMetaData
     };
 
-    KDE_DUMMY_COMPARISON_OPERATOR(KBookmark)
     /**
      * KUrl::Bookmark is a QList that contains bookmarks with a few
      * convenience methods.
@@ -46,7 +47,7 @@ public:
     class KIO_EXPORT List : public QList<KBookmark>
     {
     public:
-        List() : QList<KBookmark>() {}
+        List();
 
         /**
          * Adds this list of bookmark into the given QMimeData.
@@ -76,8 +77,8 @@ public:
         static KBookmark::List fromMimeData( const QMimeData *mimeData );
     };
 
-    KBookmark( ) {}
-    KBookmark( QDomElement elem ) : element(elem) {}
+    KBookmark( );
+    KBookmark( const QDomElement &elem );
 
     static KBookmark standaloneBookmark( const QString & text, const KUrl & url, const QString & icon = QString() );
 
@@ -96,7 +97,7 @@ public:
      * be the case for a real bookmark (in a menu), but it's used
      * for instance as the end condition for KBookmarkGroup::next()
      */
-    bool isNull() const {return element.isNull();}
+    bool isNull() const;
 
     /**
      * @return true if bookmark is contained by a QDomDocument,
@@ -116,15 +117,33 @@ public:
      * You should not use this - this is mainly for keditbookmarks.
      */
     QString fullText() const;
+    /**
+     * Set the text shown for the bookmark.
+     *
+     * @param fullText the new bookmark title
+     */
+    void setFullText(const QString &fullText);
     /**
      * URL contained by the bookmark
      */
     KUrl url() const;
+    /**
+     * Set the URL of the bookmark
+     *
+     * @param url the new bookmark URL
+     */
+    void setUrl(const KUrl &url);
     /**
      * @return the pixmap file for this bookmark
      * (i.e. the name of the icon)
      */
     QString icon() const;
+    /**
+     * Set the icon name of the bookmark
+     *
+     * @param icon the new icon name for this bookmark
+     */
+    void setIcon(const QString &icon);
 
     /**
      * @return the group containing this bookmark
@@ -141,10 +160,16 @@ public:
      * Return the "address" of this bookmark in the whole tree.
      * This is used when telling other processes about a change
      * in a given bookmark. The encoding of the address is "/4/2", for
-     * instance, to design the 2nd child inside the 4th child of the root bk.
+     * instance, to designate the 2nd child inside the 4th child of the 
+     * root bookmark.
      */
     QString address() const;
 
+    /**
+     * Return the position in the parent, i.e. the last number in the address
+     */
+    int positionInParent() const;
+
     // Hard to decide. Good design would imply that each bookmark
     // knows about its manager, so that there can be several managers.
     // But if we say there is only one manager (i.e. set of bookmarks)
@@ -154,7 +179,7 @@ public:
     /**
      * @internal for KEditBookmarks
      */
-    QDomElement internalElement() const { return element; }
+    QDomElement internalElement() const;
 
     /**
      * Updates the bookmarks access metadata
@@ -167,37 +192,30 @@ public:
     /**
      * @return address of parent
      */
-    static QString parentAddress( const QString & address )
-    { return address.left( address.lastIndexOf('/') ); }
+    static QString parentAddress( const QString & address );
 
     /**
      * @return position in parent (e.g. /4/5/2 -> 2)
      */
-    static uint positionInParent( const QString & address )
-    { return address.mid( address.lastIndexOf('/') + 1 ).toInt(); }
+    static uint positionInParent( const QString & address );
 
     /**
      * @return address of previous sibling (e.g. /4/5/2 -> /4/5/1)
      * Returns QString() for a first child
      */
-    static QString previousAddress( const QString & address )
-    {
-        uint pp = positionInParent(address);
-        return pp>0 ? parentAddress(address) + '/' + QString::number(pp-1) : QString();
-    }
+    static QString previousAddress( const QString & address );
 
     /**
      * @return address of next sibling (e.g. /4/5/2 -> /4/5/3)
      * This doesn't check whether it actually exists
      */
-    static QString nextAddress( const QString & address )
-    { return parentAddress(address) + '/' + QString::number(positionInParent(address)+1); }
+    static QString nextAddress( const QString & address );
 
     /**
      * @return the common parent of both addresses which
      * has the greatest depth
      */
-     static QString commonParent(QString A, QString B);
+     static QString commonParent( const QString &A, const QString &B );
 
     /**
      * Get the value of a specific metadata item.
@@ -225,6 +243,10 @@ public:
      */
     void populateMimeData( QMimeData* mimeData ) const;
 
+    /**
+     * Comparison operator
+     */
+    bool operator==(const KBookmark& rhs) const;
 
 protected:
     QDomElement element;
@@ -235,7 +257,6 @@ protected:
 
 private:
     bool hasMetaData() const;
-    static QString left(const QString & str, uint len);
 };
 
 #ifdef MAKE_KIO_LIB
@@ -259,7 +280,7 @@ public:
     /**
      * Create a bookmark group as specified by the given element
      */
-    KBookmarkGroup( QDomElement elem );
+    KBookmarkGroup( const QDomElement &elem );
 
     /**
      * Much like KBookmark::address, but caches the
@@ -288,12 +309,15 @@ public:
     KBookmark next( const KBookmark & current ) const;
 
     /**
-     * Create a new bookmark folder, as the last child of this group
-     * @param mgr the manager of the bookmark
-     * @param text for the folder. If empty, the user will be queried for it.
-     * @param emitSignal if true emit KBookmarkNotifier signal
+     * Return the index of a child bookmark, -1 if not found
      */
-    KBookmarkGroup createNewFolder( KBookmarkManager* mgr, const QString & text = QString(), bool emitSignal = true );
+    int indexOf(const KBookmark& child) const;
+
+    /**
+     * Create a new bookmark folder, as the last child of this group
+     * @param text for the folder. If empty, the user will be queried for it.
+     */
+    KBookmarkGroup createNewFolder( const QString & text = QString() );
     /**
      * Create a new bookmark separator
      * Don't forget to use KBookmarkManager::self()->emitChanged( parentBookmark );
@@ -303,23 +327,19 @@ public:
     /**
      * Create a new bookmark, as the last child of this group
      * Don't forget to use KBookmarkManager::self()->emitChanged( parentBookmark );
-     * @param mgr the manager of the bookmark
      * @param bm the bookmark to add
-     * @param emitSignal if true emit KBookmarkNotifier signal
      */
-    KBookmark addBookmark( KBookmarkManager* mgr, const KBookmark &bm, bool emitSignal = true );
+    KBookmark addBookmark( const KBookmark &bm );
 
     /**
      * Create a new bookmark, as the last child of this group
      * Don't forget to use KBookmarkManager::self()->emitChanged( parentBookmark );
-     * @param mgr the manager of the bookmark
      * @param text for the bookmark
      * @param url the URL that the bookmark points to
      * @param icon the name of the icon to associate with the bookmark. A suitable default
      * will be determined from the URL if not specified.
-     * @param emitSignal if true emit KBookmarkNotifier signal
      */
-    KBookmark addBookmark( KBookmarkManager* mgr, const QString & text, const KUrl & url, const QString & icon = QString(), bool emitSignal = true );
+    KBookmark addBookmark( const QString & text, const KUrl & url, const QString & icon = QString() );
 
     /**
      * Moves @p item after @p after (which should be a child of ours).
@@ -332,7 +352,7 @@ public:
      * Delete a bookmark - it has to be one of our children !
      * Don't forget to use KBookmarkManager::self()->emitChanged( parentBookmark );
      */
-    void deleteBookmark( KBookmark bk );
+    void deleteBookmark( const KBookmark &bk );
 
     /**
      * @return true if this is the toolbar group
@@ -348,8 +368,24 @@ public:
      */
     QList<KUrl> groupUrlList() const;
 
+    /**
+     * Returns the closest bookmark for the URL \a url.
+     * The closest bookmark is defined as bookmark which is equal to
+     * the URL or at least is a parent URL. If there are more than
+     * one possible parent URL candidates, the bookmark which covers
+     * the bigger range of the URL is returned.
+     *
+     * Example: the url is '/home/peter/Documents/Music'.
+     * Available bookmarks are:
+     * - /home/peter
+     * - /home/peter/Documents
+     *
+     * The returned bookmark will the one for '/home/peter/Documents'.
+     */
+    KBookmark closestBookmark( const KUrl& url ) const;
+
 protected:
-    QDomElement nextKnownTag( QDomElement start, bool goNext ) const;
+    QDomElement nextKnownTag( const QDomElement &start, bool goNext ) const;
 
 private:
     mutable QString m_address;
@@ -361,11 +397,11 @@ private:
 
 class KIO_EXPORT KBookmarkGroupTraverser {
 protected:
-    virtual ~KBookmarkGroupTraverser() {}
+    virtual ~KBookmarkGroupTraverser();
     void traverse(const KBookmarkGroup &);
-    virtual void visit(const KBookmark &) {}
-    virtual void visitEnter(const KBookmarkGroup &) {}
-    virtual void visitLeave(const KBookmarkGroup &) {}
+    virtual void visit(const KBookmark &);
+    virtual void visitEnter(const KBookmarkGroup &);
+    virtual void visitLeave(const KBookmarkGroup &);
 };
 
 #endif
