@@ -18,6 +18,8 @@
    Boston, MA 02110-1301, USA.
 */
 
+#include "kbookmarkimporter_ie.h"
+
 #include <kfiledialog.h>
 #include <kstringhandler.h>
 #include <klocale.h>
@@ -30,7 +32,35 @@
 #include <sys/stat.h>
 
 #include "kbookmarkimporter.h"
-#include "kbookmarkimporter_ie.h"
+
+/**
+ * A class for importing IE bookmarks
+ * @deprecated
+ */
+class  KIEBookmarkImporter : public QObject
+{
+    Q_OBJECT
+public:
+    KIEBookmarkImporter( const QString & fileName ) : m_fileName(fileName) {}
+    ~KIEBookmarkImporter() {}
+
+    void parseIEBookmarks();
+
+    // Usual place for IE bookmarks
+    static QString IEBookmarksDir();
+
+Q_SIGNALS:
+    void newBookmark( const QString & text, const QString & url, const QString & additionalInfo );
+    void newFolder( const QString & text, bool open, const QString & additionalInfo );
+    void newSeparator();
+    void endFolder();
+
+protected:
+    void parseIEBookmarks_dir( const QString &dirname, const QString &name = QString() );
+    void parseIEBookmarks_url_file( const QString &filename, const QString &name );
+
+    QString m_fileName;
+};
 
 void KIEBookmarkImporter::parseIEBookmarks_url_file( const QString &filename, const QString &name ) {
     static const int g_lineLimit = 16*1024;
@@ -44,7 +74,7 @@ void KIEBookmarkImporter::parseIEBookmarks_url_file( const QString &filename, co
         while(f.readLine(s.data(), g_lineLimit)>=0) {
             if ( s[s.length()-1] != '\n' ) // Gosh, this line is longer than g_lineLimit. Skipping.
             {
-               kWarning() << "IE bookmarks contain a line longer than " << g_lineLimit << ". Skipping." << endl;
+               kWarning() << "IE bookmarks contain a line longer than " << g_lineLimit << ". Skipping.";
                continue;
             }
             QByteArray t = s.trimmed();
@@ -128,7 +158,7 @@ QString KIEBookmarkImporterImpl::findDefaultLocation(bool) const
 class IEExporter : private KBookmarkGroupTraverser {
 public:
     IEExporter( const QString & );
-    void write( const KBookmarkGroup &grp ) { traverse(grp); };
+    void write( const KBookmarkGroup &grp ) { traverse(grp); }
 private:
     virtual void visit( const KBookmark & );
     virtual void visitEnter( const KBookmarkGroup & );
@@ -149,7 +179,7 @@ IEExporter::IEExporter( const QString & dname ) {
 
 void IEExporter::visit( const KBookmark &bk ) {
     QString fname = m_currentDir.path() + '/' + ieStyleQuote( bk.fullText() ) + ".url";
-    // kDebug() << "visit(" << bk.text() << "), fname == " << fname << endl;
+    // kDebug() << "visit(" << bk.text() << "), fname == " << fname;
     QFile file( fname );
     file.open( QIODevice::WriteOnly );
     QTextStream ts( &file );
@@ -159,17 +189,17 @@ void IEExporter::visit( const KBookmark &bk ) {
 
 void IEExporter::visitEnter( const KBookmarkGroup &grp ) {
     QString dname = m_currentDir.path() + '/' + ieStyleQuote( grp.fullText() );
-    // kDebug() << "visitEnter(" << grp.text() << "), dname == " << dname << endl;
+    // kDebug() << "visitEnter(" << grp.text() << "), dname == " << dname;
     m_currentDir.mkdir( dname );
     m_currentDir.cd( dname );
 }
 
 void IEExporter::visitLeave( const KBookmarkGroup & ) {
-    // kDebug() << "visitLeave()" << endl;
+    // kDebug() << "visitLeave()";
     m_currentDir.cdUp();
 }
 
-void KIEBookmarkExporterImpl::write(KBookmarkGroup parent) {
+void KIEBookmarkExporterImpl::write(const KBookmarkGroup& parent) {
     IEExporter exporter( m_fileName );
     exporter.write( parent );
 }
