@@ -20,6 +20,7 @@
    Boston, MA 02110-1301, USA.
 */
 
+#include "kbookmarkimporter_ns.h"
 #include "kbookmarkimporter.h"
 #include "kbookmarkexporter.h"
 #include "kbookmarkmanager.h"
@@ -32,6 +33,8 @@
 #include <qtextcodec.h>
 #include <qtextdocument.h> // Qt::escape
 
+
+
 void KNSBookmarkImporterImpl::parse()
 {
     QFile f(m_fileName);
@@ -52,7 +55,7 @@ void KNSBookmarkImporterImpl::parse()
         while(f.readLine(s.data(), g_lineLimit)>=0) {
             if ( s[s.length()-1] != '\n' ) // Gosh, this line is longer than g_lineLimit. Skipping.
             {
-               kWarning() << "Netscape bookmarks contain a line longer than " << g_lineLimit << ". Skipping." << endl;
+               kWarning() << "Netscape bookmarks contain a line longer than " << g_lineLimit << ". Skipping.";
                continue;
             }
             QByteArray t = s.trimmed();
@@ -118,60 +121,11 @@ QString KNSBookmarkImporterImpl::findDefaultLocation(bool forSaving) const
 
 ////////////////////////////////////////////////////////////////
 
-
-void KNSBookmarkImporter::parseNSBookmarks( bool utf8 )
-{
-    KNSBookmarkImporterImpl importer;
-    importer.setFilename(m_fileName);
-    importer.setUtf8(utf8);
-    importer.setupSignalForwards(&importer, this);
-    importer.parse();
-}
-
-QString KNSBookmarkImporter::netscapeBookmarksFile( bool forSaving )
-{
-    static KNSBookmarkImporterImpl *p = 0;
-    if (!p)
-    {
-        p = new KNSBookmarkImporterImpl;
-        p->setUtf8(false);
-    }
-    return p->findDefaultLocation(forSaving);
-}
-
-QString KNSBookmarkImporter::mozillaBookmarksFile( bool forSaving )
-{
-    static KNSBookmarkImporterImpl *p = 0;
-    if (!p)
-    {
-        p = new KNSBookmarkImporterImpl;
-        p->setUtf8(true);
-    }
-    return p->findDefaultLocation(forSaving);
-}
-
-
-////////////////////////////////////////////////////////////////
-//                   compat only
-////////////////////////////////////////////////////////////////
-
-void KNSBookmarkExporter::write(bool utf8) {
-   KNSBookmarkExporterImpl exporter(m_pManager, m_fileName);
-   exporter.setUtf8(utf8);
-   exporter.write(m_pManager->root());
-}
-
-void KNSBookmarkExporter::writeFolder(QTextStream &/*stream*/, KBookmarkGroup /*gp*/) {
-   // TODO - requires a d pointer workaround hack?
-}
-
-////////////////////////////////////////////////////////////////
-
 void KNSBookmarkExporterImpl::setUtf8(bool utf8) {
    m_utf8 = utf8;
 }
 
-void KNSBookmarkExporterImpl::write(KBookmarkGroup parent) {
+void KNSBookmarkExporterImpl::write(const KBookmarkGroup &parent) {
    if (QFile::exists(m_fileName)) {
       ::rename(
          QFile::encodeName(m_fileName),
@@ -202,7 +156,7 @@ void KNSBookmarkExporterImpl::write(KBookmarkGroup parent) {
            << "</DL><P>" << endl;
 }
 
-QString KNSBookmarkExporterImpl::folderAsString(KBookmarkGroup parent) const {
+QString KNSBookmarkExporterImpl::folderAsString(const KBookmarkGroup &parent) const {
    QString str;
    QTextStream fstream(&str, QIODevice::WriteOnly);
 
