@@ -30,26 +30,24 @@
 #include <kmessagebox.h>
 #include <qprocess.h>
 #include <klocale.h>
-#include <kapplication.h>
+#include <QtGui/QApplication>
+#include <kconfiggroup.h>
 #include <qdatetime.h>
 #include <qfile.h>
 #include <qfileinfo.h>
-#include <qtextstream.h>
 #include <QtDBus/QtDBus>
-#include <QTextStream>
-#include <kstaticdeleter.h>
+#include <QtCore/QTextStream>
 #include "kbookmarkmanageradaptor_p.h"
 
 class KBookmarkManagerList : public QList<KBookmarkManager *>
 {
 public:
     ~KBookmarkManagerList() {
-        qDeleteAll( *this ); // auto-delete functionality
+        qDeleteAll( begin() , end() ); // auto-delete functionality
     }
 };
 
-KBookmarkManagerList* KBookmarkManager::s_pSelf;
-static KStaticDeleter<KBookmarkManagerList> sdbm;
+K_GLOBAL_STATIC(KBookmarkManagerList, s_pSelf)
 
 class KBookmarkMap : private KBookmarkGroupTraverser {
 public:
@@ -88,18 +86,40 @@ void KBookmarkMap::visit(const KBookmark &bk)
     }
 }
 
+// #########################
+// KBookmarkManager::Private
+class KBookmarkManager::Private
+{
+public:
+    Private(bool bDocIsloaded, const QString &dbusObjectName = QString())
+      : m_doc("xbel")
+      , m_dbusObjectName(dbusObjectName)
+      , m_docIsLoaded(bDocIsloaded)
 
-KBookmarkManager* KBookmarkManager::managerForFile( const QString& bookmarksFile, const QString& dbusObjectName, bool bImportDesktopFiles )
+    {}
+
+    mutable QDomDocument m_doc;
+    mutable QDomDocument m_toolbarDoc;
+    QString m_bookmarksFile;
+    QString m_dbusObjectName;
+    mutable bool m_docIsLoaded;
+    bool m_update;
+
+    bool m_browserEditor;
+    QString m_editorCaption;
+
+};
+
+// ################
+// KBookmarkManager
+KBookmarkManager* KBookmarkManager::managerForFile( const QString& bookmarksFile, const QString& dbusObjectName )
 {
-    if ( !s_pSelf ) {
-        sdbm.setObject( s_pSelf, new KBookmarkManagerList );
-    }
     for ( KBookmarkManagerList::ConstIterator bmit = s_pSelf->constBegin(), bmend = s_pSelf->constEnd();
           bmit != bmend; ++bmit )
         if ( (*bmit)->path() == bookmarksFile )
             return *bmit;
 
-    KBookmarkManager* mgr = new KBookmarkManager( bookmarksFile, dbusObjectName, bImportDesktopFiles );
+    KBookmarkManager* mgr = new KBookmarkManager( bookmarksFile, dbusObjectName );
     s_pSelf->append( mgr );
     return mgr;
 }
@@ -107,9 +127,6 @@ KBookmarkManager* KBookmarkManager::managerForFile( const QString& bookmarksFile
 // principally used for filtered toolbars
 KBookmarkManager* KBookmarkManager::createTempManager()
 {
-    if ( !s_pSelf ) {
-        sdbm.setObject( s_pSelf, new KBookmarkManagerList );
-    }
     KBookmarkManager* mgr = new KBookmarkManager();
     s_pSelf->append( mgr );
     return mgr;
@@ -117,36 +134,34 @@ KBookmarkManager* KBookmarkManager::createTempManager()
 
 #define PI_DATA "version=\"1.0\" encoding=\"UTF-8\""
 
-KBookmarkManager::KBookmarkManager( const QString & bookmarksFile, const QString & dbusObjectName, bool bImportDesktopFiles )
-    : m_doc("xbel"), m_docIsLoaded(false), m_dbusObjectName(dbusObjectName)
+KBookmarkManager::KBookmarkManager( const QString & bookmarksFile, const QString & dbusObjectName )
+ : d(new Private(false, dbusObjectName))
 {
     init( "/KBookmarkManager/"+dbusObjectName );
 
-    m_update = true;
+    d->m_update = true;
 
     Q_ASSERT( !bookmarksFile.isEmpty() );
-    m_bookmarksFile = bookmarksFile;
+    d->m_bookmarksFile = bookmarksFile;
 
-    if ( !QFile::exists(m_bookmarksFile) )
+    if ( !QFile::exists(d->m_bookmarksFile) )
     {
-        QDomElement topLevel = m_doc.createElement("xbel");
-        m_doc.appendChild( topLevel );
-        m_doc.insertBefore( m_doc.createProcessingInstruction( "xml", PI_DATA), topLevel );
-        if ( bImportDesktopFiles )
-            importDesktopFiles();
-        m_docIsLoaded = true;
+        QDomElement topLevel = d->m_doc.createElement("xbel");
+        d->m_doc.appendChild( topLevel );
+        d->m_doc.insertBefore( d->m_doc.createProcessingInstruction( "xml", PI_DATA), topLevel );
+        d->m_docIsLoaded = true;
     }
 }
 
 KBookmarkManager::KBookmarkManager( )
-    : m_doc("xbel"), m_docIsLoaded(true)
+    : d(new Private(true))
 {
     init( "/KBookmarkManager/generated" );
-    m_update = false; // TODO - make it read/write
+    d->m_update = false; // TODO - make it read/write
 
-    QDomElement topLevel = m_doc.createElement("xbel");
-    m_doc.appendChild( topLevel );
-    m_doc.insertBefore( m_doc.createProcessingInstruction( "xml", PI_DATA), topLevel );
+    QDomElement topLevel = d->m_doc.createElement("xbel");
+    d->m_doc.appendChild( topLevel );
+    d->m_doc.insertBefore( d->m_doc.createProcessingInstruction( "xml", PI_DATA), topLevel );
 }
 
 void KBookmarkManager::init( const QString& dbusPath )
@@ -167,62 +182,50 @@ void KBookmarkManager::init( const QString& dbusPath )
 
 KBookmarkManager::~KBookmarkManager()
 {
-    if ( s_pSelf )
+    if(!s_pSelf.isDestroyed())
         s_pSelf->removeAll( this );
+    delete d;
 }
 
 void KBookmarkManager::setUpdate( bool update )
 {
-    m_update = update;
+    d->m_update = update;
 }
 
-const QDomDocument &KBookmarkManager::internalDocument() const
+QDomDocument KBookmarkManager::internalDocument() const
 {
-    if(!m_docIsLoaded)
+    if(!d->m_docIsLoaded)
     {
         parse();
-        m_toolbarDoc.clear();
+        d->m_toolbarDoc.clear();
     }
-    return m_doc;
+    return d->m_doc;
 }
 
 
 void KBookmarkManager::parse() const
 {
-    m_docIsLoaded = true;
-    //kDebug(7043) << "KBookmarkManager::parse " << m_bookmarksFile << endl;
-    QFile file( m_bookmarksFile );
+    d->m_docIsLoaded = true;
+    //kDebug(7043) << "KBookmarkManager::parse " << d->m_bookmarksFile;
+    QFile file( d->m_bookmarksFile );
     if ( !file.open( QIODevice::ReadOnly ) )
     {
-        kWarning() << "Can't open " << m_bookmarksFile << endl;
+        kWarning() << "Can't open " << d->m_bookmarksFile;
         return;
     }
-    m_doc = QDomDocument("xbel");
-    m_doc.setContent( &file );
+    d->m_doc = QDomDocument("xbel");
+    d->m_doc.setContent( &file );
 
-    QDomElement docElem = m_doc.documentElement();
+    QDomElement docElem = d->m_doc.documentElement();
     if ( docElem.isNull() )
-        kWarning() << "KBookmarkManager::parse : can't parse " << m_bookmarksFile << endl;
+        kWarning() << "KBookmarkManager::parse : can't parse " << d->m_bookmarksFile;
     else
     {
         QString mainTag = docElem.tagName();
-        if ( mainTag == "BOOKMARKS" )
-        {
-            kWarning() << "Old style bookmarks found. Calling convertToXBEL." << endl;
-            docElem.setTagName("xbel");
-            if ( docElem.hasAttribute( "HIDE_NSBK" ) ) // non standard either, but we need it
-            {
-                docElem.setAttribute( "hide_nsbk", docElem.attribute( "HIDE_NSBK" ) == "1" ? "yes" : "no" );
-                docElem.removeAttribute( "HIDE_NSBK" );
-            }
+        if ( mainTag != "xbel" )
+            kWarning() << "KBookmarkManager::parse : unknown main tag " << mainTag;
 
-            convertToXBEL( docElem );
-            save();
-        }
-        else if ( mainTag != "xbel" )
-            kWarning() << "KBookmarkManager::parse : unknown main tag " << mainTag << endl;
-
-        QDomNode n = m_doc.documentElement().previousSibling();
+        QDomNode n = d->m_doc.documentElement().previousSibling();
         if ( n.isProcessingInstruction() )
         {
             QDomProcessingInstruction pi = n.toProcessingInstruction();
@@ -230,8 +233,8 @@ void KBookmarkManager::parse() const
         }
 
         QDomProcessingInstruction pi;
-        pi = m_doc.createProcessingInstruction( "xml", PI_DATA );
-        m_doc.insertBefore( pi, docElem );
+        pi = d->m_doc.createProcessingInstruction( "xml", PI_DATA );
+        d->m_doc.insertBefore( pi, docElem );
     }
 
     file.close();
@@ -240,84 +243,14 @@ void KBookmarkManager::parse() const
     s_bk_map->update();
 }
 
-void KBookmarkManager::convertToXBEL( QDomElement & group )
-{
-    QDomNode n = group.firstChild();
-    while( !n.isNull() )
-    {
-        QDomElement e = n.toElement();
-        if ( !e.isNull() )
-            if ( e.tagName() == "TEXT" )
-            {
-                e.setTagName("title");
-            }
-            else if ( e.tagName() == "SEPARATOR" )
-            {
-                e.setTagName("separator"); // so close...
-            }
-            else if ( e.tagName() == "GROUP" )
-            {
-                e.setTagName("folder");
-                convertAttribute(e, "ICON","icon"); // non standard, but we need it
-                if ( e.hasAttribute( "TOOLBAR" ) ) // non standard either, but we need it
-                {
-                    e.setAttribute( "toolbar", e.attribute( "TOOLBAR" ) == "1" ? "yes" : "no" );
-                    e.removeAttribute( "TOOLBAR" );
-                }
-
-                convertAttribute(e, "NETSCAPEINFO","netscapeinfo"); // idem
-                bool open = (e.attribute("OPEN") == "1");
-                e.removeAttribute("OPEN");
-                e.setAttribute("folded", open ? "no" : "yes");
-                convertToXBEL( e );
-            }
-            else
-                if ( e.tagName() == "BOOKMARK" )
-                {
-                    e.setTagName("bookmark"); // so much difference :-)
-                    convertAttribute(e, "ICON","icon"); // non standard, but we need it
-                    convertAttribute(e, "NETSCAPEINFO","netscapeinfo"); // idem
-                    convertAttribute(e, "URL","href");
-                    QString text = e.text();
-                    while ( !e.firstChild().isNull() ) // clean up the old contained text
-                        e.removeChild(e.firstChild());
-                    QDomElement titleElem = e.ownerDocument().createElement("title");
-                    e.appendChild( titleElem ); // should be the only child anyway
-                    titleElem.appendChild( e.ownerDocument().createTextNode( text ) );
-                }
-                else
-                    kWarning(7043) << "Unknown tag " << e.tagName() << endl;
-        n = n.nextSibling();
-    }
-}
-
-void KBookmarkManager::convertAttribute( QDomElement elem, const QString & oldName, const QString & newName )
-{
-    if ( elem.hasAttribute( oldName ) )
-    {
-        elem.setAttribute( newName, elem.attribute( oldName ) );
-        elem.removeAttribute( oldName );
-    }
-}
-
-void KBookmarkManager::importDesktopFiles()
-{
-    KBookmarkImporter importer( const_cast<QDomDocument *>(&internalDocument()) );
-    QString path(KGlobal::dirs()->saveLocation("data", "kfm/bookmarks", true));
-    importer.import( path );
-    //kDebug(7043) << internalDocument().toCString() << endl;
-
-    save();
-}
-
 bool KBookmarkManager::save( bool toolbarCache ) const
 {
-    return saveAs( m_bookmarksFile, toolbarCache );
+    return saveAs( d->m_bookmarksFile, toolbarCache );
 }
 
 bool KBookmarkManager::saveAs( const QString & filename, bool toolbarCache ) const
 {
-    kDebug(7043) << "KBookmarkManager::save " << filename << endl;
+    kDebug(7043) << "KBookmarkManager::save " << filename;
 
     // Save the bookmark toolbar folder for quick loading
     // but only when it will actually make things quicker
@@ -368,6 +301,11 @@ bool KBookmarkManager::saveAs( const QString & filename, bool toolbarCache ) con
     return false;
 }
 
+QString KBookmarkManager::path() const
+{
+    return d->m_bookmarksFile;
+}
+
 KBookmarkGroup KBookmarkManager::root() const
 {
     return KBookmarkGroup(internalDocument().documentElement());
@@ -375,32 +313,32 @@ KBookmarkGroup KBookmarkManager::root() const
 
 KBookmarkGroup KBookmarkManager::toolbar()
 {
-    kDebug(7043) << "KBookmarkManager::toolbar begin" << endl;
+    kDebug(7043) << "KBookmarkManager::toolbar begin";
     // Only try to read from a toolbar cache if the full document isn't loaded
-    if(!m_docIsLoaded)
+    if(!d->m_docIsLoaded)
     {
-        kDebug(7043) << "KBookmarkManager::toolbar trying cache" << endl;
-        const QString cacheFilename = m_bookmarksFile + QLatin1String(".tbcache");
-        QFileInfo bmInfo(m_bookmarksFile);
+        kDebug(7043) << "KBookmarkManager::toolbar trying cache";
+        const QString cacheFilename = d->m_bookmarksFile + QLatin1String(".tbcache");
+        QFileInfo bmInfo(d->m_bookmarksFile);
         QFileInfo cacheInfo(cacheFilename);
-        if (m_toolbarDoc.isNull() &&
+        if (d->m_toolbarDoc.isNull() &&
             QFile::exists(cacheFilename) &&
             bmInfo.lastModified() < cacheInfo.lastModified())
         {
-            kDebug(7043) << "KBookmarkManager::toolbar reading file" << endl;
+            kDebug(7043) << "KBookmarkManager::toolbar reading file";
             QFile file( cacheFilename );
 
             if ( file.open( QIODevice::ReadOnly ) )
             {
-                m_toolbarDoc = QDomDocument("cache");
-                m_toolbarDoc.setContent( &file );
-                kDebug(7043) << "KBookmarkManager::toolbar opened" << endl;
+                d->m_toolbarDoc = QDomDocument("cache");
+                d->m_toolbarDoc.setContent( &file );
+                kDebug(7043) << "KBookmarkManager::toolbar opened";
             }
         }
-        if (!m_toolbarDoc.isNull())
+        if (!d->m_toolbarDoc.isNull())
         {
-            kDebug(7043) << "KBookmarkManager::toolbar returning element" << endl;
-            QDomElement elem = m_toolbarDoc.firstChild().toElement();
+            kDebug(7043) << "KBookmarkManager::toolbar returning element";
+            QDomElement elem = d->m_toolbarDoc.firstChild().toElement();
             return KBookmarkGroup(elem);
         }
     }
@@ -414,14 +352,14 @@ KBookmarkGroup KBookmarkManager::toolbar()
         return KBookmarkGroup(root().findToolbar());
 }
 
-KBookmark KBookmarkManager::findByAddress( const QString & address, bool tolerant )
+KBookmark KBookmarkManager::findByAddress( const QString & address )
 {
-    //kDebug(7043) << "KBookmarkManager::findByAddress " << address << endl;
+    //kDebug(7043) << "KBookmarkManager::findByAddress " << address;
     KBookmark result = root();
     // The address is something like /5/10/2+
-    QStringList addresses = address.split(QRegExp("[/+]"),QString::SkipEmptyParts);
-    // kWarning() << addresses.join(",") << endl;
-    for ( QStringList::Iterator it = addresses.begin() ; it != addresses.end() ; )
+    const QStringList addresses = address.split(QRegExp("[/+]"),QString::SkipEmptyParts);
+    // kWarning() << addresses.join(",");
+    for ( QStringList::const_iterator it = addresses.begin() ; it != addresses.end() ; )
     {
        bool append = ((*it) == "+");
        uint number = (*it).toUInt();
@@ -431,27 +369,20 @@ KBookmark KBookmarkManager::findByAddress( const QString & address, bool toleran
        for ( uint i = 0 ; ( (i<number) || append ) && !bk.isNull() ; ++i ) {
            lbk = bk;
            bk = group.next(bk);
-         //kWarning() << i << endl;
+         //kWarning() << i;
        }
        it++;
-       int shouldBeGroup = !bk.isGroup() && (it != addresses.end());
-       if ( tolerant && ( bk.isNull() || shouldBeGroup ) ) {
-          if (!lbk.isNull()) result = lbk;
-          //kWarning() << "break" << endl;
-          break;
-       }
-       //kWarning() << "found section" << endl;
+       //kWarning() << "found section";
        result = bk;
     }
     if (result.isNull()) {
-       kWarning() << "KBookmarkManager::findByAddress: couldn't find item " << address << endl;
-       Q_ASSERT(!tolerant);
+       kWarning() << "KBookmarkManager::findByAddress: couldn't find item " << address;
     }
-    //kWarning() << "found " << result.address() << endl;
+    //kWarning() << "found " << result.address();
     return result;
  }
 
-static QString pickUnusedTitle( KBookmarkGroup parentBookmark,
+static QString pickUnusedTitle( const KBookmarkGroup &parentBookmark,
                                 const QString &title, const QString &url
 ) {
     // If this title is already used, we'll try to find something unused.
@@ -518,18 +449,26 @@ KBookmarkGroup KBookmarkManager::addBookmarkDialog(
 
     QString uniqueTitle = pickUnusedTitle( parentBookmark, title, url ); //TODO pickUnusedTitle is used only here. Why?
     if ( !uniqueTitle.isNull() )
-        parentBookmark.addBookmark( this, uniqueTitle, KUrl( url ));
+    {
+        parentBookmark.addBookmark( uniqueTitle, KUrl( url ));
+        emitChanged(parentBookmark);
+    }
 
     return parentBookmark;
 }
 
+void KBookmarkManager::emitChanged()
+{
+    emitChanged(root());
+}
+
 
 void KBookmarkManager::emitChanged( const KBookmarkGroup & group )
 {
     save();
 
     // Tell the other processes too
-    // kDebug(7043) << "KBookmarkManager::emitChanged : broadcasting change " << group.address() << endl;
+    // kDebug(7043) << "KBookmarkManager::emitChanged : broadcasting change " << group.address();
 
     emit bookmarksChanged(group.address());
 
@@ -542,11 +481,12 @@ void KBookmarkManager::emitConfigChanged()
     emit bookmarkConfigChanged();
 }
 
-void KBookmarkManager::notifyCompleteChange( QString caller ) // DBUS call
+void KBookmarkManager::notifyCompleteChange( const QString &caller ) // DBUS call
 {
-    if (!m_update) return;
+    if (!d->m_update)
+        return;
 
-    kDebug(7043) << "KBookmarkManager::notifyCompleteChange" << endl;
+    kDebug(7043) << "KBookmarkManager::notifyCompleteChange";
     // The bk editor tells us we should reload everything
     // Reparse
     parse();
@@ -557,22 +497,24 @@ void KBookmarkManager::notifyCompleteChange( QString caller ) // DBUS call
 
 void KBookmarkManager::notifyConfigChanged() // DBUS call
 {
-    kDebug() << "reloaded bookmark config!" << endl;
+    kDebug() << "reloaded bookmark config!";
     KBookmarkSettings::self()->readSettings();
     parse(); // reload, and thusly recreate the menus
+    emit configChanged();
 }
 
-void KBookmarkManager::notifyChanged( QString groupAddress, const QDBusMessage &msg ) // DBUS call
+void KBookmarkManager::notifyChanged( const QString &groupAddress, const QDBusMessage &msg ) // DBUS call
 {
-    kDebug() << "KBookmarkManager::notifyChanged ( "<<groupAddress<<")"<<endl;
-    if (!m_update) return;
+    kDebug() << "KBookmarkManager::notifyChanged ( "<<groupAddress<<")";
+    if (!d->m_update)
+        return;
 
     // Reparse (the whole file, no other choice)
     // if someone else notified us
     if (msg.service() != QDBusConnection::sessionBus().baseService())
        parse();
 
-    //kDebug(7043) << "KBookmarkManager::notifyChanged " << groupAddress << endl;
+    //kDebug(7043) << "KBookmarkManager::notifyChanged " << groupAddress;
     //KBookmarkGroup group = findByAddress( groupAddress ).toGroup();
     //Q_ASSERT(!group.isNull());
     emit changed( groupAddress, QString() );
@@ -580,20 +522,20 @@ void KBookmarkManager::notifyChanged( QString groupAddress, const QDBusMessage &
 
 void KBookmarkManager::setEditorOptions( const QString& caption, bool browser )
 {
-    m_editorCaption = caption;
-    m_browserEditor = browser;
+    d->m_editorCaption = caption;
+    d->m_browserEditor = browser;
 }
 
 void KBookmarkManager::slotEditBookmarks()
 {
     QStringList args;
-    if ( !m_editorCaption.isEmpty() )
-       args << QLatin1String("--customcaption") << m_editorCaption;
-    if ( !m_browserEditor )
+    if ( !d->m_editorCaption.isEmpty() )
+       args << QLatin1String("--customcaption") << d->m_editorCaption;
+    if ( !d->m_browserEditor )
        args << QLatin1String("--nobrowser");
-    if( !m_dbusObjectName.isEmpty() )
-      args << QLatin1String("--dbusObjectName") << m_dbusObjectName;
-    args << m_bookmarksFile;
+    if( !d->m_dbusObjectName.isEmpty() )
+      args << QLatin1String("--dbusObjectName") << d->m_dbusObjectName;
+    args << d->m_bookmarksFile;
     QProcess::startDetached("keditbookmarks", args);
 }
 
@@ -602,12 +544,12 @@ void KBookmarkManager::slotEditBookmarksAtAddress( const QString& address )
     QStringList args;
     //TODO shouldn't we pass --customcaption and --nobrowser too?
     args << QLatin1String("--address") << address
-         << m_bookmarksFile;
+         << d->m_bookmarksFile;
     QProcess::startDetached("keditbookmarks", args);
 }
 
 ///////
-bool KBookmarkManager::updateAccessMetadata( const QString & url, bool emitSignal )
+bool KBookmarkManager::updateAccessMetadata( const QString & url )
 {
     if (!s_bk_map) {
         s_bk_map = new KBookmarkMap(this);
@@ -622,13 +564,10 @@ bool KBookmarkManager::updateAccessMetadata( const QString & url, bool emitSigna
           it != list.end(); ++it )
         (*it).updateAccessMetadata();
 
-    if (emitSignal)
-        emit KBookmarkNotifier::updatedAccessMetadata( path(), url );
-
     return true;
 }
 
-void KBookmarkManager::updateFavicon( const QString &url, const QString &faviconurl, bool emitSignal )
+void KBookmarkManager::updateFavicon( const QString &url, const QString &faviconurl )
 {
     Q_UNUSED(faviconurl);
 
@@ -645,33 +584,26 @@ void KBookmarkManager::updateFavicon( const QString &url, const QString &favicon
         //        but only when the previously used icon
         //        isn't a manually set one.
     }
-
-    if (emitSignal)
-    {
-        // TODO
-        // emit notifier().updatedFavicon( path(), url, faviconurl );
-    }
 }
 
 KBookmarkManager* KBookmarkManager::userBookmarksManager()
 {
    QString bookmarksFile = KStandardDirs::locateLocal("data", QLatin1String("konqueror/bookmarks.xml"));
-   return KBookmarkManager::managerForFile( bookmarksFile, "konqueror", true );
+   return KBookmarkManager::managerForFile( bookmarksFile, "konqueror" );
 }
 
 KBookmarkSettings* KBookmarkSettings::s_self = 0;
 
 void KBookmarkSettings::readSettings()
 {
-   KConfig config("kbookmarkrc", false, false);
-   config.setGroup("Bookmarks");
+   KConfig config("kbookmarkrc", KConfig::NoGlobals);
+   KConfigGroup cg(&config, "Bookmarks");
 
    // add bookmark dialog usage - no reparse
-   s_self->m_advancedaddbookmark = config.readEntry("AdvancedAddBookmarkDialog", false);
+   s_self->m_advancedaddbookmark = cg.readEntry("AdvancedAddBookmarkDialog", false);
 
-   // these three alter the menu, therefore all need a reparse
-   s_self->m_contextmenu = config.readEntry("ContextMenuActions", true);
-   s_self->m_filteredtoolbar = config.readEntry("FilteredToolbar", false);
+   // this one alters the menu, therefore it needs a reparse
+   s_self->m_contextmenu = cg.readEntry("ContextMenuActions", true);
 }
 
 KBookmarkSettings *KBookmarkSettings::self()
@@ -684,11 +616,15 @@ KBookmarkSettings *KBookmarkSettings::self()
    return s_self;
 }
 
-void KBookmarkOwner::openBookmark(const KBookmark & bm, Qt::MouseButtons mb, Qt::KeyboardModifiers km)
+/////////// KBookmarkOwner
+
+bool KBookmarkOwner::enableOption(BookmarkOption action) const 
 {
-   Q_UNUSED(bm)
-   Q_UNUSED(mb)
-   Q_UNUSED(km)
+    if(action == ShowAddBookmark)
+        return true;
+    if(action == ShowEditBookmark)
+        return true;
+    return false;
 }
 
 #include "kbookmarkmanager.moc"
