@@ -20,15 +20,14 @@
 #ifndef __kbookmarkmanager_h
 #define __kbookmarkmanager_h
 
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qobject.h>
-#include <qdom.h>
-#include <qpair.h>
+#include <QtCore/QString>
+#include <QtCore/QStringList>
+#include <QtCore/QObject>
+#include <QtCore/QPair>
+#include <QtXml/QDomDocument>
+#include <QtXml/QDomElement>
 #include "kbookmark.h"
-#include "kbookmarknotifier.h"
 
-class KBookmarkManagerList;
 class KBookmarkGroup;
 class QDBusMessage;
 
@@ -40,7 +39,7 @@ class QDBusMessage;
  * A sample file looks like this :
  * \code
  * <xbel>
- *   <bookmark href="http://developer.kde.org"><title>Developer Web Site</title></bookmark>
+ *   <bookmark href="http://techbase.kde.org"><title>Developer Web Site</title></bookmark>
  *   <folder folded="no">
  *     <title>Title of this folder</title>
  *     <bookmark icon="kde" href="http://www.kde.org"><title>KDE Web Site</title></bookmark>
@@ -74,12 +73,8 @@ protected:
      * konqueror bookmarks, "kfile" for KFileDialog bookmarks, etc.
      * The final DBus object path is /KBookmarkManager/dbusObjectName
      * An empty dbusObjectName disables the registration to dbus (used for temporary managers)
-     *
-     * @param bImportDesktopFiles if true, and if the bookmarksFile
-     * doesn't already exist, import bookmarks from desktop files
      */
-    KBookmarkManager( const QString & bookmarksFile, const QString& dbusObjectName, bool bImportDesktopFiles = true );
-
+    KBookmarkManager( const QString & bookmarksFile, const QString& dbusObjectName );
 
     KBookmarkManager();
 
@@ -95,16 +90,6 @@ public:
      */
     void setUpdate( bool update );
 
-    /**
-     * Save the bookmarks to an XML file on disk.
-     * You should use emitChanged() instead of this function, it saves
-     * and notifies everyone that the file has changed.
-     * @param toolbarCache iff true save a cache of the toolbar folder, too
-     * @return true if saving was successful
-     */
-    bool save( bool toolbarCache = true ) const;
-    //TODO protected
-
     /**
      * Save the bookmarks to the given XML file on disk.
      * @param filename full path to the desired bookmarks file location
@@ -116,10 +101,9 @@ public:
     /**
      * Update access time stamps for a given url.
      * @param url the viewed url
-     * @param emitSignal iff true emit KBookmarkNotifier signal
      * @return true if any metadata was modified (bookmarks file is not saved automatically)
      */
-    bool updateAccessMetadata( const QString &url, bool emitSignal = true );
+    bool updateAccessMetadata( const QString &url );
 
     /*
      * NB. currently *unimplemented*
@@ -127,9 +111,8 @@ public:
      * Update favicon url for a given url.
      * @param url the viewed url
      * @param faviconurl the favicion url
-     * @emitSignal iff true emit KBookmarkNotifier signal
      */
-    void updateFavicon( const QString &url, const QString &faviconurl, bool emitSignal = true );
+    void updateFavicon( const QString &url, const QString &faviconurl );
 
     /**
      * This will return the path that this manager is using to read
@@ -137,7 +120,7 @@ public:
      * @internal
      * @return the path containing the bookmarks
      */
-    QString path() { return m_bookmarksFile; }
+    QString path() const;
 
     /**
      * This will return the root bookmark.  It is used to iterate
@@ -150,7 +133,7 @@ public:
     /**
      * This returns the root of the toolbar menu.
      * In the XML, this is the group with the attribute toolbar=yes
-     *
+     * 
      * @return the toolbar group
      */
     KBookmarkGroup toolbar();
@@ -161,8 +144,14 @@ public:
      * @param tolerate when true tries to find the most tolerable bookmark position
      * @see KBookmark::address
      */
-    KBookmark findByAddress( const QString & address, bool tolerate = false );
-    //TODO tolerate needed?
+    KBookmark findByAddress( const QString & address);
+
+
+    /**
+     * Saves the bookmark file and notifies everyone.
+     * 
+     **/
+    void emitChanged();
 
     /**
      * Saves the bookmark file and notifies everyone.
@@ -170,6 +159,17 @@ public:
      */
     void emitChanged( const KBookmarkGroup & group );
 
+    /**
+     * Save the bookmarks to an XML file on disk.
+     * You should use emitChanged() instead of this function, it saves
+     * and notifies everyone that the file has changed.
+     * Only use this if you don't want the emitChanged signal.
+     * @param toolbarCache iff true save a cache of the toolbar folder, too
+     * @return true if saving was successful
+     */
+    bool save( bool toolbarCache = true ) const;
+
+
     void emitConfigChanged();
 
     /**
@@ -201,13 +201,9 @@ public:
      * The final DBus object path is /KBookmarkManager/dbusObjectName
      * An empty dbusObjectName disables the registration to dbus (used for temporary managers)
      *
-     * @param bImportDesktopFiles if true, and if the bookmarksFile
-     * doesn't already exist, import bookmarks from desktop files
-     * @return a pointer to an instance of the KBookmarkManager.
      */
     static KBookmarkManager* managerForFile( const QString& bookmarksFile,
-                                             const QString& dbusObjectName,
-                                             bool bImportDesktopFiles = true );
+                                             const QString& dbusObjectName );
     /**
      * only used for KBookmarkBar
      */
@@ -221,7 +217,7 @@ public:
     /**
      * @internal
      */
-    const QDomDocument & internalDocument() const;
+    QDomDocument internalDocument() const;
 
     KBookmarkGroup addBookmarkDialog( const QString & _url, const QString & _title,
                                       const QString & _parentBookmarkAddress = QString() );
@@ -234,63 +230,71 @@ public Q_SLOTS:
 
     /**
      * Reparse the whole bookmarks file and notify about the change
+     * Doesn't send signal over DBUS to the other Bookmark Managers
+     * You probably want to use emitChanged()
+     *
      */
-    void notifyCompleteChange( QString caller );
+    void notifyCompleteChange( const QString &caller );
 
     /**
      * Emit the changed signal for the group whose address is given
      * @see KBookmark::address()
      * Called by the process that saved the file after
      * a small change (new bookmark or new folder).
+     * Does not send signal over DBUS to the other Bookmark Managers
+     * You probably want to call emitChanged()
      */
-    void notifyChanged( QString groupAddress, const QDBusMessage &msg );
+    void notifyChanged( const QString &groupAddress, const QDBusMessage &msg );
 
     void notifyConfigChanged();
 
 Q_SIGNALS:
+    /**
+     * Signal send over DBUS
+     */
     void bookmarkCompleteChange( QString caller );
 
+    /**
+     * Signals send over DBUS
+     */
     void bookmarksChanged( QString groupAddress );
 
+    /**
+     * Signals send over DBUS
+     */
     void bookmarkConfigChanged();
 
     /**
      * Signals that the group (or any of its children) with the address
      * @p groupAddress (e.g. "/4/5")
      * has been modified by the caller @p caller.
+     * connect to this
      */
     void changed( const QString & groupAddress, const QString & caller );
 
+    /**
+     * Signals that the config changed
+     */
+    void configChanged();
+
 protected:
     // consts added to avoid a copy-and-paste of internalDocument
     void parse() const;
-    void importDesktopFiles();
-    static void convertToXBEL( QDomElement & group ); //TODO used to convert pre KDE 2.1 bookmarks, remove?
-    static void convertAttribute( QDomElement elem, const QString & oldName, const QString & newName );
 
 private:
     /**
     * You need to pass a dbusObjectName as the second parameter
-    * In kde 3 managerForFile had the parameters (const  QString &, bool)
+    * In kde 3 managerForFile had the parameters (const QString &, bool)
     * We want old calls which pass a bool as a second parameter to fail.
-    * Unfourtanetly C++ can convert a bool to a QString, via QString(char(bool))
-    * This private overloaded method pervents this, as it is a better match,
+    * Unfortunately C++ can convert a bool to a QString, via QString(char(bool))
+    * This private overloaded method prevents this, as it is a better match,
     * and thus old calls fail at compile time.
     */
     static KBookmarkManager* managerForFile( const QString&, int);
     void init( const QString& dbusPath );
 
-    QString m_bookmarksFile;
-    mutable QDomDocument m_doc;
-    mutable QDomDocument m_toolbarDoc;
-    mutable bool m_docIsLoaded;
-    bool m_update;
-    QString m_dbusObjectName;
-    static KBookmarkManagerList* s_pSelf;
-
-    QString m_editorCaption;
-    bool m_browserEditor;
-    class KBookmarkManagerPrivate* d;
+    class Private;
+    Private * const d;
 
     friend class KBookmarkGroup;
 };
@@ -352,15 +356,16 @@ public:
    */
   virtual QList<QPair<QString, QString> > currentBookmarkList() const { return QList<QPair<QString, QString> >(); }
 
-  /**
-   * Returns true if the bookmark menu/toolbar should show an "Add Bookmark" Entry
-   */
-  virtual bool addBookmarkEntry() const { return true; }
+  enum BookmarkOption { ShowAddBookmark, ShowEditBookmark };
 
-  /**
-   * Returns true if the bookmark menu/toolbar should show an "Edit Bookmarks" Entry
+
+  /** Returns true if \p action should be shown in the menu
+   *  The default is to show both a add and editBookmark Entry
+   *  //TODO ContextMenuAction? to disable the contextMenu?
+   *         Delete and Propeties to disable those in the
+   *         context menu?
    */
-  virtual bool editBookmarkEntry() const { return true; }
+  virtual bool enableOption(BookmarkOption option) const;
 
   /**
    * Called if a bookmark is selected. You need to override this.
