@@ -1,5 +1,3 @@
-//  -*- c-basic-offset:2; indent-tabs-mode:nil -*-
-// vim: set ts=2 sts=2 sw=2 et:
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
    Copyright (C) 2006 Daniel Teske <teske@squorn.de>
@@ -23,7 +21,6 @@
 #include "kbookmarkmenu.h"
 #include "kbookmarkmenu_p.h"
 
-#include <kapplication.h>
 #include <kauthorized.h>
 #include <kconfig.h>
 #include <kdebug.h>
@@ -36,7 +33,6 @@
 #include <kstandardaction.h>
 #include <kstringhandler.h>
 #include <krun.h>
-#include <kstringhandler.h>
 #include <kactioncollection.h>
 
 #include <qclipboard.h>
@@ -48,28 +44,9 @@
 #include <qmimedata.h>
 
 
-#include <QStack>
-#include <QHeaderView>
-
-static QString makeTextNodeMod(KBookmark bk, const QString &m_nodename, const QString &m_newText) {
-  QDomNode subnode = bk.internalElement().namedItem(m_nodename);
-  if (subnode.isNull()) {
-    subnode = bk.internalElement().ownerDocument().createElement(m_nodename);
-    bk.internalElement().appendChild(subnode);
-  }
-
-  if (subnode.firstChild().isNull()) {
-    QDomText domtext = subnode.ownerDocument().createTextNode("");
-    subnode.appendChild(domtext);
-  }
-
-  QDomText domtext = subnode.firstChild().toText();
-
-  QString m_oldText = domtext.data();
-  domtext.setData(m_newText);
-
-  return m_oldText;
-}
+#include <QtCore/QStack>
+#include <QtGui/QHeaderView>
+#include <QtGui/QApplication>
 
 /********************************************************************/
 /********************************************************************/
@@ -79,15 +56,15 @@ KBookmarkMenu::KBookmarkMenu( KBookmarkManager* mgr,
                               KBookmarkOwner * _owner, KMenu * _parentMenu,
                               KActionCollection * actionCollection)
   : QObject(),
+    m_actionCollection( actionCollection ),
     m_bIsRoot(true),
     m_pManager(mgr), m_pOwner(_owner),
     m_parentMenu( _parentMenu ),
-    m_actionCollection( actionCollection ),
     m_parentAddress( QString("") ) //TODO KBookmarkAdress::root
 {
   m_parentMenu->setKeyboardShortcutsEnabled( true );
 
-  //kDebug(7043) << "KBookmarkMenu::KBookmarkMenu " << this << " address : " << m_parentAddress << endl;
+  //kDebug(7043) << "KBookmarkMenu::KBookmarkMenu " << this << " address : " << m_parentAddress;
 
   connect( _parentMenu, SIGNAL( aboutToShow() ),
             SLOT( slotAboutToShow() ) );
@@ -95,18 +72,13 @@ KBookmarkMenu::KBookmarkMenu( KBookmarkManager* mgr,
   if ( KBookmarkSettings::self()->m_contextmenu )
   {
     m_parentMenu->setContextMenuPolicy(Qt::CustomContextMenu);
-    connect(m_parentMenu, SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(contextMenu(const QPoint &)));
+    connect(m_parentMenu, SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(slotCustomContextMenu(const QPoint &)));
   }
 
   connect( m_pManager, SIGNAL( changed(const QString &, const QString &) ),
               SLOT( slotBookmarksChanged(const QString &) ) );
 
   m_bDirty = true;
-
-  // add entries that possibly have a shortcut, so they are available _before_ first popup
-  addAddBookmark();
-  addAddBookmarksList();
-  addEditBookmarks();
 }
 
 void KBookmarkMenu::addActions()
@@ -115,8 +87,8 @@ void KBookmarkMenu::addActions()
   {
     addAddBookmark();
     addAddBookmarksList();
-    addEditBookmarks();
     addNewFolder();
+    addEditBookmarks();
   }
   else
   {
@@ -133,10 +105,10 @@ KBookmarkMenu::KBookmarkMenu( KBookmarkManager* mgr,
                               KBookmarkOwner * _owner, KMenu * _parentMenu,
                               const QString & parentAddress)
   : QObject(),
+    m_actionCollection( new KActionCollection(this) ),
     m_bIsRoot(false),
     m_pManager(mgr), m_pOwner(_owner),
     m_parentMenu( _parentMenu ),
-    m_actionCollection( 0 ),
     m_parentAddress( parentAddress )
 {
   m_parentMenu->setKeyboardShortcutsEnabled( true );
@@ -144,7 +116,7 @@ KBookmarkMenu::KBookmarkMenu( KBookmarkManager* mgr,
   if ( KBookmarkSettings::self()->m_contextmenu )
   {
     m_parentMenu->setContextMenuPolicy(Qt::CustomContextMenu);
-    connect(m_parentMenu, SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(contextMenu(const QPoint &)));
+    connect(m_parentMenu, SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(slotCustomContextMenu(const QPoint &)));
   }
   m_bDirty = true;
 }
@@ -172,20 +144,57 @@ void KBookmarkMenu::slotAboutToShow()
   }
 }
 
-void KBookmarkMenu::contextMenu( const QPoint & pos )
+void KBookmarkMenu::slotCustomContextMenu( const QPoint & pos)
 {
-  QAction * action = m_parentMenu->actionAt(pos);
-  KBookmarkActionInterface* act = dynamic_cast<KBookmarkActionInterface *>(action);
-  if (!act)
-      return;
-  act->contextMenu(m_parentMenu->mapToGlobal(pos), m_pManager, m_pOwner);
+    QAction * action = m_parentMenu->actionAt(pos);
+    KBookmarkActionInterface* act = dynamic_cast<KBookmarkActionInterface *>(action);
+    if (!act)
+        return;
+    KMenu * menu = contextMenu(act->bookmark());
+    menu->setAttribute(Qt::WA_DeleteOnClose);
+    menu->popup(m_parentMenu->mapToGlobal(pos));
+}
+
+KMenu * KBookmarkMenu::contextMenu( const KBookmark & bm )
+{ 
+  return new KBookmarkContextMenu(bm, m_pManager, m_pOwner);
+}
+
+bool KBookmarkMenu::isRoot() const 
+{
+    return m_bIsRoot;
+}
+
+bool KBookmarkMenu::isDirty() const 
+{
+    return m_bDirty;
+}
+
+QString KBookmarkMenu::parentAddress() const 
+{
+    return m_parentAddress;
+}
+
+KBookmarkManager * KBookmarkMenu::manager() const
+{
+    return m_pManager;
+}
+
+KBookmarkOwner * KBookmarkMenu::owner() const 
+{
+    return m_pOwner;
+}
+
+KMenu * KBookmarkMenu::parentMenu() const 
+{
+    return m_parentMenu;
 }
 
 /********************************************************************/
 /********************************************************************/
 /********************************************************************/
 
-KBookmarkActionInterface::KBookmarkActionInterface(KBookmark bk)
+KBookmarkActionInterface::KBookmarkActionInterface(const KBookmark &bk)
 : bm(bk)
 {}
 
@@ -193,10 +202,6 @@ KBookmarkActionInterface::~KBookmarkActionInterface()
 {
 }
 
-void KBookmarkActionInterface::contextMenu(QPoint, KBookmarkManager*, KBookmarkOwner*)
-{
-}
-
 const KBookmark KBookmarkActionInterface::bookmark() const
 {
   return bm;
@@ -206,110 +211,89 @@ const KBookmark KBookmarkActionInterface::bookmark() const
 /********************************************************************/
 /********************************************************************/
 
-KBookmarkActionContextMenu & KBookmarkActionContextMenu::self()
+
+KBookmarkContextMenu::KBookmarkContextMenu(const KBookmark & bk, KBookmarkManager * manager, KBookmarkOwner *owner, QWidget * parent)
+    : KMenu(parent), bm(bk), m_pManager(manager), m_pOwner(owner)
 {
-  static KBookmarkActionContextMenu s;
-  return s;
+    connect(this, SIGNAL(aboutToShow()), SLOT(slotAboutToShow()));
 }
 
-void KBookmarkActionContextMenu::contextMenu(QPoint pos, QString highlightedAddress,
-	KBookmarkManager *pManager, KBookmarkOwner *pOwner)
+void KBookmarkContextMenu::slotAboutToShow()
 {
-  m_parentAddress = KBookmark::parentAddress(highlightedAddress) ;
-  m_highlightedAddress = highlightedAddress;
-  m_pManager = pManager;
-  m_pOwner = pOwner;
-  delete m_contextMenu;
-  m_contextMenu = new QMenu();
+    addActions();
+}
 
-  KBookmark bookmark = atAddress(m_highlightedAddress);
-  addBookmark();
-
-  if (bookmark.isGroup())
+void KBookmarkContextMenu::addActions()
+{
+  if (bm.isGroup())
     addFolderActions();
   else
     addBookmarkActions();
-
+  addSeparator();
   addProperties();
-
-  if(!m_highlightedAddress.isNull())
-    m_contextMenu->popup(pos);
 }
 
-void KBookmarkActionContextMenu::addBookmark()
+KBookmarkContextMenu::~KBookmarkContextMenu()
 {
-  if( m_pOwner && m_pOwner->addBookmarkEntry() )
-    m_contextMenu->addAction( SmallIcon("bookmark_add"), i18n( "Add Bookmark Here" ), this, SLOT(slotInsert()) );
-}
 
-void KBookmarkActionContextMenu::addFolderActions()
-{
-  m_contextMenu->addAction( i18n( "Open Folder in Bookmark Editor" ), this, SLOT(slotEditAt()) );
-  m_contextMenu->addSeparator();
-  m_contextMenu->addAction( SmallIcon("editdelete"), i18n( "Delete Folder" ), this, SLOT(slotRemove()) );
-  m_contextMenu->addSeparator();
 }
 
 
-void KBookmarkActionContextMenu::addProperties()
+void KBookmarkContextMenu::addBookmark()
 {
-  m_contextMenu->addAction( i18n( "Properties" ), this, SLOT(slotProperties()) );
+  if( m_pOwner && m_pOwner->enableOption(KBookmarkOwner::ShowAddBookmark)  )
+      addAction( SmallIcon("bookmark-new"), i18n( "Add Bookmark Here" ), this, SLOT(slotInsert()) );
 }
 
-void KBookmarkActionContextMenu::addBookmarkActions()
+void KBookmarkContextMenu::addFolderActions()
 {
-  m_contextMenu->addAction( i18n( "Copy Link Address" ), this, SLOT(slotCopyLocation()) );
-  m_contextMenu->addSeparator();
-  m_contextMenu->addAction( SmallIcon("editdelete"), i18n( "Delete Bookmark" ), this, SLOT(slotRemove()) );
-  m_contextMenu->addSeparator();
+  addAction( i18n( "Open Folder in Bookmark Editor" ), this, SLOT(slotEditAt()) );
+  addSeparator();
+  addAction( SmallIcon("edit-delete"), i18n( "Delete Folder" ), this, SLOT(slotRemove()) );
 }
 
-KBookmarkActionContextMenu::~KBookmarkActionContextMenu()
+
+void KBookmarkContextMenu::addProperties()
 {
-    delete m_contextMenu;
+  addAction( i18n( "Properties" ), this, SLOT(slotProperties()) );
 }
 
-KBookmark KBookmarkActionContextMenu::atAddress(const QString & address)
+void KBookmarkContextMenu::addBookmarkActions()
 {
-  KBookmark bookmark = m_pManager->findByAddress( address );
-  Q_ASSERT(!bookmark.isNull());
-  return bookmark;
+  addAction( i18n( "Copy Link Address" ), this, SLOT(slotCopyLocation()) );
+  addSeparator();
+  addAction( SmallIcon("edit-delete"), i18n( "Delete Bookmark" ), this, SLOT(slotRemove()) );
 }
 
-void KBookmarkActionContextMenu::slotEditAt()
+void KBookmarkContextMenu::slotEditAt()
 {
-  //kDebug(7043) << "KBookmarkMenu::slotEditAt" << m_highlightedAddress << endl;
-  KBookmark bookmark = atAddress(m_highlightedAddress);
-  m_pManager->slotEditBookmarksAtAddress( m_highlightedAddress );
+  //kDebug(7043) << "KBookmarkMenu::slotEditAt" << m_highlightedAddress;
+  m_pManager->slotEditBookmarksAtAddress( bm.address() );
 }
 
-void KBookmarkActionContextMenu::slotProperties()
+void KBookmarkContextMenu::slotProperties()
 {
-  //kDebug(7043) << "KBookmarkMenu::slotProperties" << m_highlightedAddress << endl;
+  //kDebug(7043) << "KBookmarkMenu::slotProperties" << m_highlightedAddress;
 
-  KBookmark bookmark = atAddress(m_highlightedAddress);
-
-  QString folder = bookmark.isGroup() ? QString() : bookmark.url().pathOrUrl();
-  KBookmarkEditDialog dlg( bookmark.fullText(), folder,
+  QString folder = bm.isGroup() ? QString() : bm.url().pathOrUrl();
+  KBookmarkEditDialog dlg( bm.fullText(), folder,
                            m_pManager, KBookmarkEditDialog::ModifyMode, 0,
                            0, i18n("Bookmark Properties") );
   if ( dlg.exec() != KDialog::Accepted )
     return;
 
-  makeTextNodeMod(bookmark, "title", dlg.finalTitle());
+  bm.setFullText(dlg.finalTitle());
   if ( !dlg.finalUrl().isNull() )
-  {
-    KUrl u(dlg.finalUrl());
-    bookmark.internalElement().setAttribute("href", u.url()); // utf8
+  {    
+    bm.setUrl(dlg.finalUrl());
   }
 
-  KBookmarkGroup parentBookmark = atAddress(m_parentAddress).toGroup();
-  m_pManager->emitChanged( parentBookmark );
+  m_pManager->emitChanged( bm.parentGroup() );
 }
 
-void KBookmarkActionContextMenu::slotInsert()
+void KBookmarkContextMenu::slotInsert()
 {
-  //kDebug(7043) << "KBookmarkMenu::slotInsert" << m_highlightedAddress << endl;
+  //kDebug(7043) << "KBookmarkMenu::slotInsert" << m_highlightedAddress;
 
   QString url = m_pOwner->currentUrl();
   if (url.isEmpty())
@@ -321,38 +305,35 @@ void KBookmarkActionContextMenu::slotInsert()
   if (title.isEmpty())
     title = url;
 
-  KBookmark bookmark = atAddress( m_highlightedAddress );
-
   // TODO use unique title
 
-  if (bookmark.isGroup())
+  if (bm.isGroup())
   {
-    KBookmarkGroup parentBookmark = bookmark.toGroup();
+    KBookmarkGroup parentBookmark = bm.toGroup();
     Q_ASSERT(!parentBookmark.isNull());
-    parentBookmark.addBookmark( m_pManager, title, KUrl(  url ) );
+    parentBookmark.addBookmark( title, KUrl(  url ) );
     m_pManager->emitChanged( parentBookmark );
   }
   else
   {
-    KBookmarkGroup parentBookmark = bookmark.parentGroup();
+    KBookmarkGroup parentBookmark = bm.parentGroup();
     Q_ASSERT(!parentBookmark.isNull());
-    KBookmark newBookmark = parentBookmark.addBookmark( m_pManager, title, KUrl( url ) );
-    parentBookmark.moveItem( newBookmark, parentBookmark.previous(bookmark) );
+    KBookmark newBookmark = parentBookmark.addBookmark( title, KUrl( url ) );
+    parentBookmark.moveItem( newBookmark, parentBookmark.previous(bm) );
     m_pManager->emitChanged( parentBookmark );
   }
 }
 
-void KBookmarkActionContextMenu::slotRemove()
+void KBookmarkContextMenu::slotRemove()
 {
-  //kDebug(7043) << "KBookmarkMenu::slotRemove" << m_highlightedAddress << endl;
+  //kDebug(7043) << "KBookmarkMenu::slotRemove" << m_highlightedAddress;
 
-  KBookmark bookmark = atAddress( m_highlightedAddress );
-  bool folder = bookmark.isGroup();
+  bool folder = bm.isGroup();
 
   if (KMessageBox::warningContinueCancel(
-          m_parentMenu,
-          folder ? i18n("Are you sure you wish to remove the bookmark folder\n\"%1\"?", bookmark.text())
-                 : i18n("Are you sure you wish to remove the bookmark\n\"%1\"?", bookmark.text()),
+          0,
+          folder ? i18n("Are you sure you wish to remove the bookmark folder\n\"%1\"?", bm.text())
+                 : i18n("Are you sure you wish to remove the bookmark\n\"%1\"?", bm.text()),
           folder ? i18n("Bookmark Folder Deletion")
                  : i18n("Bookmark Deletion"),
           KStandardGuiItem::del())
@@ -360,39 +341,50 @@ void KBookmarkActionContextMenu::slotRemove()
      )
     return;
 
-  KBookmarkGroup parentBookmark = atAddress( m_parentAddress ).toGroup();
-  parentBookmark.deleteBookmark( bookmark );
+  KBookmarkGroup parentBookmark = bm.parentGroup();
+  parentBookmark.deleteBookmark( bm );
   m_pManager->emitChanged( parentBookmark );
-  if (m_parentMenu)
-    m_parentMenu->hide();
 }
 
-void KBookmarkActionContextMenu::slotCopyLocation()
+void KBookmarkContextMenu::slotCopyLocation()
 {
-  //kDebug(7043) << "KBookmarkMenu::slotCopyLocation" << m_highlightedAddress << endl;
+  //kDebug(7043) << "KBookmarkMenu::slotCopyLocation" << m_highlightedAddress;
 
-  const KBookmark bookmark = atAddress( m_highlightedAddress );
-
-  if ( !bookmark.isGroup() )
+  if ( !bm.isGroup() )
   {
     QMimeData* mimeData = new QMimeData;
-    bookmark.populateMimeData( mimeData );
+    bm.populateMimeData( mimeData );
     QApplication::clipboard()->setMimeData( mimeData, QClipboard::Selection );
     mimeData = new QMimeData;
-    bookmark.populateMimeData( mimeData );
+    bm.populateMimeData( mimeData );
     QApplication::clipboard()->setMimeData( mimeData, QClipboard::Clipboard );
   }
 }
 
+KBookmarkManager * KBookmarkContextMenu::manager() const
+{
+    return m_pManager;
+}
+
+KBookmarkOwner * KBookmarkContextMenu::owner() const
+{
+    return m_pOwner;
+}
+
+KBookmark KBookmarkContextMenu::bookmark() const
+{
+    return bm;
+}
+
 /********************************************************************/
 /********************************************************************/
 /********************************************************************/
 void KBookmarkMenu::slotBookmarksChanged( const QString & groupAddress )
 {
-  kDebug(7043)<<"KBookmarkMenu::slotBookmarksChanged( "<<groupAddress<<endl;
+  kDebug(7043)<<"KBookmarkMenu::slotBookmarksChanged( "<<groupAddress;
   if ( groupAddress == m_parentAddress )
   {
-    //kDebug(7043) << "KBookmarkMenu::slotBookmarksChanged -> setting m_bDirty on " << groupAddress << endl;
+    //kDebug(7043) << "KBookmarkMenu::slotBookmarksChanged -> setting m_bDirty on " << groupAddress;
     m_bDirty = true;
   }
   else
@@ -422,7 +414,7 @@ void KBookmarkMenu::clear()
 
 void KBookmarkMenu::refill()
 {
-  //kDebug(7043) << "KBookmarkMenu::refill()" << endl;
+  //kDebug(7043) << "KBookmarkMenu::refill()";
   if(m_bIsRoot)
     addActions();
   fillBookmarks();
@@ -432,14 +424,14 @@ void KBookmarkMenu::refill()
 
 void KBookmarkMenu::addAddBookmarksList()
 {
-  if( !m_pOwner || !m_pOwner->addBookmarkEntry() || !m_pOwner->supportsTabs() || !KAuthorized::authorizeKAction("bookmarks") )
+  if( !m_pOwner || !m_pOwner->enableOption(KBookmarkOwner::ShowAddBookmark) || !m_pOwner->supportsTabs() || !KAuthorized::authorizeKAction("bookmarks") )
     return;
 
   QString title = i18n( "Bookmark Tabs as Folder..." );
 
   KAction * paAddBookmarksList = new KAction( title, this );
   m_actionCollection->addAction( m_bIsRoot ? "add_bookmarks_list" : 0, paAddBookmarksList );
-  paAddBookmarksList->setIcon( KIcon( "bookmarks_list_add" ) );
+  paAddBookmarksList->setIcon( KIcon( "bookmark-new-list" ) );
   paAddBookmarksList->setToolTip( i18n( "Add a folder of bookmarks for all open tabs." ) );
   connect( paAddBookmarksList, SIGNAL( triggered( bool ) ), this, SLOT( slotAddBookmarksList() ) );
 
@@ -449,14 +441,14 @@ void KBookmarkMenu::addAddBookmarksList()
 
 void KBookmarkMenu::addAddBookmark()
 {
-  if( !m_pOwner || !m_pOwner->addBookmarkEntry() || !KAuthorized::authorizeKAction("bookmarks") )
+  if( !m_pOwner || !m_pOwner->enableOption(KBookmarkOwner::ShowAddBookmark) || !KAuthorized::authorizeKAction("bookmarks") )
     return;
 
   QString title = i18n( "Add Bookmark" );
 
   KAction * paAddBookmarks = new KAction( title, this );
   m_actionCollection->addAction( m_bIsRoot ? "add_bookmark" : 0, paAddBookmarks );
-  paAddBookmarks->setIcon( KIcon( "bookmark_add" ) );
+  paAddBookmarks->setIcon( KIcon( "bookmark-new" ) );
   paAddBookmarks->setShortcut( m_bIsRoot ? KStandardShortcut::addBookmark() : KShortcut() );
   paAddBookmarks->setToolTip( i18n( "Add a bookmark for the current document" ) );
   connect( paAddBookmarks, SIGNAL( triggered( bool ) ), this, SLOT( slotAddBookmark() ) );
@@ -467,7 +459,7 @@ void KBookmarkMenu::addAddBookmark()
 
 void KBookmarkMenu::addEditBookmarks()
 {
-  if( m_pOwner && !m_pOwner->editBookmarkEntry() || !KAuthorized::authorizeKAction("bookmarks") )
+  if( m_pOwner && !m_pOwner->enableOption(KBookmarkOwner::ShowEditBookmark) || !KAuthorized::authorizeKAction("bookmarks") )
     return;
 
   QAction * m_paEditBookmarks = m_actionCollection->addAction( KStandardAction::EditBookmarks, "edit_bookmarks",
@@ -479,15 +471,12 @@ void KBookmarkMenu::addEditBookmarks()
 
 void KBookmarkMenu::addNewFolder()
 {
-  if( !m_pOwner || !m_pOwner->addBookmarkEntry() || !KAuthorized::authorizeKAction("bookmarks"))
+  if( !m_pOwner || !m_pOwner->enableOption(KBookmarkOwner::ShowAddBookmark) || !KAuthorized::authorizeKAction("bookmarks"))
     return;
 
-  QString title = i18n( "&New Bookmark Folder..." );
-  title.remove( QChar( '&' ) ); //FIXME Hmm, why?
-
-  KAction * paNewFolder = new KAction( title, this );
+  KAction * paNewFolder = new KAction( i18n( "New Bookmark Folder..." ), this );
   m_actionCollection->addAction( "dummyname", paNewFolder );
-  paNewFolder->setIcon( KIcon( "folder_new" ) );
+  paNewFolder->setIcon( KIcon( "folder-new" ) );
   paNewFolder->setToolTip( i18n( "Create a new bookmark folder in this menu" ) );
   connect( paNewFolder, SIGNAL( triggered( bool ) ), this, SLOT( slotNewFolder() ) );
 
@@ -511,11 +500,11 @@ void KBookmarkMenu::fillBookmarks()
   }
 }
 
-QAction* KBookmarkMenu::actionForBookmark(KBookmark bm)
+QAction* KBookmarkMenu::actionForBookmark(const KBookmark &bm)
 {
   if ( bm.isGroup() )
   {
-    //kDebug(7043) << "Creating bookmark submenu named " << bm.text() << endl;
+    //kDebug(7043) << "Creating bookmark submenu named " << bm.text();
     KActionMenu * actionMenu = new KBookmarkActionMenu( bm, this );
     m_actionCollection->addAction( "kbookmarkmenu", actionMenu );
     m_actions.append( actionMenu );
@@ -532,7 +521,7 @@ QAction* KBookmarkMenu::actionForBookmark(KBookmark bm)
   }
   else
   {
-    //kDebug(7043) << "Creating bookmark menu item for " << bm.text() << endl;
+    //kDebug(7043) << "Creating bookmark menu item for " << bm.text();
     KAction * action = new KBookmarkAction( bm, m_pOwner, this );
     m_actionCollection->addAction(action->objectName(), action);
     m_actions.append( action );
@@ -549,13 +538,13 @@ void KBookmarkMenu::slotAddBookmarksList()
 
   KBookmarkGroup parentBookmark = m_pManager->findByAddress( m_parentAddress ).toGroup();
   Q_ASSERT(!parentBookmark.isNull());
-  KBookmarkGroup group = parentBookmark.createNewFolder( m_pManager );
+  KBookmarkGroup group = parentBookmark.createNewFolder();
   if ( group.isNull() )
     return; // user canceled i guess
 
   QList<QPair<QString, QString> >::const_iterator it;
   for ( it = list.begin(); it != list.end(); ++it )
-    group.addBookmark( m_pManager, (*it).first, KUrl((*it).second) );
+    group.addBookmark( (*it).first, KUrl((*it).second) );
 
   m_pManager->emitChanged( parentBookmark );
 }
@@ -577,7 +566,7 @@ void KBookmarkMenu::slotNewFolder()
   if ( !m_pOwner ) return; // this view doesn't handle bookmarks...
   KBookmarkGroup parentBookmark = m_pManager->findByAddress( m_parentAddress ).toGroup();
   Q_ASSERT(!parentBookmark.isNull());
-  KBookmarkGroup group = parentBookmark.createNewFolder( m_pManager );
+  KBookmarkGroup group = parentBookmark.createNewFolder();
   if ( !group.isNull() )
   {
     KBookmarkGroup parentGroup = group.parentGroup();
@@ -587,12 +576,12 @@ void KBookmarkMenu::slotNewFolder()
 
 void KImportedBookmarkMenu::slotNSLoad()
 {
-  kDebug(7043)<<"**** slotNSLoad  ****"<<m_type<<"  "<<m_location<<endl;
+  kDebug(7043)<<"**** slotNSLoad  ****"<<m_type<<"  "<<m_location;
   // only fill menu once
-  m_parentMenu->disconnect(SIGNAL(aboutToShow()));
+  parentMenu()->disconnect(SIGNAL(aboutToShow()));
 
   // not NSImporter, but kept old name for BC reasons
-  KBookmarkMenuNSImporter importer( m_pManager, this, m_actionCollection );
+  KBookmarkMenuImporter importer( manager(), this, m_actionCollection );
   importer.openBookmarks(m_location, m_type);
 }
 
@@ -685,14 +674,14 @@ KBookmarkTreeItem::KBookmarkTreeItem(QTreeWidget * tree)
     tree->setItemSelected( this, true );
 }
 
-KBookmarkTreeItem::KBookmarkTreeItem(QTreeWidgetItem * parent, QTreeWidget * tree, KBookmarkGroup bk)
+KBookmarkTreeItem::KBookmarkTreeItem(QTreeWidgetItem * parent, QTreeWidget * tree, const KBookmarkGroup &bk)
     : QTreeWidgetItem(parent)
 {
     setIcon(0, SmallIcon(bk.icon()));
     setText(0, bk.fullText() );
     tree->expandItem(this);
     m_address = bk.address();
-    kDebug()<<"** setting address to "<<bk.address()<<endl;
+    kDebug()<<"** setting address to "<<bk.address();
 }
 
 KBookmarkTreeItem::~KBookmarkTreeItem()
@@ -713,7 +702,7 @@ KBookmarkEditDialog::KBookmarkEditDialog(const QString& title, const QString& ur
 
   if ( editType == InsertionMode ) {
     setButtons( User1 | Ok | Cancel );
-    setButtonGuiItem( KDialog::Ok,  KGuiItem( i18n( "&Add" ), "bookmark_add") );
+    setButtonGuiItem( KDialog::Ok,  KGuiItem( i18n( "&Add" ), "bookmark-new") );
   } else {
     setButtons( Ok | Cancel );
     setButtonGuiItem( KDialog::Ok, KGuiItem(i18n( "&Update" )) );
@@ -721,7 +710,7 @@ KBookmarkEditDialog::KBookmarkEditDialog(const QString& title, const QString& ur
 
   setDefaultButton( KDialog::Ok );
   if (editType == InsertionMode) {
-    setButtonGuiItem( User1, KGuiItem( i18n( "&New Folder..." ), "folder_new") );
+    setButtonGuiItem( User1, KGuiItem( i18n( "&New Folder..." ), "folder-new") );
   }
 
   bool folder = url.isNull();
@@ -799,7 +788,7 @@ QString KBookmarkEditDialog::finalTitle() const
 
 void KBookmarkEditDialog::slotUser1()
 {
-  // kDebug(7043) << "KBookmarkEditDialog::slotUser1" << endl;
+  // kDebug(7043) << "KBookmarkEditDialog::slotUser1";
   Q_ASSERT( m_folderTree );
 
   QString address = finalAddress();
@@ -807,7 +796,7 @@ void KBookmarkEditDialog::slotUser1()
   Q_ASSERT(!bm.isNull());
   Q_ASSERT(m_editType == InsertionMode);
 
-  KBookmarkGroup group = bm.createNewFolder( m_mgr );
+  KBookmarkGroup group = bm.createNewFolder();
   if ( !group.isNull() )
   {
      KBookmarkGroup parentGroup = group.parentGroup();
@@ -818,7 +807,7 @@ void KBookmarkEditDialog::slotUser1()
    }
 }
 
-void KBookmarkEditDialog::fillGroup( QTreeWidget* view, QTreeWidgetItem * parentItem, KBookmarkGroup group, const QString& address)
+void KBookmarkEditDialog::fillGroup( QTreeWidget* view, QTreeWidgetItem * parentItem, const KBookmarkGroup &group, const QString& address)
 {
   for ( KBookmark bk = group.first() ; !bk.isNull() ; bk = group.next(bk) )
   {
@@ -840,15 +829,7 @@ void KBookmarkEditDialog::fillGroup( QTreeWidget* view, QTreeWidgetItem * parent
 /********************************************************************/
 /********************************************************************/
 
-// NOTE - KBookmarkMenuNSImporter is really === KBookmarkMenuImporter
-//        i.e, it is _not_ ns specific. and in KDE4 it should be renamed.
-
-void KBookmarkMenuNSImporter::openNSBookmarks()
-{
-  openBookmarks( KNSBookmarkImporter::netscapeBookmarksFile(), "netscape" );
-}
-
-void KBookmarkMenuNSImporter::openBookmarks( const QString &location, const QString &type )
+void KBookmarkMenuImporter::openBookmarks( const QString &location, const QString &type )
 {
   mstack.push(m_menu);
 
@@ -862,7 +843,7 @@ void KBookmarkMenuNSImporter::openBookmarks( const QString &location, const QStr
   delete importer;
 }
 
-void KBookmarkMenuNSImporter::connectToImporter(const QObject &importer)
+void KBookmarkMenuImporter::connectToImporter(const QObject &importer)
 {
   connect( &importer, SIGNAL( newBookmark( const QString &, const QString &, const QString & ) ),
            SLOT( newBookmark( const QString &, const QString &, const QString & ) ) );
@@ -872,34 +853,34 @@ void KBookmarkMenuNSImporter::connectToImporter(const QObject &importer)
   connect( &importer, SIGNAL( endFolder() ), SLOT( endFolder() ) );
 }
 
-void KBookmarkMenuNSImporter::newBookmark( const QString & text, const QString & url, const QString & )
+void KBookmarkMenuImporter::newBookmark( const QString & text, const QString & url, const QString & )
 {
   KBookmark bm = KBookmark::standaloneBookmark(text, url, QString("html"));
-  KAction * action = new KImportedBookmarkAction(bm, mstack.top()->m_pOwner, this);
+  KAction * action = new KImportedBookmarkAction(bm, mstack.top()->owner(), this);
   m_actionCollection->addAction(action->objectName(), action);
-  mstack.top()->m_parentMenu->addAction(action);
+  mstack.top()->parentMenu()->addAction(action);
   mstack.top()->m_actions.append( action );
 }
 
-void KBookmarkMenuNSImporter::newFolder( const QString & text, bool, const QString & )
+void KBookmarkMenuImporter::newFolder( const QString & text, bool, const QString & )
 {
   QString _text = KStringHandler::csqueeze(text).replace( '&', "&&" );
   KActionMenu * actionMenu = new KImportedBookmarkActionMenu( KIcon("folder"), _text, this );
   m_actionCollection->addAction( actionMenu->objectName(), actionMenu );
-  mstack.top()->m_parentMenu->addAction(actionMenu);
+  mstack.top()->parentMenu()->addAction(actionMenu);
   mstack.top()->m_actions.append( actionMenu );
-  KImportedBookmarkMenu *subMenu = new KImportedBookmarkMenu( m_pManager, m_menu->m_pOwner, actionMenu->menu());
+  KImportedBookmarkMenu *subMenu = new KImportedBookmarkMenu( m_pManager, m_menu->owner(), actionMenu->menu());
   mstack.top()->m_lstSubMenus.append( subMenu );
 
   mstack.push(subMenu);
 }
 
-void KBookmarkMenuNSImporter::newSeparator()
+void KBookmarkMenuImporter::newSeparator()
 {
-  mstack.top()->m_parentMenu->addSeparator();
+  mstack.top()->parentMenu()->addSeparator();
 }
 
-void KBookmarkMenuNSImporter::endFolder()
+void KBookmarkMenuImporter::endFolder()
 {
   mstack.pop();
 }
@@ -909,7 +890,7 @@ void KBookmarkMenuNSImporter::endFolder()
 /********************************************************************/
 
 
-KBookmarkAction::KBookmarkAction(KBookmark bk, KBookmarkOwner* owner, QObject *parent )
+KBookmarkAction::KBookmarkAction(const KBookmark &bk, KBookmarkOwner* owner, QObject *parent )
   : KAction( KStringHandler::csqueeze(bk.text()).replace('&', "&&"), parent),
     KBookmarkActionInterface(bk),
     m_pOwner(owner)
@@ -924,11 +905,6 @@ KBookmarkAction::~KBookmarkAction()
 {
 }
 
-void KBookmarkAction::contextMenu(QPoint pos, KBookmarkManager* m_pManager, KBookmarkOwner* m_pOwner)
-{
-  KBookmarkActionContextMenu::self().contextMenu(pos, bookmark().address(), m_pManager, m_pOwner);
-}
-
 void KBookmarkAction::slotSelected(Qt::MouseButtons mb, Qt::KeyboardModifiers km)
 {
   if( !m_pOwner )
@@ -937,13 +913,13 @@ void KBookmarkAction::slotSelected(Qt::MouseButtons mb, Qt::KeyboardModifiers km
     m_pOwner->openBookmark( bookmark(), mb, km );
 }
 
-KBookmarkActionMenu::KBookmarkActionMenu(KBookmark bm, QObject *parent)
+KBookmarkActionMenu::KBookmarkActionMenu(const KBookmark &bm, QObject *parent)
   : KActionMenu(KIcon(bm.icon()), KStringHandler::csqueeze(bm.text()).replace('&', "&&"), parent),
     KBookmarkActionInterface(bm)
 {
 }
 
-KBookmarkActionMenu::KBookmarkActionMenu(KBookmark bm, const QString & text, QObject *parent)
+KBookmarkActionMenu::KBookmarkActionMenu(const KBookmark &bm, const QString & text, QObject *parent)
   : KActionMenu(text, parent),
     KBookmarkActionInterface(bm)
 {
@@ -953,12 +929,8 @@ KBookmarkActionMenu::~KBookmarkActionMenu()
 {
 }
 
-void KBookmarkActionMenu::contextMenu(QPoint pos, KBookmarkManager* m_pManager, KBookmarkOwner* m_pOwner)
-{
-  KBookmarkActionContextMenu::self().contextMenu(pos, bookmark().address(), m_pManager, m_pOwner );
-}
 
-KImportedBookmarkAction::KImportedBookmarkAction(KBookmark bk, KBookmarkOwner* owner, QObject *parent )
+KImportedBookmarkAction::KImportedBookmarkAction(const KBookmark &bk, KBookmarkOwner* owner, QObject *parent )
 : KAction( KStringHandler::csqueeze(bk.text()).replace('&', "&&"), parent),
   KBookmarkActionInterface(bk),
   m_pOwner(owner)
@@ -973,10 +945,6 @@ KImportedBookmarkAction::~KImportedBookmarkAction()
 {
 }
 
-void KImportedBookmarkAction::contextMenu(QPoint pos, KBookmarkManager* m_pManager, KBookmarkOwner* m_pOwner)
-{
-}
-
 void KImportedBookmarkAction::slotSelected(Qt::MouseButtons mb, Qt::KeyboardModifiers km)
 {
   if( !m_pOwner )
