@@ -22,19 +22,14 @@
 #ifndef __kbookmarkmenu_p_h__
 #define __kbookmarkmenu_p_h__
 
-#include <sys/types.h>
-
-#include <qobject.h>
+#include <QtCore/QObject>
 
 #include <kdialog.h>
 #include <kicon.h>
 #include <klocale.h>
 #include <kaction.h>
 #include <kactionmenu.h>
-#include <krun.h>
-#include <kmenu.h>
 #include <QtGui/QBoxLayout>
-#include <QtCore/QModelIndex>
 #include <QtGui/QTreeWidget>
 
 #include "kbookmark.h"
@@ -42,7 +37,6 @@
 #include "kbookmarkmanager.h"
 
 class QString;
-class QMenu;
 class QPushButton;
 class KLineEdit;
 class KBookmark;
@@ -52,8 +46,27 @@ class KActionMenu;
 class KActionCollection;
 class KBookmarkOwner;
 class KBookmarkMenu;
-class KBookmarkBar;
-class KMenu;
+
+class KImportedBookmarkMenu : public KBookmarkMenu
+{
+    friend class KBookmarkMenuImporter;
+  Q_OBJECT
+public:
+  //TODO simplfy
+  KImportedBookmarkMenu( KBookmarkManager* mgr,
+                 KBookmarkOwner * owner, KMenu * parentMenu,
+                 const QString & type, const QString & location );
+  KImportedBookmarkMenu( KBookmarkManager* mgr,
+                 KBookmarkOwner * owner, KMenu * parentMenu);
+  ~KImportedBookmarkMenu();
+  virtual void clear();
+  virtual void refill();
+protected Q_SLOTS:
+  void slotNSLoad();
+private:
+   QString m_type;
+   QString m_location;
+};
 
 class KBookmarkEditFields {
 public:
@@ -86,7 +99,7 @@ protected Q_SLOTS:
   void slotDoubleClicked(QTreeWidgetItem* item);
 
 private:
-  void fillGroup( QTreeWidget* listview, QTreeWidgetItem * parentItem, KBookmarkGroup group, const QString& address);
+  void fillGroup( QTreeWidget* listview, QTreeWidgetItem * parentItem, const KBookmarkGroup &group, const QString& address);
   QWidget * m_main;
   KBookmarkEditFields * m_fields;
   QTreeWidget * m_folderTree;
@@ -99,7 +112,7 @@ class KBookmarkTreeItem : public QTreeWidgetItem
 {
 public:
     KBookmarkTreeItem(QTreeWidget * tree);
-    KBookmarkTreeItem(QTreeWidgetItem * parent, QTreeWidget * tree, KBookmarkGroup bk);
+    KBookmarkTreeItem(QTreeWidgetItem * parent, QTreeWidget * tree, const KBookmarkGroup &bk);
     ~KBookmarkTreeItem();
     QString address();
 private:
@@ -111,7 +124,6 @@ class KBookmarkSettings
 public:
   bool m_advancedaddbookmark;
   bool m_contextmenu;
-  bool m_filteredtoolbar;
   static KBookmarkSettings *s_self;
   static void readSettings();
   static KBookmarkSettings *self();
@@ -120,14 +132,13 @@ public:
 /**
  * A class connected to KNSBookmarkImporter, to fill KActionMenus.
  */
-class KBookmarkMenuNSImporter : public QObject
+class KBookmarkMenuImporter : public QObject
 {
   Q_OBJECT
 public:
-  KBookmarkMenuNSImporter( KBookmarkManager* mgr, KImportedBookmarkMenu * menu, KActionCollection * act ) :
+  KBookmarkMenuImporter( KBookmarkManager* mgr, KImportedBookmarkMenu * menu, KActionCollection * act ) :
      m_menu(menu), m_actionCollection(act), m_pManager(mgr) {}
 
-  void openNSBookmarks();
   void openBookmarks( const QString &location, const QString &type );
   void connectToImporter( const QObject &importer );
 
@@ -154,21 +165,14 @@ public:
   }
   ~KImportedBookmarkActionMenu()
   {}
-  virtual void contextMenu(QPoint pos, KBookmarkManager* m_pManager, KBookmarkOwner* m_pOwner)
-  {
-    Q_UNUSED(pos)
-    Q_UNUSED(m_pManager)
-    Q_UNUSED(m_pOwner)
-  }
 };
 
 class KImportedBookmarkAction : public KAction, public KBookmarkActionInterface
 {
   Q_OBJECT
 public:
-  KImportedBookmarkAction(KBookmark bk, KBookmarkOwner* owner, QObject *parent );
+  KImportedBookmarkAction(const KBookmark &bk, KBookmarkOwner* owner, QObject *parent );
   ~KImportedBookmarkAction();
-  virtual void contextMenu(QPoint pos, KBookmarkManager* m_pManager, KBookmarkOwner* m_pOwner);
 
 public Q_SLOTS:
   void slotSelected(Qt::MouseButtons mb, Qt::KeyboardModifiers km);
