@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2005 by Sean Harmer <sh@rama.homelinux.org>             *
- *                         Till Adam <adam@kde.org>                        *
+ *                 2005 - 2007 Till Adam <adam@kde.org>                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU Library General Public License as       *
@@ -18,7 +18,6 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 
-
 #include "kacleditwidget.h"
 #include "kacleditwidget_p.h"
 
@@ -35,8 +34,8 @@
 #include <qcheckbox.h>
 #include <qlayout.h>
 #include <QStackedWidget>
-#include <q3header.h>
 #include <QMouseEvent>
+#include <QHeaderView>
 
 #include <klocale.h>
 #include <kfileitem.h>
@@ -54,8 +53,6 @@ extern "C" {
 }
 #include <assert.h>
 
-#include "images.h"
-
 static struct {
     const char* label;
     const char* pixmapName;
@@ -69,38 +66,63 @@ static struct {
     { I18N_NOOP( "Named Group" ), "group", 0 },
 };
 
-KACLEditWidget::KACLEditWidget( QWidget *parent )
-   :QWidget( parent )
+class KACLEditWidget::KACLEditWidgetPrivate
 {
-    KHBox *hbox = new KHBox( parent );
+public:
+    KACLEditWidgetPrivate()
+    {
+    }
+
+    // slots
+    void _k_slotUpdateButtons();
+
+    KACLListView *m_listView;
+    QPushButton *m_AddBtn;
+    QPushButton *m_EditBtn;
+    QPushButton *m_DelBtn;
+};
+
+KACLEditWidget::KACLEditWidget( QWidget *parent )
+    : QWidget(parent), d(new KACLEditWidgetPrivate)
+{
+    QHBoxLayout *hbox = new QHBoxLayout( this );
+    hbox->setMargin( 0 );
     hbox->setSpacing(  KDialog::spacingHint() );
-    m_listView = new KACLListView( hbox );
-    connect( m_listView, SIGNAL( selectionChanged() ),
-            this, SLOT( slotUpdateButtons() ) );
-    KVBox *vbox = new KVBox( hbox );
+    d->m_listView = new KACLListView(this);
+    hbox->addWidget(d->m_listView);
+    connect(d->m_listView->selectionModel(),
+            SIGNAL(selectionChanged(const QItemSelection&, const QItemSelection& )),
+            this,
+            SLOT(_k_slotUpdateButtons()));
+    QVBoxLayout *vbox = new QVBoxLayout();
+    hbox->addLayout( vbox );
     vbox->setSpacing(  KDialog::spacingHint() );
-    m_AddBtn = new QPushButton( i18n( "Add Entry..." ), vbox );
-    m_AddBtn->setObjectName( QLatin1String( "add_entry_button" ) );
-    connect( m_AddBtn, SIGNAL( clicked() ), m_listView, SLOT( slotAddEntry() ) );
-    m_EditBtn = new QPushButton( i18n( "Edit Entry..." ), vbox );
-    m_EditBtn->setObjectName( QLatin1String( "edit_entry_button" ) );
-    connect( m_EditBtn, SIGNAL( clicked() ), m_listView, SLOT( slotEditEntry() ) );
-    m_DelBtn = new QPushButton( i18n( "Delete Entry" ), vbox );
-    m_DelBtn->setObjectName( QLatin1String( "delete_entry_button" ) );
-    connect( m_DelBtn, SIGNAL( clicked() ), m_listView, SLOT( slotRemoveEntry() ) );
-    QWidget *spacer = new QWidget( vbox );
-    spacer->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Expanding );
-    slotUpdateButtons();
+    d->m_AddBtn = new QPushButton(i18n("Add Entry..."), this);
+    vbox->addWidget(d->m_AddBtn);
+    d->m_AddBtn->setObjectName(QLatin1String("add_entry_button"));
+    connect(d->m_AddBtn, SIGNAL(clicked()), d->m_listView, SLOT(slotAddEntry()));
+    d->m_EditBtn = new QPushButton(i18n("Edit Entry..."), this);
+    vbox->addWidget(d->m_EditBtn);
+    d->m_EditBtn->setObjectName(QLatin1String("edit_entry_button"));
+    connect(d->m_EditBtn, SIGNAL(clicked()), d->m_listView, SLOT(slotEditEntry()));
+    d->m_DelBtn = new QPushButton(i18n("Delete Entry"), this);
+    vbox->addWidget(d->m_DelBtn);
+    d->m_DelBtn->setObjectName(QLatin1String("delete_entry_button"));
+    connect(d->m_DelBtn, SIGNAL(clicked()), d->m_listView, SLOT(slotRemoveEntry()));
+    vbox->addItem( new QSpacerItem( 10, 10, QSizePolicy::Fixed, QSizePolicy::Expanding ) );
+    d->_k_slotUpdateButtons();
 }
 
-void KACLEditWidget::slotUpdateButtons()
+void KACLEditWidget::KACLEditWidgetPrivate::_k_slotUpdateButtons()
 {
     bool atLeastOneIsNotDeletable = false;
     bool atLeastOneIsNotAllowedToChangeType = false;
     int selectedCount = 0;
-    Q3ListViewItemIterator it( m_listView, Q3ListViewItemIterator::Selected );
-    while ( KACLListViewItem *item = dynamic_cast<KACLListViewItem*>( it.current() ) ) {
-        ++it; ++selectedCount;
+    QList<QTreeWidgetItem*> selected = m_listView->selectedItems();
+    QListIterator<QTreeWidgetItem*> it( selected );
+    while ( it.hasNext() ) {
+        KACLListViewItem *item = static_cast<KACLListViewItem*>( it.next() );
+        ++selectedCount;
         if ( !item->isDeletable() )
             atLeastOneIsNotDeletable = true;
         if ( !item->isAllowedToChangeType() )
@@ -112,34 +134,34 @@ void KACLEditWidget::slotUpdateButtons()
 
 KACL KACLEditWidget::getACL() const
 {
-  return m_listView->getACL();
+    return d->m_listView->getACL();
 }
 
 KACL KACLEditWidget::getDefaultACL() const
 {
-  return m_listView->getDefaultACL();
+    return d->m_listView->getDefaultACL();
 }
 
 void KACLEditWidget::setACL( const KACL &acl )
 {
-  return m_listView->setACL( acl );
+    return d->m_listView->setACL(acl);
 }
 
 void KACLEditWidget::setDefaultACL( const KACL &acl )
 {
-  return m_listView->setDefaultACL( acl );
+    return d->m_listView->setDefaultACL(acl);
 }
 
 void KACLEditWidget::setAllowDefaults( bool value )
 {
-    m_listView->setAllowDefaults( value );
+    d->m_listView->setAllowDefaults(value);
 }
 
-KACLListViewItem::KACLListViewItem( Q3ListView* parent,
+KACLListViewItem::KACLListViewItem( QTreeWidget* parent,
                                     KACLListView::EntryType _type,
                                     unsigned short _value, bool defaults,
                                     const QString& _qualifier )
- : K3ListViewItem( parent, parent->lastItem() ), // we want to append
+ : QTreeWidgetItem( parent),
    type( _type ), value( _value ), isDefault( defaults ),
    qualifier( _qualifier ), isPartial( false )
 {
@@ -153,7 +175,7 @@ KACLListViewItem::~ KACLListViewItem()
 
 }
 
-QString KACLListViewItem::key( int, bool ) const
+QString KACLListViewItem::key() const
 {
     QString key;
     if ( !isDefault )
@@ -187,20 +209,25 @@ QString KACLListViewItem::key( int, bool ) const
     return key;
 }
 
+bool KACLListViewItem::operator< ( const QTreeWidgetItem& other ) const
+{
+    return key() < static_cast<const KACLListViewItem&>(other).key();
+}
+
 void KACLListViewItem::paintCell( QPainter* p, const QColorGroup &cg,
                                   int column, int width, int alignment )
 {
-    QColorGroup mycg = cg;
+    /*
     if ( isDefault ) {
-        mycg.setColor( QPalette::Text, QColor( 0, 0, 255 ) );
+        setForeground( QColor( 0, 0, 255 ) );
     }
     if ( isPartial ) {
         QFont font = p->font();
         font.setItalic( true );
-        mycg.setColor( QPalette::Text, QColor( 100, 100, 100 ) );
+        setForeground( QColor( 100, 100, 100 ) );
         p->setFont( font );
     }
-    K3ListViewItem::paintCell( p, mycg, column, width, alignment );
+    QTreeWidgetItem::paintCell( p, mycg, column, width, alignment );
 
     KACLListViewItem *below =0;
     if ( itemBelow() )
@@ -214,6 +241,7 @@ void KACLListViewItem::paintCell( QPainter* p, const QColorGroup &cg,
             p->drawLine( 0, 0, width - 1, 0 );
         p->drawLine( 0, height() - 1, width - 1, height() - 1 );
     }
+     */
 }
 
 
@@ -222,31 +250,30 @@ void KACLListViewItem::updatePermPixmaps()
     unsigned int partialPerms = value;
 
     if ( value & ACL_READ )
-        setPixmap( 2, m_pACLListView->getYesPixmap() );
+        setIcon( 2, m_pACLListView->getYesPixmap() );
     else if ( partialPerms & ACL_READ )
-        setPixmap( 2, m_pACLListView->getYesPartialPixmap() );
+        setIcon( 2, m_pACLListView->getYesPartialPixmap() );
     else
-        setPixmap( 2, QPixmap() );
+        setIcon( 2, QIcon() );
 
     if ( value & ACL_WRITE )
-        setPixmap( 3, m_pACLListView->getYesPixmap() );
+        setIcon( 3, m_pACLListView->getYesPixmap() );
     else if ( partialPerms & ACL_WRITE )
-        setPixmap( 3, m_pACLListView->getYesPartialPixmap() );
+        setIcon( 3, m_pACLListView->getYesPartialPixmap() );
     else
-        setPixmap( 3, QPixmap() );
+        setIcon( 3, QIcon() );
 
     if ( value & ACL_EXECUTE )
-        setPixmap( 4, m_pACLListView->getYesPixmap() );
+        setIcon( 4, m_pACLListView->getYesPixmap() );
     else if ( partialPerms & ACL_EXECUTE )
-        setPixmap( 4, m_pACLListView->getYesPartialPixmap() );
+        setIcon( 4, m_pACLListView->getYesPartialPixmap() );
     else
-        setPixmap( 4, QPixmap() );
+        setIcon( 4, QIcon() );
 }
 
 void KACLListViewItem::repaint()
 {
     int idx = 0;
-    kWarning() << "painting tyupe: " << type << endl;
     switch ( type )
     {
       case KACLListView::User:
@@ -272,7 +299,7 @@ void KACLListViewItem::repaint()
             break;
     }
     setText( 0, i18n(s_itemAttributes[idx].label) );
-    setPixmap( 0, *s_itemAttributes[idx].pixmap );
+    setIcon( 0, *s_itemAttributes[idx].pixmap );
     if ( isDefault )
         setText( 0, text( 0 ) + i18n( " (Default)" ) );
     setText( 1, qualifier );
@@ -410,7 +437,6 @@ EditACLEntryDialog::EditACLEntryDialog( KACLListView *listView, KACLListViewItem
     mainLayout->setSpacing( spacingHint() );
     QGroupBox *gb = new QGroupBox( i18n("Entry Type"), page );
     QVBoxLayout *gbLayout = new QVBoxLayout( gb );
-    gbLayout->setMargin( 0 );
     gbLayout->setSpacing( spacingHint() );
 
     m_buttonGroup = new QButtonGroup( page );
@@ -545,7 +571,7 @@ void EditACLEntryDialog::slotOk()
 {
     KACLListView::EntryType type = static_cast<KACLListView::EntryType>( m_buttonIds[m_buttonGroup->checkedButton()] );
 
-    kWarning() << "Type 2: " << type << endl;
+    kWarning() << "Type 2: " << type;
 
     QString qualifier;
     if ( type == KACLListView::NamedUser )
@@ -590,27 +616,31 @@ void EditACLEntryDialog::slotSelectionChanged( QAbstractButton *button )
 
 
 KACLListView::KACLListView( QWidget* parent )
- : K3ListView( parent ),
+ : QTreeWidget( parent ),
    m_hasMask( false ), m_allowDefaults( false )
 {
     // Add the columns
-    addColumn( i18n( "Type" ) );
-    addColumn( i18n( "Name" ) );
-    addColumn( i18nc( "read permission", "r" ) );
-    addColumn( i18nc( "write permission", "w" ) );
-    addColumn( i18nc( "execute permission", "x" ) );
-    addColumn( i18n( "Effective" ) );
+    setColumnCount( 6 );
+    QStringList headers;
+    headers <<  i18n( "Type" );
+    headers <<  i18n( "Name" );
+    headers <<  i18nc( "read permission", "r" );
+    headers <<  i18nc( "write permission", "w" );
+    headers <<  i18nc( "execute permission", "x" );
+    headers <<  i18n( "Effective" );
+    setHeaderLabels( headers );
 
-    header()->setClickEnabled( false );
+    setSortingEnabled( false );
+    setSelectionMode( QAbstractItemView::ExtendedSelection );
+    header()->setResizeMode( QHeaderView::ResizeToContents );
 
     // Load the avatars
     for ( int i=0; i < LAST_IDX; ++i ) {
-        s_itemAttributes[i].pixmap = new QPixmap( qembed_findImage( s_itemAttributes[i].pixmapName ) );
+        s_itemAttributes[i].pixmap = new QPixmap( QString::fromLatin1(":/images/%1").arg(s_itemAttributes[i].pixmapName) );
     }
-    m_yesPixmap = new QPixmap( qembed_findImage( "yes" ) );
-    m_yesPartialPixmap = new QPixmap( qembed_findImage( "yespartial" ) );
+    m_yesPixmap = new QPixmap( ":/images/yes.png" );
+    m_yesPartialPixmap = new QPixmap( ":/images/yespartial.png" );
 
-    setSelectionMode( Q3ListView::Extended );
 
     // fill the lists of all legal users and groups
     struct passwd *user = 0;
@@ -628,6 +658,9 @@ KACLListView::KACLListView( QWidget* parent )
     endgrent();
     m_allUsers.sort();
     m_allGroups.sort();
+
+    connect( this, SIGNAL( itemClicked( QTreeWidgetItem*, int ) ),
+             this, SLOT( slotItemClicked( QTreeWidgetItem*, int ) ) );
 }
 
 
@@ -643,8 +676,8 @@ KACLListView::~KACLListView()
 QStringList KACLListView::allowedUsers( bool defaults, KACLListViewItem *allowedItem )
 {
     QStringList allowedUsers = m_allUsers;
-    Q3ListViewItemIterator it( this );
-    while ( it.current() ) {
+    QTreeWidgetItemIterator it( this );
+    while ( *it ) {
         const KACLListViewItem *item = static_cast<const KACLListViewItem*>( *it );
         ++it;
         if ( !item->type == NamedUser || item->isDefault != defaults ) continue;
@@ -657,8 +690,8 @@ QStringList KACLListView::allowedUsers( bool defaults, KACLListViewItem *allowed
 QStringList KACLListView::allowedGroups( bool defaults, KACLListViewItem *allowedItem )
 {
     QStringList allowedGroups = m_allGroups;
-    Q3ListViewItemIterator it( this );
-    while ( it.current() ) {
+    QTreeWidgetItemIterator it( this );
+    while ( *it ) {
         const KACLListViewItem *item = static_cast<const KACLListViewItem*>( *it );
         ++it;
         if ( !item->type == NamedGroup || item->isDefault != defaults ) continue;
@@ -671,8 +704,8 @@ QStringList KACLListView::allowedGroups( bool defaults, KACLListViewItem *allowe
 void KACLListView::fillItemsFromACL( const KACL &pACL, bool defaults )
 {
     // clear out old entries of that ilk
-    Q3ListViewItemIterator it( this );
-    while ( KACLListViewItem *item = static_cast<KACLListViewItem*>( it.current() ) ) {
+    QTreeWidgetItemIterator it( this );
+    while ( KACLListViewItem *item = static_cast<KACLListViewItem*>( *it ) ) {
         ++it;
         if ( item->isDefault == defaults )
             delete item;
@@ -732,8 +765,8 @@ KACL KACLListView::itemsToACL( bool defaults ) const
     bool atLeastOneEntry = false;
     ACLUserPermissionsList users;
     ACLGroupPermissionsList groups;
-    Q3ListViewItemIterator it( const_cast<KACLListView*>( this ) );
-    while ( Q3ListViewItem* qlvi = it.current() ) {
+    QTreeWidgetItemIterator it( const_cast<KACLListView*>( this ) );
+    while ( QTreeWidgetItem* qlvi = *it ) {
         ++it;
         const KACLListViewItem* item = static_cast<KACLListViewItem*>( qlvi );
         if ( item->isDefault != defaults ) continue;
@@ -783,11 +816,12 @@ KACL KACLListView::getDefaultACL()
 
 void KACLListView::contentsMousePressEvent( QMouseEvent * e )
 {
-    Q3ListViewItem *clickedItem = itemAt( contentsToViewport(  e->pos() ) );
+    /*
+    QTreeWidgetItem *clickedItem = itemAt( e->pos() );
     if ( !clickedItem ) return;
     // if the click is on an as yet unselected item, select it first
     if ( !clickedItem->isSelected() )
-        K3ListView::contentsMousePressEvent( e );
+        QAbstractItemView::contentsMousePressEvent( e );
 
     if ( !currentItem() ) return;
     int column = header()->sectionAt( e->x() );
@@ -804,26 +838,27 @@ void KACLListView::contentsMousePressEvent( QMouseEvent * e )
             perm = ACL_EXECUTE;
             break;
         default:
-            return K3ListView::contentsMousePressEvent( e );
+            return QTreeWidget::contentsMousePressEvent( e );
     }
     KACLListViewItem* referenceItem = static_cast<KACLListViewItem*>( clickedItem );
     unsigned short referenceHadItSet = referenceItem->value & perm;
-    Q3ListViewItemIterator it( this );
-    while ( KACLListViewItem* item = static_cast<KACLListViewItem*>( it.current() ) ) {
+    QTreeWidgetItemIterator it( this );
+    while ( KACLListViewItem* item = static_cast<KACLListViewItem*>( *it ) ) {
         ++it;
         if ( !item->isSelected() ) continue;
         // toggle those with the same value as the clicked item, leave the others
         if ( referenceHadItSet == ( item->value & perm ) )
             item->togglePerm( perm );
     }
+     */
 }
 
-void KACLListView::entryClicked( Q3ListViewItem* pItem, const QPoint& /*pt*/, int col )
+void KACLListView::slotItemClicked( QTreeWidgetItem* pItem,  int col )
 {
     if ( !pItem ) return;
 
-    Q3ListViewItemIterator it( this );
-    while ( KACLListViewItem* item = static_cast<KACLListViewItem*>( it.current() ) ) {
+    QTreeWidgetItemIterator it( this );
+    while ( KACLListViewItem* item = static_cast<KACLListViewItem*>( *it ) ) {
         ++it;
         if ( !item->isSelected() ) continue;
         switch ( col )
@@ -869,9 +904,9 @@ void KACLListView::entryClicked( Q3ListViewItem* pItem, const QPoint& /*pt*/, in
 
 void KACLListView::calculateEffectiveRights()
 {
-    Q3ListViewItemIterator it( this );
+    QTreeWidgetItemIterator it( this );
     KACLListViewItem* pItem;
-    while ( ( pItem = dynamic_cast<KACLListViewItem*>( it.current() ) ) != 0 )
+    while ( ( pItem = dynamic_cast<KACLListViewItem*>( *it ) ) != 0 )
     {
         ++it;
         pItem->calcEffectiveRights();
@@ -907,9 +942,9 @@ void KACLListView::setMaskPartialPermissions( acl_perm_t /*maskPartialPerms*/ )
 
 bool KACLListView::hasDefaultEntries() const
 {
-    Q3ListViewItemIterator it( const_cast<KACLListView*>( this ) );
-    while ( it.current() ) {
-        const KACLListViewItem *item = static_cast<const KACLListViewItem*>( it.current() );
+    QTreeWidgetItemIterator it( const_cast<KACLListView*>( this ) );
+    while ( *it ) {
+        const KACLListViewItem *item = static_cast<const KACLListViewItem*>( *it );
         ++it;
         if ( item->isDefault ) return true;
     }
@@ -923,9 +958,9 @@ const KACLListViewItem* KACLListView::findDefaultItemByType( EntryType type ) co
 
 const KACLListViewItem* KACLListView::findItemByType( EntryType type, bool defaults ) const
 {
-    Q3ListViewItemIterator it( const_cast<KACLListView*>( this ) );
-    while ( it.current() ) {
-        const KACLListViewItem *item = static_cast<const KACLListViewItem*>( it.current() );
+    QTreeWidgetItemIterator it( const_cast<KACLListView*>( this ) );
+    while ( *it ) {
+        const KACLListViewItem *item = static_cast<const KACLListViewItem*>( *it );
         ++it;
         if ( item->isDefault == defaults && item->type == type ) {
             return item;
@@ -994,17 +1029,17 @@ void KACLListView::slotAddEntry()
         m_mask = v;
     }
     calculateEffectiveRights();
-    sort();
+    sortItems( sortColumn(), Qt::AscendingOrder );
     setCurrentItem( item );
-    // Q3ListView doesn't seem to emit, in this case, and we need to update
+    // QTreeWidget doesn't seem to emit, in this case, and we need to update
     // the buttons...
-    if ( childCount() == 1 )
-        emit currentChanged( item );
+    if ( topLevelItemCount() == 1 )
+        emit currentItemChanged( item, item );
 }
 
 void KACLListView::slotEditEntry()
 {
-    Q3ListViewItem * current = currentItem();
+    QTreeWidgetItem * current = currentItem();
     if ( !current ) return;
     KACLListViewItem *item = static_cast<KACLListViewItem*>( current );
     int allowedTypes = item->type | NamedUser | NamedGroup;
@@ -1031,14 +1066,14 @@ void KACLListView::slotEditEntry()
         m_hasMask = true;
     }
     calculateEffectiveRights();
-    sort();
+    sortItems( sortColumn(), Qt::AscendingOrder );
 }
 
 void KACLListView::slotRemoveEntry()
 {
-    Q3ListViewItemIterator it( this, Q3ListViewItemIterator::Selected );
-    while ( it.current() ) {
-        KACLListViewItem *item = static_cast<KACLListViewItem*>( it.current() );
+    QTreeWidgetItemIterator it( this, QTreeWidgetItemIterator::Selected );
+    while ( *it ) {
+        KACLListViewItem *item = static_cast<KACLListViewItem*>( *it );
         ++it;
         /* First check if it's a mask entry and if so, make sure that there is
          * either no name user or group entry, which means the mask can be
