@@ -19,16 +19,16 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include "config-kfile.h"
-
 #include "kencodingfiledialog.h"
+
+#include <config-kfile.h>
+
 #include <kcombobox.h>
 #include <ktoolbar.h>
 #include <kglobal.h>
 #include <klocale.h>
 #include <kcharsets.h>
-#include <qtextcodec.h>
-#include <kdiroperator.h>
+#include <QtCore/QTextCodec>
 #include <krecentdocument.h>
 
 struct KEncodingFileDialogPrivate
@@ -41,11 +41,12 @@ KEncodingFileDialog::KEncodingFileDialog(const QString& startDir, const QString&
    : KFileDialog(startDir,filter,parent), d(new KEncodingFileDialogPrivate)
 {
   setCaption(caption);
+  //ops->clearHistory();
 
   setOperationMode( type );
 
   KToolBar *tb = toolBar();
-  tb->addSeparator();
+
   d->encoding = new KComboBox(tb);
   tb->addWidget(d->encoding);
 
@@ -101,7 +102,6 @@ KEncodingFileDialog::Result KEncodingFileDialog::getOpenFileNameAndEncoding(cons
                             Opening, parent);
 
     dlg.setMode( KFile::File | KFile::LocalOnly );
-    dlg.ops->clearHistory();
     dlg.exec();
 
     Result res;
@@ -119,7 +119,6 @@ KEncodingFileDialog::Result KEncodingFileDialog::getOpenFileNamesAndEncoding(con
     KEncodingFileDialog dlg(startDir, encoding, filter, caption.isNull() ? i18n("Open") : caption,
                             Opening, parent);
     dlg.setMode(KFile::Files | KFile::LocalOnly);
-    dlg.ops->clearHistory();
     dlg.exec();
 
     Result res;
@@ -136,7 +135,6 @@ KEncodingFileDialog::Result KEncodingFileDialog::getOpenUrlAndEncoding(const QSt
                             Opening, parent);
 
     dlg.setMode( KFile::File );
-    dlg.ops->clearHistory();
     dlg.exec();
 
     Result res;
@@ -155,7 +153,6 @@ KEncodingFileDialog::Result KEncodingFileDialog::getOpenUrlsAndEncoding(const QS
                             Opening, parent);
 
     dlg.setMode(KFile::Files);
-    dlg.ops->clearHistory();
     dlg.exec();
 
     Result res;
