@@ -18,9 +18,9 @@
 #ifndef KFILE_H
 #define KFILE_H
 
-#include <qdir.h>
+#include <QtCore/QDir>
 
-#include "kdelibs_export.h"
+#include <kio/kio_export.h>
 
 /**
  * KFile is a class which provides a namespace for some enumerated
