@@ -5,6 +5,7 @@
                   1998 Daniel Grana <grana@ie.iwi.unibe.ch>
                   2000,2001 Carsten Pfeiffer <pfeiffer@kde.org>
                   2001 Frerich Raabe <raabe@kde.org>
+                  2007 David Faure <faure@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -29,27 +30,19 @@
 #include <kfile.h>
 #include <kurl.h>
 #include <kmimetype.h>
-#include <kio/jobclasses.h>
+#include <kio/jobclasses.h> // TODO remove
 
-class QCheckBox;
-class QHBoxLayout;
-class QGridLayout;
-class QLabel;
-class QMenu;
-class QVBoxLayout;
+class KAbstractFileWidget;
+class KFileWidget;
 
 class KActionCollection;
-class KDirOperator;
-class KUrlBar;
 class KUrlComboBox;
 class KFileFilterCombo;
-class KFileView;
-class KFileItem;
 class KPushButton;
 class KToolBar;
 class KPreviewWidgetBase;
 
-struct KFileDialogPrivate;
+class KFileDialogPrivate;
 
 /**
  * Provides a user (and developer) friendly way to
@@ -108,14 +101,15 @@ public:
       *
       * @param filter A shell glob or a mime-type-filter that specifies
       *               which files to display.
-      * See setFilter() for details on how to use this argument.
+      * See setFilter() and setMimeFilter() for details on how to use this argument.
+      *
+      * @param parent The parent widget of this dialog
       *
       * @param widget A widget, or a widget of widgets, for displaying custom
       *               data in the dialog. This can be used, for example, to
       *               display a check box with the caption "Open as read-only".
       *               When creating this widget, you don't need to specify a parent,
       *               since the widget's parent will be set automatically by KFileDialog.
-      * @param parent The parent widget of this dialog
       */
     KFileDialog( const KUrl& startDir, const QString& filter,
                  QWidget *parent, QWidget* widget = 0 );
@@ -219,9 +213,9 @@ public:
      * Sets the filter to be used to @p filter.
      *
      * You can set more
-     * filters for the user to select separated by '\n'. Every
-     * filter entry is defined through namefilter|text to diplay.
-     * If no | is found in the expression, just the namefilter is
+     * filters for the user to select separated by @c '\\n'. Every
+     * filter entry is defined through @c namefilter|text to display.
+     * If no @c '|' is found in the expression, just the namefilter is
      * shown. Examples:
      *
      * \code
@@ -236,9 +230,9 @@ public:
      * want to show the suffix to select by a specific filter, you must
      * repeat it.
      *
-     * If the filter contains an unescaped '/', a mimetype-filter is assumed.
+     * If the filter contains an unescaped @c '/', a mimetype-filter is assumed.
      * If you would like a '/' visible in your filter it can be escaped with
-     * a '\'. You can specify multiple mimetypes like this (separated with
+     * a @c '\'. You can specify multiple mimetypes like this (separated with
      * space):
      *
      * \code
@@ -310,7 +304,10 @@ public:
      *
      * @param w The widget to be used for the preview.
      */
-   void setPreviewWidget(const KPreviewWidgetBase *w);
+    void setPreviewWidget(const KPreviewWidgetBase *w);
+
+    /** @see QWidget::sizeHint() */
+    virtual QSize sizeHint() const;
 
     /**
      * Creates a modal file dialog and return the selected
@@ -330,10 +327,10 @@ public:
      *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;?global' to start
      *             in the directory last used by a filedialog in any application that specified the
      *             same keyword.
-     * @param filter This is a space separated list of shell globs.
-     * You can set the text to be displayed for the glob, and
-     * provide multiple globs.  See setFilter() for details on
-     * how to do this...
+     * @param filter A shell glob or a mime-type-filter that specifies which files to display.
+     *    The preferred option is to set a list of mimetype names, see setMimeFilter() for details.
+     *    Otherwise you can set the text to be displayed for the each glob, and
+     *    provide multiple globs, see setFilter() for details.
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
      */
@@ -371,10 +368,10 @@ public:
      *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;?global' to start
      *             in the directory last used by a filedialog in any application that specified the
      *             same keyword.
-     * @param filter This is a space separated list of shell globs.
-     * You can set the text to be displayed for the glob, and
-     * provide multiple globs.  See setFilter() for details on
-     * how to do this...
+     * @param filter A shell glob or a mime-type-filter that specifies which files to display.
+     *    The preferred option is to set a list of mimetype names, see setMimeFilter() for details.
+     *    Otherwise you can set the text to be displayed for the each glob, and
+     *    provide multiple globs, see setFilter() for details.
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
      */
@@ -403,10 +400,10 @@ public:
      *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;?global' to start
      *             in the directory last used by a filedialog in any application that specified the
      *             same keyword.
-     * @param filter This is a space separated list of shell globs.
-     * You can set the text to be displayed for the glob, and
-     * provide multiple globs.  See setFilter() for details on
-     * how to do this...
+     * @param filter A shell glob or a mime-type-filter that specifies which files to display.
+     *    The preferred option is to set a list of mimetype names, see setMimeFilter() for details.
+     *    Otherwise you can set the text to be displayed for the each glob, and
+     *    provide multiple globs, see setFilter() for details.
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
      */
@@ -435,10 +432,10 @@ public:
      *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;?global' to start
      *             in the directory last used by a filedialog in any application that specified the
      *             same keyword.
-     * @param filter This is a space separated list of shell globs.
-     * You can set the text to be displayed for the glob, and
-     * provide multiple globs.  See setFilter() for details on
-     * how to do this...
+     * @param filter A shell glob or a mime-type-filter that specifies which files to display.
+     *    The preferred option is to set a list of mimetype names, see setMimeFilter() for details.
+     *    Otherwise you can set the text to be displayed for the each glob, and
+     *    provide multiple globs, see setFilter() for details.
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
      */
@@ -467,10 +464,10 @@ public:
      *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;?global' to start
      *             in the directory last used by a filedialog in any application that specified the
      *             same keyword.
-     * @param filter This is a space separated list of shell globs.
-     * You can set the text to be displayed for the glob, and
-     * provide multiple globs.  See setFilter() for details on
-     * how to do this...
+     * @param filter A shell glob or a mime-type-filter that specifies which files to display.
+     *    The preferred option is to set a list of mimetype names, see setMimeFilter() for details.
+     *    Otherwise you can set the text to be displayed for the each glob, and
+     *    provide multiple globs, see setFilter() for details.
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
      */
@@ -506,10 +503,10 @@ public:
      *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;?global' to start
      *             in the directory last used by a filedialog in any application that specified the
      *             same keyword.
-     * @param filter This is a space separated list of shell globs.
-     * You can set the text to be displayed for the glob, and
-     * provide multiple globs.  See setFilter() for details on
-     * how to do this...
+     * @param filter A shell glob or a mime-type-filter that specifies which files to display.
+     *    The preferred option is to set a list of mimetype names, see setMimeFilter() for details.
+     *    Otherwise you can set the text to be displayed for the each glob, and
+     *    provide multiple globs, see setFilter() for details.
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
      */
@@ -520,8 +517,8 @@ public:
 
 
     /**
-     * Creates a modal file dialog and returns the selected
-     * directory or an empty string if none was chosen.
+     * Creates a modal directory-selection dialog and returns the selected
+     * directory (local only) or an empty string if none was chosen.
      *
      * @param startDir This can either be
      *         @li The URL of the directory to start in.
@@ -536,17 +533,16 @@ public:
      *             same keyword.
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
+     * @return the path to an existing local directory.
      */
     static QString getExistingDirectory( const KUrl& startDir = KUrl(),
                                          QWidget * parent = 0,
                                          const QString& caption= QString() );
 
     /**
-     * Creates a modal file dialog and returns the selected
+     * Creates a modal directory-selection dialog and returns the selected
      * directory or an empty string if none was chosen.
-     *
-     * Contrary to getExistingDirectory(), this method allows the
-     * selection of a remote directory.
+     * This version supports remote urls.
      *
      * @param startDir This can either be
      *         @li The URL of the directory to start in.
@@ -561,10 +557,11 @@ public:
      *             same keyword.
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
+     * @return the url to an existing directory (local or remote).
      */
-    static KUrl getExistingUrl( const KUrl& startDir = KUrl(),
-                                QWidget * parent = 0,
-                                const QString& caption= QString() );
+    static KUrl getExistingDirectoryUrl( const KUrl& startDir = KUrl(),
+                                         QWidget * parent = 0,
+                                         const QString& caption= QString() );
 
     /**
      * Creates a modal file dialog with an image previewer and returns the
@@ -626,6 +623,12 @@ public:
      */
     void setLocationLabel(const QString& text);
 
+    /**
+     * Returns the KFileWidget that implements most of this file dialog.
+     * If you link to libkfile you can cast this to a KFileWidget*.
+     */
+    KAbstractFileWidget* fileWidget();
+
     /**
      * Returns a pointer to the toolbar.
      *
@@ -638,7 +641,7 @@ public:
      *      yourAction->plug( kfileDialog->toolBar() );
      * \endcode
      */
-    KToolBar *toolBar() const { return toolbar; }
+    KToolBar *toolBar() const;
 
     /**
      * @returns a pointer to the OK-Button in the filedialog. You may use it
@@ -653,33 +656,22 @@ public:
     KPushButton *cancelButton() const;
 
     /**
-     * @returns the KUrlBar object used as the "speed bar". You can add custom
-     * entries to it like that:
-     * \code
-     * KUrlBar *urlBar = fileDialog->speedBar();
-     * if ( urlBar )
-     *     urlBar->insertDynamicItem( someURL, i18n("The URL's description") );
-     * \endcode
-     *
-     * Note that this method may return a null-pointer if the user configured
-     * to not use the speed-bar.
-     * @see KUrlBar
-     * @see KUrlBar::insertDynamicItem
+     * @returns the combobox used to type the filename or full location of the file.
+     * You need to link to libkfile to use this widget.
      */
-    KUrlBar *speedBar();
+    KUrlComboBox *locationEdit() const;
 
     /**
-     * @returns a pointer to the action collection, holding all the used
-     * KActions.
+     * @returns the combobox that contains the filters
+     * You need to link to libkfile to use this widget.
+     */
+    KFileFilterCombo *filterWidget() const;
+
+    /**
+     * @returns a pointer to the action collection, holding all the used KActions.
      */
     KActionCollection *actionCollection() const;
 
-    /**
-     * @returns the action before the path combobox so subclasses may insert widgets into
-     * the dialog
-     */
-    QAction* pathComboIndex();
-
     /**
      * This method implements the logic to determine the user's default directory
      * to be listed. E.g. the documents directory, home directory or a recently
@@ -738,140 +730,20 @@ Q_SIGNALS:
     void filterChanged( const QString& filter );
 
 protected:
-    KToolBar *toolbar;
-
-    static KUrl *lastDirectory;
-
-    KUrlComboBox *locationEdit;
-
-    KFileFilterCombo *filterWidget;
-
-    virtual void showEvent(QShowEvent* event);
-
     /**
      * Reimplemented to animate the cancel button.
      */
     virtual void keyPressEvent( QKeyEvent *e );
 
-    /**
-      * Perform basic initialization tasks. Called by constructors.
-      */
-    void init(const KUrl& startDir, const QString& filter, QWidget* widget);
-
-    /**
-      * rebuild geometry management.
-      *
-      */
-    virtual void initGUI();
-
-    /**
-     * called when an item is highlighted/selected in multiselection mode.
-     * handles setting the locationEdit.
-     */
-    void multiSelectionChanged();
-
-    /**
-     * Reads configuration and applies it (size, recent directories, ...)
-     * Recommended usage together with KConfigGroup
-     */
-    virtual void readConfig( KConfigGroup * configGroup);
-
-    /**
-     * Saves the current configuration
-     * Recommended usage together with KConfigGroup
-     */
-    virtual void writeConfig( KConfigGroup *configGroup);
-
-    /**
-     * Reads the recent used files and inserts them into the location combobox
-     */
-    virtual void readRecentFiles( KConfig * );
-
-    /**
-     * Saves the entries from the location combobox.
-     */
-    virtual void saveRecentFiles( KConfig * );
-
-    /**
-     * Parses the string "line" for files. If line doesn't contain any ", the
-     * whole line will be interpreted as one file. If the number of " is odd,
-     * an empty list will be returned. Otherwise, all items enclosed in " "
-     * will be returned as correct urls.
-     */
-    KUrl::List tokenize(const QString& line) const;
-
-    /**
-     * Returns the absolute version of the URL specified in locationEdit.
-     */
-    KUrl getCompleteUrl(const QString&);
-
-    /**
-     * Returns the filename extension associated with the currentFilter().
-     * QString() is returned if an extension is not available or if
-     * operationMode() != Saving.
-     */
-    QString currentFilterExtension();
-
-    /**
-     * Updates the currentFilterExtension and the availability of the
-     * Automatically Select Extension Checkbox (visible if operationMode()
-     * == Saving and enabled if an extension _will_ be associated with the
-     * currentFilter(), _after_ this call).  You should call this after
-     * filterWidget->setCurrentItem().
-     */
-    void updateAutoSelectExtension();
-
-
 protected Q_SLOTS:
-    void urlEntered( const KUrl& );
-    void enterUrl( const KUrl& url );
-    void enterUrl( const QString& url );
-    void locationActivated( const QString& url );
-
-
-    void slotFilterChanged();
-    void fileHighlighted(const KFileItem *i);
-    void fileSelected(const KFileItem *i);
-    void slotStatResult(KJob* job);
-    void slotLoadingFinished();
-    void fileCompletion( const QString& );
-    void toggleSpeedbar( bool );
-    void toggleBookmarks(bool show);
-
     virtual void slotOk();
     virtual void accept();
     virtual void slotCancel();
 
-    void slotAutoSelectExtClicked();
-    void addToRecentDocuments();
-    void initSpeedbar();
-
-private Q_SLOTS:
-    void slotLocationChanged( const QString& text );
-
 private:
-    KFileDialog(const KFileDialog&);
-    KFileDialog operator=(const KFileDialog&);
+    Q_DISABLE_COPY(KFileDialog)
 
-    void setLocationText( const QString& text );
-    void updateLocationWhatsThis();
-
-    void appendExtension(KUrl &url);
-    void updateLocationEditExtension(const QString &);
-    void updateFilter();
-
-    static void initStatic();
-
-    void setNonExtSelection();
-
-protected:
-    KDirOperator *ops;
-    bool autoDirectoryFollowing;
-
-    KUrl::List& parseSelectedUrls() const;
-
-private:
-    KFileDialogPrivate *d;
+    KFileDialogPrivate * const d;
 };
 
 #endif
