@@ -14,30 +14,25 @@
 #ifndef __KIconDialog_h__
 #define __KIconDialog_h__
 
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qpushbutton.h>
+#include <kio/kio_export.h>
+
+#include <QtCore/QStringList>
+#include <QtGui/QPushButton>
 
-#include <kicontheme.h>
 #include <kdialog.h>
-#include <k3iconview.h>
+#include <klistwidget.h>
 
-class QComboBox;
-class QTimer;
-class QKeyEvent;
-class QRadioButton;
-class QProgressBar;
 class KIconLoader;
 
 /**
  * Icon canvas for KIconDialog.
  */
-class KIO_EXPORT KIconCanvas: public K3IconView
+class KIO_EXPORT KIconCanvas: public KListWidget
 {
     Q_OBJECT
 
 public:
-    KIconCanvas(QWidget *parent=0L);
+    explicit KIconCanvas(QWidget *parent=0L);
     ~KIconCanvas();
 
     /**
@@ -63,18 +58,14 @@ Q_SIGNALS:
     void progress(int);
     void finished();
 
-private Q_SLOTS:
-    void slotLoadFiles();
-    void slotCurrentChanged(Q3IconViewItem *item);
-
-private:
-    QStringList mFiles;
-    QTimer *mpTimer;
-
-
 private:
     class KIconCanvasPrivate;
     KIconCanvasPrivate* const d;
+
+    Q_DISABLE_COPY(KIconCanvas)
+
+    Q_PRIVATE_SLOT(d, void _k_slotLoadFiles())
+    Q_PRIVATE_SLOT(d, void _k_slotCurrentChanged(QListWidgetItem *item))
 };
 
 
@@ -92,11 +83,11 @@ public:
     /**
      * Constructs an icon selection dialog using the global iconloader.
      */
-    KIconDialog(QWidget *parent=0L);
+    explicit KIconDialog(QWidget *parent=0L);
     /**
      * Constructs an icon selection dialog using a specific iconloader.
      */
-    KIconDialog(KIconLoader *loader, QWidget *parent=0);
+    explicit KIconDialog(KIconLoader *loader, QWidget *parent=0);
     /**
      * Destructs the dialog.
      */
@@ -131,15 +122,6 @@ public:
      */
     int iconSize() const;
 
-    /**
-     * Allows you to set the same parameters as in the class method
-     * getIcon().
-     */
-    void setup( K3Icon::Group group,
-                K3Icon::Context context = K3Icon::Application,
-                bool strictIconSize = false, int iconSize = 0,
-                bool user = false );
-
     /**
      * Allows you to set the same parameters as in the class method
      * getIcon(), as well as two additional parameters to lock
@@ -147,9 +129,11 @@ public:
      * dir itself.
      */
 
-    void setup( K3Icon::Group group, K3Icon::Context context,
-                bool strictIconSize, int iconSize, bool user, bool lockUser,
-                bool lockCustomDir );
+    void setup( K3Icon::Group group,
+                K3Icon::Context context = K3Icon::Application,
+                bool strictIconSize = false, int iconSize = 0,
+                bool user = false, bool lockUser = false,
+                bool lockCustomDir = false );
 
     /**
      * exec()utes this modal dialog and returns the name of the selected icon,
@@ -196,37 +180,20 @@ Q_SIGNALS:
 protected Q_SLOTS:
     void slotOk();
 
-private Q_SLOTS:
-    void slotContext(int);
-    void slotStartLoading(int);
-    void slotProgress(int);
-    void slotFinished();
-    void slotAcceptIcons();
-    void slotBrowse();
-    void slotOtherIconClicked();
-    void slotSystemIconClicked();
-
-private:
-    void init();
-    void showIcons();
-    void setContext( K3Icon::Context context );
-
-    int mGroupOrSize;
-    K3Icon::Context mContext;
-
-    QStringList mFileList;
-    QComboBox *mpCombo;
-    QPushButton *mpBrowseBut;
-    QRadioButton *mpRb1, *mpRb2;
-    QProgressBar *mpProgress;
-    KIconLoader *mpLoader;
-    KIconCanvas *mpCanvas;
-    int mNumContext;
-    K3Icon::Context mContextMap[ 12 ]; // must match KIcon::Context size, code has assert
-
 private:
     class KIconDialogPrivate;
     KIconDialogPrivate* const d;
+
+    Q_DISABLE_COPY(KIconDialog)
+
+    Q_PRIVATE_SLOT(d, void _k_slotContext(int))
+    Q_PRIVATE_SLOT(d, void _k_slotStartLoading(int))
+    Q_PRIVATE_SLOT(d, void _k_slotProgress(int))
+    Q_PRIVATE_SLOT(d, void _k_slotFinished())
+    Q_PRIVATE_SLOT(d, void _k_slotAcceptIcons())
+    Q_PRIVATE_SLOT(d, void _k_slotBrowse())
+    Q_PRIVATE_SLOT(d, void _k_slotOtherIconClicked())
+    Q_PRIVATE_SLOT(d, void _k_slotSystemIconClicked())
 };
 
 
@@ -249,7 +216,7 @@ public:
     /**
      * Constructs a KIconButton using the global iconloader.
      */
-    KIconButton(QWidget *parent=0L);
+    explicit KIconButton(QWidget *parent=0L);
 
     /**
      * Constructs a KIconButton using a specific KIconLoader.
@@ -282,8 +249,7 @@ public:
      */
     void setIcon(const QString& icon);
 
-    void setIcon(const QIcon& icon)
-    {QPushButton::setIcon(icon);}
+    void setIcon(const QIcon& icon);
 
     /**
      * Resets the icon (reverts to an empty button).
@@ -293,7 +259,7 @@ public:
     /**
      * Returns the name of the selected icon.
      */
-    QString icon() const { return mIcon; }
+    const QString &icon() const;
 
     /**
      * Sets the size of the icon to be shown / selected.
@@ -314,22 +280,14 @@ Q_SIGNALS:
      */
     void iconChanged(const QString &icon);
 
-private Q_SLOTS:
-    void slotChangeIcon();
-    void newIconName(const QString& name);
-
 private:
-    void init( KIconLoader *loader );
-
-    bool mbUser;
-    K3Icon::Group mGroup;
-    K3Icon::Context mContext;
-
-    QString mIcon;
-    KIconDialog *mpDialog;
-    KIconLoader *mpLoader;
     class KIconButtonPrivate;
     KIconButtonPrivate* const d;
+
+    Q_DISABLE_COPY(KIconButton)
+
+    Q_PRIVATE_SLOT(d, void _k_slotChangeIcon())
+    Q_PRIVATE_SLOT(d, void _k_newIconName(const QString&))
 };
 
 
