@@ -11,20 +11,14 @@
 #ifndef KIMAGEFILEPREVIEW_H
 #define KIMAGEFILEPREVIEW_H
 
-#include <qpixmap.h>
+#include <QtGui/QPixmap>
 
 #include <kurl.h>
 #include <kpreviewwidgetbase.h>
 
-class QCheckBox;
-class QPushButton;
-class QLabel;
-class QTimer;
-
-class KFileDialog;
 class KFileItem;
 class KJob;
-namespace KIO { class Job; class PreviewJob; }
+namespace KIO { class PreviewJob; }
 
 /**
  * Image preview widget for the file dialog.
@@ -34,7 +28,7 @@ class KIO_EXPORT KImageFilePreview : public KPreviewWidgetBase
 	Q_OBJECT
 
 	public:
-		KImageFilePreview(QWidget *parent);
+        explicit KImageFilePreview(QWidget *parent);
 		~KImageFilePreview();
 
 		virtual QSize sizeHint() const;
@@ -48,7 +42,7 @@ class KIO_EXPORT KImageFilePreview : public KPreviewWidgetBase
 		void showPreview( const KUrl& url, bool force );
 
 		void toggleAuto(bool);
-		virtual void gotPreview( const KFileItem*, const QPixmap& );
+		virtual void gotPreview( const KFileItem&, const QPixmap& );
 
 	protected:
 		virtual void resizeEvent(QResizeEvent *e);
@@ -57,20 +51,13 @@ class KIO_EXPORT KImageFilePreview : public KPreviewWidgetBase
 
 	private Q_SLOTS:
 		void slotResult( KJob * );
-		virtual void slotFailed( const KFileItem* );
+		virtual void slotFailed( const KFileItem& );
 
-	private:
-		bool autoMode;
-		KUrl currentURL;
-		QTimer *timer;
-		QLabel *imageLabel;
-		QLabel *infoLabel;
-		QCheckBox *autoPreview;
-		QPushButton *previewButton;
-		KIO::PreviewJob *m_job;
         private:
                 class KImageFilePreviewPrivate;
-                KImageFilePreviewPrivate *d;
+        KImageFilePreviewPrivate *const d;
+
+        Q_DISABLE_COPY(KImageFilePreview)
 };
 
 #endif // KIMAGEFILEPREVIEW_H
