@@ -26,57 +26,28 @@
 #include <klocale.h>
 #include <kprotocolinfo.h>
 
-#include <qvalidator.h>
-#include <qlayout.h>
-#include <qlabel.h>
-#include <qfileinfo.h>
-#include <qdatetime.h>
-#include <qgroupbox.h>
+#include <QtGui/QDoubleValidator>
+#include <QtGui/QLayout>
+#include <QtGui/QLabel>
+#include <QtCore/QFileInfo>
+#include <QtCore/QDate>
+#include <QtGui/QGroupBox>
 #include <QResizeEvent>
-#include <qlinkedlist.h>
-#include <Q3ScrollView>
+#include <QtCore/QLinkedList>
+#include <QScrollArea>
 #include <QTextDocument>
 
-#undef Bool
-
-class MetaPropsScrollView : public Q3ScrollView
-{
-public:
-    MetaPropsScrollView(QWidget* parent = 0, const char* name = 0)
-        : Q3ScrollView(parent, name)
-    {
-      setFrameStyle(QFrame::NoFrame);
-      m_frame = new QFrame(viewport());
-	  m_frame->setObjectName("MetaPropsScrollView::m_frame");
-      m_frame->setFrameStyle(QFrame::NoFrame);
-      addChild(m_frame, 0, 0);
-    };
-
-    QFrame* frame() {return m_frame;};
-
-protected:
-    virtual void viewportResizeEvent(QResizeEvent* ev)
-    {
-      Q3ScrollView::viewportResizeEvent(ev);
-      m_frame->resize( qMax(m_frame->sizeHint().width(), ev->size().width()),
-                       qMax(m_frame->sizeHint().height(), ev->size().height()));
-    };
-
-private:
-      QFrame* m_frame;
-};
-
 class KFileMetaPropsPlugin::KFileMetaPropsPluginPrivate
 {
 public:
     KFileMetaPropsPluginPrivate()  {}
     ~KFileMetaPropsPluginPrivate() {}
 
-    QFrame*                       m_frame;
+    QWidget*                      m_frame;
     QGridLayout*                  m_framelayout;
     KFileMetaInfo                 m_info;
 //    QPushButton*                m_add;
-    Q3PtrList<KFileMetaInfoWidget> m_editWidgets;
+    QList<KFileMetaInfoWidget *> m_editWidgets;
 };
 
 KFileMetaPropsPlugin::KFileMetaPropsPlugin(KPropertiesDialog* props)
@@ -84,12 +55,12 @@ KFileMetaPropsPlugin::KFileMetaPropsPlugin(KPropertiesDialog* props)
 {
 
     KFileItem * fileitem = properties->item();
-    kDebug(250) << "KFileMetaPropsPlugin constructor" << endl;
+    kDebug(250) << "KFileMetaPropsPlugin constructor";
 
     d->m_info  = fileitem->metaInfo();
     if (!d->m_info.isValid())
     {
-      d->m_info = KFileMetaInfo(properties->kurl().path(KUrl::RemoveTrailingSlash));
+        d->m_info = KFileMetaInfo(properties->kurl().path(KUrl::RemoveTrailingSlash));
         fileitem->setMetaInfo(d->m_info);
     }
 
@@ -110,64 +81,47 @@ void KFileMetaPropsPlugin::createLayout()
 {
     QFileInfo file_info(properties->item()->url().path());
 
-    kDebug(250) << "KFileMetaPropsPlugin::createLayout" << endl;
+    kDebug(250) << "KFileMetaPropsPlugin::createLayout";
 
     // is there any valid and non-empty info at all?
-    if ( !d->m_info.isValid() || (d->m_info.preferredKeys()).isEmpty() )
+    if ( !d->m_info.isValid() )
         return;
 
     // now get a list of groups
-    KFileMetaInfoProvider* prov = KFileMetaInfoProvider::self();
-    QStringList groupList = d->m_info.preferredGroups();
-
-    const KFileMimeTypeInfo* mtinfo = prov->mimeTypeInfo(d->m_info.mimeType());
-    if (!mtinfo)
-    {
-        kDebug(7034) << "no mimetype info there\n";
+    //KFileMetaInfoProvider* prov = KFileMetaInfoProvider::self();
+    KFileMetaInfoGroupList groupList = d->m_info.preferredGroups();
+    if (groupList.isEmpty())
         return;
-    }
 
-    // let the dialog create the page frame
-    QFrame* topframe = new QFrame();
-    properties->addPage(topframe, i18n("&Meta Info"));
-    topframe->setFrameStyle(QFrame::NoFrame);
-    QVBoxLayout* tmp = new QVBoxLayout(topframe);
-    tmp->setMargin(0);
+    QScrollArea* scrollArea = new QScrollArea;
+    scrollArea->setFrameStyle(QFrame::NoFrame);
+    properties->addPage(scrollArea, i18n("&Meta Info"));
 
-    // create a scroll view in the page
-    MetaPropsScrollView* view = new MetaPropsScrollView(topframe);
-
-    tmp->addWidget(view);
-
-    d->m_frame = view->frame();
+    d->m_frame = new QWidget(scrollArea);
+    scrollArea->setWidget(d->m_frame);
+    scrollArea->setWidgetResizable(true);
 
     QVBoxLayout *toplayout = new QVBoxLayout(d->m_frame);
     toplayout->setSpacing(KDialog::spacingHint());
 
-    for (QStringList::Iterator git=groupList.begin();
-            git!=groupList.end(); ++git)
-    {
-        kDebug(7033) << *git << endl;
+    foreach (const KFileMetaInfoGroup& group, groupList) {
+        //kDebug(7033) << *git;
 
-        QStringList itemList = d->m_info.group(*git).preferredKeys();
+        KFileMetaInfoItemList itemList = group.items();
         if (itemList.isEmpty())
             continue;
 
-        QGroupBox *groupBox = new QGroupBox(
-            Qt::escape(mtinfo->groupInfo(*git)->translatedName()),
+        QGroupBox *groupBox = new QGroupBox( Qt::escape(group.name()),
             d->m_frame);
         QGridLayout *grouplayout = new QGridLayout(groupBox);
         grouplayout->activate();
 
         toplayout->addWidget(groupBox);
 
-        QLinkedList<KFileMetaInfoItem> readItems;
-        QLinkedList<KFileMetaInfoItem> editItems;
+        KFileMetaInfoItemList readItems;
+        KFileMetaInfoItemList editItems;
 
-        for (QStringList::Iterator iit = itemList.begin();
-                iit!=itemList.end(); ++iit)
-        {
-            KFileMetaInfoItem item = d->m_info[*git][*iit];
+        foreach (const KFileMetaInfoItem& item, itemList) {
             if ( !item.isValid() ) continue;
 
             bool editable = file_info.isWritable() && item.isEditable();
@@ -181,15 +135,14 @@ void KFileMetaPropsPlugin::createLayout()
         KFileMetaInfoWidget* w = 0L;
         int row = 0;
         // then first add the editable items to the layout
-        for (QLinkedList<KFileMetaInfoItem>::Iterator iit= editItems.begin();
-                iit!=editItems.end(); ++iit)
-        {
-            QLabel* l = new QLabel((*iit).translatedKey() + ':', groupBox);
+        foreach (const KFileMetaInfoItem& item, editItems) {
+            QLabel* l = new QLabel(item.name() + ':', groupBox);
             grouplayout->addWidget(l, row, 0);
-            l->setAlignment( Qt::AlignLeft | Qt::AlignTop | Qt::TextExpandTabs );
-            QValidator* val = mtinfo->createValidator(*git, (*iit).key());
-            if (!val) kDebug(7033) << "didn't get a validator for " << *git << "/" << (*iit).key() << endl;
-            w = new KFileMetaInfoWidget(*iit, val, groupBox);
+            l->setAlignment( Qt::AlignLeft | Qt::AlignTop );
+            QValidator* val = item.properties().createValidator();
+            if (!val) kDebug(7033) << "didn't get a validator for "
+                << item.name() << endl;
+            w = new KFileMetaInfoWidget(item, val, groupBox);
             grouplayout->addWidget(w, row, 1);
             d->m_editWidgets.append( w );
             connect(w, SIGNAL(valueChanged(const QVariant&)), this, SIGNAL(changed()));
@@ -197,13 +150,11 @@ void KFileMetaPropsPlugin::createLayout()
         }
 
         // and then the read only items
-        for (QLinkedList<KFileMetaInfoItem>::Iterator iit= readItems.begin();
-                iit!=readItems.end(); ++iit)
-        {
-            QLabel* l = new QLabel((*iit).translatedKey() + ':', groupBox);
+        foreach (const KFileMetaInfoItem& item, readItems) {
+            QLabel* l = new QLabel(item.name() + ':', groupBox);
             grouplayout->addWidget(l, row, 0);
-            l->setAlignment( Qt::AlignLeft | Qt::AlignTop | Qt::TextExpandTabs );
-            w = new KFileMetaInfoWidget(*iit, KFileMetaInfoWidget::ReadOnly, 0L, groupBox);
+            l->setAlignment( Qt::AlignLeft | Qt::AlignTop );
+            w = new KFileMetaInfoWidget(item, KFileMetaInfoWidget::ReadOnly, 0L, groupBox);
             grouplayout->addWidget(w, row, 1);
             ++row;
         }
@@ -231,10 +182,10 @@ void KFileMetaPropsPlugin::createLayout()
                 if ( l.find(*it)==l.end() )
                 {
                     d->m_add->setEnabled(true);
-                    kDebug(250) << "**first addable key is " << (*it).toLatin1().constData() << "**" <<endl;
+                    kDebug(250) << "**first addable key is " << (*it).toLatin1().constData() << "**";
                     break;
                 }
-                kDebug(250) << "**already existing key is " << (*it).toLatin1().constData() << "**" <<endl;
+                kDebug(250) << "**already existing key is " << (*it).toLatin1().constData() << "**";
         }
     } */
 }
@@ -251,32 +202,35 @@ void KFileMetaPropsPlugin::createLayout()
 
 KFileMetaPropsPlugin::~KFileMetaPropsPlugin()
 {
-  delete d;
+    delete d;
 }
 
 bool KFileMetaPropsPlugin::supports( const KFileItemList& _items )
 {
-#ifdef _GNUC
-#warning TODO: Add support for more than one item
-#endif
-  // TODO check that KDesktopPropsPlugin is correct, i.e. that we never want metainfo for
-  // a .desktop file? Used to be that only Application desktop files were filtered out
-  if (KDesktopPropsPlugin::supports(_items) || KUrlPropsPlugin::supports(_items))
-     return false; // Having both is redundant.
+    kDebug() ;
 
-  bool metaDataEnabled = KGlobalSettings::showFilePreview(_items.first()->url());
-  return _items.count() == 1 && metaDataEnabled;
+    // TODO: Add support for more than one item
+
+    // TODO check that KDesktopPropsPlugin is correct, i.e. that we never want metainfo for
+    // a .desktop file? Used to be that only Application desktop files were filtered out
+    if (KDesktopPropsPlugin::supports(_items) || KUrlPropsPlugin::supports(_items))
+        return false; // Having both is redundant.
+    if (_items.count() != 1)
+        return false;
+
+    bool metaDataEnabled = KGlobalSettings::showFilePreview(_items.first()->url());
+    kDebug() << "metaDataEnabled=" << metaDataEnabled;
+    return metaDataEnabled;
 }
 
 void KFileMetaPropsPlugin::applyChanges()
 {
-  kDebug(250) << "applying changes" << endl;
-  // insert the fields that changed into the info object
+    kDebug(250) << "applying changes";
+    // insert the fields that changed into the info object
 
-  Q3PtrListIterator<KFileMetaInfoWidget> it( d->m_editWidgets );
-  KFileMetaInfoWidget* w;
-  for (; (w = it.current()); ++it) w->apply();
-  d->m_info.applyChanges(properties->kurl().path());
+    foreach(KFileMetaInfoWidget* w, d->m_editWidgets)
+        w->apply();
+    d->m_info.applyChanges();
 }
 
 #include "kmetaprops.moc"
