@@ -3,6 +3,7 @@
     Copyright (C) 1997 Torben Weis <weis@stud.uni-frankfurt.de>
     Copyright (C) 1999 Dirk Mueller <mueller@kde.org>
     Portions copyright (C) 1999 Preston Brown <pbrown@kde.org>
+    Copyright (C) 2007 Pino Toscano <pino@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -20,13 +21,18 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qcheckbox.h>
+#include "kopenwithdialog.h"
+#include "kopenwithdialog_p.h"
+
+#include <QtCore/QtAlgorithms>
+#include <QtCore/QList>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtGui/QCheckBox>
 
-#include <kapplication.h>
 #include <kauthorized.h>
-#include <kcombobox.h>
+#include <khistorycombobox.h>
+#include <kdesktopfile.h>
 #include <klineedit.h>
 #include <klocale.h>
 #include <kiconloader.h>
@@ -38,9 +44,7 @@
 #include <kurlrequester.h>
 #include <kmimetype.h>
 #include <kservicegroup.h>
-
-#include "kopenwithdialog.h"
-#include "kopenwithdialog_p.h"
+#include <kserviceoffer.h>
 
 #include <assert.h>
 #include <stdlib.h>
@@ -48,142 +52,88 @@
 #include <kconfiggroup.h>
 
 template <> inline
-void KConfigBase::writeEntry( const char *pKey,
+void KConfigGroup::writeEntry( const char *pKey,
                               const KGlobalSettings::Completion& aValue,
                               KConfigBase::WriteConfigFlags flags)
 {
   writeEntry(pKey, int(aValue), flags);
 }
 
-// ----------------------------------------------------------------------
-
-KAppTreeListItem::KAppTreeListItem( K3ListView* parent, const QString & name,
-                                    const QPixmap& pixmap, bool parse, bool dir, const QString &p, const QString &c )
-    : Q3ListViewItem( parent, name )
+class AppNode
 {
-    init(pixmap, parse, dir, p, c);
-}
-
-
-// ----------------------------------------------------------------------
-
-KAppTreeListItem::KAppTreeListItem( Q3ListViewItem* parent, const QString & name,
-                                    const QPixmap& pixmap, bool parse, bool dir, const QString &p, const QString &c )
-    : Q3ListViewItem( parent, name )
-{
-    init(pixmap, parse, dir, p, c);
-}
-
-
-// ----------------------------------------------------------------------
-
-void KAppTreeListItem::init(const QPixmap& pixmap, bool parse, bool dir, const QString &_path, const QString &_exec)
-{
-    setPixmap(0, pixmap);
-    parsed = parse;
-    directory = dir;
-    path = _path; // relative path
-    exec = _exec;
-}
-
-
-/* Ensures that directories sort before non-directories */
-int KAppTreeListItem::compare(Q3ListViewItem *i, int col, bool ascending) const
-{
-	KAppTreeListItem *other = static_cast<KAppTreeListItem *>(i);
-
-	// Directories sort first
-	if (directory && !other->directory)
-		return -1;
-
-	else if (!directory && other->directory)
-		return 1;
-
-	else // both directories or both not
-		return Q3ListViewItem::compare(i, col, ascending);
-}
-
-// ----------------------------------------------------------------------
-// Ensure that case is ignored
-QString KAppTreeListItem::key(int column, bool /*ascending*/) const
-{
-        return text(column).toUpper();
-}
-
-void KAppTreeListItem::activate()
-{
-    if ( directory )
-        setOpen(!isOpen());
-}
-
-void KAppTreeListItem::setOpen( bool o )
-{
-    if( o && !parsed ) { // fill the children before opening
-        ((KApplicationTree *) parent())->addDesktopGroup( path, this );
-        parsed = true;
-    }
-    Q3ListViewItem::setOpen( o );
-}
-
-bool KAppTreeListItem::isDirectory()
-{
-    return directory;
-}
-
-// ----------------------------------------------------------------------
-
-KApplicationTree::KApplicationTree( QWidget *parent )
-    : K3ListView( parent ), currentitem(0)
-{
-    addColumn( i18n("Known Applications") );
-    setRootIsDecorated( true );
-
-    addDesktopGroup( QString() );
-    cleanupTree();
-
-    connect( this, SIGNAL( currentChanged(Q3ListViewItem*) ),
-            SLOT( slotItemHighlighted(Q3ListViewItem*) ) );
-    connect( this, SIGNAL( selectionChanged(Q3ListViewItem*) ),
-            SLOT( slotSelectionChanged(Q3ListViewItem*) ) );
-}
-
-// ----------------------------------------------------------------------
-
-bool KApplicationTree::isDirSel()
-{
-    if (!currentitem) return false; // if currentitem isn't set
-    return currentitem->isDirectory();
-}
-
-// ----------------------------------------------------------------------
-
-static QPixmap appIcon(const QString &iconName)
-{
-    QPixmap normal = KIconLoader::global()->loadIcon(iconName, K3Icon::Small, 0, K3Icon::DefaultState, 0L, true);
-    // make sure they are not larger than 20x20
-    if (normal.width() > 20 || normal.height() > 20)
+public:
+    AppNode()
+        : isDir(false), parent(0), fetched(false)
     {
-       QImage tmp = normal.toImage();
-       tmp = tmp.scaled(20, 20, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
-       normal = QPixmap::fromImage(tmp);
     }
-    return normal;
+    ~AppNode()
+    {
+        qDeleteAll(children);
+    }
+
+    QString icon;
+    QString text;
+    QString relPath;
+    QString exec;
+    bool isDir;
+
+    AppNode *parent;
+    bool fetched;
+
+    QList<AppNode*> children;
+};
+
+static bool AppNodeLessThan(AppNode *n1, AppNode *n2)
+{
+    if (n1->isDir) {
+        if (n2->isDir) {
+            return n1->text.compare(n2->text, Qt::CaseInsensitive) < 0;
+        } else {
+            return true;
+        }
+    } else {
+        if (n2->isDir) {
+            return false;
+        } else {
+            return n1->text.compare(n2->text, Qt::CaseInsensitive) < 0;
+        }
+    }
+    return true;
 }
 
-void KApplicationTree::addDesktopGroup( const QString &relPath, KAppTreeListItem *item)
+
+class KApplicationModelPrivate
 {
-   KServiceGroup::Ptr root = KServiceGroup::group(relPath);
+public:
+    KApplicationModelPrivate(KApplicationModel *qq)
+        : q(qq), root(new AppNode())
+    {
+    }
+    ~KApplicationModelPrivate()
+    {
+        delete root;
+    }
+
+    void fillNode(const QString &relPath, AppNode *node);
+
+    KApplicationModel *q;
+
+    AppNode *root;
+};
+
+void KApplicationModelPrivate::fillNode(const QString &_relPath, AppNode *node)
+{
+   KServiceGroup::Ptr root = KServiceGroup::group(_relPath);
    if (!root || !root->isValid()) return;
 
    KServiceGroup::List list = root->entries();
 
-   KAppTreeListItem * newItem;
    for( KServiceGroup::List::ConstIterator it = list.begin();
-       it != list.end(); it++)
+       it != list.end(); ++it)
    {
       QString icon;
       QString text;
-      QString relPath;
+      QString relPath = _relPath;
       QString exec;
       bool isDir = false;
       const KSycocaEntry::Ptr p = (*it);
@@ -212,84 +162,252 @@ void KApplicationTree::addDesktopGroup( const QString &relPath, KAppTreeListItem
       }
       else
       {
-         kWarning(250) << "KServiceGroup: Unexpected object in list!" << endl;
+         kWarning(250) << "KServiceGroup: Unexpected object in list!";
          continue;
       }
 
-      QPixmap pixmap = appIcon( icon );
-
-      if (item)
-         newItem = new KAppTreeListItem( item, text, pixmap, false, isDir,
-                                         relPath, exec );
-      else
-         newItem = new KAppTreeListItem( this, text, pixmap, false, isDir,
-                                         relPath, exec );
-      if (isDir)
-         newItem->setExpandable( true );
+      AppNode *newnode = new AppNode();
+      newnode->icon = icon;
+      newnode->text = text;
+      newnode->relPath = relPath;
+      newnode->exec = exec;
+      newnode->isDir = isDir;
+      newnode->parent = node;
+      node->children.append(newnode);
    }
+   qStableSort(node->children.begin(), node->children.end(), AppNodeLessThan);
 }
 
 
-// ----------------------------------------------------------------------
 
-void KApplicationTree::slotItemHighlighted(Q3ListViewItem* i)
+KApplicationModel::KApplicationModel(QObject *parent)
+    : QAbstractItemModel(parent), d(new KApplicationModelPrivate(this))
 {
-    // i may be 0 (see documentation)
-    if(!i)
+    d->fillNode(QString(), d->root);
+}
+
+KApplicationModel::~KApplicationModel()
+{
+    delete d;
+}
+
+bool KApplicationModel::canFetchMore(const QModelIndex &parent) const
+{
+    if (!parent.isValid())
+        return false;
+
+    AppNode *node = static_cast<AppNode*>(parent.internalPointer());
+    return node->isDir && !node->fetched;
+}
+
+int KApplicationModel::columnCount(const QModelIndex &parent) const
+{
+    Q_UNUSED(parent)
+    return 1;
+}
+
+QVariant KApplicationModel::data(const QModelIndex &index, int role) const
+{
+    if (!index.isValid())
+        return QVariant();
+
+    AppNode *node = static_cast<AppNode*>(index.internalPointer());
+
+    switch (role) {
+    case Qt::DisplayRole:
+        return node->text;
+        break;
+    case Qt::DecorationRole:
+        if (!node->icon.isEmpty()) {
+            return KIcon(node->icon);
+        }
+        break;
+    default:
+        ;
+    }
+    return QVariant();
+}
+
+void KApplicationModel::fetchMore(const QModelIndex &parent)
+{
+    if (!parent.isValid())
         return;
 
-    KAppTreeListItem *item = (KAppTreeListItem *) i;
-
-    currentitem = item;
-
-    if( (!item->directory ) && (!item->exec.isEmpty()) )
-        emit highlighted( item->text(0), item->exec );
-}
-
-
-// ----------------------------------------------------------------------
-
-void KApplicationTree::slotSelectionChanged(Q3ListViewItem* i)
-{
-    // i may be 0 (see documentation)
-    if(!i)
+    AppNode *node = static_cast<AppNode*>(parent.internalPointer());
+    if (!node->isDir)
         return;
 
-    KAppTreeListItem *item = (KAppTreeListItem *) i;
-
-    currentitem = item;
-
-    if( ( !item->directory ) && (!item->exec.isEmpty() ) )
-        emit selected( item->text(0), item->exec );
+    emit layoutAboutToBeChanged();
+    d->fillNode(node->relPath, node);
+    node->fetched = true;
+    emit layoutChanged();
 }
 
-// ----------------------------------------------------------------------
-
-void KApplicationTree::resizeEvent( QResizeEvent * e)
+bool KApplicationModel::hasChildren(const QModelIndex &parent) const
 {
-    setColumnWidth(0, width()-QApplication::style()->pixelMetric(QStyle::PM_ScrollBarExtent)
-                         -2*QApplication::style()->pixelMetric(QStyle::PM_DefaultFrameWidth));
-    K3ListView::resizeEvent(e);
+    if (!parent.isValid())
+        return true;
+
+    AppNode *node = static_cast<AppNode*>(parent.internalPointer());
+    return node->isDir;
 }
 
-// Prune empty directories from the tree
-void KApplicationTree::cleanupTree()
+QVariant KApplicationModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
-	Q3ListViewItem *item=firstChild();
-	while(item!=0)
-	{
-		if(item->isExpandable())
-		{
-			Q3ListViewItem *temp=item->itemBelow();
-			if(item->text(0)!=i18n("Applications"))
-				item->setOpen(false);
-			item=temp;
-			continue;
-		}
-		item=item->itemBelow();
-	}
+    if (orientation != Qt::Horizontal || section != 0)
+        return QVariant();
+
+    switch (role) {
+    case Qt::DisplayRole:
+        return i18n("Known Applications");
+        break;
+    default:
+        return QVariant();
+    }
 }
 
+QModelIndex KApplicationModel::index(int row, int column, const QModelIndex &parent) const
+{
+    if (row < 0 || column != 0)
+        return QModelIndex();
+
+    AppNode *node = d->root;
+    if (parent.isValid())
+        node = static_cast<AppNode*>(parent.internalPointer());
+
+    if (row >= node->children.count())
+        return QModelIndex();
+    else
+        return createIndex(row, 0, node->children.at(row));
+}
+
+QModelIndex KApplicationModel::parent(const QModelIndex &index) const
+{
+    if (!index.isValid())
+        return QModelIndex();
+
+    AppNode *node = static_cast<AppNode*>(index.internalPointer());
+    if (node->parent->parent) {
+        int id = node->parent->parent->children.indexOf(node->parent);
+
+        if (id >= 0 && id < node->parent->parent->children.count())
+           return createIndex(id, 0, node->parent);
+        else
+            return QModelIndex();
+    }
+    else
+        return QModelIndex();
+}
+
+int KApplicationModel::rowCount(const QModelIndex &parent) const
+{
+    if (!parent.isValid())
+        return d->root->children.count();
+
+    AppNode *node = static_cast<AppNode*>(parent.internalPointer());
+    return node->children.count();
+}
+
+QString KApplicationModel::nameFor(const QModelIndex &index) const
+{
+    if (!index.isValid())
+        return QString();
+
+    AppNode *node = static_cast<AppNode*>(index.internalPointer());
+    return node->text;
+}
+
+QString KApplicationModel::execFor(const QModelIndex &index) const
+{
+    if (!index.isValid())
+        return QString();
+
+    AppNode *node = static_cast<AppNode*>(index.internalPointer());
+    return node->exec;
+}
+
+bool KApplicationModel::isDirectory(const QModelIndex &index) const
+{
+    if (!index.isValid())
+        return false;
+
+    AppNode *node = static_cast<AppNode*>(index.internalPointer());
+    return node->isDir;
+}
+
+class KApplicationViewPrivate
+{
+public:
+    KApplicationViewPrivate()
+        : appModel(0)
+    {
+    }
+
+    KApplicationModel *appModel;
+};
+
+KApplicationView::KApplicationView(QWidget *parent)
+    : QTreeView(parent), d(new KApplicationViewPrivate)
+{
+}
+
+KApplicationView::~KApplicationView()
+{
+    delete d;
+}
+
+void KApplicationView::setModel(QAbstractItemModel *model)
+{
+    if (d->appModel) {
+        disconnect(selectionModel(), SIGNAL(selectionChanged(QItemSelection, QItemSelection)),
+                this, SLOT(slotSelectionChanged(QItemSelection, QItemSelection)));
+    }
+
+    QTreeView::setModel(model);
+
+    d->appModel = qobject_cast<KApplicationModel*>(model);
+    if (d->appModel) {
+        connect(selectionModel(), SIGNAL(selectionChanged(QItemSelection, QItemSelection)),
+                this, SLOT(slotSelectionChanged(QItemSelection, QItemSelection)));
+    }
+}
+
+bool KApplicationView::isDirSel() const
+{
+    if (d->appModel) {
+        QModelIndex index = selectionModel()->currentIndex();
+        return d->appModel->isDirectory(index);
+    }
+    return false;
+}
+
+void KApplicationView::currentChanged(const QModelIndex &current, const QModelIndex &previous)
+{
+    QTreeView::currentChanged(current, previous);
+
+    if (d->appModel && !d->appModel->isDirectory(current)) {
+        QString exec = d->appModel->execFor(current);
+        if (!exec.isEmpty()) {
+            emit highlighted(d->appModel->nameFor(current), exec);
+        }
+    }
+}
+
+void KApplicationView::slotSelectionChanged(const QItemSelection &selected, const QItemSelection &deselected)
+{
+    Q_UNUSED(deselected)
+
+    QModelIndexList indexes = selected.indexes();
+    if (indexes.count() == 1 && !d->appModel->isDirectory(indexes.at(0))) {
+        QString exec = d->appModel->execFor(indexes.at(0));
+        if (!exec.isEmpty()) {
+            emit this->selected(d->appModel->nameFor(indexes.at(0)), exec);
+        }
+    }
+}
+
+
+
 /***************************************************************
  *
  * KOpenWithDialog
@@ -298,13 +416,48 @@ void KApplicationTree::cleanupTree()
 class KOpenWithDialogPrivate
 {
 public:
-    KOpenWithDialogPrivate() : saveNewApps(false) { };
+    KOpenWithDialogPrivate(KOpenWithDialog *qq)
+        : q(qq), saveNewApps(false)
+    {
+    }
+
+    KOpenWithDialog *q;
+
+    /**
+     * Determine mime type from URLs
+     */
+    void setMimeType(const KUrl::List &_urls);
+
+    /**
+     * Create a dialog that asks for a application to open a given
+     * URL(s) with.
+     *
+     * @param text   appears as a label on top of the entry box.
+     * @param value  is the initial value of the line
+     */
+    void init(const QString &text, const QString &value);
+
+    // slots
+    void _k_slotDbClick();
+    void _k_slotOK();
+
     bool saveNewApps;
+    bool m_terminaldirty;
     KService::Ptr curService;
+    KApplicationView *view;
+    KUrlRequester *edit;
+    QString m_command;
+    QLabel *label;
+    QString qName;
+    QString qMimeType;
+    QCheckBox *terminal;
+    QCheckBox *remember;
+    QCheckBox *nocloseonexit;
+    KService::Ptr m_pService;
 };
 
 KOpenWithDialog::KOpenWithDialog( const KUrl::List& _urls, QWidget* parent )
-             :KDialog( parent ),d(new KOpenWithDialogPrivate)
+    : KDialog(parent), d(new KOpenWithDialogPrivate(this))
 {
     setObjectName( QLatin1String( "openwith" ) );
     setModal( true );
@@ -320,27 +473,29 @@ KOpenWithDialog::KOpenWithDialog( const KUrl::List& _urls, QWidget* parent )
     else
         // Should never happen ??
         text = i18n( "Choose the name of the program with which to open the selected files." );
-    setMimeType( _urls );
-    init( text, QString() );
+    d->setMimeType(_urls);
+    d->init(text, QString());
 }
 
 KOpenWithDialog::KOpenWithDialog( const KUrl::List& _urls, const QString&_text,
                             const QString& _value, QWidget *parent)
-             :KDialog( parent ),d(new KOpenWithDialogPrivate)
+    : KDialog(parent), d(new KOpenWithDialogPrivate(this))
 {
   setObjectName( QLatin1String( "openwith" ) );
   setModal( true );
-  QString caption = KStringHandler::csqueeze( _urls.first().prettyUrl() );
+  QString caption;
+  if (_urls.count()>0 && !_urls.first().isEmpty())
+     caption = KStringHandler::csqueeze( _urls.first().prettyUrl() );
   if (_urls.count() > 1)
       caption += QString::fromLatin1("...");
   setCaption(caption);
-  setMimeType( _urls );
-  init( _text, _value );
+    d->setMimeType(_urls);
+    d->init(_text, _value);
 }
 
 KOpenWithDialog::KOpenWithDialog( const QString &mimeType, const QString& value,
                             QWidget *parent)
-             :KDialog( parent ),d(new KOpenWithDialogPrivate)
+    : KDialog(parent), d(new KOpenWithDialogPrivate(this))
 {
   setObjectName( QLatin1String( "openwith" ) );
   setModal( true );
@@ -348,14 +503,15 @@ KOpenWithDialog::KOpenWithDialog( const QString &mimeType, const QString& value,
   QString text = i18n("<qt>Select the program for the file type: <b>%1</b>. "
                       "If the program is not listed, enter the name or click "
                       "the browse button.</qt>", mimeType);
-  qMimeType = mimeType;
-  init( text, value );
-  if (remember)
-      remember->hide();
+    d->qMimeType = mimeType;
+    d->init(text, value);
+    if (d->remember) {
+        d->remember->hide();
+    }
 }
 
 KOpenWithDialog::KOpenWithDialog( QWidget *parent)
-             :KDialog( parent ),d(new KOpenWithDialogPrivate)
+    : KDialog(parent), d(new KOpenWithDialogPrivate(this))
 {
   setObjectName( QLatin1String( "openwith" ) );
   setModal( true );
@@ -363,47 +519,45 @@ KOpenWithDialog::KOpenWithDialog( QWidget *parent)
   QString text = i18n("<qt>Select a program. "
                       "If the program is not listed, enter the name or click "
                       "the browse button.</qt>");
-  qMimeType.clear();
-  init( text, QString() );
+    d->qMimeType.clear();
+    d->init(text, QString());
 }
 
-void KOpenWithDialog::setMimeType( const KUrl::List& _urls )
+void KOpenWithDialogPrivate::setMimeType(const KUrl::List &_urls)
 {
   if ( _urls.count() == 1 )
   {
     qMimeType = KMimeType::findByUrl( _urls.first())->name();
-    if (qMimeType == QString::fromLatin1("application/octet-stream"))
+    if (qMimeType == QLatin1String("application/octet-stream"))
       qMimeType.clear();
   }
   else
       qMimeType.clear();
 }
 
-void KOpenWithDialog::init( const QString& _text, const QString& _value )
+void KOpenWithDialogPrivate::init(const QString &_text, const QString &_value)
 {
-  bool bReadOnly = kapp && !KAuthorized::authorize("shell_access");
+  bool bReadOnly = !KAuthorized::authorize("shell_access");
   m_terminaldirty = false;
-  m_pTree = 0L;
+    view = 0;
   m_pService = 0L;
-  d->curService = 0L;
+    curService = 0L;
 
-  setButtons( Ok | Cancel );
+    q->setButtons(KDialog::Ok | KDialog::Cancel);
 
-
-  QWidget *mainWidget = new QWidget( this );
-  setMainWidget( mainWidget );
+    QWidget *mainWidget = q->mainWidget();
 
   QBoxLayout *topLayout = new QVBoxLayout( mainWidget );
-  topLayout->setMargin( KDialog::marginHint() );
+  topLayout->setMargin(0);
   topLayout->setSpacing( KDialog::spacingHint() );
-  label = new QLabel( _text, this );
+    label = new QLabel(_text, q);
   label->setWordWrap(true);
   topLayout->addWidget(label);
 
   if (!bReadOnly)
   {
     // init the history combo and insert it into the URL-Requester
-    KHistoryCombo *combo = new KHistoryCombo();
+    KHistoryComboBox *combo = new KHistoryComboBox();
     KLineEdit *lineEdit = new KLineEdit();
     lineEdit->setClearButtonShown(true);
     combo->setLineEdit(lineEdit);
@@ -447,24 +601,25 @@ void KOpenWithDialog::init( const QString& _text, const QString& _value )
     edit->comboBox()->setAutoDeleteCompletionObject( true );
   }
 
-  connect ( edit, SIGNAL(returnPressed()), SLOT(slotOK()) );
-  connect ( this, SIGNAL(okClicked()),SLOT(slotOK()));
-  connect ( edit, SIGNAL(textChanged(const QString&)), SLOT(slotTextChanged()) );
+    QObject::connect(edit, SIGNAL(returnPressed()), q, SLOT(_k_slotOK()));
+    QObject::connect(q, SIGNAL(okClicked()), q, SLOT(_k_slotOK()));
+    QObject::connect(edit, SIGNAL(textChanged(QString)), q, SLOT(slotTextChanged()));
 
-  m_pTree = new KApplicationTree( mainWidget );
-  topLayout->addWidget(m_pTree);
+    view = new KApplicationView(mainWidget);
+    view->setModel(new KApplicationModel(view));
+    topLayout->addWidget(view);
 
-  connect( m_pTree, SIGNAL( selected( const QString&, const QString& ) ),
-           SLOT( slotSelected( const QString&, const QString& ) ) );
-  connect( m_pTree, SIGNAL( highlighted( const QString&, const QString& ) ),
-           SLOT( slotHighlighted( const QString&, const QString& ) ) );
-  connect( m_pTree, SIGNAL( doubleClicked(Q3ListViewItem*) ),
-           SLOT( slotDbClick() ) );
+    QObject::connect(view, SIGNAL(selected(QString, QString)),
+                     q, SLOT(slotSelected(QString, QString)));
+    QObject::connect(view, SIGNAL(highlighted(QString, QString)),
+                     q, SLOT(slotHighlighted(QString, QString)));
+    QObject::connect(view, SIGNAL(doubleClicked(QModelIndex)),
+                     q, SLOT(_k_slotDbClick()));
 
   terminal = new QCheckBox( i18n("Run in &terminal"), mainWidget );
   if (bReadOnly)
      terminal->hide();
-  connect(terminal, SIGNAL(toggled(bool)), SLOT(slotTerminalToggled(bool)));
+    QObject::connect(terminal, SIGNAL(toggled(bool)), q, SLOT(slotTerminalToggled(bool)));
 
   topLayout->addWidget(terminal);
 
@@ -503,7 +658,7 @@ void KOpenWithDialog::init( const QString& _text, const QString& _value )
   // Probably due to the resizeEvent handler using width().
   //resize( minimumWidth(), sizeHint().height() );
   edit->setFocus();
-  slotTextChanged();
+    q->slotTextChanged();
 }
 
 
@@ -519,9 +674,9 @@ KOpenWithDialog::~KOpenWithDialog()
 
 void KOpenWithDialog::slotSelected( const QString& /*_name*/, const QString& _exec )
 {
-    kDebug(250)<<"KOpenWithDialog::slotSelected"<<endl;
+    kDebug(250)<<"KOpenWithDialog::slotSelected";
     KService::Ptr pService = d->curService;
-    edit->setUrl( KUrl(_exec) ); // calls slotTextChanged :(
+    d->edit->setUrl(KUrl(_exec)); // calls slotTextChanged :(
     d->curService = pService;
 }
 
@@ -530,16 +685,16 @@ void KOpenWithDialog::slotSelected( const QString& /*_name*/, const QString& _ex
 
 void KOpenWithDialog::slotHighlighted( const QString& _name, const QString& )
 {
-    kDebug(250)<<"KOpenWithDialog::slotHighlighted"<<endl;
-    qName = _name;
-    d->curService = KService::serviceByName( qName );
-    if (!m_terminaldirty)
+    kDebug(250)<<"KOpenWithDialog::slotHighlighted";
+    d->qName = _name;
+    d->curService = KService::serviceByName(d->qName);
+    if (!d->m_terminaldirty)
     {
         // ### indicate that default value was restored
-        terminal->setChecked(d->curService->terminal());
+        d->terminal->setChecked(d->curService->terminal());
         QString terminalOptions = d->curService->terminalOptions();
-        nocloseonexit->setChecked( (terminalOptions.contains( "--noclose" ) > 0) );
-        m_terminaldirty = false; // slotTerminalToggled changed it
+        d->nocloseonexit->setChecked((terminalOptions.contains(QLatin1String("--noclose")) > 0));
+        d->m_terminaldirty = false; // slotTerminalToggled changed it
     }
 }
 
@@ -547,10 +702,10 @@ void KOpenWithDialog::slotHighlighted( const QString& _name, const QString& )
 
 void KOpenWithDialog::slotTextChanged()
 {
-    kDebug(250)<<"KOpenWithDialog::slotTextChanged"<<endl;
+    kDebug(250)<<"KOpenWithDialog::slotTextChanged";
     // Forget about the service
     d->curService = 0L;
-    enableButton( Ok, !edit->url().isEmpty());
+    enableButton(Ok, !d->edit->url().isEmpty());
 }
 
 // ----------------------------------------------------------------------
@@ -558,16 +713,19 @@ void KOpenWithDialog::slotTextChanged()
 void KOpenWithDialog::slotTerminalToggled(bool)
 {
     // ### indicate that default value was overridden
-    m_terminaldirty = true;
-    nocloseonexit->setDisabled( ! terminal->isChecked() );
+    d->m_terminaldirty = true;
+    d->nocloseonexit->setDisabled(!d->terminal->isChecked());
 }
 
 // ----------------------------------------------------------------------
 
-void KOpenWithDialog::slotDbClick()
+void KOpenWithDialogPrivate::_k_slotDbClick()
 {
-   if (m_pTree->isDirSel() ) return; // check if a directory is selected
-   slotOK();
+    // check if a directory is selected
+    if (view->isDirSel()) {
+        return;
+    }
+    _k_slotOK();
 }
 
 void KOpenWithDialog::setSaveNewApplications(bool b)
@@ -575,7 +733,7 @@ void KOpenWithDialog::setSaveNewApplications(bool b)
   d->saveNewApps = b;
 }
 
-void KOpenWithDialog::slotOK()
+void KOpenWithDialogPrivate::_k_slotOK()
 {
   QString typedExec(edit->url().pathOrUrl());
   QString fullExec(typedExec);
@@ -583,7 +741,7 @@ void KOpenWithDialog::slotOK()
   QString serviceName;
   QString initialServiceName;
   QString preferredTerminal;
-  m_pService = d->curService;
+  m_pService = curService;
   if (!m_pService) {
     // No service selected - check the command line
 
@@ -595,12 +753,12 @@ void KOpenWithDialog::slotOK()
       return;
     }
     initialServiceName = serviceName;
-    kDebug(250) << "initialServiceName=" << initialServiceName << endl;
+    kDebug(250) << "initialServiceName=" << initialServiceName;
     int i = 1; // We have app, app-2, app-3... Looks better for the user.
     bool ok = false;
     // Check if there's already a service by that name, with the same Exec line
     do {
-        kDebug(250) << "looking for service " << serviceName << endl;
+        kDebug(250) << "looking for service " << serviceName;
         KService::Ptr serv = KService::serviceByDesktopName( serviceName );
         ok = !serv; // ok if no such service yet
         // also ok if we find the exact same service (well, "kwrite" == "kwrite %U"
@@ -619,7 +777,7 @@ void KOpenWithDialog::slotOK()
             {
                 ok = true;
                 m_pService = serv;
-                kDebug(250) << k_funcinfo << "OK, found identical service: " << serv->desktopEntryPath() << endl;
+                kDebug(250) << "OK, found identical service: " << serv->desktopEntryPath();
             }
         }
         if (!ok) // service was found, but it was different -> keep looking
@@ -648,7 +806,7 @@ void KOpenWithDialog::slotOK()
       m_command += QString::fromLatin1(" --noclose");
     m_command += QString::fromLatin1(" -e ");
     m_command += edit->url().pathOrUrl();
-    kDebug(250) << "Setting m_command to " << m_command << endl;
+    kDebug(250) << "Setting m_command to " << m_command;
   }
   if ( m_pService && terminal->isChecked() != m_pService->terminal() )
       m_pService = 0L; // It's not exactly this service we're running
@@ -657,11 +815,11 @@ void KOpenWithDialog::slotOK()
 
   if ( !bRemember && m_pService)
   {
-    accept();
+        q->accept();
     return;
   }
 
-  if (!bRemember && !d->saveNewApps)
+    if (!bRemember && !saveNewApps)
   {
     // Create temp service
     m_pService = new KService(initialServiceName, fullExec, QString());
@@ -672,7 +830,7 @@ void KOpenWithDialog::slotOK()
       if (preferredTerminal == "konsole" && nocloseonexit->isChecked())
          m_pService->setTerminalOptions("--noclose");
     }
-    accept();
+        q->accept();
     return;
   }
 
@@ -688,17 +846,18 @@ void KOpenWithDialog::slotOK()
     oldPath = m_pService->desktopEntryPath();
     newPath = m_pService->locateLocal();
     menuId = m_pService->menuId();
-    kDebug(250) << "Updating exitsing service " << m_pService->desktopEntryPath() << " ( " << newPath << " ) " << endl;
+    kDebug(250) << "Updating exitsing service " << m_pService->desktopEntryPath() << " ( " << newPath << " ) ";
   }
   else
   {
     newPath = KService::newServicePath(false /* hidden */, serviceName, &menuId);
-    kDebug(250) << "Creating new service " << serviceName << " ( " << newPath << " ) " << endl;
+    kDebug(250) << "Creating new service " << serviceName << " ( " << newPath << " ) ";
   }
 
   int maxPreference = 1;
   if (!qMimeType.isEmpty())
   {
+    // Find max highest preference from either initial preference or from profile
     const KServiceOfferList offerList = KMimeTypeTrader::self()->weightedOffers( qMimeType );
     if (!offerList.isEmpty())
       maxPreference = offerList.first().preference();
@@ -707,85 +866,91 @@ void KOpenWithDialog::slotOK()
   KDesktopFile *desktop = 0;
   if (!oldPath.isEmpty() && (oldPath != newPath))
   {
-     KDesktopFile orig(oldPath, true);
-     desktop = orig.copyTo(newPath);
+     KDesktopFile orig( oldPath );
+     desktop = orig.copyTo( newPath );
   }
   else
   {
      desktop = new KDesktopFile(newPath);
   }
-  desktop->writeEntry("Type", QString::fromLatin1("Application"));
-  desktop->writeEntry("Name", initialServiceName);
-  desktop->writePathEntry("Exec", fullExec);
+  KConfigGroup cg = desktop->desktopGroup();
+  cg.writeEntry("Type", QString::fromLatin1("Application"));
+  cg.writeEntry("Name", initialServiceName);
+  cg.writePathEntry("Exec", fullExec);
   if (terminal->isChecked())
   {
-    desktop->writeEntry("Terminal", true);
+    cg.writeEntry("Terminal", true);
     // only add --noclose when we are sure it is konsole we're using
     if (preferredTerminal == "konsole" && nocloseonexit->isChecked())
-      desktop->writeEntry("TerminalOptions", "--noclose");
+      cg.writeEntry("TerminalOptions", "--noclose");
   }
   else
   {
-    desktop->writeEntry("Terminal", false);
+    cg.writeEntry("Terminal", false);
   }
-  desktop->writeEntry("InitialPreference", maxPreference + 1);
+  cg.writeEntry("InitialPreference", maxPreference + 1);
 
 
-  if (bRemember || d->saveNewApps)
+    if (bRemember || saveNewApps)
   {
-    QStringList mimeList = desktop->readEntry("MimeType", QStringList(), ';');
+    QStringList mimeList = cg.readEntry("MimeType", QStringList(), ';');
     if (!qMimeType.isEmpty() && !mimeList.contains(qMimeType))
       mimeList.append(qMimeType);
-    desktop->writeEntry("MimeType", mimeList, ';');
+    cg.writeEntry("MimeType", mimeList, ';');
 
     if ( !qMimeType.isEmpty() )
     {
       // Also make sure the "auto embed" setting for this mimetype is off
       KDesktopFile mimeDesktop( KStandardDirs::locateLocal( "mime", qMimeType + ".desktop" ) );
-      mimeDesktop.writeEntry( "X-KDE-AutoEmbed", false );
+      mimeDesktop.desktopGroup().writeEntry( "X-KDE-AutoEmbed", false );
       mimeDesktop.sync();
     }
   }
 
   // write it all out to the file
-  desktop->sync();
+  cg.sync();
   delete desktop;
 
-  KBuildSycocaProgressDialog::rebuildKSycoca(this);
+    KBuildSycocaProgressDialog::rebuildKSycoca(q);
 
   m_pService = KService::serviceByMenuId( menuId );
 
   Q_ASSERT( m_pService );
 
-  accept();
+    q->accept();
 }
 
 QString KOpenWithDialog::text() const
 {
-    if (!m_command.isEmpty())
-        return m_command;
+    if (!d->m_command.isEmpty())
+        return d->m_command;
     else
-        return edit->url().url();
+        return d->edit->url().url();
 }
 
 void KOpenWithDialog::hideNoCloseOnExit()
 {
     // uncheck the checkbox because the value could be used when "Run in Terminal" is selected
-    nocloseonexit->setChecked( false );
-    nocloseonexit->hide();
+    d->nocloseonexit->setChecked(false);
+    d->nocloseonexit->hide();
 }
 
 void KOpenWithDialog::hideRunInTerminal()
 {
-    terminal->hide();
+    d->terminal->hide();
     hideNoCloseOnExit();
 }
 
+KService::Ptr KOpenWithDialog::service() const
+{
+    return d->m_pService;
+}
+
 void KOpenWithDialog::accept()
 {
-    KHistoryCombo *combo = static_cast<KHistoryCombo*>( edit->comboBox() );
+    KHistoryComboBox *combo = static_cast<KHistoryComboBox*>(d->edit->comboBox());
     if ( combo ) {
-        combo->addToHistory( edit->url().url() );
+        combo->addToHistory(d->edit->url().url());
 
         KConfigGroup cg( KGlobal::config(), QString::fromLatin1("Open-with settings") );
         cg.writeEntry( QString::fromLatin1("History"), combo->historyItems() );
