@@ -25,11 +25,10 @@
  * display a properties dialog.
  */
 
-#ifndef __propsdialog_h
-#define __propsdialog_h
+#ifndef KPROPERTIESDIALOG_H
+#define KPROPERTIESDIALOG_H
 
-#include <qstring.h>
-#include <q3ptrlist.h>
+#include <QtCore/QString>
 
 #include <kdemacros.h>
 #include <kurl.h>
@@ -93,8 +92,8 @@ public:
    * @param parent is the parent of the dialog widget.
    * @param name is the internal name.
    */
-  KPropertiesDialog( KFileItem * item,
-                     QWidget* parent = 0 );
+  explicit KPropertiesDialog( KFileItem * item,
+                              QWidget* parent = 0 );
 
   /**
    * \overload
@@ -108,8 +107,8 @@ public:
    * @param parent is the parent of the dialog widget.
    * @param name is the internal name.
    */
-  KPropertiesDialog( const KFileItemList& _items,
-                     QWidget *parent = 0 );
+  explicit KPropertiesDialog( const KFileItemList& _items,
+                              QWidget *parent = 0 );
 
   /**
    * Brings up a Properties dialog. Convenience constructor for
@@ -127,8 +126,8 @@ public:
    * For local files with a known mimetype, simply create a KFileItem and pass
    * it to the other constructor.
    */
-  KPropertiesDialog( const KUrl& _url,
-                     QWidget* parent = 0 );
+  explicit KPropertiesDialog( const KUrl& _url,
+                              QWidget* parent = 0 );
 
   /**
    * Creates a properties dialog for a new .desktop file (whose name
@@ -155,8 +154,8 @@ public:
    * @param name is the internal name.
    * @param modal tells the dialog whether it should be modal.
    */
-  KPropertiesDialog(const QString& title,
-                    QWidget* parent = 0);
+  explicit KPropertiesDialog(const QString& title,
+                             QWidget* parent = 0);
 
   /**
    * Cleans up the properties dialog and frees any associated resources,
@@ -221,7 +220,7 @@ public:
    *
    * @return a parsed URL.
    */
-  const KUrl& kurl() const { return m_singleUrl; }
+  KUrl kurl() const;
 
   /**
    * @return the file item for which the dialog is shown
@@ -230,12 +229,12 @@ public:
    * This means that you should use this only if you are sure the dialog is used
    * for a single item. Otherwise, you probably want items() instead.
    */
-  KFileItem *item() { return m_items.first(); }
+  KFileItem *item();
 
   /**
    * @return the items for which the dialog is shown
    */
-  KFileItemList items() const { return m_items; }
+  KFileItemList items() const;
 
   /**
    * If the dialog is being built from a template, this method
@@ -244,7 +243,7 @@ public:
    *
    * @return the current directory or QString()
    */
-  const KUrl& currentDir() const { return m_currentDir; }
+  KUrl currentDir() const;
 
   /**
    * If the dialog is being built from a template, this method
@@ -252,7 +251,7 @@ public:
    * See the template form of the constructor.
    * @return the default name or QString()
    */
-  const QString& defaultName() const { return m_defaultName; }
+  QString defaultName() const;
 
   /**
    * Updates the item URL (either called by rename or because
@@ -335,46 +334,13 @@ Q_SIGNALS:
    */
   void saveAs(const KUrl &oldUrl, KUrl &newUrl);
 
-private:
-
-  /**
-   * Common initialization for all constructors
-   */
-  void init();
-
-  /**
-   * Inserts all pages in the dialog.
-   */
-  void insertPages();
-
-  /**
-   * The URL of the props dialog (when shown for only one file)
-   */
-  KUrl m_singleUrl;
-
-  /**
-   * List of items this props dialog is shown for
-   */
-  KFileItemList m_items;
-
-  /**
-   * For templates
-   */
-  QString m_defaultName;
-  KUrl m_currentDir;
-
-  /**
-   * List of all plugins inserted ( first one first )
-   */
-  Q3PtrList<KPropertiesDialogPlugin> m_pageList;
-
-private Q_SLOTS:
-  void slotStatResult( KJob * ); // No longer used
 Q_SIGNALS:
   void leaveModality();
 private:
   class KPropertiesDialogPrivate;
   KPropertiesDialogPrivate* const d;
+
+    Q_DISABLE_COPY(KPropertiesDialog)
 };
 
 /**
@@ -478,21 +444,18 @@ public:
 
 protected Q_SLOTS:
   void slotEditFileType();
-  void slotCopyFinished( KIO::Job * );
+  void slotCopyFinished( KJob * );
   void slotFileRenamed( KIO::Job *, const KUrl &, const KUrl & );
   void slotDirSizeUpdate();
   void slotDirSizeFinished( KJob * );
-  void slotFoundMountPoint( const QString& mp, unsigned long kBSize,
-			    unsigned long kBUsed, unsigned long kBAvail );
+  void slotFoundMountPoint( const QString& mp, quint64 kBSize,
+                            quint64 kBUsed, quint64 kBAvail );
   void slotSizeStop();
   void slotSizeDetermine();
 
 Q_SIGNALS:
   void leaveModality();
 private Q_SLOTS:
-  // workaround for compiler bug
-  void slotFoundMountPoint( const unsigned long& kBSize, const unsigned long&
-			  kBUsed, const unsigned long& kBAvail, const QString& mp );
   void nameFileChanged(const QString &text );
   void slotIconChanged();
 
@@ -500,21 +463,6 @@ private:
   void determineRelativePath( const QString & path );
   void applyIconChanges();
 
-  QWidget *iconArea;
-  QWidget *nameArea;
-
-  QLabel *m_sizeLabel;
-  QPushButton *m_sizeDetermineButton;
-  QPushButton *m_sizeStopButton;
-
-  QString m_sRelativePath;
-  bool m_bFromTemplate;
-
-  /**
-   * The initial filename
-   */
-  QString oldName;
-
   class KFilePropsPluginPrivate;
   KFilePropsPluginPrivate* const d;
 };
@@ -578,27 +526,6 @@ private:
   static const mode_t standardPermissions[4];
   static const char *permissionsTexts[4][4];
 
-  // unused, for binary compatibility!
-  QCheckBox *permBox[3][4];
-
-  QComboBox *grpCombo;
-
-  KLineEdit *usrEdit, *grpEdit;
-
-  /**
-   * Old permissions
-   */
-  mode_t permissions;
-  /**
-   * Old group
-   */
-  QString strGroup;
-  /**
-   * Old owner
-   */
-  QString strOwner;
-
-  // unused, for compatibility
   static mode_t fperm[3][4];
 
   class KFilePermissionsPropsPluginPrivate;
@@ -628,15 +555,6 @@ public:
 
   static bool supports( const KFileItemList& _items );
 
-private:
-  KUrlRequester *URLEdit;
-  KIconButton *iconBox;
-
-  QString URLStr;
-  QString iconStr;
-
-  QPixmap pixmap;
-  QString pixmapFile;
 private:
   class KUrlPropsPluginPrivate;
   KUrlPropsPluginPrivate* const d;
@@ -664,13 +582,6 @@ public:
 
 private:
 
-  QLineEdit *commentEdit;
-  QLineEdit *patternEdit;
-  QLineEdit *mimeEdit;
-  QString m_sMimeStr;
-
-  QCheckBox * cbAutoEmbed;
-
   class KBindingPropsPluginPrivate;
   KBindingPropsPluginPrivate* const d;
 };
@@ -693,30 +604,13 @@ public:
 private Q_SLOTS:
   void slotActivated( int );
   void slotDeviceChanged();
-  void slotFoundMountPoint( const unsigned long& kBSize,
-                            const unsigned long& /*kBUsed*/,
-                            const unsigned long& kBAvail,
-                            const QString& );
+  void slotFoundMountPoint( const QString& mp, quint64 kBSize,
+                            quint64 kBUsed, quint64 kBAvail );
 
 private:
   void updateInfo();
 
 private:
-  QComboBox* device;
-  QLabel* mountpoint;
-  QCheckBox* readonly;
-  void* unused;
-  //KIconButton* mounted;
-  KIconButton* unmounted;
-
-  QStringList m_devicelist;
-  int indexDevice;
-  int indexMountPoint;
-  int indexFSType;
-
-  QPixmap pixmap;
-  QString pixmapFile;
-
   class KDevicePropsPluginPrivate;
   KDevicePropsPluginPrivate* const d;
 };
@@ -755,21 +649,8 @@ private:
   void checkCommandChanged();
 
 private:
-  Ui_KPropertiesDesktopBase* w;
-  QWidget *m_frame;
-
-  QString m_origCommandStr;
-  QString m_terminalOptionStr;
-  QString m_suidUserStr;
-  QString m_dbusStartusType;
-  bool m_terminalBool;
-  bool m_terminalCloseBool;
-  bool m_suidBool;
-  bool m_startupBool;
-  bool m_systrayBool;
-
   class KDesktopPropsPluginPrivate;
-  KDesktopPropsPluginPrivate* d;
+  KDesktopPropsPluginPrivate * const d;
 };
 
 #endif
