@@ -26,18 +26,18 @@
  *
  */
 #include <krecentdocument.h>
-#include <ksimpleconfig.h>
+#include <kconfig.h>
 #include <kstandarddirs.h>
 #include <kapplication.h>
 #include <kurl.h>
 #include <kdebug.h>
 #include <kmimetype.h>
 #include <kdesktopfile.h>
-#include <qdir.h>
-#include <qfileinfo.h>
-#include <qtextstream.h>
-#include <qstringlist.h>
-#include <qregexp.h>
+#include <QtCore/QDir>
+#include <QtCore/QFileInfo>
+#include <QtCore/QTextIStream>
+#include <QtCore/QMutableStringListIterator>
+#include <QtCore/QRegExp>
 
 #include <sys/types.h>
 #include <utime.h>
@@ -62,7 +62,7 @@ QStringList KRecentDocument::recentDocuments()
 
     for (QStringList::ConstIterator it = list.begin(); it != list.end(); ++it) {
        QString pathDesktop = d.absoluteFilePath( *it );
-       KDesktopFile tmpDesktopFile( pathDesktop, false);
+       KDesktopFile tmpDesktopFile( pathDesktop );
        KUrl urlDesktopFile(tmpDesktopFile.readUrl());
        if( urlDesktopFile.isLocalFile() && !QFile(urlDesktopFile.path()).exists())
            d.remove(pathDesktop);
@@ -81,20 +81,17 @@ void KRecentDocument::add(const KUrl& url)
 
 void KRecentDocument::add(const KUrl& url, const QString& desktopEntryName)
 {
-	if ( url.isLocalFile() && !KGlobal::dirs()->relativeLocation("tmp", url.path()).startsWith("/"))
+	if ( url.isLocalFile() && !KGlobal::dirs()->relativeLocation("tmp", url.path()).startsWith('/'))
 		return;
 
     QString openStr = url.url();
     openStr.replace( QRegExp("\\$"), "$$" ); // Desktop files with type "Link" are $-variable expanded
 
-    kDebug(250) << "KRecentDocument::add for " << openStr << endl;
-    KSharedConfig::Ptr config = KGlobal::config();
-    QString oldGrp = config->group();
-    config->setGroup(QLatin1String("RecentDocuments"));
-    bool useRecent = config->readEntry(QLatin1String("UseRecent"), true);
-    int maxEntries = config->readEntry(QLatin1String("MaxEntries"), 10);
+    kDebug(250) << "KRecentDocument::add for " << openStr;
+    KConfigGroup config = KGlobal::config()->group(QByteArray("RecentDocuments"));
+    bool useRecent = config.readEntry(QLatin1String("UseRecent"), true);
+    int maxEntries = config.readEntry(QLatin1String("MaxEntries"), 10);
 
-    config->setGroup(oldGrp);
     if(!useRecent)
         return;
 
@@ -108,11 +105,8 @@ void KRecentDocument::add(const KUrl& url, const QString& desktopEntryName)
     // check for duplicates
     while(QFile::exists(ddesktop)){
         // see if it points to the same file and application
-        KSimpleConfig tmp(ddesktop);
-        tmp.setDesktopGroup();
-        if(tmp.readEntry("X-KDE-LastOpenedWith")
-	   == desktopEntryName)
-	{
+        KDesktopFile tmp(ddesktop);
+        if ( tmp.desktopGroup().readEntry("X-KDE-LastOpenedWith") == desktopEntryName ) {
             utime(QFile::encodeName(ddesktop), NULL);
             return;
         }
@@ -137,8 +131,8 @@ void KRecentDocument::add(const KUrl& url, const QString& desktopEntryName)
     }
 
     // create the applnk
-    KSimpleConfig conf(ddesktop);
-    conf.setDesktopGroup();
+    KDesktopFile configFile(ddesktop);
+    KConfigGroup conf = configFile.desktopGroup();
     conf.writeEntry( "Type", QString::fromLatin1("Link") );
     conf.writePathEntry( "URL", openStr );
     // If you change the line below, change the test in the above loop
