@@ -16,7 +16,9 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include <qdir.h>
+#include "kurlcombobox.h"
+
+#include <QtCore/QDir>
 
 #include <kdebug.h>
 #include <kglobal.h>
@@ -24,8 +26,6 @@
 #include <klocale.h>
 #include <kmimetype.h>
 
-#include <kurlcombobox.h>
-
 class KUrlComboBox::KUrlComboBoxPrivate
 {
 public:
@@ -34,6 +34,10 @@ public:
     {}
 
     KIcon dirIcon;
+    bool urlAdded;
+    int myMaximum;
+    Mode myMode; // can be used as parameter to KUR::path( int ) or url( int )
+                 // to specify if we want a trailing slash or not
 };
 
 
@@ -61,15 +65,14 @@ KUrlComboBox::~KUrlComboBox()
 
 void KUrlComboBox::init( Mode mode )
 {
-
-    myMode    = mode;
-    urlAdded  = false;
-    myMaximum = 10; // default
+    d->myMode = mode;
+    d->urlAdded = false;
+    d->myMaximum = 10; // default
     setInsertPolicy( NoInsert );
     setTrapReturnKey( true );
     setSizePolicy( QSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed ));
 
-    opendirIcon = KIcon(QLatin1String("folder_open"));
+    opendirIcon = KIcon(QLatin1String("folder-open"));
 
     connect( this, SIGNAL( activated( int )), SLOT( slotActivated( int )));
 }
@@ -77,7 +80,7 @@ void KUrlComboBox::init( Mode mode )
 
 QStringList KUrlComboBox::urls() const
 {
-    kDebug(250) << "::urls()" << endl;
+    kDebug(250) << "::urls()";
     //static const QString &fileProt = KGlobal::staticQString("file:");
     QStringList list;
     QString url;
@@ -109,7 +112,7 @@ void KUrlComboBox::addDefaultUrl( const KUrl& url, const QIcon& icon,
     item->icon = icon;
     if ( text.isEmpty() ) {
         KUrl::AdjustPathOption mode = KUrl::LeaveTrailingSlash;
-        if (myMode == Directories)
+        if (d->myMode == Directories)
           mode = KUrl::AddTrailingSlash;
         else
           mode = KUrl::RemoveTrailingSlash;
@@ -137,38 +140,40 @@ void KUrlComboBox::setDefaults()
     }
 }
 
-void KUrlComboBox::setUrls( QStringList urls )
+void KUrlComboBox::setUrls( const QStringList &urls )
 {
     setUrls( urls, RemoveBottom );
 }
 
-void KUrlComboBox::setUrls( QStringList urls, OverLoadResolving remove )
+void KUrlComboBox::setUrls( const QStringList &_urls, OverLoadResolving remove )
 {
     setDefaults();
     qDeleteAll( itemList );
     itemList.clear();
+    d->urlAdded = false;
 
-    if ( urls.isEmpty() )
+    if ( _urls.isEmpty() )
         return;
 
-    QStringList::Iterator it = urls.begin();
+    QStringList urls;
+    QStringList::ConstIterator it = _urls.constBegin();
 
     // kill duplicates
-    while ( it != urls.end() ) {
-        while ( urls.count( *it ) > 1 ) {
-            it = urls.erase( it );
-            continue;
-        }
+    while ( it != _urls.constEnd() ) {
+        if ( !urls.contains( *it ) )
+            urls += *it;
         ++it;
     }
 
     // limit to myMaximum items
     /* Note: overload is an (old) C++ keyword, some compilers (KCC) choke
        on that, so call it Overload (capital 'O').  (matz) */
-    int Overload = urls.count() - myMaximum + defaultList.count();
+    int Overload = urls.count() - d->myMaximum + defaultList.count();
     while ( Overload > 0 ) {
-        if (remove == RemoveBottom) urls.removeLast();
-	else urls.removeFirst();
+        if (remove == RemoveBottom)
+            urls.removeLast();
+        else
+            urls.removeFirst();
         Overload--;
     }
 
@@ -196,7 +201,7 @@ void KUrlComboBox::setUrls( QStringList urls, OverLoadResolving remove )
         if ( u.isLocalFile() )
         {
           KUrl::AdjustPathOption mode = KUrl::LeaveTrailingSlash;
-          if (myMode == Directories)
+          if (d->myMode == Directories)
               mode = KUrl::AddTrailingSlash;
           else
               mode = KUrl::RemoveTrailingSlash;
@@ -217,19 +222,21 @@ void KUrlComboBox::setUrl( const KUrl& url )
     if ( url.isEmpty() )
         return;
 
-    blockSignals( true );
+    bool blocked = blockSignals( true );
 
     // check for duplicates
     QMap<int,const KUrlComboItem*>::ConstIterator mit = itemMapper.begin();
     QString urlToInsert = url.url(KUrl::RemoveTrailingSlash);
     while ( mit != itemMapper.end() ) {
+      Q_ASSERT( mit.value() );
+
       if ( urlToInsert == mit.value()->url.url(KUrl::RemoveTrailingSlash) ) {
             setCurrentIndex( mit.key() );
 
-            if ( myMode == Directories )
+            if (d->myMode == Directories)
                 updateItem( mit.value(), mit.key(), opendirIcon );
 
-            blockSignals( false );
+            blockSignals( blocked );
             return;
         }
         ++mit;
@@ -238,9 +245,10 @@ void KUrlComboBox::setUrl( const KUrl& url )
     // not in the combo yet -> create a new item and insert it
 
     // first remove the old item
-    if ( urlAdded ) {
+    if (d->urlAdded) {
+        Q_ASSERT(!itemList.isEmpty());
         itemList.removeLast();
-        urlAdded = false;
+        d->urlAdded = false;
     }
 
     setDefaults();
@@ -250,7 +258,7 @@ void KUrlComboBox::setUrl( const KUrl& url )
         insertUrlItem( it.next() );
 
     KUrl::AdjustPathOption mode = KUrl::LeaveTrailingSlash;
-    if (myMode == Directories)
+    if (d->myMode == Directories)
       mode = KUrl::AddTrailingSlash;
     else
       mode = KUrl::RemoveTrailingSlash;
@@ -261,27 +269,29 @@ void KUrlComboBox::setUrl( const KUrl& url )
       item->text = url.path( mode );
     else
       item->text = url.prettyUrl( mode );
-     kDebug(250) << "setURL: text=" << item->text << endl;
+     kDebug(250) << "setURL: text=" << item->text;
 
     int id = count();
     QString text = /*isEditable() ? item->url.prettyUrl( (KUrl::AdjustPathOption)myMode ) : */ item->text;
 
-    if ( myMode == Directories )
+    if (d->myMode == Directories)
         KComboBox::insertItem( id,opendirIcon, text);
     else
         KComboBox::insertItem( id,item->icon, text);
+    
     itemMapper.insert( id, item );
     itemList.append( item );
 
     setCurrentIndex( id );
-    urlAdded = true;
-    blockSignals( false );
+    Q_ASSERT(!itemList.isEmpty());
+    d->urlAdded = true;
+    blockSignals( blocked );
 }
 
 
 void KUrlComboBox::slotActivated( int index )
 {
-    const KUrlComboItem *item = itemMapper[ index ];
+    const KUrlComboItem *item = itemMapper.value(index);
 
     if ( item ) {
         setUrl( item->url );
@@ -292,7 +302,9 @@ void KUrlComboBox::slotActivated( int index )
 
 void KUrlComboBox::insertUrlItem( const KUrlComboItem *item )
 {
-// kDebug(250) << "insertURLItem " << item->text << endl;
+    Q_ASSERT( item );
+
+// kDebug(250) << "insertURLItem " << item->text;
     int id = count();
     KComboBox::insertItem(id, item->icon, item->text);
     itemMapper.insert( id, item );
@@ -301,15 +313,15 @@ void KUrlComboBox::insertUrlItem( const KUrlComboItem *item )
 
 void KUrlComboBox::setMaxItems( int max )
 {
-    myMaximum = max;
+    d->myMaximum = max;
 
-    if ( count() > myMaximum ) {
+    if (count() > d->myMaximum) {
         int oldCurrent = currentIndex();
 
         setDefaults();
 
         QListIterator<const KUrlComboItem*> it( itemList );
-        int Overload = itemList.count() - myMaximum + defaultList.count();
+        int Overload = itemList.count() - d->myMaximum + defaultList.count();
         for ( int i = 0; i <= Overload; i++ )
             it.next();
 
@@ -324,6 +336,10 @@ void KUrlComboBox::setMaxItems( int max )
     }
 }
 
+int KUrlComboBox::maxItems() const
+{
+    return d->myMaximum;
+}
 
 void KUrlComboBox::removeUrl( const KUrl& url, bool checkDefaultURLs )
 {
@@ -336,19 +352,19 @@ void KUrlComboBox::removeUrl( const KUrl& url, bool checkDefaultURLs )
         ++mit;
     }
 
-    blockSignals( true );
+    bool blocked = blockSignals( true );
     setDefaults();
     QListIterator<const KUrlComboItem*> it( itemList );
     while ( it.hasNext() ) {
         insertUrlItem( it.next() );
     }
-    blockSignals( false );
+    blockSignals( blocked );
 }
 
 
 QIcon KUrlComboBox::getIcon( const KUrl& url ) const
 {
-    if ( myMode == Directories )
+    if (d->myMode == Directories)
         return d->dirIcon;
     else
         return KIcon(KMimeType::iconNameForUrl(url, 0));
@@ -363,7 +379,7 @@ void KUrlComboBox::updateItem( const KUrlComboItem *item,
 
     if ( isEditable() ) {
         KUrl::AdjustPathOption mode = KUrl::LeaveTrailingSlash;
-        if (myMode == Directories)
+        if (d->myMode == Directories)
             mode = KUrl::AddTrailingSlash;
         else
             mode = KUrl::RemoveTrailingSlash;
