@@ -16,14 +16,15 @@
     Boston, MA 02110-1301, USA.
 */
 
-#ifndef KDIRCOMBOBOX_H
-#define KDIRCOMBOBOX_H
+#ifndef KURLCOMBOBOX_H
+#define KURLCOMBOBOX_H
+
+#include <kio/kio_export.h>
 
-#include <qevent.h>
 #include <QtCore/QList>
-#include <qmap.h>
-#include <qicon.h>
-#include <qstringlist.h>
+#include <QtCore/QMap>
+#include <QtCore/QStringList>
+#include <QtGui/QIcon>
 
 #include <kcombobox.h>
 #include <kurl.h>
@@ -72,7 +73,7 @@ public:
      * @li Both  Don't mess with anything, just show the url as given.
      * @param parent The parent object of this widget.
      */
-    KUrlComboBox( Mode mode, QWidget *parent=0);
+    explicit KUrlComboBox(Mode mode, QWidget *parent = 0);
     KUrlComboBox( Mode mode, bool rw, QWidget *parent=0);
     /**
      * Destructs the combo box.
@@ -100,7 +101,7 @@ public:
      * If the list of urls contains more items than maxItems, the first items
      * will be stripped.
      */
-    void setUrls( QStringList urls );
+    void setUrls( const QStringList &urls );
 
     /**
      * Inserts @p urls into the combobox below the "default urls" (see
@@ -109,7 +110,7 @@ public:
      * If the list of urls contains more items than maxItems, the @p remove
      * parameter determines whether the first or last items will be stripped.
      */
-    void setUrls( QStringList urls, OverLoadResolving remove );
+    void setUrls( const QStringList &urls, OverLoadResolving remove );
 
     /**
      * @returns a list of all urls currently handled. The list contains at most
@@ -133,7 +134,7 @@ public:
      * @returns the maximum of items the combobox handles.
      * @see setMaxItems
      */
-    int maxItems() const { return myMaximum; }
+    int maxItems() const;
 
     /**
      * Adds a url that will always be shown in the combobox, it can't be
@@ -177,11 +178,9 @@ Q_SIGNALS:
      */
     void urlActivated( const KUrl& url );
 
-
 protected Q_SLOTS:
     void slotActivated( int );
 
-
 protected:
     struct _KUrlComboItem {
 	QString text;
@@ -211,17 +210,12 @@ protected:
     QIcon opendirIcon;
     int firstItemIndex;
 
-
-private:
-    bool urlAdded;
-    int myMaximum;
-    Mode myMode; // can be used as parameter to KUR::path( int ) or url( int )
-                 // to specify if we want a trailing slash or not
-
 private:
     class KUrlComboBoxPrivate;
     KUrlComboBoxPrivate* const d;
+
+    Q_DISABLE_COPY(KUrlComboBox)
 };
 
 
-#endif // KDIRCOMBOBOX_H
+#endif // KURLCOMBOBOX_H
