@@ -19,7 +19,6 @@
 #include "kurlrequester.h"
 
 #include <kcombobox.h>
-#include <kdirselectdialog.h>
 #include <kfiledialog.h>
 #include <klineedit.h>
 #include <klocale.h>
@@ -87,8 +86,16 @@ public:
             }
             else
             {
-               combo->addItem( text );
-               combo->setCurrentIndex( combo->count()-1 );
+               int i = combo->findText( text );
+               if ( i == -1 )
+               {
+                  combo->addItem( text );
+                  combo->setCurrentIndex( combo->count()-1 );
+               }
+               else
+               {
+                  combo->setCurrentIndex( i );
+               }
             }
         }
         else
@@ -105,8 +112,13 @@ public:
         else
             sender = edit;
 
-        connect( sender, SIGNAL( textChanged( const QString& )),
-                 receiver, SIGNAL( textChanged( const QString& )));
+        if (combo )
+            connect( sender, SIGNAL( editTextChanged( const QString& )),
+                     receiver, SIGNAL( textChanged( const QString& )));
+        else
+            connect( sender, SIGNAL( textChanged( const QString& )),
+                     receiver, SIGNAL( textChanged( const QString& )));
+
         connect( sender, SIGNAL( returnPressed() ),
                  receiver, SIGNAL( returnPressed() ));
         connect( sender, SIGNAL( returnPressed( const QString& ) ),
@@ -138,11 +150,16 @@ public:
             return KUrl( txt );
     }
 
+    // slots
+    void _k_slotUpdateUrl();
+
     KLineEdit *edit;
     KComboBox *combo;
     KFile::Modes fileDialogMode;
     QString fileDialogFilter;
     KEditListBox::CustomEditor editor;
+    KUrlDragPushButton *myButton;
+    KFileDialog *myFileDialog;
 };
 
 
@@ -152,8 +169,11 @@ KUrlRequester::KUrlRequester( QWidget *editWidget, QWidget *parent)
 {
     // must have this as parent
     editWidget->setParent( this );
-    d->edit = qobject_cast<KLineEdit*>( editWidget );
     d->combo = qobject_cast<KComboBox*>( editWidget );
+    d->edit = qobject_cast<KLineEdit*>( editWidget );
+    if ( d->edit ) {
+        d->edit->setClearButtonShown( true );
+    }
 
     init();
 }
@@ -177,7 +197,7 @@ KUrlRequester::KUrlRequester( const KUrl& url, QWidget *parent)
 KUrlRequester::~KUrlRequester()
 {
     delete myCompletion;
-    delete myFileDialog;
+    delete d->myFileDialog;
     delete d;
 }
 
@@ -186,18 +206,20 @@ void KUrlRequester::init()
 {
     setMargin(0);
 
-    myFileDialog = 0L;
+    d->myFileDialog = 0L;
 
-    if ( !d->combo && !d->edit )
-        d->edit = new KLineEdit( this);
+    if ( !d->combo && !d->edit ) {
+        d->edit = new KLineEdit( this );
+        d->edit->setClearButtonShown( true );
+    }
 
-    myButton = new KUrlDragPushButton( this);
-    myButton->setIcon( KIcon(QLatin1String("fileopen")) );
+    d->myButton = new KUrlDragPushButton(this);
+    d->myButton->setIcon(KIcon(QLatin1String("document-open")));
     const int pixmapSize = style()->pixelMetric(QStyle::PM_SmallIconSize);
-    myButton->setFixedSize( pixmapSize+8, pixmapSize+8 );
-    myButton->setToolTip(i18n("Open file dialog"));
+    d->myButton->setFixedSize(pixmapSize + 8, pixmapSize + 8);
+    d->myButton->setToolTip(i18n("Open file dialog"));
 
-    connect( myButton, SIGNAL( pressed() ), SLOT( slotUpdateUrl() ));
+    connect(d->myButton, SIGNAL(pressed()), SLOT(_k_slotUpdateUrl()));
 
     setSpacing( KDialog::spacingHint() );
 
@@ -207,7 +229,7 @@ void KUrlRequester::init()
     setFocusPolicy(Qt::StrongFocus);
 
     d->connectSignals( this );
-    connect( myButton, SIGNAL( clicked() ), this, SLOT( slotOpenDialog() ));
+    connect(d->myButton, SIGNAL(clicked()), this, SLOT(slotOpenDialog()));
 
     myCompletion = new KUrlCompletion();
     d->setCompletionObject( myCompletion );
@@ -230,8 +252,8 @@ void KUrlRequester::setPath( const QString& path )
 void KUrlRequester::changeEvent(QEvent *e)
 {
    if (e->type()==QEvent::WindowTitleChange) {
-     if (myFileDialog) {
-        myFileDialog->setWindowTitle( windowTitle() );
+     if (d->myFileDialog) {
+        d->myFileDialog->setWindowTitle(windowTitle());
      }
    }
    KHBox::changeEvent(e);
@@ -247,10 +269,13 @@ void KUrlRequester::slotOpenDialog()
     KUrl newurl;
     if ( (d->fileDialogMode & KFile::Directory) && !(d->fileDialogMode & KFile::File) ||
          /* catch possible fileDialog()->setMode( KFile::Directory ) changes */
-         (myFileDialog && ( (myFileDialog->mode() & KFile::Directory) &&
-         (myFileDialog->mode() & (KFile::File | KFile::Files)) == 0 ) ) )
+         (d->myFileDialog && ((d->myFileDialog->mode() & KFile::Directory) &&
+         (d->myFileDialog->mode() & (KFile::File | KFile::Files)) == 0 ) ) )
     {
-        newurl = KDirSelectDialog::selectDirectory(url(), d->fileDialogMode & KFile::LocalOnly);
+        if (d->fileDialogMode & KFile::LocalOnly)
+            newurl = KFileDialog::getExistingDirectory(url(), this);
+        else
+            newurl = KFileDialog::getExistingDirectoryUrl(url(), this);
         if ( !newurl.isValid() )
         {
             return;
@@ -287,8 +312,9 @@ void KUrlRequester::setMode( KFile::Modes mode)
     if ( (mode & KFile::Directory) && !(mode & KFile::File) )
         myCompletion->setMode( KUrlCompletion::DirCompletion );
 
-    if (myFileDialog)
-       myFileDialog->setMode( d->fileDialogMode );
+    if (d->myFileDialog) {
+        d->myFileDialog->setMode(d->fileDialogMode);
+    }
 }
 
 KFile::Modes KUrlRequester::mode() const
@@ -299,8 +325,9 @@ KFile::Modes KUrlRequester::mode() const
 void KUrlRequester::setFilter(const QString &filter)
 {
     d->fileDialogFilter = filter;
-    if (myFileDialog)
-       myFileDialog->setFilter( d->fileDialogFilter );
+    if (d->myFileDialog) {
+        d->myFileDialog->setFilter(d->fileDialogFilter);
+    }
 }
 
 QString KUrlRequester::filter( ) const
@@ -310,15 +337,15 @@ QString KUrlRequester::filter( ) const
 
 KFileDialog * KUrlRequester::fileDialog() const
 {
-    if ( !myFileDialog ) {
+    if (!d->myFileDialog) {
         QWidget *p = parentWidget();
-        myFileDialog = new KFileDialog( QString(), d->fileDialogFilter, p);
-        myFileDialog->setModal(true);
-        myFileDialog->setMode( d->fileDialogMode );
-        myFileDialog->setWindowTitle( windowTitle() );
+        d->myFileDialog = new KFileDialog(QString(), d->fileDialogFilter, p);
+        d->myFileDialog->setModal(true);
+        d->myFileDialog->setMode(d->fileDialogMode);
+        d->myFileDialog->setWindowTitle(windowTitle());
     }
 
-    return myFileDialog;
+    return d->myFileDialog;
 }
 
 void KUrlRequester::clear()
@@ -336,7 +363,7 @@ KComboBox * KUrlRequester::comboBox() const
     return d->combo;
 }
 
-void KUrlRequester::slotUpdateUrl()
+void KUrlRequester::KUrlRequesterPrivate::_k_slotUpdateUrl()
 {
     KUrl u( KUrl::fromPath( QDir::currentPath() + '/' ), url().url() );
     myButton->setURL( u );
@@ -355,7 +382,12 @@ bool KUrlRequester::eventFilter( QObject *obj, QEvent *ev )
 
 KPushButton * KUrlRequester::button() const
 {
-    return myButton;
+    return d->myButton;
+}
+
+KUrlCompletion *KUrlRequester::completionObject() const
+{
+    return myCompletion;
 }
 
 const KEditListBox::CustomEditor &KUrlRequester::customEditor()
