@@ -21,20 +21,21 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <sys/stat.h>
-#include <qdir.h>
-#include <qlayout.h>
-#include <qstringlist.h>
-#include <qwidget.h>
+#include <QtCore/QDir>
+#include <QtGui/QLayout>
+#include <QtCore/QMutableStringListIterator>
+#include <QtGui/QWidget>
 
 #include <kfiledialog.h>
-#include <kfileiconview.h>
 #include <kmessagebox.h>
 #include <kconfig.h>
 #include <kapplication.h>
 #include <kcmdlineargs.h>
 #include <kurl.h>
+#if 0 // SPLIT-TODO
 #include <kurlbar.h>
 #include <kdiroperator.h>
+#endif
 #include <kfile.h>
 #include <kdebug.h>
 #include <kicondialog.h>
@@ -42,16 +43,13 @@
 #include "kfdtest.h"
 #include <kconfiggroup.h>
 
-static const KCmdLineOptions options[] =
-{
-    { "+[cmd]", "", 0 },
-    { "+[url]", "", 0 },
-    KCmdLineLastOption
-};
-
 int main(int argc, char **argv)
 {
-    KCmdLineArgs::init(argc, argv, "kfstest","kfstest","test app","0");
+    KCmdLineOptions options;
+    options.add("+[cmd]");
+    options.add("+[url]");
+
+    KCmdLineArgs::init(argc, argv, "kfstest", 0, ki18n("kfstest"), "0", ki18n("test app"));
     KCmdLineArgs::addCmdLineOptions(options);
     KApplication a;
     a.setQuitOnLastWindowClosed(false);
@@ -66,22 +64,24 @@ int main(int argc, char **argv)
     if ( argc > 2 )
         startDir = KUrl( argv[2] );
 
+#if 0 // SPLIT-TODO
     if (argv1 == QLatin1String("diroperator")) {
         KDirOperator *op = new KDirOperator(startDir, 0);
         KConfigGroup grp(KGlobal::config(), "TestGroup" );
-        op->setViewConfig(&grp);
+        op->setViewConfig(grp);
         op->setView(KFile::Simple);
         op->show();
         a.exec();
     }
+#endif
 
     else if (argv1 == QLatin1String("justone")) {
         QString name = KFileDialog::getOpenFileName(startDir);
         qDebug("filename=%s",name.toLatin1().constData());
     }
 
-    else if (argv1 == QLatin1String("existingUrl")) {
-        KUrl url = KFileDialog::getExistingUrl();
+    else if (argv1 == QLatin1String("existingDirectoryUrl")) {
+        KUrl url = KFileDialog::getExistingDirectoryUrl();
         qDebug("URL=%s",url.url().toLatin1().constData());
         name1 = url.url();
     }
@@ -110,13 +110,14 @@ int main(int argc, char **argv)
         QStringList filter;
         filter << "all/allfiles" << "text/plain";
         dlg->setMimeFilter( filter, "all/allfiles" );
+#if 0 // SPLIT-TODO
         KUrlBar *urlBar = dlg->speedBar();
         if ( urlBar )
         {
             urlBar->insertDynamicItem( KUrl("ftp://ftp.kde.org"),
                                        QLatin1String("KDE FTP Server") );
         }
-
+#endif
         if ( dlg->exec() == KDialog::Accepted )
             name1 = dlg->selectedUrl().url();
     }
@@ -137,7 +138,7 @@ int main(int argc, char **argv)
     else if (argv1 == QLatin1String("icon")) {
         KIconDialog dlg;
         QString icon = dlg.getIcon();
-        kDebug() << icon << endl;
+        kDebug() << icon;
     }
 
 //     else if ( argv1 == QLatin1String("dirselect") ) {
