@@ -19,17 +19,18 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include "kio/chmodjob.h"
+#include "chmodjob.h"
 
-#include "kio/job.h"
+#include "job.h"
+#include "jobuidelegate.h"
 
 #include <kglobal.h>
+#include <kuiserverjobtracker.h>
 
 #include <klocale.h>
 #include <kdebug.h>
 #include <kmessagebox.h>
-#include <qtimer.h>
-#include <qfile.h>
+#include <QtCore/QFile>
 
 #include <config.h>
 
@@ -39,21 +40,80 @@
 #include <unistd.h>
 #include <assert.h>
 
+#include "job_p.h"
+
+namespace KIO {
+
+    struct ChmodInfo
+    {
+        KUrl url;
+        int permissions;
+    };
+
+    enum ChmodJobState {
+        STATE_LISTING,
+        STATE_CHMODING
+    };
+
+    class ChmodJobPrivate: public KIO::JobPrivate
+    {
+    public:
+        ChmodJobPrivate(const KFileItemList& lstItems, int permissions, int mask,
+                        int newOwner, int newGroup, bool recursive)
+            : state( STATE_LISTING )
+            , m_permissions( permissions )
+            , m_mask( mask )
+            , m_newOwner( newOwner )
+            , m_newGroup( newGroup )
+            , m_recursive( recursive )
+            , m_lstItems( lstItems )
+        {
+        }
+
+        ChmodJobState state;
+        int m_permissions;
+        int m_mask;
+        int m_newOwner;
+        int m_newGroup;
+        bool m_recursive;
+        KFileItemList m_lstItems;
+        QLinkedList<ChmodInfo> m_infos; // linkedlist since we keep removing the first item
+
+        void chmodNextFile();
+        void _k_slotEntries( KIO::Job * , const KIO::UDSEntryList & );
+        void _k_processList();
+
+        Q_DECLARE_PUBLIC(ChmodJob)
+
+        static inline ChmodJob *newJob(const KFileItemList& lstItems, int permissions, int mask,
+                                       int newOwner, int newGroup, bool recursive, bool showProgressInfo)
+        {
+            ChmodJob *job = new ChmodJob(*new ChmodJobPrivate(lstItems,permissions,mask,
+                                                              newOwner,newGroup,recursive));
+            job->setUiDelegate(new JobUiDelegate());
+            if (showProgressInfo)
+                KIO::getJobTracker()->registerJob(job);
+            return job;
+        }
+    };
+
+} // namespace KIO
+
 using namespace KIO;
 
-ChmodJob::ChmodJob( const KFileItemList& lstItems, int permissions, int mask,
-                    int newOwner, int newGroup,
-                    bool recursive, bool showProgressInfo )
-    : KIO::Job( showProgressInfo ), state( STATE_LISTING ),
-      m_permissions( permissions ), m_mask( mask ),
-      m_newOwner( newOwner ), m_newGroup( newGroup ),
-      m_recursive( recursive ), m_lstItems( lstItems )
+ChmodJob::ChmodJob(ChmodJobPrivate &dd)
+    : KIO::Job(dd)
 {
-    QTimer::singleShot( 0, this, SLOT(processList()) );
+    QMetaObject::invokeMethod( this, "_k_processList", Qt::QueuedConnection );
 }
 
-void ChmodJob::processList()
+ChmodJob::~ChmodJob()
 {
+}
+
+void ChmodJobPrivate::_k_processList()
+{
+    Q_Q(ChmodJob);
     while ( !m_lstItems.isEmpty() )
     {
         KFileItem * item = m_lstItems.first();
@@ -72,39 +132,38 @@ void ChmodJob::processList()
                           << "\n new permissions = " << QString::number(info.permissions,8)
                           << endl;*/
             m_infos.prepend( info );
-            //kDebug(7007) << "processList : Adding info for " << info.url.prettyUrl() << endl;
+            //kDebug(7007) << "processList : Adding info for " << info.url.prettyUrl();
             // Directory and recursive -> list
             if ( item->isDir() && m_recursive )
             {
-                //kDebug(7007) << "ChmodJob::processList dir -> listing" << endl;
+                //kDebug(7007) << "ChmodJob::processList dir -> listing";
                 KIO::ListJob * listJob = KIO::listRecursive( item->url(), false /* no GUI */ );
-                connect( listJob, SIGNAL(entries( KIO::Job *,
-                                                  const KIO::UDSEntryList& )),
-                         SLOT( slotEntries( KIO::Job*,
-                                            const KIO::UDSEntryList& )));
-                addSubjob( listJob );
+                q->connect( listJob, SIGNAL(entries( KIO::Job *,
+                                                     const KIO::UDSEntryList& )),
+                            SLOT(_k_slotEntries( KIO::Job*, const KIO::UDSEntryList& )));
+                q->addSubjob( listJob );
                 return; // we'll come back later, when this one's finished
             }
         }
         m_lstItems.removeFirst();
     }
-    kDebug(7007) << "ChmodJob::processList -> going to STATE_CHMODING" << endl;
+    kDebug(7007) << "ChmodJob::processList -> going to STATE_CHMODING";
     // We have finished, move on
     state = STATE_CHMODING;
     chmodNextFile();
 }
 
-void ChmodJob::slotEntries( KIO::Job*, const KIO::UDSEntryList & list )
+void ChmodJobPrivate::_k_slotEntries( KIO::Job*, const KIO::UDSEntryList & list )
 {
     KIO::UDSEntryList::ConstIterator it = list.begin();
     KIO::UDSEntryList::ConstIterator end = list.end();
     for (; it != end; ++it) {
         const KIO::UDSEntry& entry = *it;
-        const bool isLink = !entry.stringValue( KIO::UDS_STRING ).isEmpty();
-        const QString relativePath = entry.stringValue( KIO::UDS_NAME );
+        const bool isLink = !entry.stringValue( KIO::UDSEntry::UDS_STRING ).isEmpty();
+        const QString relativePath = entry.stringValue( KIO::UDSEntry::UDS_NAME );
         if ( !isLink && relativePath != ".." )
         {
-            const mode_t permissions = entry.numberValue( KIO::UDS_ACCESS );
+            const mode_t permissions = entry.numberValue( KIO::UDSEntry::UDS_ACCESS );
 
             ChmodInfo info;
             info.url = m_lstItems.first()->url(); // base directory
@@ -140,8 +199,9 @@ void ChmodJob::slotEntries( KIO::Job*, const KIO::UDSEntryList & list )
     }
 }
 
-void ChmodJob::chmodNextFile()
+void ChmodJobPrivate::chmodNextFile()
 {
+    Q_Q(ChmodJob);
     if ( !m_infos.isEmpty() )
     {
         ChmodInfo info = m_infos.takeFirst();
@@ -155,8 +215,8 @@ void ChmodJob::chmodNextFile()
                 int answer = KMessageBox::warningContinueCancel( 0, i18n( "<qt>Could not modify the ownership of file <b>%1</b>. You have insufficient access to the file to perform the change.</qt>" , path), QString(), KGuiItem(i18n("&Skip File")) );
                 if (answer == KMessageBox::Cancel)
                 {
-                    setError( ERR_USER_CANCELED );
-                    emitResult();
+                    q->setError( ERR_USER_CANCELED );
+                    q->emitResult();
                     return;
                 }
             }
@@ -166,21 +226,22 @@ void ChmodJob::chmodNextFile()
                       << " to " << QString::number(info.permissions,8) << endl;
         KIO::SimpleJob * job = KIO::chmod( info.url, info.permissions );
         // copy the metadata for acl and default acl
-        const QString aclString = queryMetaData( QLatin1String("ACL_STRING") );
-        const QString defaultAclString = queryMetaData( QLatin1String("DEFAULT_ACL_STRING") );
+        const QString aclString = q->queryMetaData( QLatin1String("ACL_STRING") );
+        const QString defaultAclString = q->queryMetaData( QLatin1String("DEFAULT_ACL_STRING") );
         if ( !aclString.isEmpty() )
             job->addMetaData( QLatin1String("ACL_STRING"), aclString );
         if ( !defaultAclString.isEmpty() )
             job->addMetaData( QLatin1String("DEFAULT_ACL_STRING"), defaultAclString );
-        addSubjob(job);
+        q->addSubjob(job);
     }
     else
         // We have finished
-        emitResult();
+        q->emitResult();
 }
 
 void ChmodJob::slotResult( KJob * job )
 {
+    Q_D(ChmodJob);
     if ( job->error() )
     {
         setError( job->error() );
@@ -188,19 +249,19 @@ void ChmodJob::slotResult( KJob * job )
         emitResult();
         return;
     }
-    //kDebug(7007) << " ChmodJob::slotResult( KJob * job ) m_lstItems:" << m_lstItems.count() << endl;
-    switch ( state )
+    //kDebug(7007) << " ChmodJob::slotResult( KJob * job ) d->m_lstItems:" << d->m_lstItems.count();
+    switch ( d->state )
     {
         case STATE_LISTING:
             removeSubjob(job);
-            m_lstItems.removeFirst();
-            kDebug(7007) << "ChmodJob::slotResult -> processList" << endl;
-            processList();
+            d->m_lstItems.removeFirst();
+            kDebug(7007) << "ChmodJob::slotResult -> processList";
+            d->_k_processList();
             return;
         case STATE_CHMODING:
             removeSubjob(job);
-            kDebug(7007) << "ChmodJob::slotResult -> chmodNextFile" << endl;
-            chmodNextFile();
+            kDebug(7007) << "ChmodJob::slotResult -> chmodNextFile";
+            d->chmodNextFile();
             return;
         default:
             assert(0);
@@ -230,7 +291,8 @@ ChmodJob *KIO::chmod( const KFileItemList& lstItems, int permissions, int mask,
         else
             newGroupID = g->gr_gid;
     }
-    return new ChmodJob( lstItems, permissions, mask, newOwnerID, newGroupID, recursive, showProgressInfo );
+    return ChmodJobPrivate::newJob(lstItems, permissions, mask, newOwnerID,
+                                   newGroupID, recursive, showProgressInfo);
 }
 
 #include "chmodjob.moc"
