@@ -22,14 +22,15 @@
 #define KIO_CHMODJOB_H
 
 #include <kurl.h>
-#include <kio/global.h>
-#include <kio/job.h>
+#include "global.h"
+#include "job.h"
 #include <kfileitem.h>
 
-#include <qlinkedlist.h>
+#include <QtCore/QLinkedList>
 
 namespace KIO {
 
+    class ChmodJobPrivate;
     /**
      * This job changes permissions on a list of files or directories,
      * optionally in a recursive manner.
@@ -39,38 +40,18 @@ namespace KIO {
     {
         Q_OBJECT
     public:
-	/**
-	 * Create new ChmodJobs using the KIO::chmod() function.
-	 */
-        ChmodJob( const KFileItemList & lstItems,  int permissions, int mask,
-                  int newOwner, int newGroup,
-                  bool recursive, bool showProgressInfo );
-
-    protected:
-        void chmodNextFile();
+        virtual ~ChmodJob();
 
     protected Q_SLOTS:
-
         virtual void slotResult( KJob *job );
-        void slotEntries( KIO::Job * , const KIO::UDSEntryList & );
-        void processList();
+
+    protected:
+        ChmodJob(ChmodJobPrivate &dd);
 
     private:
-        struct ChmodInfo
-        {
-            KUrl url;
-            int permissions;
-        };
-        enum { STATE_LISTING, STATE_CHMODING } state;
-        int m_permissions;
-        int m_mask;
-        int m_newOwner;
-        int m_newGroup;
-        bool m_recursive;
-        KFileItemList m_lstItems;
-        QLinkedList<ChmodInfo> m_infos; // linkedlist since we keep removing the first item
-    private:
-	class ChmodJobPrivate* d;
+        Q_PRIVATE_SLOT(d_func(), void _k_slotEntries( KIO::Job * , const KIO::UDSEntryList & ))
+        Q_PRIVATE_SLOT(d_func(), void _k_processList())
+        Q_DECLARE_PRIVATE(ChmodJob)
     };
 
 
