@@ -22,22 +22,23 @@
 #ifndef KIO_COPYJOB_H
 #define KIO_COPYJOB_H
 
-#include <qobject.h>
-#include <qstringlist.h>
+#include <QtCore/QObject>
+#include <QtCore/QStringList>
 
 #include <sys/types.h> // time_t
 
 #include <kurl.h>
 
-#include <kio/jobclasses.h>
+#include "jobclasses.h"
 
-class Observer;
 class QTimer;
 
 namespace KIO {
 
     /// @internal
-    struct KIO_EXPORT CopyInfo
+    /// FIXME: If this is internal, why is being used in a public signal below?
+    /// (aboutToCreate, see also konq_operations.h/cpp
+    struct CopyInfo
     {
         KUrl uSource;
         KUrl uDest;
@@ -48,6 +49,7 @@ namespace KIO {
         KIO::filesize_t size; // 0 for dirs
     };
 
+    class CopyJobPrivate;
     /**
      * CopyJob is used to move, copy or symlink files and directories.
      * Don't create the job directly, but use KIO::copy(),
@@ -70,38 +72,19 @@ namespace KIO {
 	 */
         enum CopyMode{ Copy, Move, Link };
 
-	/**
-	 * Do not create a CopyJob directly. Use KIO::copy(),
-	 * KIO::move(), KIO::link() and friends instead.
-	 *
-	 * @param src the list of source URLs
-	 * @param dest the destination URL
-	 * @param mode specifies whether the job should copy, move or link
-	 * @param asMethod if true, behaves like KIO::copyAs(),
-	 * KIO::moveAs() or KIO::linkAs()
-	 * @param showProgressInfo true to show progress information to the user
-	 * @see KIO::copy()
-	 * @see KIO::copyAs()
-	 * @see KIO::move()
-	 * @see KIO::moveAs()
-	 * @see KIO::link()
-	 * @see KIO::linkAs()
-	 */
-        CopyJob( const KUrl::List& src, const KUrl& dest, CopyMode mode, bool asMethod, bool showProgressInfo );
-
         virtual ~CopyJob();
 
 	/**
 	 * Returns the list of source URLs.
 	 * @return the list of source URLs.
 	 */
-        KUrl::List srcUrls() const { return m_srcList; }
+        KUrl::List srcUrls() const;
 
 	/**
 	 * Returns the destination URL.
 	 * @return the destination URL
 	 */
-        KUrl destUrl() const { return m_dest; }
+        KUrl destUrl() const;
 
         /**
          * By default the permissions of the copied files will be those of the source files.
@@ -115,7 +98,7 @@ namespace KIO {
         /**
          * Reimplemented for internal reasons
          */
-        virtual void suspend();
+        virtual bool doSuspend();
 
     Q_SIGNALS:
 
@@ -217,87 +200,20 @@ namespace KIO {
          * @param to the destination URL
          */
         void copyingLinkDone( KIO::Job *job, const KUrl &from, const QString& target, const KUrl& to );
+    protected Q_SLOTS:
+        virtual void slotResult( KJob *job );
 
     protected:
-        void statCurrentSrc();
-        void statNextSrc();
-
-        // Those aren't slots but submethods for slotResult.
-        void slotResultStating( KJob * job );
-        void startListing( const KUrl & src );
-        void slotResultCreatingDirs( KJob * job );
-        void slotResultConflictCreatingDirs( KJob * job );
-        void createNextDir();
-        void slotResultCopyingFiles( KJob * job );
-        void slotResultConflictCopyingFiles( KJob * job );
-        void copyNextFile();
-        void slotResultDeletingDirs( KJob * job );
-        void deleteNextDir();
-        void skip( const KUrl & sourceURL );
-        void slotResultRenaming( KJob * job );
-        //void slotResultSettingDirAttributes( KJob * job );
-        void setNextDirAttribute();
-    private:
-        void startRenameJob(const KUrl &slave_url);
-        bool shouldOverwrite( const QString& path ) const;
-        bool shouldSkip( const QString& path ) const;
-        void skipSrc();
-
-    protected Q_SLOTS:
-        void slotStart();
-        void slotEntries( KIO::Job*, const KIO::UDSEntryList& list );
-        virtual void slotResult( KJob *job );
-        /**
-         * Forward signal from subjob
-         */
-        void slotProcessedSize( KJob*, qulonglong data_size );
-        /**
-         * Forward signal from subjob
-	 * @param size the total size
-         */
-        void slotTotalSize( KJob*, qulonglong size );
-
-        void slotReport();
+        CopyJob(CopyJobPrivate &dd);
 
     private:
-        CopyMode m_mode;
-        bool m_asMethod;
-        enum DestinationState { DEST_NOT_STATED, DEST_IS_DIR, DEST_IS_FILE, DEST_DOESNT_EXIST };
-        DestinationState destinationState;
-        enum { STATE_STATING, STATE_RENAMING, STATE_LISTING, STATE_CREATING_DIRS,
-               STATE_CONFLICT_CREATING_DIRS, STATE_COPYING_FILES, STATE_CONFLICT_COPYING_FILES,
-               STATE_DELETING_DIRS, STATE_SETTING_DIR_ATTRIBUTES } state;
-        KIO::filesize_t m_totalSize;
-        KIO::filesize_t m_processedSize;
-        KIO::filesize_t m_fileProcessedSize;
-        int m_processedFiles;
-        int m_processedDirs;
-        QList<CopyInfo> files;
-        QList<CopyInfo> dirs;
-        KUrl::List dirsToRemove;
-        KUrl::List m_srcList;
-        KUrl::List::Iterator m_currentStatSrc;
-        bool m_bCurrentSrcIsDir;
-        bool m_bCurrentOperationIsLink;
-        bool m_bSingleFileCopy;
-        bool m_bOnlyRenames;
-        KUrl m_dest;
-        KUrl m_currentDest;
-        //
-        QStringList m_skipList;
-        QStringList m_overwriteList;
-        bool m_bAutoSkip;
-        bool m_bOverwriteAll;
-        int m_conflictError;
+        Q_PRIVATE_SLOT(d_func(), void slotStart())
+        Q_PRIVATE_SLOT(d_func(), void slotEntries( KIO::Job*, const KIO::UDSEntryList& list ))
+        Q_PRIVATE_SLOT(d_func(), void slotProcessedSize( KJob*, qulonglong data_size ))
+        Q_PRIVATE_SLOT(d_func(), void slotTotalSize( KJob*, qulonglong size ))
+        Q_PRIVATE_SLOT(d_func(), void slotReport())
 
-        QTimer *m_reportTimer;
-        //these both are used for progress dialog reporting
-        KUrl m_currentSrcURL;
-        KUrl m_currentDestURL;
-    private:
-	class CopyJobPrivate;
-        CopyJobPrivate* d;
-        friend class CopyJobPrivate; // for DestinationState
+        Q_DECLARE_PRIVATE(CopyJob)
     };
 
     /**
