@@ -25,8 +25,9 @@
 #include "scheduler.h"
 #include "kdirwatch.h"
 #include "kprotocolmanager.h"
-#include "kio/observer.h"
+#include "jobuidelegate.h"
 #include <kdirnotify.h>
+#include <kuiserverjobtracker.h>
 
 #include <kauthorized.h>
 #include <klocale.h>
@@ -37,97 +38,147 @@
 #include <stdlib.h>
 #include <time.h>
 
-#include <qtimer.h>
-#include <qfile.h>
+#include <QtCore/QTimer>
+#include <QtCore/QFile>
 #include <QPointer>
 
+#include "job_p.h"
+
+namespace KIO
+{
+    enum DeleteJobState {
+        STATE_STATING,
+        STATE_LISTING,
+        STATE_DELETING_FILES,
+        STATE_DELETING_DIRS
+    };
+
+    class DeleteJobPrivate: public KIO::JobPrivate
+    {
+    public:
+        DeleteJobPrivate(const KUrl::List& src)
+            : state( STATE_STATING )
+            , m_totalSize( 0 )
+            , m_processedSize( 0 )
+            , m_fileProcessedSize( 0 )
+            , m_processedFiles( 0 )
+            , m_processedDirs( 0 )
+            , m_totalFilesDirs( 0 )
+            , m_srcList( src )
+            , m_currentStat( m_srcList.begin() )
+            , m_reportTimer( 0 )
+        {
+        }
+        DeleteJobState state;
+        KIO::filesize_t m_totalSize;
+        KIO::filesize_t m_processedSize;
+        KIO::filesize_t m_fileProcessedSize;
+        int m_processedFiles;
+        int m_processedDirs;
+        int m_totalFilesDirs;
+        KUrl m_currentURL;
+        KUrl::List files;
+        KUrl::List symlinks;
+        KUrl::List dirs;
+        KUrl::List m_srcList;
+        KUrl::List::Iterator m_currentStat;
+	QStringList m_parentDirs;
+        QTimer *m_reportTimer;
+
+        void statNextSrc();
+        void deleteNextFile();
+        void deleteNextDir();
+        /**
+         * Forward signal from subjob
+         */
+        void slotProcessedSize( KJob*, qulonglong data_size );
+        void slotReport();
+        void slotStart();
+        void slotEntries( KIO::Job*, const KIO::UDSEntryList& list );
+
+        Q_DECLARE_PUBLIC(DeleteJob)
+
+        static inline DeleteJob *newJob(const KUrl::List &src, bool showProgressInfo)
+        {
+            DeleteJob *job = new DeleteJob(*new DeleteJobPrivate(src));
+            job->setUiDelegate(new JobUiDelegate);
+            if (showProgressInfo)
+                KIO::getJobTracker()->registerJob(job);
+            return job;
+        }
+    };
+
+} // namespace KIO
+
 using namespace KIO;
 
-DeleteJob::DeleteJob( const KUrl::List& src, bool showProgressInfo )
-: Job(showProgressInfo), m_totalSize( 0 ), m_processedSize( 0 ), m_fileProcessedSize( 0 ),
-  m_processedFiles( 0 ), m_processedDirs( 0 ), m_totalFilesDirs( 0 ),
-  m_srcList(src), m_currentStat(m_srcList.begin()), m_reportTimer(0)
+DeleteJob::DeleteJob(DeleteJobPrivate &dd)
+    : Job(dd)
 {
-  if ( showProgressInfo ) {
+    d_func()->m_reportTimer = new QTimer(this);
+    connect(d_func()->m_reportTimer,SIGNAL(timeout()),this,SLOT(slotReport()));
+    //this will update the report dialog with 5 Hz, I think this is fast enough, aleXXX
+    d_func()->m_reportTimer->start( 200 );
 
-     connect( this, SIGNAL( totalFiles( KJob*, unsigned long ) ),
-              Observer::self(), SLOT( slotTotalFiles( KJob*, unsigned long ) ) );
-
-     connect( this, SIGNAL( totalDirs( KJob*, unsigned long ) ),
-              Observer::self(), SLOT( slotTotalDirs( KJob*, unsigned long ) ) );
-
-     // See slotReport
-     /*connect( this, SIGNAL( processedFiles( KIO::Job*, unsigned long ) ),
-      m_observer, SLOT( slotProcessedFiles( KIO::Job*, unsigned long ) ) );
-
-      connect( this, SIGNAL( processedDirs( KIO::Job*, unsigned long ) ),
-      m_observer, SLOT( slotProcessedDirs( KIO::Job*, unsigned long ) ) );
-
-      connect( this, SIGNAL( deleting( KIO::Job*, const KUrl& ) ),
-      m_observer, SLOT( slotDeleting( KIO::Job*, const KUrl& ) ) );*/
-
-     m_reportTimer=new QTimer(this);
-     connect(m_reportTimer,SIGNAL(timeout()),this,SLOT(slotReport()));
-     //this will update the report dialog with 5 Hz, I think this is fast enough, aleXXX
-     m_reportTimer->start( 200 );
-  }
-
-  QTimer::singleShot(0, this, SLOT(slotStart()));
+    QTimer::singleShot(0, this, SLOT(slotStart()));
 }
 
-void DeleteJob::slotStart()
+DeleteJob::~DeleteJob()
 {
-  statNextSrc();
+}
+
+KUrl::List DeleteJob::urls() const
+{
+    return d_func()->m_srcList;
+}
+
+void DeleteJobPrivate::slotStart()
+{
+    statNextSrc();
 }
 
 //this is called often, so calling the functions
 //from Observer here directly might improve the performance a little bit
 //aleXXX
-void DeleteJob::slotReport()
+void DeleteJobPrivate::slotReport()
 {
-   if (progressId()==0)
-      return;
-
-   Observer * observer = Observer::self();
-
-   emit deleting( this, m_currentURL );
-   observer->slotDeleting(this,m_currentURL);
+   Q_Q(DeleteJob);
+   emit q->deleting( q, m_currentURL );
+   JobPrivate::emitDeleting( q, m_currentURL);
 
    switch( state ) {
         case STATE_STATING:
         case STATE_LISTING:
-            emit totalSize( this, m_totalSize );
-            emit totalFiles( this, files.count() );
-            emit totalDirs( this, dirs.count() );
+            q->setTotalAmount(KJob::Bytes, m_totalSize);
+            q->setTotalAmount(KJob::Files, files.count());
+            q->setTotalAmount(KJob::Directories, dirs.count());
             break;
         case STATE_DELETING_DIRS:
-            emit processedDirs( this, m_processedDirs );
-            observer->slotProcessedDirs(this,m_processedDirs);
-            emitPercent( m_processedFiles + m_processedDirs, m_totalFilesDirs );
+            q->setProcessedAmount(KJob::Directories, m_processedDirs);
+            q->emitPercent( m_processedFiles + m_processedDirs, m_totalFilesDirs );
             break;
         case STATE_DELETING_FILES:
-            observer->slotProcessedFiles(this,m_processedFiles);
-            emit processedFiles( this, m_processedFiles );
-            emitPercent( m_processedFiles, m_totalFilesDirs );
+            q->setProcessedAmount(KJob::Files, m_processedFiles);
+            q->emitPercent( m_processedFiles, m_totalFilesDirs );
             break;
    }
 }
 
 
-void DeleteJob::slotEntries(KIO::Job* job, const UDSEntryList& list)
+void DeleteJobPrivate::slotEntries(KIO::Job* job, const UDSEntryList& list)
 {
     UDSEntryList::ConstIterator it = list.begin();
     const UDSEntryList::ConstIterator end = list.end();
     for (; it != end; ++it)
     {
         const UDSEntry& entry = *it;
-        const QString displayName = entry.stringValue( KIO::UDS_NAME );
+        const QString displayName = entry.stringValue( KIO::UDSEntry::UDS_NAME );
 
         assert(!displayName.isEmpty());
         if (displayName != ".." && displayName != ".")
         {
             KUrl url;
-            const QString urlStr = entry.stringValue( KIO::UDS_URL );
+            const QString urlStr = entry.stringValue( KIO::UDSEntry::UDS_URL );
             if ( !urlStr.isEmpty() )
                 url = urlStr;
             else {
@@ -135,9 +186,9 @@ void DeleteJob::slotEntries(KIO::Job* job, const UDSEntryList& list)
                 url.addPath( displayName );
             }
 
-            m_totalSize += (KIO::filesize_t)entry.numberValue( KIO::UDS_SIZE, 0 );
+            m_totalSize += (KIO::filesize_t)entry.numberValue( KIO::UDSEntry::UDS_SIZE, 0 );
 
-            //kDebug(7007) << "DeleteJob::slotEntries " << displayName << " (" << url << ")" << endl;
+            //kDebug(7007) << "DeleteJob::slotEntries " << displayName << " (" << url << ")";
             if ( entry.isLink() )
                 symlinks.append( url );
             else if ( entry.isDir() )
@@ -149,30 +200,29 @@ void DeleteJob::slotEntries(KIO::Job* job, const UDSEntryList& list)
 }
 
 
-void DeleteJob::statNextSrc()
+void DeleteJobPrivate::statNextSrc()
 {
-    //kDebug(7007) << "statNextSrc" << endl;
+    Q_Q(DeleteJob);
+    //kDebug(7007) << "statNextSrc";
     if ( m_currentStat != m_srcList.end() )
     {
         m_currentURL = (*m_currentStat);
 
         // if the file system doesn't support deleting, we do not even stat
         if (!KProtocolManager::supportsDeleting(m_currentURL)) {
-            QPointer<DeleteJob> that = this;
+            QPointer<DeleteJob> that = q;
             ++m_currentStat;
-            emit warning( this, buildErrorString(ERR_CANNOT_DELETE, m_currentURL.prettyUrl()) );
+            emit q->warning( q, buildErrorString(ERR_CANNOT_DELETE, m_currentURL.prettyUrl()) );
             if (that)
                 statNextSrc();
             return;
         }
         // Stat it
         state = STATE_STATING;
-        KIO::SimpleJob * job = KIO::stat( m_currentURL, true, 1, false );
+        KIO::SimpleJob * job = KIO::stat( m_currentURL, StatJob::SourceSide, 1, false );
         Scheduler::scheduleJob(job);
-        //kDebug(7007) << "KIO::stat (DeleteJob) " << m_currentURL << endl;
-        addSubjob(job);
-        //if ( progressId() ) // Did we get an ID from the observer ?
-        //  Observer::self()->slotDeleting( this, *it ); // show asap
+        //kDebug(7007) << "KIO::stat (DeleteJob) " << m_currentURL;
+        q->addSubjob(job);
     } else
     {
         m_totalFilesDirs = files.count()+symlinks.count() + dirs.count();
@@ -188,9 +238,10 @@ void DeleteJob::statNextSrc()
     }
 }
 
-void DeleteJob::deleteNextFile()
+void DeleteJobPrivate::deleteNextFile()
 {
-    //kDebug(7007) << "deleteNextFile" << endl;
+    Q_Q(DeleteJob);
+    //kDebug(7007) << "deleteNextFile";
     if ( !files.isEmpty() || !symlinks.isEmpty() )
     {
         SimpleJob *job;
@@ -224,7 +275,7 @@ void DeleteJob::deleteNextFile()
             else
                 files.erase(it);
             if ( job ) {
-                addSubjob(job);
+                q->addSubjob(job);
                 return;
             }
             // loop only if direct deletion worked (job=0) and there is something else to delete
@@ -234,8 +285,9 @@ void DeleteJob::deleteNextFile()
     deleteNextDir();
 }
 
-void DeleteJob::deleteNextDir()
+void DeleteJobPrivate::deleteNextDir()
 {
+    Q_Q(DeleteJob);
     if ( !dirs.isEmpty() ) // some dirs to delete ?
     {
         do {
@@ -260,7 +312,7 @@ void DeleteJob::deleteNextDir()
                 }
                 Scheduler::scheduleJob(job);
                 dirs.erase(it);
-                addSubjob( job );
+                q->addSubjob( job );
                 return;
             }
             dirs.erase(it);
@@ -274,46 +326,40 @@ void DeleteJob::deleteNextDir()
     // Finished - tell the world
     if ( !m_srcList.isEmpty() )
     {
-        //kDebug(7007) << "KDirNotify'ing FilesRemoved " << m_srcList.toStringList() << endl;
+        //kDebug(7007) << "KDirNotify'ing FilesRemoved " << m_srcList.toStringList();
         org::kde::KDirNotify::emitFilesRemoved( m_srcList.toStringList() );
     }
     if (m_reportTimer!=0)
        m_reportTimer->stop();
-    emitResult();
+    q->emitResult();
 }
 
-void DeleteJob::slotProcessedSize( KJob*, qulonglong data_size )
+// Note: I don't think this slot is connected to anywhere! -thiago
+void DeleteJobPrivate::slotProcessedSize( KJob*, qulonglong data_size )
 {
+   Q_Q(DeleteJob);
    // Note: this is the same implementation as CopyJob::slotProcessedSize but
    // it's different from FileCopyJob::slotProcessedSize - which is why this
    // is not in Job.
 
    m_fileProcessedSize = data_size;
-   setProcessedSize(m_processedSize + m_fileProcessedSize);
+   q->setProcessedAmount(KJob::Bytes, m_processedSize + m_fileProcessedSize);
 
-   //kDebug(7007) << "DeleteJob::slotProcessedSize " << (unsigned int) (m_processedSize + m_fileProcessedSize) << endl;
+   //kDebug(7007) << "DeleteJob::slotProcessedSize " << (unsigned int) (m_processedSize + m_fileProcessedSize);
 
-   emit processedSize( this, m_processedSize + m_fileProcessedSize );
+   q->setProcessedAmount(KJob::Bytes, m_processedSize + m_fileProcessedSize);
 
    // calculate percents
-   unsigned long ipercent = percent();
-
    if ( m_totalSize == 0 )
-      setPercent( 100 );
+      q->setPercent( 100 );
    else
-      setPercent( (unsigned long)(( (float)(m_processedSize + m_fileProcessedSize) / (float)m_totalSize ) * 100.0) );
-
-   if ( percent() > ipercent )
-   {
-      emit percent( this, percent() );
-      //kDebug(7007) << "DeleteJob::slotProcessedSize - percent =  " << (unsigned int) m_percent << endl;
-   }
-
+      q->setPercent( (unsigned long)(( (float)(m_processedSize + m_fileProcessedSize) / (float)m_totalSize ) * 100.0) );
 }
 
 void DeleteJob::slotResult( KJob *job )
 {
-    switch ( state )
+    Q_D(DeleteJob);
+    switch ( d->state )
     {
     case STATE_STATING:
     {
@@ -336,14 +382,14 @@ void DeleteJob::slotResult( KJob *job )
         if (entry.isDir() && !isLink)
         {
             // Add toplevel dir in list of dirs
-            dirs.append( url );
-            if ( url.isLocalFile() && !m_parentDirs.contains( url.path(KUrl::RemoveTrailingSlash) ) )
-              m_parentDirs.append( url.path(KUrl::RemoveTrailingSlash) );
+            d->dirs.append( url );
+            if ( url.isLocalFile() && !d->m_parentDirs.contains( url.path(KUrl::RemoveTrailingSlash) ) )
+              d->m_parentDirs.append( url.path(KUrl::RemoveTrailingSlash) );
 
             if ( !KProtocolManager::canDeleteRecursive( url ) ) {
-                //kDebug(7007) << " Target is a directory " << endl;
+                //kDebug(7007) << " Target is a directory ";
                 // List it
-                state = STATE_LISTING;
+                d->state = STATE_LISTING;
                 ListJob *newjob = listRecursive( url, false );
                 newjob->setUnrestricted(true); // No KIOSK restrictions
                 Scheduler::scheduleJob(newjob);
@@ -353,23 +399,23 @@ void DeleteJob::slotResult( KJob *job )
                                            const KIO::UDSEntryList& )));
                 addSubjob(newjob);
             } else {
-                ++m_currentStat;
-                statNextSrc();
+                ++d->m_currentStat;
+                d->statNextSrc();
             }
         }
         else
         {
             if ( isLink ) {
-                //kDebug(7007) << " Target is a symlink" << endl;
-                symlinks.append( url );
+                //kDebug(7007) << " Target is a symlink";
+                d->symlinks.append( url );
             } else {
-                //kDebug(7007) << " Target is a file" << endl;
-                files.append( url );
+                //kDebug(7007) << " Target is a file";
+                d->files.append( url );
             }
-            if ( url.isLocalFile() && !m_parentDirs.contains( url.directory(KUrl::ObeyTrailingSlash) ) )
-                m_parentDirs.append( url.directory(KUrl::ObeyTrailingSlash) );
-            ++m_currentStat;
-            statNextSrc();
+            if ( url.isLocalFile() && !d->m_parentDirs.contains( url.directory(KUrl::ObeyTrailingSlash) ) )
+                d->m_parentDirs.append( url.directory(KUrl::ObeyTrailingSlash) );
+            ++d->m_currentStat;
+            d->statNextSrc();
         }
     }
         break;
@@ -380,8 +426,8 @@ void DeleteJob::slotResult( KJob *job )
         }
         removeSubjob( job );
         assert( !hasSubjobs() );
-        ++m_currentStat;
-        statNextSrc();
+        ++d->m_currentStat;
+        d->statNextSrc();
         break;
     case STATE_DELETING_FILES:
         if ( job->error() )
@@ -391,9 +437,9 @@ void DeleteJob::slotResult( KJob *job )
         }
         removeSubjob( job );
         assert( !hasSubjobs() );
-        m_processedFiles++;
+        d->m_processedFiles++;
 
-        deleteNextFile();
+        d->deleteNextFile();
         break;
     case STATE_DELETING_DIRS:
         if ( job->error() )
@@ -403,12 +449,12 @@ void DeleteJob::slotResult( KJob *job )
         }
         removeSubjob( job );
         assert( !hasSubjobs() );
-        m_processedDirs++;
-        //emit processedDirs( this, m_processedDirs );
+        d->m_processedDirs++;
+        //emit processedAmount( this, KJob::Directories, d->m_processedDirs );
         //if (!m_shred)
-        //emitPercent( m_processedFiles + m_processedDirs, m_totalFilesDirs );
+        //emitPercent( d->m_processedFiles + d->m_processedDirs, d->m_totalFilesDirs );
 
-        deleteNextDir();
+        d->deleteNextDir();
         break;
     default:
         assert(0);
@@ -417,16 +463,14 @@ void DeleteJob::slotResult( KJob *job )
 
 DeleteJob *KIO::del( const KUrl& src, bool /*shred*/, bool showProgressInfo )
 {
-  KUrl::List srcList;
-  srcList.append( src );
-  DeleteJob *job = new DeleteJob( srcList, showProgressInfo );
-  return job;
+    KUrl::List srcList;
+    srcList.append( src );
+    return DeleteJobPrivate::newJob(srcList, showProgressInfo);
 }
 
 DeleteJob *KIO::del( const KUrl::List& src, bool /*shred*/, bool showProgressInfo )
 {
-  DeleteJob *job = new DeleteJob( src, showProgressInfo );
-  return job;
+    return DeleteJobPrivate::newJob(src, showProgressInfo);
 }
 
 #include "deletejob.moc"
