@@ -22,18 +22,18 @@
 #ifndef KIO_DELETEJOB_H
 #define KIO_DELETEJOB_H
 
-#include <qstringlist.h>
+#include <QtCore/QStringList>
 
 #include <kurl.h>
-#include <kio/global.h>
+#include "global.h"
 
-#include <kio/jobclasses.h>
+#include "jobclasses.h"
 
-class Observer;
 class QTimer;
 
 namespace KIO {
 
+    class DeleteJobPrivate;
     /**
      * A more complex Job to delete files and directories.
      * Don't create the job directly, but use KIO::del() instead.
@@ -44,21 +44,13 @@ namespace KIO {
     Q_OBJECT
 
     public:
-	/**
-	 * Do not create a DeleteJob directly. Use KIO::del()
-	 * instead.
-	 *
-	 * @param src the list of URLs to delete
-	 * @param showProgressInfo true to show progress information to the user
-	 * @see KIO::del()
-	 */
-        DeleteJob( const KUrl::List& src, bool showProgressInfo );
+        virtual ~DeleteJob();
 
 	/**
 	 * Returns the list of URLs.
 	 * @return the list of URLs.
 	 */
-        KUrl::List urls() const { return m_srcList; }
+        KUrl::List urls() const;
 
     Q_SIGNALS:
 
@@ -97,40 +89,16 @@ namespace KIO {
         void deleting( KIO::Job *job, const KUrl& file );
 
     protected Q_SLOTS:
-        void slotStart();
-        void slotEntries( KIO::Job*, const KIO::UDSEntryList& list );
         virtual void slotResult( KJob *job );
 
-        /**
-         * Forward signal from subjob
-         */
-        void slotProcessedSize( KJob*, qulonglong data_size );
-        void slotReport();
+    protected:
+        DeleteJob(DeleteJobPrivate &dd);
 
     private:
-        void statNextSrc();
-        void deleteNextFile();
-        void deleteNextDir();
-
-    private:
-        enum { STATE_STATING, STATE_LISTING,
-               STATE_DELETING_FILES, STATE_DELETING_DIRS } state;
-        KIO::filesize_t m_totalSize;
-        KIO::filesize_t m_processedSize;
-        KIO::filesize_t m_fileProcessedSize;
-        int m_processedFiles;
-        int m_processedDirs;
-        int m_totalFilesDirs;
-        KUrl m_currentURL;
-        KUrl::List files;
-        KUrl::List symlinks;
-        KUrl::List dirs;
-        KUrl::List m_srcList;
-        KUrl::List::Iterator m_currentStat;
-	QStringList m_parentDirs;
-        QTimer *m_reportTimer;
-    private:
-	class DeleteJobPrivate* d;
+        Q_PRIVATE_SLOT(d_func(), void slotStart())
+        Q_PRIVATE_SLOT(d_func(), void slotEntries( KIO::Job*, const KIO::UDSEntryList& list ))
+        Q_PRIVATE_SLOT(d_func(), void slotReport())
+        Q_DECLARE_PRIVATE(DeleteJob)
     };
 
     /**
