@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (c) 2004 Kevin Ottens <ervin ipsquad net>
+   Copyright (c) 2004 Kevin Ottens <ervin@ipsquad.net>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,8 +23,8 @@
 #include <kio/slavebase.h>
 #include <kio/jobclasses.h>
 
-#include <qobject.h>
-#include <qeventloop.h>
+#include <QtCore/QObject>
+#include <QtCore/QEventLoop>
 
 namespace KIO
 {
@@ -114,6 +114,8 @@ public:
 
     virtual void chmod(const KUrl &url, int permissions);
 
+    virtual void setModificationTime(const KUrl& url, const QDateTime& mtime);
+
     virtual void copy(const KUrl &src, const KUrl &dest,
                       int permissions, bool overwrite);
 
@@ -151,48 +153,37 @@ protected:
      * Return the URL being processed by the ioslave
      * Only access it inside prepareUDSEntry()
      */
-    KUrl processedUrl() const { return m_processedURL; }
+    KUrl processedUrl() const;
 
     /**
      * Return the URL asked to the ioslave
      * Only access it inside prepareUDSEntry()
      */
-    KUrl requestedUrl() const { return m_requestedURL; }
+    KUrl requestedUrl() const;
 
 private:
-    KUrl m_processedURL;
-    KUrl m_requestedURL;
-    ForwardingSlaveBasePrivate *d;
-
-    bool internalRewriteUrl(const KUrl &url, KUrl &newURL);
-
-    void connectJob(Job *job);
-    void connectSimpleJob(SimpleJob *job);
-    void connectListJob(ListJob *job);
-    void connectTransferJob(TransferJob *job);
-
-    QEventLoop eventLoop;
-
-private Q_SLOTS:
     // KIO::Job
-    void slotResult(KJob *job);
-    void slotWarning(KJob *job, const QString &msg);
-    void slotInfoMessage(KJob *job, const QString &msg);
-    void slotTotalSize(KJob *job, qulonglong size);
-    void slotProcessedSize(KJob *job, qulonglong size);
-    void slotSpeed(KJob *job, unsigned long bytesPerSecond);
+    Q_PRIVATE_SLOT(d, void _k_slotResult(KJob *job))
+    Q_PRIVATE_SLOT(d, void _k_slotWarning(KJob *job, const QString &msg))
+    Q_PRIVATE_SLOT(d, void _k_slotInfoMessage(KJob *job, const QString &msg))
+    Q_PRIVATE_SLOT(d, void _k_slotTotalSize(KJob *job, qulonglong size))
+    Q_PRIVATE_SLOT(d, void _k_slotProcessedSize(KJob *job, qulonglong size))
+    Q_PRIVATE_SLOT(d, void _k_slotSpeed(KJob *job, unsigned long bytesPerSecond))
 
     // KIO::SimpleJob subclasses
-    void slotRedirection(KIO::Job *job, const KUrl &url);
+    Q_PRIVATE_SLOT(d, void _k_slotRedirection(KIO::Job *job, const KUrl &url))
 
     // KIO::ListJob
-    void slotEntries(KIO::Job *job, const KIO::UDSEntryList &entries);
+    Q_PRIVATE_SLOT(d, void _k_slotEntries(KIO::Job *job, const KIO::UDSEntryList &entries))
 
     // KIO::TransferJob
-    void slotData(KIO::Job *job, const QByteArray &data);
-    void slotDataReq(KIO::Job *job, QByteArray &data);
-    void slotMimetype (KIO::Job *job, const QString &type);
-    void slotCanResume (KIO::Job *job, KIO::filesize_t offset);
+    Q_PRIVATE_SLOT(d, void _k_slotData(KIO::Job *job, const QByteArray &data))
+    Q_PRIVATE_SLOT(d, void _k_slotDataReq(KIO::Job *job, QByteArray &data))
+    Q_PRIVATE_SLOT(d, void _k_slotMimetype (KIO::Job *job, const QString &type))
+    Q_PRIVATE_SLOT(d, void _k_slotCanResume (KIO::Job *job, KIO::filesize_t offset))
+
+    friend class ForwardingSlaveBasePrivate;
+    ForwardingSlaveBasePrivate *const d;
 };
 
 }
