@@ -16,10 +16,12 @@
    Boston, MA 02110-1301, USA.
 */
 
-#include <config.h>
+#include "global.h"
+#include "job.h"
+#include "thumbcreator.h"   // needed to create a reference to ThumbCreator class in the export lib
+                            // other solution: don't use KIO_EXPORT there...
 
-#include "kio/global.h"
-#include "kio/job.h"
+#include <config.h>
 
 #include <kdebug.h>
 #include <klocale.h>
@@ -28,10 +30,11 @@
 #include <kprotocolmanager.h>
 #include <kde_file.h>
 #include <kmimetype.h>
+#include <kuiserverjobtracker.h>
 
-#include <qbytearray.h>
-#include <qdatetime.h>
-#include <QTextDocument>
+#include <QtCore/QByteArray>
+#include <QtCore/QDate>
+#include <QtGui/QTextDocument>
 
 #include <sys/types.h>
 #include <sys/wait.h>
@@ -44,9 +47,7 @@
 #include <unistd.h>
 #include <stdio.h>
 
-#ifdef HAVE_VOLMGT
-#include <volmgt.h>
-#endif
+K_GLOBAL_STATIC(KUiServerJobTracker, globalJobTracker)
 
 // If someone wants the SI-standard prefixes kB/MB/GB/TB, I would recommend
 // a hidden kconfig option and getting the code from #57240 into the same
@@ -303,6 +304,9 @@ KIO_EXPORT QString KIO::buildErrorString(int errorCode, const QString &errorText
     case  KIO::ERR_CANNOT_CHMOD:
       result = i18n( "Could not change permissions for %1." ,  errorText );
       break;
+    case  KIO::ERR_CANNOT_CHOWN:
+      result = i18n( "Could not change ownership for %1." ,  errorText );
+      break;
     case  KIO::ERR_CANNOT_DELETE:
       result = i18n( "Could not delete file %1." ,  errorText );
       break;
@@ -412,6 +416,8 @@ KIO_EXPORT QString KIO::unsupportedActionErrorString(const QString &protocol, in
       return i18n("Creating folders is not supported with protocol %1.", protocol);
     case CMD_CHMOD:
       return i18n("Changing the attributes of files is not supported with protocol %1.", protocol);
+    case CMD_CHOWN:
+      return i18n("Changing the ownership of files is not supported with protocol %1.", protocol);
     case CMD_SUBURL:
       return i18n("Using sub-URLs with %1 is not supported.", protocol);
     case CMD_MULTI_GET:
@@ -439,11 +445,11 @@ KIO_EXPORT QStringList KIO::Job::detailedErrorStrings( const KUrl *reqUrl /*= 0L
     url = Qt::escape(reqUrl->prettyUrl());
     protocol = reqUrl->protocol();
   } else {
-    url = i18n( "(unknown)" );
+    url = i18nc("@info url", "(unknown)" );
   }
 
   datetime = KGlobal::locale()->formatDateTime( QDateTime::currentDateTime(),
-                                                false );
+                                                KLocale::LongDate );
 
   ret << errorName;
   ret << QLatin1String( "<qt><p><b>" ) + errorName +
@@ -521,11 +527,11 @@ KIO_EXPORT QByteArray KIO::rawErrorDetail(int errorCode, const QString &errorTex
   } else {
     // assume that the errorText has the location we are interested in
     url = host = domain = path = filename = dir = errorText;
-    protocol = i18n( "(unknown)" );
+    protocol = i18nc("@info protocol", "(unknown)" );
   }
 
   datetime = KGlobal::locale()->formatDateTime( QDateTime::currentDateTime(),
-                                                false );
+                                                KLocale::LongDate );
 
   QString errorName, techName, description;
   QStringList causes, solutions;
@@ -1019,6 +1025,14 @@ KIO_EXPORT QByteArray KIO::rawErrorDetail(int errorCode, const QString &errorTex
       solutions << sAccess << sExists;
       break;
 
+    case  KIO::ERR_CANNOT_CHOWN:
+      errorName = i18n( "Could Not Change Ownership of Resource" );
+      description = i18n( "An attempt to change the ownership of the specified "
+        "resource <strong>%1</strong> failed." ,  url );
+      causes << cAccess << cExists;
+      solutions << sAccess << sExists;
+      break;
+
     case  KIO::ERR_CANNOT_DELETE:
       errorName = i18n( "Could Not Delete Resource" );
       description = i18n( "An attempt to delete the specified resource "
@@ -1215,729 +1229,12 @@ KIO_EXPORT QByteArray KIO::rawErrorDetail(int errorCode, const QString &errorTex
   return ret;
 }
 
-#ifdef Q_OS_UNIX
-
-#include <limits.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <qfile.h>
-
-#include <config.h>
-
-#ifdef HAVE_PATHS_H
-#include <paths.h>
-#endif
-#ifdef HAVE_SYS_STAT_H
-#include <sys/stat.h>
-#endif
-#include <sys/param.h>
-#ifdef HAVE_LIMITS_H
-#include <limits.h>
-#endif
-#ifdef HAVE_SYS_MNTTAB_H
-#include <sys/mnttab.h>
-#endif
-#ifdef HAVE_MNTENT_H
-#include <mntent.h>
-#elif defined(HAVE_SYS_MNTENT_H)
-#include <sys/mntent.h>
-#endif
-#ifdef HAVE_SYS_UCRED_H
-#include <sys/ucred.h>
-#endif
-#ifdef HAVE_SYS_MOUNT_H
-#include <sys/mount.h>
-#endif
-#ifdef HAVE_FSTAB_H
-#include <fstab.h>
-#endif
-#if defined(_AIX)
-#include <sys/mntctl.h>
-#include <sys/vmount.h>
-#include <sys/vfs.h>
-#include "global.h"
-
-/* AIX does not prototype mntctl anywhere that I can find */
-#ifndef mntctl
-extern "C" {
-int mntctl(int command, int size, void* buffer);
-}
-#endif
-extern "C" struct vfs_ent *getvfsbytype(int vfsType);
-extern "C" void endvfsent( );
-#endif
-
 /***************************************************************
  *
  * Utility functions
  *
  ***************************************************************/
 
-#ifndef HAVE_GETMNTINFO
-
-#ifdef _PATH_MOUNTED
-// On some Linux, MNTTAB points to /etc/fstab !
-# undef MNTTAB
-# define MNTTAB _PATH_MOUNTED
-#else
-# ifndef MNTTAB
-#  ifdef MTAB_FILE
-#   define MNTTAB MTAB_FILE
-#  else
-#   define MNTTAB "/etc/mnttab"
-#  endif
-# endif
-#endif
-
-#ifndef FSTAB
-# ifdef _PATH_FSTAB
-#  define FSTAB _PATH_FSTAB
-# else
-#  define FSTAB "/etc/fstab"
-# endif
-#endif
-
-#ifdef __CYGWIN__
-#define hasmntopt(var,opt) (0)
-#endif
-
-// There are (at least) four kind of APIs:
-// setmntent + getmntent + struct mntent (linux...)
-//             getmntent + struct mnttab
-// mntctl                + struct vmount (AIX)
-// getmntinfo + struct statfs&flags (BSD 4.4 and friends)
-// getfsent + char* (BSD 4.3 and friends)
-
-#ifdef HAVE_SETMNTENT
-#define SETMNTENT setmntent
-#define ENDMNTENT endmntent
-#define STRUCT_MNTENT struct mntent *
-#define STRUCT_SETMNTENT FILE *
-#define GETMNTENT(file, var) ((var = getmntent(file)) != 0)
-#define MOUNTPOINT(var) var->mnt_dir
-#define MOUNTTYPE(var) var->mnt_type
-#define HASMNTOPT(var, opt) hasmntopt(var, opt)
-#define FSNAME(var) var->mnt_fsname
-#elif defined(_AIX)
-/* we don't need this stuff */
-#else
-#define SETMNTENT fopen
-#define ENDMNTENT fclose
-#define STRUCT_MNTENT struct mnttab
-#define STRUCT_SETMNTENT FILE *
-#define GETMNTENT(file, var) (getmntent(file, &var) == 0)
-#define MOUNTPOINT(var) var.mnt_mountp
-#define MOUNTTYPE(var) var.mnt_fstype
-#define HASMNTOPT(var, opt) hasmntopt(&var, opt)
-#define FSNAME(var) var.mnt_special
-#endif
-
-#endif /* HAVE_GETMNTINFO */
-
-QString KIO::findDeviceMountPoint( const QString& filename )
-{
-    QString result;
-
-#ifdef HAVE_VOLMGT
-	/*
-	 *  support for Solaris volume management
-	 */
-	const char *volpath;
-	FILE *mnttab;
-	struct mnttab mnt;
-	int len;
-	QByteArray devname;
-
-	if( (volpath = volmgt_root()) == NULL ) {
-		kDebug( 7007 ) << "findDeviceMountPoint: "
-			<< "VOLMGT: can't find volmgt root dir" << endl;
-		return QString();
-	}
-
-	if( (mnttab = fopen( MNTTAB, "r" )) == NULL ) {
-		kDebug( 7007 ) << "findDeviceMountPoint: "
-			<< "VOLMGT: can't open mnttab" << endl;
-		return QString();
-	}
-
-	devname = volpath;
-	devname += QFile::encodeName( filename );
-	devname += '/';
-	len = devname.length();
-//	kDebug( 7007 ) << "findDeviceMountPoint: "
-//		<< "VOLMGT: searching mountpoint for \"" << devname << "\""
-//		<< endl;
-
-	/*
-	 *  find the mountpoint
-	 *  floppies:
-	 *	/dev/disketteN    => <volpath>/dev/disketteN
-	 *  CDROM, ZIP, and other media:
-	 *	/dev/dsk/cXtYdZs2 => <volpath>/dev/dsk/cXtYdZ  (without slice#)
-	 */
-	rewind( mnttab );
-	result.clear();
-	while( getmntent( mnttab, &mnt ) == 0 ) {
-		/*
-		 *  either match the exact device name (floppies),
-		 *  or the device name without the slice#
-		 */
-		if( strncmp( devname.data(), mnt.mnt_special, len ) == 0
-			|| (strncmp( devname.data(), mnt.mnt_special, len - 3 ) == 0
-				&& mnt.mnt_special[len - 3] == '/' )
-			|| (strcmp(QFile::encodeName(filename).data()
-					, mnt.mnt_special)==0)) {
-			result = mnt.mnt_mountp;
-			break;
-		}
-	}
-	fclose( mnttab );
-#else
-
-    char    realpath_buffer[MAXPATHLEN];
-    QByteArray realname;
-
-    realname = QFile::encodeName(filename);
-    /* If the path contains symlinks, get the real name */
-    if (realpath(realname, realpath_buffer) != 0)
-      // succes, use result from realpath
-      realname = realpath_buffer;
-
-    //kDebug(7007) << "findDeviceMountPoint realname=" << realname << endl;
-
-#ifdef HAVE_GETMNTINFO
-
-#ifdef GETMNTINFO_USES_STATVFS
-    struct statvfs *mounted;
-#else
-    struct statfs *mounted;
-#endif
-
-    int num_fs = getmntinfo(&mounted, MNT_NOWAIT);
-
-    for (int i=0;i<num_fs;i++) {
-
-        QByteArray device_name = mounted[i].f_mntfromname;
-
-        // If the path contains symlinks, get
-        // the real name
-        if (realpath(device_name, realpath_buffer) != 0)
-            // succes, use result from realpath
-            device_name = realpath_buffer;
-
-        if (realname == device_name) {
-            result = mounted[i].f_mntonname;
-            break;
-        }
-    }
-
-#elif defined(_AIX)
-
-    struct vmount *mntctl_buffer;
-    struct vmount *vm;
-    char *mountedfrom;
-    char *mountedto;
-    int fsname_len, num;
-    int buf_sz = 4096;
-
-    /* mntctl can be used to query mounted file systems.
-     * mntctl takes only the command MCTL_QUERY so far.
-     * The buffer is filled with an array of vmount structures, but these
-     * vmount structures have variable size.
-     * mntctl return values:
-     * -1 error
-     *  0 look in first word of buffer for required bytes, 4096 may be
-     *    a good starting size, but if tables grow too large, look here.
-     * >0 number of vmount structures
-     */
-    mntctl_buffer = (struct vmount*)malloc(buf_sz);
-    num = mntctl(MCTL_QUERY, buf_sz, mntctl_buffer);
-    if (num == 0)
-    {
-	buf_sz = *(int*)mntctl_buffer;
-	free(mntctl_buffer);
-	mntctl_buffer = (struct vmount*)malloc(buf_sz);
-	num = mntctl(MCTL_QUERY, buf_sz, mntctl_buffer);
-    }
-
-    if (num > 0)
-    {
-        /* iterate through items in the vmount structure: */
-        vm = mntctl_buffer;
-        for ( ; num > 0; num-- )
-        {
-            /* get the name of the mounted file systems: */
-            fsname_len = vmt2datasize(vm, VMT_STUB);
-            mountedto     = (char*)malloc(fsname_len + 1);
-	    mountedto[fsname_len] = '\0';
-            strncpy(mountedto, (char *)vmt2dataptr(vm, VMT_STUB), fsname_len);
-
-            /* get the mount-from information: */
-            fsname_len = vmt2datasize(vm, VMT_OBJECT);
-            mountedfrom     = (char*)malloc(fsname_len + 1);
-	    mountedfrom[fsname_len] = '\0';
-            strncpy(mountedfrom, (char *)vmt2dataptr(vm, VMT_OBJECT), fsname_len);
-
-            QByteArray device_name = mountedfrom;
-
-            if (realpath(device_name, realpath_buffer) != 0)
-                // success, use result from realpath
-                device_name = realpath_buffer;
-
-            free(mountedfrom);
-
-            if (realname == device_name) {
-                result = mountedto;
-                free(mountedto);
-                break;
-            }
-
-            free(mountedto);
-
-            /* goto the next vmount structure: */
-            vm = (struct vmount *)((char *)vm + vm->vmt_length);
-        }
-    }
-
-    free( mntctl_buffer );
-
-#else
-
-    STRUCT_SETMNTENT mtab;
-
-    /* Get the list of mounted file systems */
-
-    if ((mtab = SETMNTENT(MNTTAB, "r")) == 0) {
-        perror("setmntent");
-        return QString();
-    }
-
-    /* Loop over all file systems and see if we can find our
-     * mount point.
-     * Note that this is the mount point with the longest match.
-     * XXX: Fails if me->mnt_dir is not a realpath but goes
-     * through a symlink, e.g. /foo/bar where /foo is a symlink
-     * pointing to /local/foo.
-     *
-     * How kinky can you get with a filesystem?
-     */
-
-    STRUCT_MNTENT me;
-
-    while (GETMNTENT(mtab, me))
-    {
-      // There may be symbolic links into the /etc/mnttab
-      // So we have to find the real device name here as well!
-      QByteArray device_name = FSNAME(me);
-      if (device_name.isEmpty() || (device_name == "none"))
-         continue;
-
-      //kDebug( 7007 ) << "device_name=" << device_name << endl;
-
-      // If the path contains symlinks, get
-      // the real name
-      if (realpath(device_name, realpath_buffer) != 0)
-          // succes, use result from realpath
-         device_name = realpath_buffer;
-
-      //kDebug( 7007 ) << "device_name after realpath =" << device_name << endl;
-
-      if (realname == device_name)
-      {
-          result = MOUNTPOINT(me);
-          break;
-      }
-    }
-
-    ENDMNTENT(mtab);
-
-#endif /* GET_MNTINFO */
-#endif /* HAVE_VOLMGT */
-
-    //kDebug( 7007 ) << "Returning result " << result << endl;
-    return result;
-}
-
-// Don't just trust the return value, keep iterating to check for a better match (bigger max)
-static bool is_my_mountpoint( const char *mountpoint, const char *realname, int &max )
-{
-    int length = strlen(mountpoint);
-
-    if (!strncmp(mountpoint, realname, length)
-        && length > max) {
-        max = length;
-        if (length == 1 || realname[length] == '/' || realname[length] == '\0')
-            return true;
-    }
-    return false;
-}
-
-typedef enum { Unseen, Right, Wrong } MountState;
-
-/**
- * Idea and code base by Olaf Kirch <okir@caldera.de>
- **/
-static void check_mount_point(const char *mounttype,
-                              const char *fsname,
-                              MountState &isslow, MountState &isautofs)
-{
-    bool nfs = !strcmp(mounttype, "nfs");
-    bool autofs = !strcmp(mounttype, "autofs") || !strcmp(mounttype,"subfs");
-    bool pid = (strstr(fsname, ":(pid") != 0);
-
-    if (nfs && !pid)
-        isslow = Right;
-    else if (isslow == Right)
-        isslow = Wrong;
-
-    /* Does this look like automounted? */
-    if (autofs || (nfs && pid)) {
-        isautofs = Right;
-        isslow = Right;
-    }
-}
-
-// returns the mount point, checks the mount state.
-// if ismanual == Wrong this function does not check the manual mount state
-static QString get_mount_info(const QString& filename,
-    MountState& isautofs, MountState& isslow, MountState& ismanual,
-    QString& fstype)
-{
-    static bool gotRoot = false;
-    static dev_t rootDevice;
-
-    struct cachedDevice_t
-    {
-       dev_t device;
-       QString mountPoint;
-       MountState isautofs;
-       MountState isslow;
-       MountState ismanual;
-       QString fstype;
-    };
-    static struct cachedDevice_t *cachedDevice = 0;
-
-    if (!gotRoot)
-    {
-       KDE_struct_stat stat_buf;
-       KDE_stat("/", &stat_buf);
-       gotRoot = true;
-       rootDevice = stat_buf.st_dev;
-    }
-
-    bool gotDevice = false;
-    KDE_struct_stat stat_buf;
-    if (KDE_stat(QFile::encodeName(filename), &stat_buf) == 0)
-    {
-       gotDevice = true;
-       if (stat_buf.st_dev == rootDevice)
-       {
-          static const QString &root = KGlobal::staticQString("/");
-          isautofs = Wrong;
-          isslow = Wrong;
-          ismanual = Wrong;
-          fstype.clear(); // ### do we need it?
-          return root;
-       }
-       if (cachedDevice && (stat_buf.st_dev == cachedDevice->device))
-       {
-          bool interestedInIsManual = ismanual != Wrong;
-          isautofs = cachedDevice->isautofs;
-          isslow = cachedDevice->isslow;
-          ismanual = cachedDevice->ismanual;
-          fstype = cachedDevice->fstype;
-          // Don't use the cache if it doesn't have the information we're looking for
-          if ( !interestedInIsManual || ismanual != Unseen )
-              return cachedDevice->mountPoint;
-       }
-    }
-
-    char realname[MAXPATHLEN];
-
-    memset(realname, 0, MAXPATHLEN);
-
-    /* If the path contains symlinks, get the real name */
-    if (realpath(QFile::encodeName(filename), realname) == 0) {
-        if( strlcpy(realname, QFile::encodeName(filename), MAXPATHLEN)>=MAXPATHLEN)
-            return QString();
-    }
-
-    int max = 0;
-    QString mountPoint;
-
-    /* Loop over all file systems and see if we can find our
-     * mount point.
-     * Note that this is the mount point with the longest match.
-     * XXX: Fails if me->mnt_dir is not a realpath but goes
-     * through a symlink, e.g. /foo/bar where /foo is a symlink
-     * pointing to /local/foo.
-     *
-     * How kinky can you get with a filesystem?
-     */
-
-#ifdef HAVE_GETMNTINFO
-
-#ifdef GETMNTINFO_USES_STATVFS
-    struct statvfs *mounted;
-#else
-    struct statfs *mounted;
-#endif
-    char    realpath_buffer[MAXPATHLEN];
-
-    int num_fs = getmntinfo(&mounted, MNT_NOWAIT);
-
-    for (int i=0;i<num_fs;i++) {
-
-        QByteArray device_name = mounted[i].f_mntfromname;
-
-        // If the path contains symlinks, get
-        // the real name
-        if (realpath(device_name, realpath_buffer) != 0)
-            // succes, use result from realpath
-            device_name = realpath_buffer;
-#ifdef __osf__
-        char * mounttype = mnt_names[mounted[i].f_type];
-#else
-        char * mounttype = mounted[i].f_fstypename;
-#endif
-        if ( is_my_mountpoint( mounted[i].f_mntonname, realname, max ) )
-        {
-            mountPoint = QFile::decodeName(mounted[i].f_mntonname);
-            fstype = QLatin1String(mounttype);
-            check_mount_point( mounttype, mounted[i].f_mntfromname,
-                               isautofs, isslow );
-            // keep going, looking for a potentially better one
-
-            if (ismanual == Unseen)
-            {
-                struct fstab *ft = getfsfile(mounted[i].f_mntonname);
-                if (!ft || strstr(ft->fs_mntops, "noauto"))
-                  ismanual = Right;
-            }
-        }
-    }
-
-#elif defined(_AIX)
-
-    struct vmount *mntctl_buffer;
-    struct vmount *vm;
-    char *mountedfrom;
-    char *mountedto;
-    int fsname_len, num;
-    char realpath_buffer[MAXPATHLEN];
-    int buf_sz = 4096;
-
-    mntctl_buffer = (struct vmount*)malloc(buf_sz);
-    num = mntctl(MCTL_QUERY, buf_sz, mntctl_buffer);
-    if (num == 0)
-    {
-	buf_sz = *(int*)mntctl_buffer;
-	free(mntctl_buffer);
-	mntctl_buffer = (struct vmount*)malloc(buf_sz);
-	num = mntctl(MCTL_QUERY, buf_sz, mntctl_buffer);
-    }
-
-    if (num > 0)
-    {
-        /* iterate through items in the vmount structure: */
-        vm = (struct vmount *)mntctl_buffer;
-        for ( ; num > 0; num-- )
-        {
-            /* get the name of the mounted file systems: */
-            fsname_len = vmt2datasize(vm, VMT_STUB);
-            mountedto     = (char*)malloc(fsname_len + 1);
-	    mountedto[fsname_len] = '\0';
-            strncpy(mountedto, (char *)vmt2dataptr(vm, VMT_STUB), fsname_len);
-
-            fsname_len = vmt2datasize(vm, VMT_OBJECT);
-            mountedfrom     = (char*)malloc(fsname_len + 1);
-	    mountedfrom[fsname_len] = '\0';
-            strncpy(mountedfrom, (char *)vmt2dataptr(vm, VMT_OBJECT), fsname_len);
-
-            /* get the mount-from information: */
-            QByteArray device_name = mountedfrom;
-
-            if (realpath(device_name, realpath_buffer) != 0)
-                // success, use result from realpath
-                device_name = realpath_buffer;
-
-	    /* Look up the string for the file system type,
-             * as listed in /etc/vfs.
-             * ex.: nfs,jfs,afs,cdrfs,sfs,cachefs,nfs3,autofs
-             */
-            struct vfs_ent* ent = getvfsbytype(vm->vmt_gfstype);
-
-            if ( is_my_mountpoint( mountedto, realname, max ) )
-            {
-                mountPoint = QFile::decodeName(mountedto);
-                fstype = QLatin1String(ent->vfsent_name);
-                check_mount_point(ent->vfsent_name, device_name, isautofs, isslow);
-
-                if (ismanual == Unseen)
-                {
-                    // TODO: add check for ismanual, I couldn't find any way
-                    // how to get the mount attribute from /etc/filesystems
-                    ismanual == Wrong;
-                }
-            }
-
-            free(mountedfrom);
-            free(mountedto);
-
-            /* goto the next vmount structure: */
-            vm = (struct vmount *)((char *)vm + vm->vmt_length);
-        }
-
-	endvfsent( );
-    }
-
-    free( mntctl_buffer );
-
-#else
-
-    STRUCT_SETMNTENT mtab;
-    /* Get the list of mounted file systems */
-
-    if ((mtab = SETMNTENT(MNTTAB, "r")) == 0) {
-        perror("setmntent");
-        return QString();
-    }
-
-    STRUCT_MNTENT me;
-
-    while (true) {
-        if (!GETMNTENT(mtab, me))
-            break;
-
-        if ( is_my_mountpoint( MOUNTPOINT(me), realname, max ) )
-        {
-            mountPoint = QFile::decodeName( MOUNTPOINT(me) );
-            fstype = MOUNTTYPE(me);
-            check_mount_point(MOUNTTYPE(me), FSNAME(me), isautofs, isslow);
-            // we don't check if ismanual is Right, if /a/b is manually
-            // mounted /a/b/c can't be automounted. At least IMO.
-            if (ismanual == Unseen)
-            {
-                // The next GETMNTENT call may destroy 'me'
-                // Copy out the info that we need
-                QByteArray fsname_me = FSNAME(me);
-                QByteArray mounttype_me = MOUNTTYPE(me);
-
-                STRUCT_SETMNTENT fstab;
-                if ((fstab = SETMNTENT(FSTAB, "r")) == 0) {
-                    continue;
-                }
-
-                bool found = false;
-                STRUCT_MNTENT fe;
-                while (GETMNTENT(fstab, fe))
-                {
-                    if (fsname_me == FSNAME(fe))
-                    {
-                        found = true;
-                        if (HASMNTOPT(fe, "noauto") ||
-                            !strcmp(MOUNTTYPE(fe), "supermount"))
-                            ismanual = Right;
-                        break;
-                    }
-                }
-                if (!found || (mounttype_me == "supermount"))
-                  ismanual = Right;
-
-                ENDMNTENT(fstab);
-            }
-        }
-    }
-
-    ENDMNTENT(mtab);
-
-#endif
-
-    if (isautofs == Right && isslow == Unseen)
-        isslow = Right;
-
-    if (gotDevice)
-    {
-       if (!cachedDevice)
-          cachedDevice = new cachedDevice_t;
-
-       cachedDevice->device = stat_buf.st_dev;
-       cachedDevice->mountPoint = mountPoint;
-       cachedDevice->isautofs = isautofs;
-       cachedDevice->isslow = isslow;
-       cachedDevice->ismanual = ismanual;
-       cachedDevice->fstype = fstype;
-    }
-
-    return mountPoint;
-}
-
-#else //!Q_OS_UNIX
-//dummy
-QString KIO::findDeviceMountPoint( const QString& filename )
-{
-    return QString();
-}
-#endif
-
-QString KIO::findPathMountPoint(const QString& filename)
-{
-#ifdef Q_OS_UNIX
-  MountState isautofs = Unseen, isslow = Unseen, ismanual = Wrong;
-  QString fstype;
-  return get_mount_info(filename, isautofs, isslow, ismanual, fstype);
-#else //!Q_OS_UNIX
-  return QString();
-#endif
-}
-
-bool KIO::manually_mounted(const QString& filename)
-{
-#ifdef Q_OS_UNIX
-  MountState isautofs = Unseen, isslow = Unseen, ismanual = Unseen;
-  QString fstype;
-  QString mountPoint = get_mount_info(filename, isautofs, isslow, ismanual, fstype);
-  return !mountPoint.isNull() && (ismanual == Right);
-#else //!Q_OS_UNIX
-  return false;
-#endif
-}
-
-bool KIO::probably_slow_mounted(const QString& filename)
-{
-#ifdef Q_OS_UNIX
-  MountState isautofs = Unseen, isslow = Unseen, ismanual = Wrong;
-  QString fstype;
-  QString mountPoint = get_mount_info(filename, isautofs, isslow, ismanual, fstype);
-  return !mountPoint.isNull() && (isslow == Right);
-#else //!Q_OS_UNIX
-  return false;
-#endif
-}
-
-bool KIO::testFileSystemFlag(const QString& filename, FileSystemFlag flag)
-{
-#ifdef Q_OS_UNIX
-  MountState isautofs = Unseen, isslow = Unseen, ismanual = Wrong;
-  QString fstype;
-  QString mountPoint = get_mount_info(filename, isautofs, isslow, ismanual, fstype);
-    kDebug() << "testFileSystemFlag: fstype=" << fstype << endl;
-  if (mountPoint.isNull())
-      return false;
-  bool isMsDos = ( fstype == "msdos" || fstype == "fat" || fstype == "vfat" );
-  switch (flag)  {
-  case SupportsChmod:
-  case SupportsChown:
-  case SupportsUTime:
-  case SupportsSymlinks:
-      return !isMsDos; // it's amazing the number of things FAT doesn't support :)
-  case CaseInsensitive:
-      return isMsDos;
-  }
-#endif
-  return false;
-}
-
 KIO::CacheControl KIO::parseCacheControl(const QString &cacheControl)
 {
   QString tmp = cacheControl.toLower();
@@ -1953,7 +1250,7 @@ KIO::CacheControl KIO::parseCacheControl(const QString &cacheControl)
   if (tmp == "reload")
      return KIO::CC_Reload;
 
-  kDebug() << "unrecognized Cache control option:"<<cacheControl<<endl;
+  kDebug() << "unrecognized Cache control option:"<<cacheControl;
   return KIO::CC_Verify;
 }
 
@@ -1969,7 +1266,7 @@ QString KIO::getCacheControlString(KIO::CacheControl cacheControl)
 	return "Refresh";
     if (cacheControl == KIO::CC_Reload)
 	return "Reload";
-    kDebug() << "unrecognized Cache control enum value:"<<cacheControl<<endl;
+    kDebug() << "unrecognized Cache control enum value:"<<cacheControl;
     return QString();
 }
 
@@ -1977,5 +1274,16 @@ QPixmap KIO::pixmapForUrl( const KUrl & _url, mode_t _mode, K3Icon::Group _group
                            int _force_size, int _state, QString * _path )
 {
     const QString iconName = KMimeType::iconNameForUrl( _url, _mode );
-    return KIconLoader::global()->loadMimeTypeIcon( iconName, _group, _force_size, _state, _path );
+    return KIconLoader::global()->loadMimeTypeIcon( iconName, _group, _force_size, _state, QStringList(), _path );
 }
+
+KUiServerJobTracker *KIO::getJobTracker()
+{
+    return globalJobTracker;
+}
+
+
+
+
+
+
