@@ -16,15 +16,15 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
-#ifndef __kio_global_h__
-#define __kio_global_h__
+#ifndef KIO_GLOBAL_H
+#define KIO_GLOBAL_H
 
-#include <kdelibs_export.h>
+#include <kio/kio_export.h>
 
-#include <qstring.h>
-#include <qhash.h>
-#include <qmap.h>
-#include <QList>
+#include <QtCore/QString>
+#include <QtCore/QHash>
+#include <QtCore/QMap>
+#include <QtCore/QList>
 
 #include <kicontheme.h> // K3Icon (for pixmapForUrl)
 #include <QtGui/QPixmap> // for pixmapForUrl
@@ -38,6 +38,7 @@ template class KDE_EXPORT QMap<QString, QString>;
 #endif
 
 class KUrl;
+class KUiServerJobTracker;
 
 class QTime;
 
@@ -135,7 +136,10 @@ namespace KIO
   KIO_EXPORT QString decodeFileName( const QString & str );
 
   /**
+   * @internal
    * Commands that can be invoked by a job.
+   *
+   * (Move this to a non-public header)
    */
   enum Command {
     CMD_HOST = '0', // 48
@@ -157,7 +161,7 @@ namespace KIO
     CMD_DEL = 'K', // 75
     CMD_CHMOD = 'L', // 76
     CMD_SPECIAL = 'M', // 77
-    // 'N', // 78  - currently unused
+    CMD_SETMODIFICATIONTIME = 'N', // 78
     CMD_REPARSECONFIGURATION = 'O', // 79
     CMD_META_DATA = 'P', // 80
     CMD_SYMLINK = 'Q', // 81
@@ -167,21 +171,16 @@ namespace KIO
     CMD_CONFIG = 'U', // 85
     CMD_MULTI_GET = 'V', // 86
     CMD_SETLINKDEST = 'W', // 87
-    CMD_OPEN = 'X' // 88
+    CMD_OPEN = 'X', // 88
+    CMD_CHOWN = 'Y', // 89
+    CMD_READ = 'Z', // 90
+    CMD_WRITE = 91,
+    CMD_SEEK = 92,
+    CMD_CLOSE = 93
     // Add new ones here once a release is done, to avoid breaking binary compatibility.
     // Note that protocol-specific commands shouldn't be added here, but should use special.
   };
 
-  /**
-   * Commands that can be invoked on a slave-file.
-   */
-  enum FileCommand {
-    CMD_READ  = 90,
-    CMD_WRITE = 91,
-    CMD_SEEK  = 92,
-    CMD_CLOSE = 93
-  };
-
   /**
    * Error codes that can be emitted by KIO.
    */
@@ -260,7 +259,9 @@ namespace KIO
                                                         // the server in order to continue.
     ERR_POST_DENIED = KJob::UserDefinedError + 65, // Issued when trying to POST data to a certain Ports
                                                   // see job.cpp
-    ERR_COULD_NOT_SEEK = KJob::UserDefinedError + 66
+    ERR_COULD_NOT_SEEK = KJob::UserDefinedError + 66,
+    ERR_CANNOT_SETTIME = KJob::UserDefinedError + 67, // Emitted by setModificationTime
+    ERR_CANNOT_CHOWN = KJob::UserDefinedError + 68
   };
 
   /**
@@ -345,63 +346,6 @@ namespace KIO
    */
   KIO_EXPORT QString getCacheControlString(KIO::CacheControl cacheControl);
 
-  /**
-   * Returns the mount point where @p device is mounted
-   * right now. This means, it has to be mounted, not just
-   * defined in fstab.
-   */
-  KIO_EXPORT QString findDeviceMountPoint( const QString& device );
-
-  /**
-   * Returns the mount point on which resides @p filename.
-   * For instance if /home is a separate partition, findPathMountPoint("/home/user/blah")
-   * will return /home
-   * @param filename the file name to check
-   * @return the mount point of the given @p filename
-   */
-  KIO_EXPORT QString findPathMountPoint( const QString & filename );
-
-  /**
-   * Checks if the path belongs to a filesystem that is probably
-   * slow. It checks for NFS or for paths belonging to automounted
-   * paths not yet mounted
-   * @param filename the file name to check
-   * @return true if the filesystem is probably slow
-   */
-  KIO_EXPORT bool probably_slow_mounted(const QString& filename);
-
-  /**
-   * Checks if the path belongs to a filesystem that is manually
-   * mounted.
-   * @param filename the file name to check
-   * @return true if the filesystem is manually mounted
-   */
-  KIO_EXPORT bool manually_mounted(const QString& filename);
-
-  enum FileSystemFlag { SupportsChmod, SupportsChown, SupportsUTime,
-                        SupportsSymlinks, CaseInsensitive };
-  /**
-   * Checks the capabilities of the filesystem to which a given file belongs.
-   * given feature (e.g. chmod).
-   * @param filename the file name to check
-   * @param flag the flag to check
-   * @return true if the filesystem has that flag, false if not (or some error occurred)
-   *
-   * The availables flags are:
-   * @li SupportsChmod: returns true if the filesystem supports chmod
-   * (e.g. msdos filesystems return false)
-   * @li SupportsChown: returns true if the filesystem supports chown
-   * (e.g. msdos filesystems return false)
-   * @li SupportsUtime: returns true if the filesystems supports utime
-   * (e.g. msdos filesystems return false)
-   * @li SupportsSymlinks: returns true if the filesystems supports symlinks
-   * (e.g. msdos filesystems return false)
-   * @li CaseInsensitive: returns true if the filesystem treats
-   * "foo" and "FOO" as being the same file (true for msdos systems)
-   *
-   */
-  KIO_EXPORT bool testFileSystemFlag(const QString& filename, FileSystemFlag flag);
-
   /**
    * Convenience method to find the pixmap for a URL.
    *
@@ -423,191 +367,7 @@ namespace KIO
   KIO_EXPORT QPixmap pixmapForUrl( const KUrl & _url, mode_t _mode = 0, K3Icon::Group _group = K3Icon::Desktop,
                                    int _force_size = 0, int _state = 0, QString * _path = 0 );
 
-  /**
-   * Constants used to specify the type of a UDSField.
-   */
-  enum UDSFieldTypes {
-
-    // First let's define the item types: bit field
-
-    /// Indicates that the field is a QString
-    UDS_STRING = 0x01000000,
-    /// Indicates that the field is a number (long long)
-    UDS_NUMBER   = 0x02000000,
-    /// Indicates that the field represents a time, which is modelled by a long long
-    UDS_TIME   = 0x04000000 | UDS_NUMBER,
-
-    // The rest isn't a bit field
-
-    /// Size of the file
-    UDS_SIZE = 1 | UDS_NUMBER,
-    /// @internal
-    UDS_SIZE_LARGE = 2 | UDS_NUMBER,
-    /// User ID of the file owner
-    UDS_USER = 3 | UDS_STRING,
-    /// Name of the icon, that should be used for displaying.
-    /// It overrides all other detection mechanisms
-    UDS_ICON_NAME = 4 | UDS_STRING,
-    /// Group ID of the file owner
-    UDS_GROUP =	5 | UDS_STRING,
-    /// Filename - as displayed in directory listings etc.
-    /// "." has the usual special meaning of "current directory"
-    UDS_NAME = 6 | UDS_STRING,
-    /// A local file path if the ioslave display files sitting
-    /// on the local filesystem (but in another hierarchy, e.g. media:/)
-    UDS_LOCAL_PATH = 7 | UDS_STRING,
-    /// Treat the file as a hidden file (if set to 1) or as a normal file (if set to 0).
-    /// This field overrides the default behavior (the check for a leading dot in the filename).
-    UDS_HIDDEN = 8 | UDS_NUMBER,
-    /// Access permissions (part of the mode returned by stat)
-    UDS_ACCESS = 9 | UDS_NUMBER,
-    /// The last time the file was modified
-    UDS_MODIFICATION_TIME = 10 | UDS_TIME,
-    /// The last time the file was opened
-    UDS_ACCESS_TIME = 11 | UDS_TIME,
-    /// The time the file was created
-    UDS_CREATION_TIME = 12 | UDS_TIME,
-    /// File type, part of the mode returned by stat
-    /// (for a link, this returns the file type of the pointed item)
-    /// check UDS_LINK_DEST to know if this is a link
-    UDS_FILE_TYPE = 13 | UDS_NUMBER,
-    /// Name of the file where the link points to
-    /// Allows to check for a symlink (don't use S_ISLNK !)
-    UDS_LINK_DEST = 14 | UDS_STRING,
-    /// An alternative URL (If different from the caption)
-    UDS_URL = 15 | UDS_STRING,
-    /// A mime type; the slave should set it if it's known.
-    UDS_MIME_TYPE = 16 | UDS_STRING,
-    /// A mime type to be used for displaying only.
-    /// But when 'running' the file, the mimetype is re-determined
-    /// This is for special cases like symlinks in FTP; you probably don't want to use this one.
-    UDS_GUESSED_MIME_TYPE = 17 | UDS_STRING,
-    /// XML properties, e.g. for WebDAV
-    UDS_XML_PROPERTIES = 18 | UDS_STRING,
-
-    /// Indicates that the entry has extended ACL entries
-    UDS_EXTENDED_ACL = 19 | UDS_NUMBER,
-    /// The access control list serialized into a single string.
-    UDS_ACL_STRING = 20 | UDS_STRING,
-    /// The default access control list serialized into a single string.
-    /// Only available for directories.
-    UDS_DEFAULT_ACL_STRING = 21 | UDS_STRING,
-
-    /// Extra data (used only if you specified Columns/ColumnsTypes)
-    /// KDE 4.0 change: you cannot repeat this entry anymore, use UDS_EXTRA + i
-    /// until UDS_EXTRA_END.
-    UDS_EXTRA = 100 | UDS_STRING,
-    /// Extra data (used only if you specified Columns/ColumnsTypes)
-    /// KDE 4.0 change: you cannot repeat this entry anymore, use UDS_EXTRA + i
-    /// until UDS_EXTRA_END.
-    UDS_EXTRA_END = 140 | UDS_STRING
-  };
-
-/**
- * A field inside a UDSEntry, to store information about a file or URL.
- * Each field is for instance the name, the size, the modification time of the file, etc.
- * You never need to use this class directly, see UDSEntry for the public API.
- */
-class KIO_EXPORT UDSField // KDE4: naming: I would get rid of "UDS" everywhere, but what about the UDS_X constants?
-{
-public:
-  /// @internal needed by QHash
-  UDSField() {}
-  /**
-   * Create a field holding a string.
-   * This constructor is called implicitly when doing
-   * \code
-   * entry.insert( KIO::UDS_XXX, myString )
-   * \endcode
-   */
-  UDSField( const QString& s ) : m_str( s ) {}
-  /**
-   * Create a field holding a long long.
-   * This constructor is called implicitly when doing
-   * \code
-   * entry.insert( KIO::UDS_XXX, myNumber )
-   * \endcode
-   */
-  UDSField( long long l ) : m_long( l ) {}
-
-  /**
-   * @return the string value held by this UDSField
-   */
-  QString toString() const { return m_str; }
-
-  /**
-   * @return the number value held by this UDSField
-   */
-  long long toNumber() const { return m_long; }
-
-private:
-  /// Whether 'm_str' or 'm_long' is used depends on the field type, stored as the key in UDSEntry.
-  QString m_str;
-  /// Whether 'm_str' or 'm_long' is used depends on the field type, stored as the key in UDSEntry.
-  long long m_long;
-};
-
-/**
- * Universal Directory Service
- *
- * UDS entry is the data structure representing all the fields about a given URL
- * (file or directory).
- *
- * The KIO::listDir() and KIO:stat() operations use this data structure.
- *
- * KIO defines a number of fields, see the UDS_XXX enums (see UDSFieldTypes).
- *
- * UDSEntry is a hashtable, so you can retrieve fields directly.
- * For instance, to retrieve the name of the entry, use:
- * \code
- * QString displayName = entry.stringValue( KIO::UDS_NAME );
- * \endcode
- *
- * To know the modification time of the file/url:
- * \code
- *  time_t mtime = entry.numberValue( KIO::UDS_MODIFICATION_TIME, -1 );
- *  if ( mtime != -1 )
- *      ...
- * \endcode
- */
-class UDSEntry : public QHash<uint, UDSField>
-{
-public:
-  QString stringValue( uint field ) const {
-    return value( field ).toString();
-  }
-  long long numberValue( uint field, long long defaultValue = 0 ) const {
-    const_iterator it = find( field );
-    return it != constEnd() ? it.value().toNumber() : defaultValue;
-  }
-
-  // Convenience methods.
-  // Let's not add one method per field, only methods that have some more logic
-  // than just calling stringValue(field) or numberValue(field).
-
-  /// @return true if this entry is a directory (or a link to a directory)
-  bool isDir() const { return S_ISDIR( numberValue( KIO::UDS_FILE_TYPE ) ); }
-  /// @return true if this entry is a link
-  bool isLink() const { return !stringValue( KIO::UDS_LINK_DEST ).isEmpty(); }
-};
-
-/**
- * A directory listing is a list of UDSEntry instances.
- *
- * To list the name and size of all the files in a directory listing you would do:
- * \code
- *   KIO::UDSEntryList::ConstIterator it = entries.begin();
- *   const KIO::UDSEntryList::ConstIterator end = entries.end();
- *   for (; it != end; ++it) {
- *     const KIO::UDSEntry& entry = *it;
- *     QString name = entry.stringValue( KIO::UDS_NAME );
- *     bool isDir = entry.isDir();
- *     KIO::filesize_t size = entry.numberValue( KIO::UDS_SIZE, -1 );
- *     ...
- *   }
- * \endcode
- */
-typedef QList<UDSEntry> UDSEntryList;
+  KIO_EXPORT KUiServerJobTracker *getJobTracker();
 
 
 /**
@@ -619,12 +379,12 @@ public:
   /**
    * Creates an empty meta data map.
    */
-   MetaData() : QMap<QString, QString>() { };
+   MetaData() : QMap<QString, QString>() { }
   /**
    * Copy constructor.
    */
    MetaData(const QMap<QString, QString>&metaData) :
-     QMap<QString, QString>(metaData) { };
+     QMap<QString, QString>(metaData) { }
 
    /**
     * Adds the given meta data map to this map.
