@@ -19,8 +19,8 @@
     Boston, MA 02110-1301, USA.
 */
 
-#ifndef __kio_job_h__
-#define __kio_job_h__
+#ifndef KIO_JOB_H
+#define KIO_JOB_H
 
 #include <kio/jobclasses.h>
 
@@ -64,6 +64,26 @@ namespace KIO {
      */
     KIO_EXPORT SimpleJob * chmod( const KUrl& url, int permissions );
 
+    /**
+     * Changes ownership and group of a file or directory.
+     *
+     * @param url The URL of file or directory.
+     * @param owner the new owner
+     * @param group the new group
+     * @return the job handling the operation.
+     */
+    KIO_EXPORT SimpleJob * chown( const KUrl& url, const QString& owner, const QString& group );
+
+    /**
+     * Changes the modification time on a file or directory.
+     *
+     * @param url The URL of file or directory.
+     * @param permissions The permissions to set.
+     * @return the job handling the operation.
+     */
+    KIO_EXPORT SimpleJob *setModificationTime( const KUrl& url, const QDateTime& mtime );
+
+
     /**
      * Rename a file or directory.
      * Warning: this operation fails if a direct renaming is not
@@ -148,6 +168,35 @@ namespace KIO {
      * @return the job handling the operation.
      */
     KIO_EXPORT StatJob * stat( const KUrl& url, bool showProgressInfo = true );
+    /**
+     * Find all details for one file or directory.
+     * This version of the call includes two additional booleans, @p sideIsSource and @p details.
+     *
+     * @param url the URL of the file
+     * @param side is SourceSide when stating a source file (we will do a get on it if
+     * the stat works) and DestinationSide when stating a destination file (target of a copy).
+     * The reason for this parameter is that in some cases the kioslave might not
+     * be able to determine a file's existence (e.g. HTTP doesn't allow it, FTP
+     * has issues with case-sensitivity on some systems).
+     * When the slave can't reliably determine the existence of a file, it will:
+     * @li be optimistic if SourceSide, i.e. it will assume the file exists,
+     * and if it doesn't this will appear when actually trying to download it
+     * @li be pessimistic if DestinationSide, i.e. it will assume the file
+     * doesn't exist, to prevent showing "about to overwrite" errors to the user.
+     * If you simply want to check for existence without downloading/uploading afterwards,
+     * then you should use DestinationSide.
+     *
+     * @param details selects the level of details we want.
+     * By default this is 2 (all details wanted, including modification time, size, etc.),
+     * setDetails(1) is used when deleting: we don't need all the information if it takes
+     * too much time, no need to follow symlinks etc.
+     * setDetails(0) is used for very simple probing: we'll only get the answer
+     * "it's a file or a directory, or it doesn't exist". This is used by KRun.
+     * @param showProgressInfo true to show progress information
+     * @return the job handling the operation.
+     */
+    KIO_EXPORT StatJob * stat( const KUrl& url, KIO::StatJob::StatSide side,
+                               short int details, bool showProgressInfo = true );
     /**
      * Find all details for one file or directory.
      * This version of the call includes two additional booleans, @p sideIsSource and @p details.
@@ -175,7 +224,8 @@ namespace KIO {
      * @param showProgressInfo true to show progress information
      * @return the job handling the operation.
      */
-    KIO_EXPORT StatJob * stat( const KUrl& url, bool sideIsSource, short int details, bool showProgressInfo = true );
+    KIO_EXPORT_DEPRECATED StatJob * stat( const KUrl& url, bool sideIsSource,
+                                          short int details, bool showProgressInfo = true );
 
     /**
      * Get (a.k.a. read).
@@ -193,10 +243,12 @@ namespace KIO {
      *
      * The file-job emits open() when opened
      * @param url the URL of the file
-     * @param access the access privileges (1 - ReadOnly, 2 - WriteOnly, 3 - Read/Write)
-     * @return the file-handling job
+     * @param mode the access privileges: see \ref OpenMode
+     *
+     * @return The file-handling job. It will never return 0. Errors are handled asynchronously
+     * (emitted as signals).
      */
-    KIO_EXPORT FileJob *open( const KUrl& url, int access );
+    KIO_EXPORT FileJob *open(const KUrl &url, QIODevice::OpenMode mode);
 
     /**
      * Put (a.k.a. write)
