@@ -19,27 +19,25 @@
     Boston, MA 02110-1301, USA.
 */
 
-#ifndef __kio_jobclasses_h__
-#define __kio_jobclasses_h__
+#ifndef KIO_JOBCLASSES_H
+#define KIO_JOBCLASSES_H
 
-#include <qobject.h>
-#include <qlinkedlist.h>
-#include <qstringlist.h>
+#include <QtCore/QObject>
+#include <QtCore/QLinkedList>
+#include <QtCore/QStringList>
 
 #include <kurl.h>
 #include <kio/global.h>
+#include <kio/udsentry.h>
 
 #include <kcompositejob.h>
 
-class Observer;
-class QTimer;
 
 namespace KIO {
 
     class JobUiDelegate;
-    class Slave;
-    class SlaveInterface;
 
+    class JobPrivate;
     /**
      * The base class for all jobs.
      * For all jobs created in an application, the code looks like
@@ -58,13 +56,13 @@ namespace KIO {
      *      job->ui()->showErrorDialog();
      * \endcode
      * @see KIO::Scheduler
-     * @see KIO::Slave
      */
     class KIO_EXPORT Job : public KCompositeJob {
         Q_OBJECT
 
     protected:
-        Job( bool showProgressInfo );
+        Job();
+        Job(JobPrivate &dd);
 
     public:
         virtual ~Job();
@@ -79,6 +77,7 @@ namespace KIO {
          */
         JobUiDelegate *ui() const;
 
+    protected:
         /**
          * Abort this job.
          * This kills all subjobs and deletes the job.
@@ -86,25 +85,19 @@ namespace KIO {
          */
         virtual bool doKill();
 
-public Q_SLOTS:
         /**
          * Suspend this job
          * @see resume
          */
-        virtual void suspend();
+        virtual bool doSuspend();
 
         /**
          * Resume this job
          * @see suspend
          */
-        virtual void resume();
-
-public:
-        /**
-         * @return true if this job was suspended by suspend()
-         */
-        bool isSuspended() const;
+        virtual bool doResume();
 
+    public:
         /**
          * Converts an error code and a non-i18n error message into an
          * error message in the current language. The low level (non-i18n)
@@ -159,7 +152,7 @@ public:
 
         /**
          * Set the parent Job.
-         * One example use of this is when FileCopyJob calls open_RenameDialog,
+         * One example use of this is when FileCopyJob calls RenameDialog::open,
          * it must pass the correct progress ID of the parent CopyJob
          * (to hide the progress dialog).
 	 * You can set the parent job only once. By default a job does not
@@ -232,6 +225,8 @@ public:
          */
         QString queryMetaData(const QString &key);
 
+    protected:
+
     Q_SIGNALS:
         /**
          * @deprecated. Don't use !
@@ -250,27 +245,6 @@ public:
          */
         void connected( KIO::Job *job );
 
-        /**
-         * Emitted to display information about the speed of this job.
-	 * @param job the job that emitted this signal
-	 * @param speed the speed in bytes/s
-         */
-        void speed( KJob *job, unsigned long speed );
-
-    protected Q_SLOTS:
-        /**
-         * Forward signal from subjob.
-	 * @param job the subjob
-	 * @param speed the speed in bytes/s
-	 * @see speed()
-         */
-        void slotSpeed( KJob *job, unsigned long speed );
-
-        /**
-         * Remove speed information.
-         */
-        void slotSpeedTimeout();
-
     protected:
         /**
          * Add a job that has to be finished before a result
@@ -292,38 +266,20 @@ public:
          * @param mergeMetaData if set, the metadata received by the subjob is
          *                      merged into this job.
          */
-        void removeSubjob( KJob *job, bool mergeMetaData = false );
-
-        /**
-         * Utility function for inherited jobs.
-         * Emits the speed signal and starts the timer for removing that info
-	 *
-	 * @param speed the speed in bytes/s
-         */
-        void emitSpeed( unsigned long speed );
-
-        /**
-         * @internal
-         * Some extra storage space for jobs that don't have their own
-         * private d pointer.
-         */
-        enum { EF_TransferJobAsync    = (1 << 0),
-               EF_TransferJobNeedData = (1 << 1),
-               EF_TransferJobDataSent = (1 << 2),
-               EF_ListJobUnrestricted = (1 << 3) };
-        int &extraFlags();
-
-        MetaData m_incomingMetaData;
-        MetaData m_outgoingMetaData;
+        bool removeSubjob( KJob *job, bool mergeMetaData = false );
 
     private:
-        QTimer *m_speedTimer;
-
-        class JobPrivate;
-        JobPrivate *d;
+        /**
+         * Forward signal from subjob.
+	 * @param job the subjob
+	 * @param speed the speed in bytes/s
+	 * @see speed()
+         */
+        Q_PRIVATE_SLOT(d_func(), void slotSpeed( KJob *job, unsigned long speed ))
+        Q_DECLARE_PRIVATE(Job)
     };
 
-
+    class SimpleJobPrivate;
     /**
      * A simple job (one url and one command).
      * This is the base class for all jobs that are scheduled.
@@ -334,38 +290,20 @@ public:
     Q_OBJECT
 
     public:
-        /**
-	 * Creates a new simple job. You don't need to use this constructor,
-	 * unless you create a new job that inherits from SimpleJob.
-	 * @param url the url of the job
-	 * @param command the command of the job
-	 * @param packedArgs the arguments
-	 * @param showProgressInfo true to show progress information to the user
-	 */
-        SimpleJob(const KUrl& url, int command, const QByteArray &packedArgs,
-                  bool showProgressInfo);
-
         ~SimpleJob();
 
-        virtual void start();
-
+    protected:
         /**
          * Suspend this job
          * @see resume
          */
-        virtual void suspend();
+        virtual bool doSuspend();
 
         /**
          * Resume this job
          * @see suspend
          */
-        virtual void resume();
-
-        /**
-	 * Returns the SimpleJob's URL
-	 * @return the url
-	 */
-        const KUrl& url() const { return m_url; }
+        virtual bool doResume();
 
         /**
          * Abort job.
@@ -373,6 +311,13 @@ public:
          */
         virtual bool doKill();
 
+    public:
+        /**
+	 * Returns the SimpleJob's URL
+	 * @return the url
+	 */
+        const KUrl& url() const;
+
         /**
          * Abort job.
          * Suspends slave to be reused by another job for the same request.
@@ -384,37 +329,13 @@ public:
          */
         static void removeOnHold();
 
-        /**
-         * @internal
-         * Called by the scheduler when a slave gets to
-         * work on this job.
-         **/
-        virtual void start( Slave *slave );
-
-        /**
-         * @internal
-         * Called to detach a slave from a job.
-         **/
-        void slaveDone();
-
-        /**
-         * @internal
-         * Slave in use by this job.
-         */
-        Slave *slave() const { return m_slave; }
-
-        /**
-         * @internal
-         */
-        int command() const { return m_command; }
-
     public Q_SLOTS:
         /**
-         * Forward signal from the slave
-         * Can also be called by the parent job, when it knows the size.
-	 * @param data_size the total size
+         * @internal
+         * Called on a slave's error.
+         * Made public for the scheduler.
          */
-        void slotTotalSize( KIO::filesize_t data_size );
+        void slotError( int , const QString & );
 
     protected Q_SLOTS:
         /**
@@ -436,25 +357,6 @@ public:
          */
         virtual void slotInfoMessage( const QString &s );
 
-        /**
-         * Called on a slave's connected signal.
-	 * @see connected()
-         */
-        void slotConnected();
-
-        /**
-         * Forward signal from the slave.
-	 * @param data_size the processed size in bytes
-	 * @see processedSize()
-         */
-        void slotProcessedSize( KIO::filesize_t data_size );
-        /**
-         * Forward signal from the slave.
-	 * @param speed the speed in bytes/s
-	 * @see speed()
-         */
-        void slotSpeed( unsigned long speed );
-
         /**
          * MetaData from the slave is received.
 	 * @param _metaData the meta data
@@ -462,27 +364,6 @@ public:
          */
         virtual void slotMetaData( const KIO::MetaData &_metaData);
 
-    public Q_SLOTS:
-        /**
-         * @internal
-         * Called on a slave's error.
-         * Made public for the scheduler.
-         */
-        virtual void slotError( int , const QString & );
-
-    protected Q_SLOTS:
-        /**
-         * @internal
-         */
-        void slotNeedProgressId();
-
-    protected:
-        Slave * m_slave;
-        QByteArray m_packedArgs;
-        KUrl m_url;
-        KUrl m_subUrl;
-        int m_command;
-        KIO::filesize_t m_totalSize;
     protected:
 	/*
 	 * Allow jobs that inherit SimpleJob and are aware
@@ -492,10 +373,22 @@ public:
 	 * used instead of m_url if not empty
 	 */
 	void storeSSLSessionFromJob(const KUrl &m_redirectionURL);
+
+        /**
+	 * Creates a new simple job. You don't need to use this constructor,
+	 * unless you create a new job that inherits from SimpleJob.
+	 */
+        SimpleJob(SimpleJobPrivate &dd);
     private:
-	class SimpleJobPrivate* d;
+        Q_PRIVATE_SLOT(d_func(), void slotConnected())
+        Q_PRIVATE_SLOT(d_func(), void slotProcessedSize( KIO::filesize_t data_size ))
+        Q_PRIVATE_SLOT(d_func(), void slotSpeed( unsigned long speed ))
+        Q_PRIVATE_SLOT(d_func(), void slotTotalSize( KIO::filesize_t data_size ))
+
+        Q_DECLARE_PRIVATE(SimpleJob)
     };
 
+    class StatJobPrivate;
     /**
      * A KIO job that retrieves information about a file or directory.
      * @see KIO::stat()
@@ -505,14 +398,21 @@ public:
     Q_OBJECT
 
     public:
+        enum StatSide {
+            SourceSide,
+            DestinationSide
+        };
+
+        ~StatJob();
+
         /**
-	 * Do not use this constructor to create a StatJob, use KIO::stat() instead.
-	 * @param url the url of the file or directory to check
-	 * @param command the command to issue
-	 * @param packedArgs the arguments
-	 * @param showProgressInfo true to show progress information to the user
-	 */
-        StatJob(const KUrl& url, int command, const QByteArray &packedArgs, bool showProgressInfo);
+	 * A stat() can have two meanings. Either we want to read from this URL,
+         * or to check if we can write to it. First case is "source", second is "dest".
+         * It is necessary to know what the StatJob is for, to tune the kioslave's behavior
+         * (e.g. with FTP).
+	 * @param side SourceSide or DestinationSide
+         */
+        void setSide(StatSide side);
 
         /**
 	 * A stat() can have two meanings. Either we want to read from this URL,
@@ -521,7 +421,7 @@ public:
          * (e.g. with FTP).
 	 * @param source true for "source" mode, false for "dest" mode
          */
-        void setSide( bool source ) { m_bSource = source; }
+        KDE_DEPRECATED void setSide( bool source );
 
         /**
          * Selects the level of @p details we want.
@@ -532,22 +432,14 @@ public:
          * "it's a file or a directory, or it doesn't exist". This is used by KRun.
 	 * @param details 2 for all details, 1 for simple, 0 for very simple
          */
-        void setDetails( short int details ) { m_details = details; }
+        void setDetails( short int details );
 
         /**
          * Call this in the slot connected to result,
          * and only after making sure no error happened.
 	 * @return the result of the stat
          */
-        const UDSEntry & statResult() const { return m_statResult; }
-
-        /**
-	 * @internal
-         * Called by the scheduler when a @p slave gets to
-         * work on this job.
-	 * @param slave the slave that starts working on this job
-         */
-        virtual void start( Slave *slave );
+        const UDSEntry & statResult() const;
 
     Q_SIGNALS:
         /**
@@ -569,112 +461,19 @@ public:
         void permanentRedirection( KIO::Job *job, const KUrl &fromUrl, const KUrl &toUrl );
 
     protected Q_SLOTS:
-        void slotStatEntry( const KIO::UDSEntry & entry );
-        void slotRedirection( const KUrl &url);
         virtual void slotFinished();
         virtual void slotMetaData( const KIO::MetaData &_metaData);
-
     protected:
-        UDSEntry m_statResult;
-        KUrl m_redirectionURL;
-        bool m_bSource;
-        short int m_details;
-    private:
-        class StatJobPrivate;
-        StatJobPrivate *d;
-    };
-
-    /**
-     * A KIO job that creates a directory
-     * @see KIO::mkdir()
-     */
-    class KIO_EXPORT MkdirJob : public SimpleJob {
-
-    Q_OBJECT
-
-    public:
-        /**
-	 * Do not use this constructor to create a MkdirJob, use KIO::mkdir() instead.
-	 * @param url the url of the file or directory to check
-	 * @param command the command to issue
-	 * @param packedArgs the arguments
-	 * @param showProgressInfo true to show progress information to the user
-	 */
-        MkdirJob(const KUrl& url, int command, const QByteArray &packedArgs, bool showProgressInfo);
-
-        /**
-	 * @internal
-         * Called by the scheduler when a @p slave gets to
-         * work on this job.
-	 * @param slave the slave that starts working on this job
-         */
-        virtual void start( Slave *slave );
-
-    Q_SIGNALS:
-        /**
-         * Signals a redirection.
-         * Use to update the URL shown to the user.
-         * The redirection itself is handled internally.
-	 * @param job the job that is redirected
-	 * @param url the new url
-         */
-        void redirection( KIO::Job *job, const KUrl &url );
-
-        /**
-         * Signals a permanent redirection.
-         * The redirection itself is handled internally.
-	 * @param job the job that is redirected
-	 * @param fromUrl the original URL
-	 * @param toUrl the new URL
-         */
-        void permanentRedirection( KIO::Job *job, const KUrl &fromUrl, const KUrl &toUrl );
-
-    protected Q_SLOTS:
-        void slotRedirection( const KUrl &url);
-        virtual void slotFinished();
-
-    protected:
-        KUrl m_redirectionURL;
+        StatJob(StatJobPrivate &dd);
 
     private:
-        class MkdirJobPrivate;
-        MkdirJobPrivate *d;
+        Q_PRIVATE_SLOT(d_func(), void slotStatEntry( const KIO::UDSEntry & entry ))
+        Q_PRIVATE_SLOT(d_func(), void slotRedirection( const KUrl &url))
+        Q_DECLARE_PRIVATE(StatJob)
     };
 
-    /**
-     * @internal
-     * Used for direct copy from or to the local filesystem (i.e. SlaveBase::copy())
-     */
-    class KIO_EXPORT DirectCopyJob : public SimpleJob {
-    Q_OBJECT
-
-    public:
-        /**
-         * Do not create a DirectCopyJob. Use KIO::copy() or KIO::file_copy() instead.
-         */
-        DirectCopyJob(const KUrl& url, int command, const QByteArray &packedArgs,
-                      bool showProgressInfo);
-        /**
-	 * @internal
-         * Called by the scheduler when a @p slave gets to
-         * work on this job.
-	 * @param slave the slave that starts working on this job
-         */
-        virtual void start(Slave *slave);
-
-    Q_SIGNALS:
-        /**
-         * @internal
-         * Emitted if the job found an existing partial file
-         * and supports resuming. Used by FileCopyJob.
-         */
-        void canResume( KIO::Job *job, KIO::filesize_t offset );
-
-    private Q_SLOTS:
-        void slotCanResume( KIO::filesize_t offset );
-    };
-
-
+    class FileCopyJobPrivate;
+    class TransferJobPrivate;
     /**
      * The transfer job pumps data into and/or out of a Slave.
      * Data is sent to the slave on request of the slave ( dataReq).
@@ -685,19 +484,7 @@ public:
     Q_OBJECT
 
     public:
-       /**
-	* Do not create a TransferJob. Use KIO::get() or KIO::put()
-	* instead.
-	* @param url the url to get or put
-	* @param command the command to issue
-	* @param packedArgs the arguments
-	* @param _staticData additional data to transmit (e.g. in a HTTP Post)
-	* @param showProgressInfo true to show progress information to the user
-	*/
-        TransferJob(const KUrl& url, int command,
-                    const QByteArray &packedArgs,
-                    const QByteArray &_staticData,
-                    bool showProgressInfo);
+        ~TransferJob();
 
         /**
          * Sets the modification time of the file to be created (by KIO::put)
@@ -705,35 +492,6 @@ public:
          */
         void setModificationTime( const QDateTime& mtime );
 
-        /**
-	 * @internal
-         * Called by the scheduler when a @p slave gets to
-         * work on this job.
-	 * @param slave the slave that starts working on this job
-         */
-        virtual void start(Slave *slave);
-
-        /**
-         * Called when m_subJob finishes.
-	 * @param job the job that finished
-         */
-        virtual void slotResult( KJob *job );
-
-        /**
-         * Flow control. Suspend data processing from the slave.
-         */
-        void internalSuspend();
-
-        /**
-         * Flow control. Resume data processing from the slave.
-         */
-        void internalResume();
-
-        /**
-         * Reimplemented for internal reasons
-         */
-        virtual void resume();
-
         /**
 	 * Checks whether we got an error page. This currently only happens
 	 * with HTTP urls. Call this from your slot connected to result().
@@ -741,7 +499,7 @@ public:
          * @return true if we got an (HTML) error page from the server
          * instead of what we asked for.
          */
-        bool isErrorPage() const { return m_errorPage; }
+        bool isErrorPage() const;
 
         /**
          * Enable the async data mode.
@@ -771,14 +529,26 @@ public:
          *  sent (true), or whether the job reports the amount of data that
          * has been received (false)
          */
-        bool reportDataSent();
+        bool reportDataSent() const;
 
         /**
          * Call this in the slot connected to result,
          * and only after making sure no error happened.
 	 * @return the mimetype of the URL
          */
-         QString mimetype() const { return m_mimetype; }
+        QString mimetype() const;
+
+    protected:
+        /**
+         * Called when m_subJob finishes.
+	 * @param job the job that finished
+         */
+        virtual void slotResult( KJob *job );
+
+        /**
+         * Reimplemented for internal reasons
+         */
+        virtual bool doResume();
 
     Q_SIGNALS:
         /**
@@ -846,27 +616,24 @@ public:
         virtual void slotData( const QByteArray &data);
         virtual void slotDataReq();
         virtual void slotMimetype( const QString &mimetype );
-        virtual void slotNeedSubUrlData();
-        virtual void slotSubUrlData(KIO::Job*, const QByteArray &);
         virtual void slotMetaData( const KIO::MetaData &_metaData);
-        void slotErrorPage();
-        void slotCanResume( KIO::filesize_t offset );
-        void slotPostRedirection();
 
     protected:
-        bool m_internalSuspended;
-        bool m_errorPage;
-        bool m_unused1;
-        bool m_unused2;
-        QByteArray staticData;
-        KUrl m_redirectionURL;
-        KUrl::List m_redirectionList;
-        QString m_mimetype;
-        TransferJob *m_subJob;
+        TransferJob(TransferJobPrivate &dd);
     private:
-	class TransferJobPrivate *d;
+        Q_PRIVATE_SLOT(d_func(), void slotErrorPage())
+        Q_PRIVATE_SLOT(d_func(), void slotCanResume( KIO::filesize_t offset ))
+        Q_PRIVATE_SLOT(d_func(), void slotPostRedirection())
+        Q_PRIVATE_SLOT(d_func(), void slotNeedSubUrlData())
+        Q_PRIVATE_SLOT(d_func(), void slotSubUrlData(KIO::Job*, const QByteArray &))
+        Q_DECLARE_PRIVATE(TransferJob)
+
+        // A FileCopyJob may control one or more TransferJobs
+        friend class FileCopyJob;
+        friend class FileCopyJobPrivate;
     };
 
+    class StoredTransferJobPrivate;
     /**
      * StoredTransferJob is a TransferJob (for downloading or uploading data) that
      * also stores a QByteArray with the data, making it simpler to use than the
@@ -889,19 +656,7 @@ public:
         Q_OBJECT
 
     public:
-       /**
-	* Do not create a StoredTransferJob. Use storedGet() or storedPut()
-	* instead.
-	* @param url the url to get or put
-	* @param command the command to issue
-	* @param packedArgs the arguments
-	* @param _staticData additional data to transmit (e.g. in a HTTP Post)
-	* @param showProgressInfo true to show progress information to the user
-	*/
-        StoredTransferJob(const KUrl& url, int command,
-                          const QByteArray &packedArgs,
-                          const QByteArray &_staticData,
-                          bool showProgressInfo);
+        ~StoredTransferJob();
 
         /**
          * Set data to be uploaded. This is for put jobs.
@@ -914,16 +669,18 @@ public:
          * Get hold of the downloaded data. This is for get jobs.
          * You're supposed to call this only from the slot connected to the result() signal.
          */
-        QByteArray data() const { return m_data; }
+        QByteArray data() const;
 
-    private Q_SLOTS:
-        void slotStoredData( KIO::Job *job, const QByteArray &data );
-        void slotStoredDataReq( KIO::Job *job, QByteArray &data );
+    protected:
+        StoredTransferJob(StoredTransferJobPrivate &dd);
     private:
-        QByteArray m_data;
-        int m_uploadOffset;
+        Q_PRIVATE_SLOT(d_func(), void slotStoredData( KIO::Job *job, const QByteArray &data ))
+        Q_PRIVATE_SLOT(d_func(), void slotStoredDataReq( KIO::Job *job, QByteArray &data ))
+
+        Q_DECLARE_PRIVATE(StoredTransferJob)
     };
 
+    class MultiGetJobPrivate;
     /**
      * The MultiGetJob is a TransferJob that allows you to get
      * several files from a single server. Don't create directly,
@@ -934,25 +691,8 @@ public:
     Q_OBJECT
 
     public:
-        /**
-	 * Do not create a MultiGetJob directly, use KIO::multi_get()
-	 * instead.
-	 *
-	 * @param url the first url to get
-	 * @param showProgressInfo true to show progress information to the user
-	 */
-        MultiGetJob(const KUrl& url, bool showProgressInfo);
-
         virtual ~MultiGetJob();
 
-        /**
-	 * @internal
-         * Called by the scheduler when a @p slave gets to
-         * work on this job.
-	 * @param slave the slave that starts working on this job
-         */
-         virtual void start(Slave *slave);
-
 	/**
 	 * Get an additional file.
 	 *
@@ -992,28 +732,14 @@ public:
         virtual void slotFinished();
         virtual void slotData( const QByteArray &data);
         virtual void slotMimetype( const QString &mimetype );
-    private:
-        struct GetRequest {
-        public:
-           GetRequest(long _id, const KUrl &_url, const MetaData &_metaData)
-             : id(_id), url(_url), metaData(_metaData) { }
-           long id;
-           KUrl url;
-           MetaData metaData;
-           bool operator==( const GetRequest& req ) const { return req.id == id; }
-        };
-        bool findCurrentEntry();
-        void flushQueue(QLinkedList<GetRequest> &queue);
 
-        typedef QLinkedList<GetRequest> RequestQueue;
-        RequestQueue m_waitQueue;
-        RequestQueue m_activeQueue;
-        bool b_multiGetActive;
-        GetRequest m_currentEntry;
+    protected:
+        MultiGetJob(MultiGetJobPrivate &dd);
     private:
-	class MultiGetJobPrivate* d;
+        Q_DECLARE_PRIVATE(MultiGetJob)
     };
 
+    class MimetypeJobPrivate;
     /**
      * A MimetypeJob is a TransferJob that  allows you to get
      * the mime type of an URL. Don't create directly,
@@ -1024,28 +750,14 @@ public:
     Q_OBJECT
 
     public:
-       /**
-	* Do not create a MimetypeJob directly. Use KIO::mimetype()
-	* instead.
-	* @param url the url to get
-	* @param command the command to issue
-	* @param packedArgs the arguments
-	* @param showProgressInfo true to show progress information to the user
-	*/
-        MimetypeJob(const KUrl& url, int command, const QByteArray &packedArgs, bool showProgressInfo);
-
-        /**
-	 * @internal
-         * Called by the scheduler when a slave gets to
-         * work on this job.
-	 * @param slave the slave that works on the job
-         */
-        virtual void start( Slave *slave );
+        ~MimetypeJob();
 
     protected Q_SLOTS:
         virtual void slotFinished( );
+    protected:
+        MimetypeJob(MimetypeJobPrivate &dd);
     private:
-	class MimetypeJobPrivate* d;
+        Q_DECLARE_PRIVATE(MimetypeJob)
     };
 
     /**
@@ -1057,20 +769,6 @@ public:
     Q_OBJECT
 
     public:
-	/**
-	* Do not create a FileCopyJob directly. Use KIO::file_move()
-	* or KIO::file_copy() instead.
-	* @param src the source URL
-	* @param dest the destination URL
-	* @param permissions the permissions of the resulting resource
-	* @param move true to move, false to copy
-	* @param overwrite true to allow overwriting, false otherwise
-	* @param resume true to resume an operation, false otherwise
-	* @param showProgressInfo true to show progress information to the user
-	 */
-        FileCopyJob( const KUrl& src, const KUrl& dest, int permissions,
-                     bool move, bool overwrite, bool resume, bool showProgressInfo);
-
         ~FileCopyJob();
         /**
          * If you know the size of the source file, call this method
@@ -1092,13 +790,16 @@ public:
 	 * Returns the source URL.
 	 * @return the source URL
 	 */
-        KUrl srcUrl() const { return m_src; }
+        KUrl srcUrl() const;
 
 	/**
 	 * Returns the destination URL.
 	 * @return the destination URL
 	 */
-        KUrl destUrl() const { return m_dest; }
+        KUrl destUrl() const;
+
+        bool doSuspend();
+        bool doResume();
 
     Q_SIGNALS:
         /**
@@ -1113,12 +814,6 @@ public:
          */
         void mimetype( KIO::Job *job, const QString &type );
 
-    public Q_SLOTS:
-        void slotStart();
-        void slotData( KIO::Job *, const QByteArray &data);
-        void slotDataReq( KIO::Job *, QByteArray &data);
-        void slotMimetype( KIO::Job*, const QString& type );
-
     protected Q_SLOTS:
         /**
          * Called whenever a subjob finishes.
@@ -1126,61 +821,23 @@ public:
          */
         virtual void slotResult( KJob *job );
 
-        /**
-         * Forward signal from subjob
-	 * @param job the job that emitted this signal
-	 * @param size the processed size in bytes
-         */
-        void slotProcessedSize( KJob *job, qulonglong size );
-        /**
-         * Forward signal from subjob
-	 * @param job the job that emitted this signal
-	 * @param size the total size
-         */
-        void slotTotalSize( KJob *job, qulonglong size );
-        /**
-         * Forward signal from subjob
-	 * @param job the job that emitted this signal
-	 * @param pct the percentage
-         */
-        void slotPercent( KJob *job, unsigned long pct );
-        /**
-         * Forward signal from subjob
-	 * @param job the job that emitted this signal
-	 * @param offset the offset to resume from
-         */
-        void slotCanResume( KIO::Job *job, KIO::filesize_t offset );
-
     protected:
-        void startCopyJob();
-        void startCopyJob(const KUrl &slave_url);
-        void startRenameJob(const KUrl &slave_url);
-        void startDataPump();
-        void connectSubjob( SimpleJob * job );
+        FileCopyJob(FileCopyJobPrivate &dd);
 
     private:
-        void startBestCopyMethod();
+        Q_PRIVATE_SLOT(d_func(), void slotStart())
+        Q_PRIVATE_SLOT(d_func(), void slotData( KIO::Job *, const QByteArray &data))
+        Q_PRIVATE_SLOT(d_func(), void slotDataReq( KIO::Job *, QByteArray &data))
+        Q_PRIVATE_SLOT(d_func(), void slotMimetype( KIO::Job*, const QString& type ))
+        Q_PRIVATE_SLOT(d_func(), void slotProcessedSize( KJob *job, qulonglong size ))
+        Q_PRIVATE_SLOT(d_func(), void slotTotalSize( KJob *job, qulonglong size ))
+        Q_PRIVATE_SLOT(d_func(), void slotPercent( KJob *job, unsigned long pct ))
+        Q_PRIVATE_SLOT(d_func(), void slotCanResume( KIO::Job *job, KIO::filesize_t offset ))
 
-    protected:
-        KUrl m_src;
-        KUrl m_dest;
-        int m_permissions;
-        bool m_move:1;
-        bool m_overwrite:1;
-        bool m_resume:1;
-        bool m_canResume:1;
-        bool m_resumeAnswerSent:1;
-        QByteArray m_buffer;
-        SimpleJob *m_moveJob;
-        SimpleJob *m_copyJob;
-        TransferJob *m_getJob;
-        TransferJob *m_putJob;
-        KIO::filesize_t m_totalSize;
-    private:
-	class FileCopyJobPrivate;
-	FileCopyJobPrivate* d;
+        Q_DECLARE_PRIVATE(FileCopyJob)
     };
 
+    class ListJobPrivate;
     /**
      * A ListJob is allows you to get the get the content of a directory.
      * Don't create the job directly, but use KIO::listRecursive() or
@@ -1192,34 +849,14 @@ public:
     Q_OBJECT
 
     public:
-       /**
-	* Do not create a ListJob directly. Use KIO::listDir() or
-	* KIO::listRecursive() instead.
-	* @param url the url of the directory
-	* @param showProgressInfo true to show progress information to the user
-	* @param recursive true to get the data recursively from child directories,
-	*        false to get only the content of the specified dir
-	* @param prefix the prefix of the files, or QString() for no prefix
-	* @param includeHidden true to include hidden files (those starting with '.')
-	*/
-        ListJob(const KUrl& url, bool showProgressInfo,
-                bool recursive = false, const QString &prefix = QString(),
-                bool includeHidden = true);
-
-        /**
-	 * @internal
-         * Called by the scheduler when a @p slave gets to
-         * work on this job.
-	 * @param slave the slave that starts working on this job
-         */
-        virtual void start( Slave *slave );
+        ~ListJob();
 
         /**
          * Returns the ListJob's redirection URL. This will be invalid if there
          * was no redirection.
          * @return the redirection url
          */
-        const KUrl& redirectionUrl() const { return m_redirectionURL; }
+        const KUrl& redirectionUrl() const;
 
         /**
          * Do not apply any KIOSK restrictions to this job.
@@ -1260,18 +897,58 @@ public:
         virtual void slotFinished( );
         virtual void slotMetaData( const KIO::MetaData &_metaData);
         virtual void slotResult( KJob *job );
-        void slotListEntries( const KIO::UDSEntryList& list );
-        void slotRedirection( const KUrl &url );
-        void gotEntries( KIO::Job * subjob, const KIO::UDSEntryList& list );
+
+    protected:
+        ListJob(ListJobPrivate &dd);
 
     private:
-        bool recursive;
-        bool includeHidden;
-        QString prefix;
-        unsigned long m_processedEntries;
-        KUrl m_redirectionURL;
+        Q_PRIVATE_SLOT(d_func(), void slotListEntries( const KIO::UDSEntryList& list ))
+        Q_PRIVATE_SLOT(d_func(), void slotRedirection( const KUrl &url ))
+        Q_PRIVATE_SLOT(d_func(), void gotEntries( KIO::Job * subjob, const KIO::UDSEntryList& list ))
+        Q_DECLARE_PRIVATE(ListJob)
+    };
+
+    class SpecialJobPrivate;
+    /**
+     * A class that sends a special command to an ioslave.
+     * This allows you to send a binary blob to an ioslave and handle
+     * its responses. The ioslave will receive the binary data as an
+     * argument to the "special" function (inherited from SlaveBase::special()).
+     *
+     * Use this only on ioslaves that belong to your application. Sending
+     * special commands to other ioslaves may cause unexpected behaviour.
+     *
+     * @see KIO::special
+     */
+    class KIO_EXPORT SpecialJob : public TransferJob
+    {
+        Q_OBJECT
+    public:
+        /**
+         * Creates a KIO::SpecialJob.
+         *
+         * @param url the URL to be passed to the ioslave
+         * @param data the data to be sent to the SlaveBase::special() function.
+         */
+        explicit SpecialJob(const KUrl &url, const QByteArray &data = QByteArray());
+
+        /**
+         * Sets the QByteArray that is passed to SlaveBase::special() on
+         * the ioslave.
+         */
+        void setArguments(const QByteArray &data);
+
+        /**
+         * Returns the QByteArray data that will be sent (or has been sent) to the
+         * ioslave.
+         */
+        QByteArray arguments() const;
+
+    public:
+        ~SpecialJob();
+
     private:
-	class ListJobPrivate* d;
+        Q_DECLARE_PRIVATE(SpecialJob)
     };
 }
 
