@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2005 Till Adam <adam@kde.org>
+   Copyright (C) 2005 - 2007 Till Adam <adam@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -18,6 +18,8 @@
 */
 // $Id: kacl.cpp 424977 2005-06-13 15:13:22Z tilladam $
 
+#include "kacl.h"
+
 #include <config-acl.h>
 
 #include <sys/types.h>
@@ -32,8 +34,6 @@
 
 #include <kdebug.h>
 
-#include "kacl.h"
-
 #include <QList>
 #include <QPair>
 
@@ -166,7 +166,7 @@ static void permissionsToEntry( acl_entry_t entry, unsigned short v )
 static void printACL( acl_t acl, const QString &comment )
 {
     ssize_t size = acl_size( acl );
-    kDebug() << comment << acl_to_text( acl, &size ) << endl;
+    kDebug() << comment << acl_to_text( acl, &size );
 }
 #endif
 #endif
