@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2005 Till Adam <adam@kde.org>
+   Copyright (C) 2005 - 2007 Till Adam <adam@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -17,8 +17,8 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef __kacl_h__
-#define __kacl_h__
+#ifndef KACL_H
+#define KACL_H
 
 
 #include <sys/types.h>
@@ -39,7 +39,7 @@ typedef QList<ACLGroupPermissions>::iterator ACLGroupPermissionsIterator;
 typedef QList<ACLGroupPermissions>::const_iterator ACLGroupPermissionsConstIterator;
 
 /**
- * The KCAL class encapsulates a POSIX Access Control List. It follows the 
+ * The KACL class encapsulates a POSIX Access Control List. It follows the 
  * little standard that couldn't, 1003.1e/1003.2c, which died in draft status.
  * @short a POSIX ACL encapsulation
  * @author Till Adam <adam@kde.org>
