@@ -19,21 +19,19 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "karchive.h"
 #include "klimitediodevice.h"
 
+#include <config.h>
+
 #include <kdebug.h>
 #include <ksavefile.h>
 #include <kde_file.h>
 
 #include <QStack>
-#include <qmap.h>
-#include <qdir.h>
-#include <qfile.h>
+#include <QtCore/QMap>
+#include <QtCore/QDir>
+#include <QtCore/QFile>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -46,21 +44,28 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
-class KArchive::KArchivePrivate
+class KArchivePrivate
 {
 public:
     KArchivePrivate()
         : rootDir( 0 ),
           saveFile( 0 ),
+          dev ( 0 ),
           fileName(),
           mode( QIODevice::NotOpen ),
           deviceOwned( false )
     {}
+    ~KArchivePrivate()
+    {
+        delete saveFile;
+        delete rootDir;
+    }
     KArchiveDirectory* rootDir;
     KSaveFile* saveFile;
+    QIODevice * dev;
     QString fileName;
     QIODevice::OpenMode mode;
-    bool deviceOwned; // if true, we (KArchive) own m_dev and must delete it
+    bool deviceOwned; // if true, we (KArchive) own dev and must delete it
 };
 
 
@@ -75,13 +80,12 @@ KArchive::KArchive( const QString& fileName )
     d->fileName = fileName;
     // This constructor leaves the device set to 0.
     // This is for the use of KSaveFile, see open().
-    m_dev = 0;
 }
 
 KArchive::KArchive( QIODevice * dev )
 	: d(new KArchivePrivate)
 {
-    m_dev = dev;
+    d->dev = dev;
 }
 
 KArchive::~KArchive()
@@ -89,8 +93,6 @@ KArchive::~KArchive()
     if ( isOpen() )
         close(); // WARNING: won't call the virtual method close in the derived class!!!
 
-    delete d->saveFile;
-    delete d->rootDir;
     delete d;
 }
 
@@ -103,14 +105,14 @@ bool KArchive::open( QIODevice::OpenMode mode )
 
     if ( !d->fileName.isEmpty() )
     {
-        Q_ASSERT( !m_dev );
+        Q_ASSERT( !d->dev );
         if ( !createDevice( mode ) )
             return false;
     }
 
-    Q_ASSERT( m_dev );
+    Q_ASSERT( d->dev );
 
-    if ( !m_dev->isOpen() && !m_dev->open( mode ) )
+    if ( !d->dev->isOpen() && !d->dev->open( mode ) )
         return false;
 
     d->mode = mode;
@@ -127,28 +129,28 @@ bool KArchive::createDevice( QIODevice::OpenMode mode )
     case QIODevice::WriteOnly:
         if ( !d->fileName.isEmpty() ) {
             // The use of KSaveFile can't be done in the ctor (no mode known yet)
-            //kDebug() << "Writing to a file using KSaveFile" << endl;
+            //kDebug() << "Writing to a file using KSaveFile";
             d->saveFile = new KSaveFile( d->fileName );
             if ( !d->saveFile->open() ) {
-                kWarning() << "KSaveFile creation for " << d->fileName << " failed, " << d->saveFile->errorString() << endl;
+                kWarning() << "KSaveFile creation for " << d->fileName << " failed, " << d->saveFile->errorString();
                 delete d->saveFile;
                 d->saveFile = 0;
                 return false;
             }
-            m_dev = d->saveFile;
-            Q_ASSERT( m_dev );
+            d->dev = d->saveFile;
+            Q_ASSERT( d->dev );
         }
         break;
     case QIODevice::ReadOnly:
     case QIODevice::ReadWrite:
         // ReadWrite mode still uses QFile for now; we'd need to copy to the tempfile, in fact.
         if ( !d->fileName.isEmpty() ) {
-            m_dev = new QFile( d->fileName );
+            d->dev = new QFile( d->fileName );
             d->deviceOwned = true;
         }
         break; // continued below
     default:
-        kWarning() << "Unsupported mode " << d->mode << endl;
+        kWarning() << "Unsupported mode " << d->mode;
         return false;
     }
     return true;
@@ -161,19 +163,19 @@ bool KArchive::close()
 
     // moved by holger to allow kzip to write the zip central dir
     // to the file in closeArchive()
-    // DF: added m_dev so that we skip closeArchive if saving aborted.
+    // DF: added d->dev so that we skip closeArchive if saving aborted.
     bool closeSucceeded = true;
-    if ( m_dev ) {
+    if ( d->dev ) {
         closeSucceeded = closeArchive();
         if ( d->mode == QIODevice::WriteOnly && !closeSucceeded )
             abortWriting();
     }
 
-    if ( m_dev )
-        m_dev->close();
+    if ( d->dev )
+        d->dev->close();
 
     if ( d->deviceOwned ) {
-        delete m_dev; // we created it ourselves in open()
+        delete d->dev; // we created it ourselves in open()
     }
     if ( d->saveFile ) {
         closeSucceeded = d->saveFile->finalize();
@@ -184,7 +186,7 @@ bool KArchive::close()
     delete d->rootDir;
     d->rootDir = 0;
     d->mode = QIODevice::NotOpen;
-    m_dev = 0;
+    d->dev = 0;
     return closeSucceeded;
 }
 
@@ -200,7 +202,7 @@ bool KArchive::addLocalFile( const QString& fileName, const QString& destName )
     QFileInfo fileInfo( fileName );
     if ( !fileInfo.isFile() && !fileInfo.isSymLink() )
     {
-        kWarning() << "KArchive::addLocalFile " << fileName << " doesn't exist or is not a regular file." << endl;
+        kWarning() << "KArchive::addLocalFile " << fileName << " doesn't exist or is not a regular file.";
         return false;
     }
 
@@ -225,14 +227,14 @@ bool KArchive::addLocalFile( const QString& fileName, const QString& destName )
     QFile file( fileName );
     if ( !file.open( QIODevice::ReadOnly ) )
     {
-        kWarning() << "KArchive::addLocalFile couldn't open file " << fileName << endl;
+        kWarning() << "KArchive::addLocalFile couldn't open file " << fileName;
         return false;
     }
 
     if ( !prepareWriting( destName, fileInfo.owner(), fileInfo.group(), size,
     		fi.st_mode, fi.st_atime, fi.st_mtime, fi.st_ctime ) )
     {
-        kWarning() << "KArchive::addLocalFile prepareWriting " << destName << " failed" << endl;
+        kWarning() << "KArchive::addLocalFile prepareWriting " << destName << " failed";
         return false;
     }
 
@@ -245,7 +247,7 @@ bool KArchive::addLocalFile( const QString& fileName, const QString& destName )
     {
         if ( !writeData( array.data(), n ) )
         {
-            kWarning() << "KArchive::addLocalFile writeData failed" << endl;
+            kWarning() << "KArchive::addLocalFile writeData failed";
             return false;
         }
         total += n;
@@ -254,7 +256,7 @@ bool KArchive::addLocalFile( const QString& fileName, const QString& destName )
 
     if ( !finishWriting( size ) )
     {
-        kWarning() << "KArchive::addLocalFile finishWriting failed" << endl;
+        kWarning() << "KArchive::addLocalFile finishWriting failed";
         return false;
     }
     return true;
@@ -271,7 +273,7 @@ bool KArchive::addLocalDirectory( const QString& path, const QString& destName )
         if ( *it != "." && *it != ".." )
         {
             QString fileName = path + '/' + *it;
-//            kDebug() << "storing " << fileName << endl;
+//            kDebug() << "storing " << fileName;
             QString dest = destName.isEmpty() ? *it : (destName + '/' + *it);
             QFileInfo fileInfo( fileName );
 
@@ -291,7 +293,7 @@ bool KArchive::writeFile( const QString& name, const QString& user,
 {
     if ( !prepareWriting( name, user, group, size, perm, atime, mtime, ctime ) )
     {
-        kWarning() << "KArchive::writeFile prepareWriting failed" << endl;
+        kWarning() << "KArchive::writeFile prepareWriting failed";
         return false;
     }
 
@@ -299,13 +301,13 @@ bool KArchive::writeFile( const QString& name, const QString& user,
     // Note: if data is 0L, don't call write, it would terminate the KFilterDev
     if ( data && size && !writeData( data, size ) )
     {
-        kWarning() << "KArchive::writeFile writeData failed" << endl;
+        kWarning() << "KArchive::writeFile writeData failed";
         return false;
     }
 
     if ( !finishWriting( size ) )
     {
-        kWarning() << "KArchive::writeFile finishWriting failed" << endl;
+        kWarning() << "KArchive::writeFile finishWriting failed";
         return false;
     }
     return true;
@@ -361,7 +363,7 @@ KArchiveDirectory * KArchive::rootDir()
 {
     if ( !d->rootDir )
     {
-        //kDebug() << "Making root dir " << endl;
+        //kDebug() << "Making root dir ";
         struct passwd* pw =  getpwuid( getuid() );
         struct group* grp = getgrgid( getgid() );
         QString username = pw ? QFile::decodeName(pw->pw_name) : QString::number( getuid() );
@@ -374,10 +376,10 @@ KArchiveDirectory * KArchive::rootDir()
 
 KArchiveDirectory * KArchive::findOrCreate( const QString & path )
 {
-    //kDebug() << "KArchive::findOrCreate " << path << endl;
+    //kDebug() << "KArchive::findOrCreate " << path;
     if ( path.isEmpty() || path == "/" || path == "." ) // root dir => found
     {
-        //kDebug() << "KArchive::findOrCreate returning rootdir" << endl;
+        //kDebug() << "KArchive::findOrCreate returning rootdir";
         return rootDir();
     }
     // Important note : for tar files containing absolute paths
@@ -391,10 +393,10 @@ KArchiveDirectory * KArchive::findOrCreate( const QString & path )
     if ( ent )
     {
         if ( ent->isDirectory() )
-            //kDebug() << "KArchive::findOrCreate found it" << endl;
+            //kDebug() << "KArchive::findOrCreate found it";
             return (KArchiveDirectory *) ent;
         else
-            kWarning() << "Found " << path << " but it's not a directory" << endl;
+            kWarning() << "Found " << path << " but it's not a directory";
     }
 
     // Otherwise go up and try again
@@ -413,7 +415,7 @@ KArchiveDirectory * KArchive::findOrCreate( const QString & path )
         parent = findOrCreate( left ); // recursive call... until we find an existing dir.
     }
 
-    //kDebug() << "KTar : found parent " << parent->name() << " adding " << dirname << " to ensure " << path << endl;
+    //kDebug() << "KTar : found parent " << parent->name() << " adding " << dirname << " to ensure " << path;
     // Found -> add the missing piece
     KArchiveDirectory * e = new KArchiveDirectory( this, dirname, d->rootDir->permissions(),
                                                    d->rootDir->date(), d->rootDir->user(),
@@ -425,8 +427,8 @@ KArchiveDirectory * KArchive::findOrCreate( const QString & path )
 void KArchive::setDevice( QIODevice * dev )
 {
     if ( d->deviceOwned )
-        delete m_dev;
-    m_dev = dev;
+        delete d->dev;
+    d->dev = dev;
     d->deviceOwned = false;
 }
 
@@ -441,6 +443,11 @@ QIODevice::OpenMode KArchive::mode() const
     return d->mode;
 }
 
+QIODevice * KArchive::device() const
+{
+    return d->dev;
+}
+
 bool KArchive::isOpen() const
 {
     return d->mode != QIODevice::NotOpen;
@@ -457,80 +464,168 @@ void KArchive::abortWriting()
         d->saveFile->abort();
         delete d->saveFile;
         d->saveFile = 0;
-        m_dev = 0;
+        d->dev = 0;
     }
 }
 
 ////////////////////////////////////////////////////////////////////////
 /////////////////////// KArchiveEntry //////////////////////////////////
 ////////////////////////////////////////////////////////////////////////
+
+class KArchiveEntryPrivate
+{
+public:
+    KArchiveEntryPrivate( KArchive* _archive, const QString& _name, int _access,
+                          int _date, const QString& _user, const QString& _group,
+                          const QString& _symlink) :
+        name(_name),
+        date(_date),
+        access(_access),
+        user(_user),
+        group(_group),
+        symlink(_symlink),
+        archive(_archive)
+    {}
+    QString name;
+    int date;
+    mode_t access;
+    QString user;
+    QString group;
+    QString symlink;
+    KArchive* archive;
+};
+
 KArchiveEntry::KArchiveEntry( KArchive* t, const QString& name, int access, int date,
                       const QString& user, const QString& group, const
-                      QString& symlink)
+                      QString& symlink) :
+    d(new KArchiveEntryPrivate(t,name,access,date,user,group,symlink))
 {
-  m_name = name;
-  m_access = access;
-  m_date = date;
-  m_user = user;
-  m_group = group;
-  m_symlink = symlink;
-  m_archive = t;
+}
 
+KArchiveEntry::~KArchiveEntry()
+{
+    delete d;
 }
 
 QDateTime KArchiveEntry::datetime() const
 {
-  QDateTime d;
-  d.setTime_t( m_date );
-  return d;
+  QDateTime datetimeobj;
+  datetimeobj.setTime_t( d->date );
+  return datetimeobj;
+}
+
+int KArchiveEntry::date() const
+{
+    return d->date;
+}
+
+QString KArchiveEntry::name() const
+{
+    return d->name;
+}
+
+mode_t KArchiveEntry::permissions() const
+{
+    return d->access;
+}
+
+QString KArchiveEntry::user() const
+{
+    return d->user;
+}
+
+QString KArchiveEntry::group() const
+{
+    return d->group;
+}
+
+QString KArchiveEntry::symlink() const
+{
+    return d->symlink;
+}
+
+bool KArchiveEntry::isFile() const
+{
+    return false;
+}
+
+bool KArchiveEntry::isDirectory() const
+{
+    return false;
+}
+
+KArchive* KArchiveEntry::archive() const
+{
+    return d->archive;
 }
 
 ////////////////////////////////////////////////////////////////////////
 /////////////////////// KArchiveFile ///////////////////////////////////
 ////////////////////////////////////////////////////////////////////////
 
+class KArchiveFilePrivate
+{
+public:
+    KArchiveFilePrivate( qint64 _pos, qint64 _size ) :
+        pos(_pos),
+        size(_size)
+    {}
+    qint64 pos;
+    qint64 size;
+};
+
 KArchiveFile::KArchiveFile( KArchive* t, const QString& name, int access, int date,
                             const QString& user, const QString& group,
                             const QString & symlink,
                             qint64 pos, qint64 size )
-  : KArchiveEntry( t, name, access, date, user, group, symlink )
+  : KArchiveEntry( t, name, access, date, user, group, symlink ),
+    d( new KArchiveFilePrivate(pos, size) )
 {
-  m_pos = pos;
-  m_size = size;
 }
 
 KArchiveFile::~KArchiveFile()
 {
+    delete d;
 }
 
 qint64 KArchiveFile::position() const
 {
-  return m_pos;
+  return d->pos;
 }
 
 qint64 KArchiveFile::size() const
 {
-  return m_size;
+  return d->size;
+}
+
+void KArchiveFile::setSize( qint64 s )
+{
+    d->size = s;
 }
 
 QByteArray KArchiveFile::data() const
 {
-  archive()->device()->seek( m_pos );
+  archive()->device()->seek( d->pos );
 
   // Read content
   QByteArray arr;
-  if ( m_size )
+  if ( d->size )
   {
     assert( arr.data() );
-    arr = archive()->device()->read( m_size );
-    Q_ASSERT( arr.size() == m_size );
+    arr = archive()->device()->read( d->size );
+    Q_ASSERT( arr.size() == d->size );
   }
   return arr;
 }
 
 QIODevice * KArchiveFile::createDevice() const
 {
-  return new KLimitedIODevice( archive()->device(), m_pos, m_size );
+  return new KLimitedIODevice( archive()->device(), d->pos, d->size );
+}
+
+bool KArchiveFile::isFile() const
+{
+    return true;
 }
 
 void KArchiveFile::copyTo(const QString& dest) const
@@ -547,23 +642,33 @@ void KArchiveFile::copyTo(const QString& dest) const
 //////////////////////// KArchiveDirectory /////////////////////////////////
 ////////////////////////////////////////////////////////////////////////
 
+class KArchiveDirectoryPrivate
+{
+public:
+    ~KArchiveDirectoryPrivate()
+    {
+        qDeleteAll(entries);
+    }
+    QHash<QString, KArchiveEntry *> entries;
+};
 
 KArchiveDirectory::KArchiveDirectory( KArchive* t, const QString& name, int access,
                               int date,
                               const QString& user, const QString& group,
                               const QString &symlink)
-  : KArchiveEntry( t, name, access, date, user, group, symlink )
+  : KArchiveEntry( t, name, access, date, user, group, symlink ),
+    d( new KArchiveDirectoryPrivate )
 {
 }
 
 KArchiveDirectory::~KArchiveDirectory()
 {
-  qDeleteAll(m_entries);
+  delete d;
 }
 
 QStringList KArchiveDirectory::entries() const
 {
-  return m_entries.keys();
+  return d->entries.keys();
 }
 
 const KArchiveEntry* KArchiveDirectory::entry( const QString& _name ) const
@@ -591,25 +696,30 @@ const KArchiveEntry* KArchiveDirectory::entry( const QString& _name ) const
     QString left = name.left( pos );
     QString right = name.mid( pos + 1 );
 
-    //kDebug() << "KArchiveDirectory::entry left=" << left << " right=" << right << endl;
+    //kDebug() << "KArchiveDirectory::entry left=" << left << " right=" << right;
 
-    const KArchiveEntry* e = m_entries.value( left );
+    const KArchiveEntry* e = d->entries.value( left );
     if ( !e || !e->isDirectory() )
       return 0;
     return static_cast<const KArchiveDirectory*>(e)->entry( right );
   }
 
-  return m_entries.value( name );
+  return d->entries.value( name );
 }
 
 void KArchiveDirectory::addEntry( KArchiveEntry* entry )
 {
   Q_ASSERT( !entry->name().isEmpty() );
-  if( m_entries.value( entry->name() ) ) {
+  if( d->entries.value( entry->name() ) ) {
       kWarning() << "KArchiveDirectory::addEntry: directory " << name()
                   << " has entry " << entry->name() << " already" << endl;
   }
-  m_entries.insert( entry->name(), entry );
+  d->entries.insert( entry->name(), entry );
+}
+
+bool KArchiveDirectory::isDirectory() const
+{
+    return true;
 }
 
 static int sortByPosition( const KArchiveFile* file1, const KArchiveFile* file2 ) {
@@ -659,7 +769,7 @@ void KArchiveDirectory::copyTo(const QString& dest, bool recursiveCopy ) const
     }
   } while (!dirStack.isEmpty());
 
-  qSort( fileList.begin(), fileList.end(), sortByPosition );  // sort on m_pos, so we have a linear access
+  qSort( fileList.begin(), fileList.end(), sortByPosition );  // sort on d->pos, so we have a linear access
 
   for ( QList<const KArchiveFile*>::const_iterator it = fileList.begin(), end = fileList.end() ;
         it != end ; ++it ) {
