@@ -20,27 +20,39 @@
 #include "kservicetypetrader.h"
 #include <kapplication.h>
 #include "kservice.h"
-#include <kstaticdeleter.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <ktoolinvocation.h>
 #include "QtDBus/QtDBus"
 
-static KStaticDeleter<KDBusServiceStarter> dss_sd;
-KDBusServiceStarter* KDBusServiceStarter::s_self;
+class KDBusServiceStarterPrivate
+{
+    public:
+        KDBusServiceStarterPrivate() : q(0) {}
+        ~KDBusServiceStarterPrivate()
+        {
+            delete q;
+        }
+        KDBusServiceStarter *q;
+};
+
+K_GLOBAL_STATIC(KDBusServiceStarterPrivate, privateObject)
 
 KDBusServiceStarter* KDBusServiceStarter::self()
 {
-    if ( !s_self )
-        dss_sd.setObject( s_self, new KDBusServiceStarter );
-    return s_self;
+    if (!privateObject->q) {
+        new KDBusServiceStarter;
+        Q_ASSERT(privateObject->q);
+    }
+    return privateObject->q;
 }
 
 KDBusServiceStarter::KDBusServiceStarter()
 {
     // Set the singleton instance - useful when a derived KDBusServiceStarter
     // was created (before self() was called)
-    s_self = this;
+    Q_ASSERT(!privateObject->q);
+    privateObject->q = this;
 }
 
 KDBusServiceStarter::~KDBusServiceStarter()
@@ -62,7 +74,7 @@ int KDBusServiceStarter::findServiceFor( const QString& serviceType,
     if ( offers.isEmpty() ) {
         if ( error )
             *error = i18n("No service implementing %1",  serviceType );
-        kWarning() << "KDBusServiceStarter: No service implementing " << serviceType << endl;
+        kWarning() << "KDBusServiceStarter: No service implementing " << serviceType;
         return -1;
     }
     KService::Ptr ptr = offers.first();
@@ -73,11 +85,11 @@ int KDBusServiceStarter::findServiceFor( const QString& serviceType,
         QString error;
         if ( startServiceFor( serviceType, constraint, &error, &dbusService, flags ) != 0 )
         {
-            kDebug() << "KDBusServiceStarter: Couldn't start service: " << error << endl;
+            kDebug() << "KDBusServiceStarter: Couldn't start service: " << error;
             return -2;
         }
     }
-    kDebug() << "KDBusServiceStarter: DBus service is available now, as " << dbusService << endl;
+    kDebug() << "KDBusServiceStarter: DBus service is available now, as " << dbusService;
     if ( pDBusService )
         *pDBusService = dbusService;
     return 0;
@@ -91,6 +103,6 @@ int KDBusServiceStarter::startServiceFor( const QString& serviceType,
     if ( offers.isEmpty() )
         return -1;
     KService::Ptr ptr = offers.first();
-    kDebug() << "KDBusServiceStarter: starting " << ptr->desktopEntryPath() << endl;
+    kDebug() << "KDBusServiceStarter: starting " << ptr->desktopEntryPath();
     return KToolInvocation::startServiceByDesktopPath( ptr->desktopEntryPath(), QStringList(), error, dbusService );
 }
