@@ -24,8 +24,8 @@
 #include "kfileitem.h"
 #include "kdirnotify.h"
 
-#include <qstring.h>
-#include <qstringlist.h>
+#include <QtCore/QString>
+#include <QtCore/QStringList>
 
 #include <kurl.h>
 
@@ -33,6 +33,8 @@ class KJob;
 namespace KIO { class Job; class ListJob; }
 
 /**
+ * @short Helper class for the kiojob used to list and update a directory.
+ *
  * The dir lister deals with the kiojob used to list and update a directory
  * and has signals for the user of this class (e.g. konqueror view or
  * kdesktop) to create/destroy its items when asked.
@@ -50,7 +52,6 @@ namespace KIO { class Job; class ListJob; }
  * Advanced usage : call openUrl with _keep = true to list directories
  * without forgetting the ones previously read (e.g. for a tree view)
  *
- * @short Helper class for the kiojob used to list and update a directory.
  * @author Michael Brade <brade@kde.org>
  */
 class KIO_EXPORT KDirLister : public QObject
@@ -217,7 +218,7 @@ public:
    *
    * @return the url used by this instance to list the files.
    */
-  const KUrl& url() const;
+  KUrl url() const;
 
   /**
    * Returns all URLs that are listed by this KDirLister. This is only
@@ -227,7 +228,7 @@ public:
    *
    * @return the list of all listed URLs
    */
-  const KUrl::List& directories() const;
+  KUrl::List directories() const;
 
   /**
    * Actually emit the changes made with setShowingDotFiles, setDirOnlyMode,
@@ -256,6 +257,8 @@ public:
 
   /**
    * Returns the file item of the URL.
+   *
+   * Can return 0. TODO is it OK? maybe use KFileItem(void)?
    * @return the file item for url() itself (".")
    */
   KFileItem *rootItem() const;
@@ -291,7 +294,7 @@ public:
    * @return the current name filter, can be QString() if filtering
    *         is turned off
    */
-  const QString& nameFilter() const;
+  QString nameFilter() const;
 
   /**
    * Set mime-based filter to only list items matching the given mimetypes.
@@ -334,7 +337,7 @@ public:
    * Returns the list of mime based filters, as set via setMimeFilter().
    * @return the list of mime based filters. Empty, when no mime filter is set.
    */
-  const QStringList& mimeFilters() const;
+  QStringList mimeFilters() const;
 
   /**
    * Checks whether @p name matches a filter in the list of name filters.
@@ -436,7 +439,6 @@ Q_SIGNALS:
   /**
    * Tell the view that the listing of the directory @p _url is finished.
    * There might be other running jobs left.
-   * This signal is only emitted if KDirLister is watching more than one directory.
    * @param _url the directory URL
    */
   void completed( const KUrl& _url );
@@ -449,7 +451,6 @@ Q_SIGNALS:
   /**
    * Tell the view that the listing of the directory @p _url was canceled.
    * There might be other running jobs left.
-   * This signal is only emitted if KDirLister is watching more than one directory.
    * @param _url the directory URL
    */
   void canceled( const KUrl& _url );
@@ -484,18 +485,44 @@ Q_SIGNALS:
 
   /**
    * Signal new items.
+   * For KDE 4 applications it is recommended using
+   * KDirLister::newItems(const QList<KFileItem>& items) instead,
+   * as the interfaces have been adjusted using KFileItem per value
+   * instead of per pointer.
+   *
+   * So use this signal only if you want to modify original KFileItems
    * @param items a list of new items
    */
   void newItems( const KFileItemList& items );
 
+  /**
+   * Signal new items.
+   * @param items a list of new items
+   */
+  void newItems( const QList<KFileItem>& items );
+
   /**
    * Send a list of items filtered-out by mime-type.
+   * For KDE 4 applications it is recommended using
+   * KDirLister::itemsFilteredByMime(const QList<KFileItem>& items) instead,
+   * as the interfaces have been adjusted using KFileItem per value
+   * instead of per pointer.
    * @param items the list of filtered items
    */
   void itemsFilteredByMime( const KFileItemList& items );
 
+  /**
+   * Send a list of items filtered-out by mime-type.
+   * @param items the list of filtered items
+   */
+  void itemsFilteredByMime( const QList<KFileItem>& items );
+
   /**
    * Signal an item to remove.
+   * For KDE 4 applications it is recommended using
+   * KDirLister::deleteItem(KFileItem _fileItem) instead,
+   * as the interfaces have been adjusted using KFileItem per value
+   * instead of per pointer.
    *
    * ATTENTION: if @p _fileItem == rootItem() the directory this lister
    *            is holding was deleted and you HAVE to release especially the
@@ -505,12 +532,36 @@ Q_SIGNALS:
    */
   void deleteItem( KFileItem *_fileItem );
 
+  /**
+   * Signal an item to remove.
+   *
+   * ATTENTION: if @p _fileItem == rootItem() the directory this lister
+   *            is holding was deleted and you HAVE to release especially the
+   *            rootItem() of this lister, otherwise your app will CRASH!!
+   *            The clear() signals have been emitted already.
+   * @param _fileItem the fileItem to delete
+   */
+  void deleteItem( KFileItem _fileItem );
+
+  /**
+   * Signal an item to refresh (its mimetype/icon/name has changed).
+   * Note: KFileItem::refresh has already been called on those items.
+   * For KDE 4 applications it is recommended using
+   * KDirLister::refreshItems(const QList<KFileItem>& items) instead,
+   * as the interfaces have been adjusted using KFileItem per value
+   * instead of per pointer.
+   *
+   * So use this signal only if you want to modify original KFileItems
+   * @param items the items to refresh
+   */
+  void refreshItems( const KFileItemList& items );
+
   /**
    * Signal an item to refresh (its mimetype/icon/name has changed).
    * Note: KFileItem::refresh has already been called on those items.
    * @param items the items to refresh
    */
-  void refreshItems( const KFileItemList& items );
+  void refreshItems( const QList<KFileItem>& items );
 
   /**
    * Emitted to display information about running jobs.
@@ -595,11 +646,6 @@ protected:
    */
   virtual bool doMimeFilter( const QString& mime, const QStringList& filters ) const;
 
-  /**
-   * @internal
-   */
-  bool doMimeExcludeFilter( const QString& mimeExclude, const QStringList& filters ) const;
-
   /** Reimplement to customize error handling */
   virtual void handleError( KIO::Job * );
 
@@ -611,19 +657,21 @@ private Q_SLOTS:
   void slotSpeed( KJob *, unsigned long );
 
 private:
+  bool doMimeExcludeFilter( const QString& mimeExclude, const QStringList& filters ) const;
+
   void jobStarted( KIO::ListJob * );
   void connectJob( KIO::ListJob * );
   void jobDone( KIO::ListJob * );
 
   uint numJobs();
 
-private:
-  virtual void addNewItem( KFileItem *item );
-  virtual void addNewItems( const KFileItemList& items );
-  virtual void aboutToRefreshItem( const KFileItem *item );
-  virtual void addRefreshItem( KFileItem *item );
-  virtual void emitItems();
-  virtual void emitDeleteItem( KFileItem *item );
+  void addNewItem( KFileItem *item );
+  void addNewItems( const KFileItemList& items );
+  void aboutToRefreshItem( const KFileItem *item );
+  void addRefreshItem( KFileItem *item );
+  void emitItems();
+  void emitDeleteItem( KFileItem *item );
+    void redirect( const KUrl& oldUrl, const KUrl& newUrl );
 
   KDirListerPrivate* const d;
 };
