@@ -22,10 +22,10 @@
 
 #include "kfileitem.h"
 
-#include <qmap.h>
-#include <q3dict.h>
-#include <q3cache.h>
-#include <qwidget.h>
+#include <QtCore/QMap>
+#include <QtCore/QHash>
+#include <QtCore/QCache>
+#include <QtGui/QWidget>
 
 #include <kurl.h>
 #include <kio/global.h>
@@ -54,10 +54,17 @@ public:
     delayedMimeTypes = false;
 
     rootFileItem = 0;
+
     lstNewItems = 0;
     lstRefreshItems = 0;
     lstMimeFilteredItems = 0;
     lstRemoveItems = 0;
+
+    lstNewItemsV2 = 0;
+    lstRefreshItemsV2 = 0;
+    lstMimeFilteredItemsV2 = 0;
+    lstRemoveItemsV2 = 0;
+
     refreshItemWasFiltered = false;
 
     changes = NONE;
@@ -74,17 +81,19 @@ public:
   // toplevel URL
   KUrl url;
 
-  bool complete;
+  bool complete:1;
 
-  bool autoUpdate;
-  bool isShowingDotFiles;
-  bool dirOnlyMode;
+  bool autoUpdate:1;
+  bool isShowingDotFiles:1;
+  bool dirOnlyMode:1;
 
-  bool autoErrorHandling;
+  bool delayedMimeTypes:1;
+
+  bool refreshItemWasFiltered:1;
+
+  bool autoErrorHandling:2;
   QWidget *errorParent;
 
-  bool delayedMimeTypes;
-
   struct JobData {
     long unsigned int percent, speed;
     KIO::filesize_t processedSize, totalSize;
@@ -98,7 +107,11 @@ public:
   KFileItemList *lstNewItems, *lstRefreshItems;
   KFileItemList *lstMimeFilteredItems, *lstRemoveItems;
 
-  bool refreshItemWasFiltered;
+  // In KDE 4 the interfaces have been adjusted using KFileItem
+  // per value instead of per pointer. For backward compatibility
+  // the KFileItemList signals are still supported.
+  QList<KFileItem> *lstNewItemsV2, *lstRefreshItemsV2;
+  QList<KFileItem> *lstMimeFilteredItemsV2, *lstRemoveItemsV2;
 
   int changes;
 
@@ -119,22 +132,39 @@ public:
  *
  * KDirListerCache also runs all the jobs for listing directories, whether they are for
  * normal listing or for updates.
- * For faster lookups, it also stores two dicts:
- * a URL -> dirlister holding that URL (urlsCurrentlyHeld)
- * a URL -> dirlister currently listing that URL (urlsCurrentlyListed)
+ * For faster lookups, it also stores a hash table, which gives for a directory URL:
+ * - the dirlisters holding that URL (listersCurrentlyHolding)
+ * - the dirlisters currently listing that URL (listersCurrentlyListing)
  */
 class KDirListerCache : public QObject
 {
-  friend class KDirLister;
-
-  Q_OBJECT
+    Q_OBJECT
 public:
-  ~KDirListerCache();
+    static KDirListerCache *self();
 
-  void updateDirectory( const KUrl& dir );
+    KDirListerCache(); // only called by K_GLOBAL_STATIC
+    ~KDirListerCache();
 
-  KFileItem *itemForUrl( const KUrl& url ) const;
-  KFileItemList *itemsForDir( const KUrl& dir ) const;
+    void updateDirectory( const KUrl& dir );
+
+    KFileItem *itemForUrl( const KUrl& url ) const;
+    KFileItemList *itemsForDir( const KUrl& dir ) const;
+
+    bool listDir( KDirLister *lister, const KUrl& _url, bool _keep, bool _reload );
+
+    // stop all running jobs for lister
+    void stop( KDirLister *lister );
+    // stop just the job listing url for lister
+    void stop( KDirLister *lister, const KUrl &_url );
+
+  void setAutoUpdate( KDirLister *lister, bool enable );
+
+  void forgetDirs( KDirLister *lister );
+  void forgetDirs( KDirLister *lister, const KUrl &_url, bool notify );
+
+  KFileItem *findByName( const KDirLister *lister, const QString &_name ) const;
+  // if lister is set, it is checked that the url is held by the lister
+  KFileItem *findByUrl( const KDirLister *lister, const KUrl &_url ) const;
 
 public Q_SLOTS:
   /**
@@ -163,43 +193,26 @@ public Q_SLOTS:
   void slotFilesChanged( const QStringList& fileList );
   void slotFileRenamed( const QString& srcUrl, const QString& dstUrl );
 
-public:
-  static KDirListerCache *self();
+private:
 
-protected:
-  KDirListerCache( int maxCount = 10 );
+    bool validUrl( const KDirLister *lister, const KUrl& _url ) const;
 
-  bool listDir( KDirLister *lister, const KUrl& _url, bool _keep, bool _reload );
-  bool validUrl( const KDirLister *lister, const KUrl& _url ) const;
-
-  // stop all running jobs for lister
-  void stop( KDirLister *lister );
-  // stop just the job listing url for lister
-  void stop( KDirLister *lister, const KUrl &_url );
-
-  void setAutoUpdate( KDirLister *lister, bool enable );
-
-  void forgetDirs( KDirLister *lister );
-  void forgetDirs( KDirLister *lister, const KUrl &_url, bool notify );
-
-
-  KFileItem *findByName( const KDirLister *lister, const QString &_name ) const;
-  // if lister is set, it is checked that the url is held by the lister
-  KFileItem *findByUrl( const KDirLister *lister, const KUrl &_url ) const;
+    // helper for both stop methods
+    struct DirectoryData;
+    void stopLister(KDirLister* lister, const QString& url, DirectoryData& dirData);
 
 private Q_SLOTS:
   void slotFileDirty( const QString &_file );
   void slotFileCreated( const QString &_file );
   void slotFileDeleted( const QString &_file );
 
-  void slotFileDirtyDelayed();
-
   void slotEntries( KIO::Job *job, const KIO::UDSEntryList &entries );
   void slotResult( KJob *j );
   void slotRedirection( KIO::Job *job, const KUrl &url );
 
   void slotUpdateEntries( KIO::Job *job, const KIO::UDSEntryList &entries );
   void slotUpdateResult( KJob *job );
+  void processPendingUpdates();
 
 private:
   KIO::ListJob *jobForUrl( const QString& url, KIO::ListJob *not_job = 0 );
@@ -207,14 +220,15 @@ private:
 
   void killJob( KIO::ListJob *job );
 
-  // check if _url is held by some lister and return true,
-  // otherwise schedule a delayed update and return false
-  bool checkUpdate( const QString& _url );
+    // Called when something tells us that the directory @p url has changed.
+    // Returns true if @p url is held by some lister (meaning: do the update now)
+    // otherwise mark the cached item as not-up-to-date for later and return false
+    bool checkUpdate( const QString& url );
+
   // when there were items deleted from the filesystem all the listers holding
   // the parent directory need to be notified, the unmarked items have to be deleted
   // and removed from the cache including all the children.
-  void deleteUnmarkedItems( Q3PtrList<KDirLister> *, KFileItemList & );
-  void processPendingUpdates();
+  void deleteUnmarkedItems( const QList<KDirLister *>&, KFileItemList & );
   // common for slotRedirection and slotFileRenamed
   void renameDir( const KUrl &oldUrl, const KUrl &url );
   // common for deleteUnmarkedItems and slotFilesRemoved
@@ -245,7 +259,7 @@ private:
       if ( autoUpdates )
       {
         if ( KDirWatch::exists() && url.isLocalFile() )
-          kdirwatch->removeDir( url.path() );
+            KDirWatch::self()->removeDir( url.path() );
         sendSignal( false, url );
       }
       delete rootItem;
@@ -254,15 +268,12 @@ private:
 
     void sendSignal( bool entering, const KUrl& url )
     {
-      // DF: this doesn't make sense. This is a cache, we delete items when deleting the cache,
-      // and maybe in other cases, but not when "leaving a directory". This needs to be rethought.
-      // It's not even much used, only kdnssd seems to use it, says lxr.
-#if 0
-      if (entering)
-        org::kde::KDirNotify::emitEnteredDirectory( url.url() );
-      else
-        org::kde::KDirNotify::emitLeftDirectory( url.url() );
-#endif
+        // Note that "entering" means "start watching", and "leaving" means "stop watching"
+        // (i.e. it's not when the user leaves the directory, it's when the directory is removed from the cache)
+        if (entering)
+            org::kde::KDirNotify::emitEnteredDirectory( url.url() );
+        else
+            org::kde::KDirNotify::emitLeftDirectory( url.url() );
     }
 
     void redirect( const KUrl& newUrl )
@@ -270,11 +281,11 @@ private:
       if ( autoUpdates )
       {
         if ( url.isLocalFile() )
-          kdirwatch->removeDir( url.path() );
+            KDirWatch::self()->removeDir( url.path() );
         sendSignal( false, url );
 
         if ( newUrl.isLocalFile() )
-          kdirwatch->addDir( newUrl.path() );
+          KDirWatch::self()->addDir( newUrl.path() );
         sendSignal( true, newUrl );
       }
 
@@ -289,7 +300,7 @@ private:
       if ( autoUpdates++ == 0 )
       {
         if ( url.isLocalFile() )
-          kdirwatch->addDir( url.path() );
+          KDirWatch::self()->addDir( url.path() );
         sendSignal( true, url );
       }
     }
@@ -299,7 +310,7 @@ private:
       if ( --autoUpdates == 0 )
       {
         if ( url.isLocalFile() )
-          kdirwatch->removeDir( url.path() );
+          KDirWatch::self()->removeDir( url.path() );
         sendSignal( false, url );
       }
 
@@ -323,39 +334,42 @@ private:
     KFileItemList lstItems;
   };
 
-  static const unsigned short MAX_JOBS_PER_LISTER;
-  QMap<KIO::ListJob *, KIO::UDSEntryList> jobs;
+    //static const unsigned short MAX_JOBS_PER_LISTER;
 
-  // an item is a complete directory
-  Q3Dict<DirItem> itemsInUse;
-  Q3Cache<DirItem> itemsCached;
+    QMap<KIO::ListJob *, KIO::UDSEntryList> jobs;
 
-  // A lister can be EITHER in urlsCurrentlyListed OR urlsCurrentlyHeld but NOT
-  // in both at the same time.
-  //     On the other hand there can be some listers in urlsCurrentlyHeld
-  // and some in urlsCurrentlyListed for the same url!
-  // Or differently said, there can be an entry for url in urlsCurrentlyListed
-  // and urlsCurrentlyHeld. This happens if more listers are requesting url at
-  // the same time and one lister was stopped during the listing of files.
+    // an item is a complete directory
+    QHash<QString /*url*/, DirItem*> itemsInUse;
+    QCache<QString /*url*/, DirItem> itemsCached;
 
-  // saves all urls that are currently being listed and maps them
-  // to their KDirListers
-  Q3Dict< Q3PtrList<KDirLister> > urlsCurrentlyListed;
+    // Data associated with a directory url
+    // This could be in DirItem but only in the itemsInUse dict...
+    struct DirectoryData
+    {
+        // A lister can be EITHER in listersCurrentlyListing OR listersCurrentlyHolding
+        // but NOT in both at the same time.
+        // But both lists can have different listers at the same time; this
+        // happens if more listers are requesting url at the same time and
+        // one lister was stopped during the listing of files.
 
-  // saves all KDirListers that are just holding url
-  Q3Dict< Q3PtrList<KDirLister> > urlsCurrentlyHeld;
+        // Listers that are currently listing this url
+        QList<KDirLister *> listersCurrentlyListing;
+        // Listers that are currently holding this url
+        QList<KDirLister *> listersCurrentlyHolding;
+    };
 
-  // running timers for the delayed update
-  Q3Dict<QTimer> pendingUpdates;
+    typedef QHash<QString /*url*/, DirectoryData> DirectoryDataHash;
+    DirectoryDataHash directoryData;
 
-  // the KDirNotify signals
-  OrgKdeKDirNotifyInterface *kdirnotify;
+    // List of files that we have changed recently
+    QSet<QString /*url*/> pendingUpdates;
+    // The timer for doing the delayed updates
+    QTimer pendingUpdateTimer;
 
-  static KDirListerCache *s_pSelf;
+    // the KDirNotify signals
+    OrgKdeKDirNotifyInterface *kdirnotify;
 };
 
-const unsigned short KDirListerCache::MAX_JOBS_PER_LISTER = 5;
-
-#define s_pCache KDirListerCache::self()
+//const unsigned short KDirListerCache::MAX_JOBS_PER_LISTER = 5;
 
 #endif
