@@ -39,15 +39,16 @@ class KDirModelDirNode;
 class KDirModelNode
 {
 public:
-    KDirModelNode( KDirModelDirNode* parent, KFileItem* item ) :
+    KDirModelNode( KDirModelDirNode* parent, const KFileItem& item ) :
         m_item(item),
         m_parent(parent),
         m_preview()
     {
     }
     //KUrl url() const { return m_item->url(); }
-    // Careful, m_item can be 0 for the root item
-    KFileItem* item() const { return m_item; }
+
+    // m_item is KFileItem() for the root item
+    const KFileItem& item() const { return m_item; }
     KDirModelDirNode* parent() const { return m_parent; }
     // linear search
     int rowNumber() const;
@@ -56,7 +57,7 @@ public:
     void setPreview( const QIcon& icn ) { m_preview = icn; }
 
 private:
-    KFileItem* m_item;
+    KFileItem m_item;
     KDirModelDirNode* const m_parent;
     QIcon m_preview;
 };
@@ -65,10 +66,11 @@ private:
 class KDirModelDirNode : public KDirModelNode
 {
 public:
-    KDirModelDirNode( KDirModelDirNode* parent, KFileItem* item )
+    KDirModelDirNode( KDirModelDirNode* parent, const KFileItem& item)
         : KDirModelNode( parent, item),
           m_childNodes(),
-          m_childCount(KDirModel::ChildCountUnknown)
+          m_childCount(KDirModel::ChildCountUnknown),
+          m_populated(false)
     {}
     ~KDirModelDirNode() {
         qDeleteAll(m_childNodes);
@@ -78,9 +80,12 @@ public:
     // If we listed the directory, the child count is known. Otherwise it can be set via setChildCount.
     int childCount() const { return m_childNodes.isEmpty() ? m_childCount : m_childNodes.count(); }
     void setChildCount(int count) { m_childCount = count; }
+    bool isPopulated() const { return m_populated; }
+    void setPopulated( bool populated ) { m_populated = populated; }
 
 private:
-    int m_childCount;
+    int m_childCount:31;
+    bool m_populated:1;
 };
 
 int KDirModelNode::rowNumber() const
@@ -96,7 +101,7 @@ class KDirModelPrivate
 public:
     KDirModelPrivate( KDirModel* model )
         : q(model), m_dirLister(0),
-          m_rootNode(new KDirModelDirNode(0, 0)),
+          m_rootNode(new KDirModelDirNode(0, KFileItem())),
           m_dropsAllowed(KDirModel::NoDrops)
     {
     }
@@ -105,50 +110,65 @@ public:
     }
     void clear() {
         delete m_rootNode;
-        m_rootNode = new KDirModelDirNode(0, 0);
+        m_rootNode = new KDirModelDirNode(0, KFileItem());
     }
-    QPair<int /*row*/, KDirModelNode*> nodeForUrl(const KUrl& url) const;
+    // Find the row number and node for a given url.
+    // This has to drill down from the root node.
+    // Returns (0,0) if there is no node for this url.
+    // If returnLastParent is set, then return the last known parent if there is no node for this url
+    // (special case for expandToUrl)
+    QPair<int /*row*/, KDirModelNode*> nodeForUrl(const KUrl& url, bool returnLastParent = false) const;
     KDirModelNode* nodeForIndex(const QModelIndex& index) const;
     QModelIndex indexForNode(KDirModelNode* node, int rowNumber = -1 /*unknown*/) const;
-    QModelIndex indexForUrl(const KUrl& url) const;
     bool isDir(KDirModelNode* node) const {
-        return (node == m_rootNode) || node->item()->isDir();
+        return (node == m_rootNode) || node->item().isDir();
     }
 
     KDirModel* q;
     KDirLister* m_dirLister;
     KDirModelDirNode* m_rootNode;
     KDirModel::DropsAllowed m_dropsAllowed;
+    // key = current known parent node (always a KDirModelDirNode but KDirModelNode is more convenient),
+    // value = final url[s] being fetched
+    QMap<KDirModelNode*, KUrl::List> m_urlsBeingFetched;
 };
 
 // If we want to support arbitrary trees like "home:/ as a child of system:/" then,
 // we need to get the parent KFileItem in slotNewItems, and then we can use a QHash<KFileItem*,KDirModelNode*> cache.
+// (well there isn't a parent kfileitem, rather a parent url... hmm, back to square one with hashes-of-urls..)
 // For now we'll assume "child url = parent url + filename"
-QPair<int /*row*/, KDirModelNode*> KDirModelPrivate::nodeForUrl(const KUrl& _url) const // O(n*m)
+QPair<int /*row*/, KDirModelNode*> KDirModelPrivate::nodeForUrl(const KUrl& _url, bool returnLastParent) const // O(n*m)
 {
     KUrl url(_url);
     url.adjustPath(KUrl::RemoveTrailingSlash);
-    //kDebug() << k_funcinfo << url << endl;
+
+    //kDebug(7008) << url;
+
     if (url == m_dirLister->url())
         return qMakePair(0, static_cast<KDirModelNode *>(m_rootNode));
 
     const QString urlStr = url.url();
     KDirModelDirNode* dirNode = m_rootNode;
     KUrl nodeUrl = m_dirLister->url();
-    while ( nodeUrl != url ) {
+
+    if ( !urlStr.startsWith(nodeUrl.url()) ) {
+        return qMakePair(0, static_cast<KDirModelNode*>(0));
+    }
+
+    for (;;) {
         Q_ASSERT( urlStr.startsWith(nodeUrl.url()) );
         bool foundChild = false;
         QList<KDirModelNode *>::const_iterator it = dirNode->m_childNodes.begin();
         const QList<KDirModelNode *>::const_iterator end = dirNode->m_childNodes.end();
         int row = 0;
         for ( ; it != end ; ++it, ++row ) {
-            const KUrl u = (*it)->item()->url();
+            const KUrl u = (*it)->item().url();
             if ( u == url ) {
-                //kDebug() << "Found! " << u << endl;
+                //kDebug(7008) << "Found! " << u;
                 return qMakePair(row, *it);
             }
             if ( urlStr.startsWith(u.url()+'/') ) {
-                //kDebug() << "going into " << node->item()->url() << endl;
+                //kDebug(7008) << "going into " << node->item().url();
                 Q_ASSERT( isDir(*it) );
                 dirNode = static_cast<KDirModelDirNode *>( *it );
                 foundChild = true;
@@ -156,13 +176,17 @@ QPair<int /*row*/, KDirModelNode*> KDirModelPrivate::nodeForUrl(const KUrl& _url
             }
         }
         if (!foundChild) {
-            //kDebug() << "child equal or starting with " << url << " not found" << endl;
-            return qMakePair(0, static_cast<KDirModelNode*>(0));
+            //kDebug(7008) << "child equal or starting with " << url << " not found";
+            if (returnLastParent)
+                return qMakePair(-1 /*not implemented*/, static_cast<KDirModelNode*>(dirNode));
+            else
+                return qMakePair(0, static_cast<KDirModelNode*>(0));
         }
-        nodeUrl = dirNode->item()->url();
-        //kDebug() << " " << nodeUrl << endl;
+        nodeUrl = dirNode->item().url();
+        //kDebug(7008) << " " << nodeUrl;
     }
-    return qMakePair(0, static_cast<KDirModelNode*>(0));
+    // NOTREACHED
+    //return qMakePair(0, static_cast<KDirModelNode*>(0));
 }
 
 // node -> index. If rowNumber is set (or node is root): O(1). Otherwise: O(n).
@@ -183,18 +207,6 @@ KDirModelNode* KDirModelPrivate::nodeForIndex(const QModelIndex& index) const
         : m_rootNode;
 }
 
-// url -> index. O(n*m)
-QModelIndex KDirModelPrivate::indexForUrl(const KUrl& url) const
-{
-    const QPair<int, KDirModelNode*> result = nodeForUrl(url); // O(n*m) (m is the depth from the root)
-    if (!result.second) {
-        kWarning() << "KDirModelPrivate::indexForUrl: " << url << " not found" << endl;
-        return QModelIndex();
-    }
-    return indexForNode(result.second, result.first); // O(1)
-}
-
-
 // We don't use QHash<KUrl,...> anymore, it's too slow.
 // Idea from George, to make QHash<KUrl,...> fast: - cache hash value into QUrl or KUrl
 // This also helps making operator== fast [which means operator== has to call qHash if cached value isn't there]
@@ -219,7 +231,7 @@ static QString debugIndex(const QModelIndex& index)
         str = "[invalid index, i.e. root]";
     else {
         KDirModelNode* node = static_cast<KDirModelNode*>(index.internalPointer());
-        str = "[index for " + node->item()->url().pathOrUrl();
+        str = "[index for " + node->item().url().pathOrUrl();
         if (index.column() > 0)
             str += ", column " + QString::number(index.column());
         str += ']';
@@ -248,12 +260,12 @@ void KDirModel::setDirLister(KDirLister* dirLister)
     }
     d->m_dirLister = dirLister;
     d->m_dirLister->setParent(this);
-    connect( d->m_dirLister, SIGNAL(newItems(KFileItemList)),
-             this, SLOT(slotNewItems(KFileItemList)) );
-    connect( d->m_dirLister, SIGNAL(deleteItem(KFileItem*)),
-             this, SLOT(slotDeleteItem(KFileItem*)) );
-    connect( d->m_dirLister, SIGNAL(refreshItems(KFileItemList)),
-             this, SLOT(slotRefreshItems(KFileItemList)) );
+    connect( d->m_dirLister, SIGNAL(newItems(QList<KFileItem>)),
+             this, SLOT(slotNewItems(QList<KFileItem>)) );
+    connect( d->m_dirLister, SIGNAL(deleteItem(KFileItem)),
+             this, SLOT(slotDeleteItem(KFileItem)) );
+    connect( d->m_dirLister, SIGNAL(refreshItems(QList<KFileItem>)),
+             this, SLOT(slotRefreshItems(QList<KFileItem>)) );
     connect( d->m_dirLister, SIGNAL(clear()),
              this, SLOT(slotClear()) );
 }
@@ -263,48 +275,71 @@ KDirLister* KDirModel::dirLister() const
     return d->m_dirLister;
 }
 
-void KDirModel::slotNewItems( const KFileItemList& items )
+void KDirModel::slotNewItems(const QList<KFileItem>& items)
 {
     // Find parent item - it's the same for all the items
-    // TODO (if Michael Brade agrees): add parent KFileItem or url to the newItems signal
+    // TODO (if Michael Brade agrees): add parent url to the newItems signal
     // This way we can finally support properly trees where the urls are using different protocols.
-    KUrl dir( items.first()->url().upUrl() );
+    KUrl dir( items.first().url().upUrl() );
     dir.adjustPath(KUrl::RemoveTrailingSlash);
 
-    //kDebug() << k_funcinfo << "dir=" << dir << endl;
+    //kDebug(7008) << "dir=" << dir;
 
     const QPair<int, KDirModelNode*> result = d->nodeForUrl(dir); // O(n*m)
-    Q_ASSERT(result.second);
+    Q_ASSERT(result.second); // Are you calling KDirLister::openUrl(url,true,false)? Please use expandToUrl() instead.
     Q_ASSERT(d->isDir(result.second));
     KDirModelDirNode* dirNode = static_cast<KDirModelDirNode *>(result.second);
 
-    KFileItemList::const_iterator it = items.begin();
-    const KFileItemList::const_iterator end = items.end();
-    for ( ; it != end ; ++it ) {
-        KDirModelNode* node = (*it)->isDir()
-                              ? new KDirModelDirNode( dirNode, *it )
-                              : new KDirModelNode( dirNode, *it );
-        dirNode->m_childNodes.append( node );
-    }
-
     const QModelIndex index = d->indexForNode(dirNode, result.first); // O(1)
-    const int newRowCount = dirNode->m_childNodes.count();
+    const int newItemsCount = items.count();
+    const int newRowCount = dirNode->m_childNodes.count() + newItemsCount;
 #ifndef NDEBUG // debugIndex only defined in debug mode
-    kDebug() << k_funcinfo << items.count() << " in " << dir
+    kDebug(7008) << items.count() << " in " << dir
              << " index=" << debugIndex(index) << " newRowCount=" << newRowCount << endl;
 #endif
-    const int newItemsCount = items.count();
     beginInsertRows( index, newRowCount - newItemsCount, newRowCount - 1 ); // parent, first, last
+
+    const KUrl::List urlsBeingFetched = d->m_urlsBeingFetched.value(dirNode);
+    //kDebug(7008) << "urlsBeingFetched for dir" << dirNode << dir << ":" << urlsBeingFetched;
+
+    QList<KFileItem>::const_iterator it = items.begin();
+    const QList<KFileItem>::const_iterator end = items.end();
+    for ( ; it != end ; ++it ) {
+        const bool isDir = it->isDir();
+        KDirModelNode* node = isDir
+                              ? new KDirModelDirNode( dirNode, *it )
+                              : new KDirModelNode( dirNode, *it );
+        dirNode->m_childNodes.append(node);
+
+        if (isDir && !urlsBeingFetched.isEmpty()) {
+            const KUrl dirUrl = it->url();
+            foreach(const KUrl& urlFetched, urlsBeingFetched) {
+                if (dirUrl.isParentOf(urlFetched)) {
+                    //kDebug(7008) << "Listing found" << dirUrl << "which is a parent of fetched url" << urlFetched;
+                    const QModelIndex parentIndex = d->indexForNode(node, dirNode->m_childNodes.count()-1);
+                    Q_ASSERT(parentIndex.isValid());
+                    emit expand(parentIndex);
+                    if (dirUrl != urlFetched) {
+                        fetchMore(parentIndex);
+                        d->m_urlsBeingFetched[node].append(urlFetched);
+                    }
+                }
+            }
+        }
+    }
+
+    d->m_urlsBeingFetched.remove(dirNode);
+
     endInsertRows();
 }
 
-void KDirModel::slotDeleteItem( KFileItem *item )
+void KDirModel::slotDeleteItem(const KFileItem& item)
 {
-    kDebug() << k_funcinfo << item << endl;
     //KUrl dir( item->url().upUrl() );
     //dir.adjustPath(KUrl::RemoveTrailingSlash);
 
-    const QPair<int, KDirModelNode*> result = d->nodeForUrl(item->url()); // O(n*m)
+    Q_ASSERT(!item.isNull());
+    const QPair<int, KDirModelNode*> result = d->nodeForUrl(item.url()); // O(n*m)
     const int rowNumber = result.first;
     KDirModelNode* node = result.second;
     Q_ASSERT(node);
@@ -320,14 +355,14 @@ void KDirModel::slotDeleteItem( KFileItem *item )
     endRemoveRows();
 }
 
-void KDirModel::slotRefreshItems( const KFileItemList& items )
+void KDirModel::slotRefreshItems(const QList<KFileItem>& items)
 {
     QModelIndex topLeft, bottomRight;
 
     // Solution 1: we could emit dataChanged for one row (if items.size()==1) or all rows
     // Solution 2: more fine-grained, actually figure out the beginning and end rows.
-    for ( KFileItemList::const_iterator fit = items.begin(), fend = items.end() ; fit != fend ; ++fit ) {
-        const QModelIndex index = d->indexForUrl( (*fit)->url() ); // O(n*m); maybe we could look up to the parent only once
+    for ( QList<KFileItem>::const_iterator fit = items.begin(), fend = items.end() ; fit != fend ; ++fit ) {
+        const QModelIndex index = indexForUrl( fit->url() ); // O(n*m); maybe we could look up to the parent only once
         if (!topLeft.isValid() || index.row() < topLeft.row()) {
             topLeft = index;
         }
@@ -336,9 +371,9 @@ void KDirModel::slotRefreshItems( const KFileItemList& items )
         }
     }
 #ifndef NDEBUG // debugIndex only defined in debug mode
-    kDebug() << "slotRefreshItems: dataChanged(" << debugIndex(topLeft) << " - " << debugIndex(bottomRight) << endl;
+    kDebug(7008) << "slotRefreshItems: dataChanged(" << debugIndex(topLeft) << " - " << debugIndex(bottomRight);
 #endif
-    bottomRight = bottomRight.sibling(bottomRight.row(), ColumnCount-1);
+    bottomRight = bottomRight.sibling(bottomRight.row(), columnCount(QModelIndex())-1);
     emit dataChanged(topLeft, bottomRight);
 }
 
@@ -367,56 +402,62 @@ QVariant KDirModel::data( const QModelIndex & index, int role ) const
 {
     if (index.isValid()) {
         KDirModelNode* node = static_cast<KDirModelNode*>(index.internalPointer());
-        KFileItem* item = node->item();
+        const KFileItem& item (node->item());
         switch (role) {
         case Qt::DisplayRole:
             switch (index.column()) {
             case Name:
-                return item->name();
+                return item.name();
             case Size:
                 //
                 //return KIO::convertSize(item->size());
                 // Default to "file size in bytes" like in kde3's filedialog
-                return KGlobal::locale()->formatNumber(item->size(), 0);
+                return KGlobal::locale()->formatNumber(item.size(), 0);
             case ModifiedTime: {
-                KDateTime dt;
-                dt.setTime_t(item->time(KIO::UDS_MODIFICATION_TIME));
+                KDateTime dt = item.time(KFileItem::ModificationTime);
                 return KGlobal::locale()->formatDateTime(dt);
             }
             case Permissions:
-                return item->permissionsString();
+                return item.permissionsString();
             case Owner:
-                return item->user();
+                return item.user();
             case Group:
-                return item->group();
+                return item.group();
+            case Type:
+                return item.mimeComment();
             }
             break;
         case Qt::DecorationRole:
             if (index.column() == Name) {
                 if (!node->preview().isNull()) {
-                    //kDebug() << item->url() << " preview found" << endl;
+                    //kDebug(7008) << item->url() << " preview found";
                     return node->preview();
                 }
-                Q_ASSERT(item);
-                const int overlays = item->overlays();
-                //kDebug() << item->url() << " overlays=" << overlays << endl;
-                return KIcon(item->iconName(), 0, overlays);
+                Q_ASSERT(!item.isNull());
+                //kDebug(7008) << item->url() << " overlays=" << item->overlays();
+                return KIcon(item.iconName(), 0, item.overlays());
+            }
+            break;
+        case Qt::TextAlignmentRole:
+            if (index.column() == Size) {
+                // use a right alignment for L2R and R2L languages
+                return Qt::AlignRight;
             }
             break;
         case FileItemRole:
             return QVariant::fromValue(item);
         case ChildCountRole:
-            if (!item->isDir())
+            if (!item.isDir())
                 return ChildCountUnknown;
             else {
                 KDirModelDirNode* dirNode = static_cast<KDirModelDirNode *>(node);
                 int count = dirNode->childCount();
-                if (count == ChildCountUnknown && item->isReadable()) {
-                    const QString path = item->localPath();
+                if (count == ChildCountUnknown && item.isReadable()) {
+                    const QString path = item.localPath();
                     if (!path.isEmpty()) {
                         QDir dir(path);
                         count = dir.entryList(QDir::AllEntries|QDir::NoDotAndDotDot|QDir::System).count();
-                        kDebug() << k_funcinfo << "child count for " << path << ":" << count << endl;
+                        //kDebug(7008) << "child count for " << path << ":" << count;
                         dirNode->setChildCount(count);
                     }
                 }
@@ -444,7 +485,7 @@ bool KDirModel::setData( const QModelIndex & index, const QVariant & value, int
             Q_ASSERT(index.isValid());
             // Set new pixmap - e.g. preview
             KDirModelNode* node = static_cast<KDirModelNode*>(index.internalPointer());
-            //kDebug() << "setting icon for " << node->item()->url() << endl;
+            //kDebug(7008) << "setting icon for " << node->item()->url();
             Q_ASSERT(node);
             if (value.type() == QVariant::Icon) {
                 const QIcon icon(qvariant_cast<QIcon>(value));
@@ -468,7 +509,7 @@ int KDirModel::rowCount( const QModelIndex & parent ) const
     KDirModelDirNode* parentNode = static_cast<KDirModelDirNode *>(d->nodeForIndex(parent));
     Q_ASSERT(parentNode);
     const int count = parentNode->m_childNodes.count();
-    //kDebug() << "rowCount for " << parentUrl << ": " << count << endl;;
+    //kDebug(7008) << "rowCount for " << parentUrl << ": " << count;;
     return count;
 }
 
@@ -496,7 +537,7 @@ QMimeData * KDirModel::mimeData( const QModelIndexList & indexes ) const
 {
     KUrl::List urls;
     foreach ( const QModelIndex &index, indexes ) {
-        urls << d->nodeForIndex( index )->item()->url();
+        urls << d->nodeForIndex( index )->item().url();
     }
     QMimeData *data = new QMimeData();
     urls.populateMimeData( data );
@@ -504,10 +545,11 @@ QMimeData * KDirModel::mimeData( const QModelIndexList & indexes ) const
 }
 
 // Public API; not much point in calling it internally
-KFileItem* KDirModel::itemForIndex( const QModelIndex& index ) const
+KFileItem KDirModel::itemForIndex( const QModelIndex& index ) const
 {
     if (!index.isValid()) {
-        return d->m_dirLister->rootItem();
+        KFileItem* item=d->m_dirLister->rootItem();
+        return item?(*item):KFileItem();
     } else {
         return static_cast<KDirModelNode*>(index.internalPointer())->item();
     }
@@ -517,14 +559,25 @@ QModelIndex KDirModel::indexForItem( const KFileItem* item ) const
 {
     // Note that we can only use the URL here, not the pointer.
     // KFileItems can be copied.
-    return d->indexForUrl(item->url()); // O(n*m)
+    return indexForUrl(item->url()); // O(n*m)
 }
 
 QModelIndex KDirModel::indexForItem( const KFileItem& item ) const
 {
     // Note that we can only use the URL here, not the pointer.
     // KFileItems can be copied.
-    return d->indexForUrl(item.url()); // O(n*m)
+    return indexForUrl(item.url()); // O(n*m)
+}
+
+// url -> index. O(n*m)
+QModelIndex KDirModel::indexForUrl(const KUrl& url) const
+{
+    const QPair<int, KDirModelNode*> result = d->nodeForUrl(url); // O(n*m) (m is the depth from the root)
+    if (!result.second) {
+        kWarning(7007) << url << "not found";
+        return QModelIndex();
+    }
+    return d->indexForNode(result.second, result.first); // O(1)
 }
 
 QModelIndex KDirModel::index( int row, int column, const QModelIndex & parent ) const
@@ -546,17 +599,19 @@ QVariant KDirModel::headerData( int section, Qt::Orientation orientation, int ro
     case Qt::DisplayRole:
         switch (section) {
         case Name:
-            return i18n("Name");
+            return i18nc("@title:column","Name");
         case Size:
-            return i18n("Size");
+            return i18nc("@title:column","Size");
         case ModifiedTime:
-            return i18n("Modified"); // was called "Date" in kde3's kfiledialog - which one is better?
+            return i18nc("@title:column","Modified"); // was called "Date" in kde3's kfiledialog - which one is better?
         case Permissions:
-            return i18n("Permissions");
+            return i18nc("@title:column","Permissions");
         case Owner:
-            return i18n("Owner");
+            return i18nc("@title:column","Owner");
         case Group:
-            return i18n("Group");
+            return i18nc("@title:column","Group");
+        case Type:
+            return i18nc("@title:column","Type");
         }
     }
     return QVariant();
@@ -567,19 +622,22 @@ bool KDirModel::hasChildren( const QModelIndex & parent ) const
     if (!parent.isValid())
         return true;
 
-    KFileItem* parentItem = static_cast<KDirModelNode*>(parent.internalPointer())->item();
-    Q_ASSERT(parentItem);
-    return parentItem->isDir();
+    const KFileItem& parentItem = static_cast<KDirModelNode*>(parent.internalPointer())->item();
+    Q_ASSERT(!parentItem.isNull());
+    return parentItem.isDir();
 }
 
 Qt::ItemFlags KDirModel::flags( const QModelIndex & index ) const
 {
-    Qt::ItemFlags f = Qt::ItemIsSelectable | Qt::ItemIsEditable | Qt::ItemIsDragEnabled | Qt::ItemIsEnabled;
+    Qt::ItemFlags f = Qt::ItemIsEnabled;
+    if (index.column() == Name) {
+        f |= Qt::ItemIsSelectable | Qt::ItemIsEditable | Qt::ItemIsDragEnabled;
+    }
 
     // Allow dropping onto this item?
     if (d->m_dropsAllowed != NoDrops) {
-        KFileItem* item = itemForIndex(index);
-        if (!item || item->isDir()) {
+        KFileItem item = itemForIndex(index);
+        if (item.isDir()) {
             if (d->m_dropsAllowed & DropOnDirectory) {
                 f |= Qt::ItemIsDropEnabled;
             }
@@ -587,12 +645,12 @@ Qt::ItemFlags KDirModel::flags( const QModelIndex & index ) const
             if (d->m_dropsAllowed & DropOnAnyFile)
                 f |= Qt::ItemIsDropEnabled;
             else if (d->m_dropsAllowed & DropOnLocalExecutable) {
-                if (item->isLocalFile()) {
+                if (item.isLocalFile()) {
                     // Desktop file?
-                    if (item->mimeTypePtr()->is("application/x-desktop"))
+                    if (item.mimeTypePtr()->is("application/x-desktop"))
                         f |= Qt::ItemIsDropEnabled;
                     // Executable, shell script ... ?
-                    else if ( QFileInfo( item->localPath() ).isExecutable() )
+                    else if ( QFileInfo( item.localPath() ).isExecutable() )
                         f |= Qt::ItemIsDropEnabled;
                 }
             }
@@ -607,14 +665,14 @@ bool KDirModel::canFetchMore( const QModelIndex & parent ) const
     if (!parent.isValid())
         return false;
 
-    // We could have a bool KDirModelNode::m_populated,
+    // We now have a bool KDirModelNode::m_populated,
     // to avoid calling fetchMore more than once on empty dirs.
     // But this wastes memory, and how often does someone open and re-open an empty dir in a treeview?
     // Maybe we can ask KDirLister "have you listed <url> already"? (to discuss with M. Brade)
 
     KDirModelNode* node = static_cast<KDirModelNode*>(parent.internalPointer());
-    KFileItem* item = node->item();
-    return item->isDir() /*&& !node->m_populated*/
+    const KFileItem& item = node->item();
+    return item.isDir() && !static_cast<KDirModelDirNode *>(node)->isPopulated()
         && static_cast<KDirModelDirNode *>(node)->m_childNodes.isEmpty();
 }
 
@@ -623,16 +681,19 @@ void KDirModel::fetchMore( const QModelIndex & parent )
     if (!parent.isValid())
         return;
 
-    //const KUrl url = urlForIndex(parent);
-    //kDebug() << k_funcinfo << url << endl;
-
     KDirModelNode* parentNode = static_cast<KDirModelNode*>(parent.internalPointer());
-    //parentNode->m_populated = true;
-    KFileItem* parentItem = parentNode->item();
-    Q_ASSERT(parentItem->isDir());
 
-    const KUrl url = parentItem->url();
-    d->m_dirLister->openUrl(url, true, true);
+    KFileItem parentItem = parentNode->item();
+    Q_ASSERT(!parentItem.isNull());
+    Q_ASSERT(parentItem.isDir());
+    KDirModelDirNode* dirNode = static_cast<KDirModelDirNode *>(parentNode);
+    if( dirNode->isPopulated() )
+        return;
+    dirNode->setPopulated( true );
+
+    //const KUrl url = parentItem.url();
+    //kDebug(7008) << "listing" << url;
+    d->m_dirLister->openUrl(parentItem.url(), true, true);
 }
 
 bool KDirModel::dropMimeData( const QMimeData * data, Qt::DropAction action, int row, int column, const QModelIndex & parent )
@@ -652,4 +713,22 @@ void KDirModel::setDropsAllowed(DropsAllowed dropsAllowed)
     d->m_dropsAllowed = dropsAllowed;
 }
 
+void KDirModel::expandToUrl(const KUrl& url)
+{
+    const QPair<int, KDirModelNode*> result = d->nodeForUrl(url, true /*return last parent*/); // O(n*m)
+    if (!result.second) // doesn't seem related to our base url?
+        return;
+    if (!(result.second->item().isNull()) && result.second->item().url() == url) {
+        // We have it already, nothing to do
+        kDebug(7008) << "have it already item=" <<url /*result.second->item()*/;
+        return;
+    }
+    //kDebug(7008) << k_funcinfo << url << result.second << result.second->item().url() << endl;
+    d->m_urlsBeingFetched[result.second].append(url);
+
+    const QModelIndex parentIndex = d->indexForNode(result.second, result.first);
+    Q_ASSERT(parentIndex.isValid());
+    fetchMore(parentIndex);
+}
+
 #include "kdirmodel.moc"
