@@ -2,6 +2,7 @@
 /* This file is part of the KDE libraries
    Copyright (C) 1998 Sven Radej <sven@lisa.exp.univie.ac.at>
    Copyright (C) 2006 Dirk Mueller <mueller@kde.org>
+   Copyright (C) 2007 Flavio Castelli <flavio.castelli@gmail.com>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,6 +21,12 @@
 
 
 // CHANGES:
+// Aug 6,  2007 - KDirWatch::WatchModes support complete, flags work fine also
+// when using FAMD (Flavio Castelli)
+// Aug 3,  2007 - Handled KDirWatch::WatchModes flags when using inotify, now
+// recursive and file monitoring modes are implemented (Flavio Castelli)
+// Jul 30, 2007 - Substituted addEntry boolean params with KDirWatch::WatchModes
+// flag (Flavio Castelli)
 // Oct 4,  2005 - Inotify support (Dirk Mueller)
 // Februar 2002 - Add file watching and remote mount check for STAT
 // Mar 30, 2001 - Native support for Linux dir change notification.
@@ -32,52 +39,44 @@
 // deep copies for list of dirs. (sven)
 // Mar 28. 1998 - Created.  (sven)
 
+#include "kdirwatch.h"
+#include "kdirwatch_p.h"
+
 #include <config-kdirwatch.h>
 #include <config.h>
 
 #include <sys/stat.h>
 #include <assert.h>
-#include <qdir.h>
-#include <qfile.h>
-#include <qsocketnotifier.h>
-#include <qstringlist.h>
-#include <qtimer.h>
+#include <QtCore/QDir>
+#include <QtCore/QFile>
+#include <QtCore/QSocketNotifier>
+#include <QtCore/QMutableStringListIterator>
+#include <QtCore/QTimer>
 
 #include <kapplication.h>
 #include <kdebug.h>
 #include <kconfig.h>
 #include <kglobal.h>
-#include <kstaticdeleter.h>
 #include <kde_file.h>
 #include <kconfiggroup.h>
+#include "kmountpoint.h"
+
+#include <stdlib.h>
 
 // debug
 #include <sys/ioctl.h>
 
-#ifdef HAVE_SYS_INOTIFY_H
-#include <unistd.h>
-#include <fcntl.h>
-#include <sys/inotify.h>
-
-#ifndef IN_DONT_FOLLOW
-#define IN_DONT_FOLLOW 0x02000000
-#endif
-
-#ifndef IN_ONLYDIR
-#define IN_ONLYDIR 0x01000000
-#endif
-
-#endif
 
 #include <sys/utsname.h>
 
-#include "kdirwatch.h"
-#include "kdirwatch_p.h"
-#include "global.h" //  KIO::probably_slow_mounted
-
 #define NO_NOTIFY (time_t) 0
 
 static KDirWatchPrivate* dwp_self = 0;
+static KDirWatchPrivate* createPrivate() {
+  if (!dwp_self)
+    dwp_self = new KDirWatchPrivate;
+  return dwp_self;
+}
 
 //
 // Class KDirWatchPrivate (singleton)
@@ -123,7 +122,22 @@ KDirWatchPrivate::KDirWatchPrivate()
   m_nfsPollInterval = config.readEntry("NFSPollInterval", 5000);
   m_PollInterval = config.readEntry("PollInterval", 500);
 
-  QString available("Stat");
+  QString method = config.readEntry("PreferredMethod", "Fam"); 
+  if (method == "Fam")
+  {
+    m_preferredMethod = Fam;
+  }else if (method == "Stat")
+  {
+    m_preferredMethod = Stat;
+  }else
+  {
+    m_preferredMethod = INotify;
+  }
+
+
+  QStringList availableMethods;
+
+  availableMethods << "Stat";
 
   // used for FAM
   rescan_timer.setObjectName( "KDirWatchPrivate::rescan_timer" );
@@ -133,7 +147,7 @@ KDirWatchPrivate::KDirWatchPrivate()
 #ifdef HAVE_FAM
   // It's possible that FAM server can't be started
   if (FAMOpen(&fc) ==0) {
-    available += ", FAM";
+    availableMethods << "FAM";
     use_fam=true;
     sn = new QSocketNotifier( FAMCONNECTION_GETFD(&fc),
 			      QSocketNotifier::Read, this);
@@ -141,7 +155,7 @@ KDirWatchPrivate::KDirWatchPrivate()
  	     this, SLOT(famEventReceived()) );
   }
   else {
-    kDebug(7001) << "Can't use FAM (fam daemon not running?)" << endl;
+    kDebug(7001) << "Can't use FAM (fam daemon not running?)";
     use_fam=false;
   }
 #endif
@@ -152,7 +166,7 @@ KDirWatchPrivate::KDirWatchPrivate()
   m_inotify_fd = inotify_init();
 
   if ( m_inotify_fd <= 0 ) {
-    kDebug(7001) << "Can't use Inotify, kernel doesn't support it" << endl;
+    kDebug(7001) << "Can't use Inotify, kernel doesn't support it";
     supports_inotify = false;
   }
 
@@ -164,24 +178,25 @@ KDirWatchPrivate::KDirWatchPrivate()
     else if (sscanf(uts.release, "%d.%d.%d", &major, &minor, &patch) != 3)
       supports_inotify = false; // *shrug*
     else if( major * 1000000 + minor * 1000 + patch < 2006014 ) { // <2.6.14
-      kDebug(7001) << "Can't use INotify, Linux kernel too old" << endl;
+      kDebug(7001) << "Can't use INotify, Linux kernel too old";
       supports_inotify = false;
     }
   }
 
   if ( supports_inotify ) {
-    available += ", INotify";
+    availableMethods << "INotify";
     fcntl(m_inotify_fd, F_SETFD, FD_CLOEXEC);
 
     mSn = new QSocketNotifier( m_inotify_fd, QSocketNotifier::Read, this );
-    connect( mSn, SIGNAL(activated( int )), this, SLOT( slotActivated() ) );
+    connect( mSn, SIGNAL(activated( int )),
+             this, SLOT( inotifyEventReceived() ) );
   }
 #endif
 
-  kDebug(7001) << "Available methods: " << available << endl;
+  kDebug(7001) << "Available methods: " << availableMethods;
 }
 
-/* This is called on app exit (KStaticDeleter) */
+/* This is called on app exit (K_GLOBAL_STATIC) */
 KDirWatchPrivate::~KDirWatchPrivate()
 {
   timer.stop();
@@ -200,11 +215,9 @@ KDirWatchPrivate::~KDirWatchPrivate()
 #endif
 }
 
-#include <stdlib.h>
-
-void KDirWatchPrivate::slotActivated()
+void KDirWatchPrivate::inotifyEventReceived()
 {
-
+  kDebug(7001) << "KDirWatchPrivate::inotifyEventReceived";
 #ifdef HAVE_SYS_INOTIFY_H
   if ( !supports_inotify )
     return;
@@ -246,7 +259,7 @@ void KDirWatchPrivate::slotActivated()
           e->dirty = true;
 
           if( event->mask & IN_DELETE_SELF) {
-            kDebug(7001) << "-->got deleteself signal for " << e->path << endl;
+            kDebug(7001) << "-->got deleteself signal for" << e->path;
             e->m_status = NonExistent;
             if (e->isDir)
               addEntry(0, QDir::cleanPath(e->path+"/.."), e, true);
@@ -276,6 +289,32 @@ void KDirWatchPrivate::slotActivated()
                 useStat(sub_entry);
               sub_entry->dirty = true;
             }
+            else if ((e->isDir) && (!e->m_clients.empty())) {
+              Client* client = 0;
+
+              KDE_struct_stat stat_buf;
+              QByteArray tpath = QFile::encodeName(e->path+'/'+path);
+              KDE_stat(tpath, &stat_buf);
+              bool isDir = S_ISDIR(stat_buf.st_mode);
+
+              KDirWatch::WatchModes flag;
+              flag = isDir ? KDirWatch::WatchSubDirs : KDirWatch::WatchFiles;
+
+              int counter = 0;
+              Q_FOREACH(client, e->m_clients) {
+                  if (client->m_watchModes & flag) {
+                      addEntry (client->instance, tpath, 0, isDir,
+                                client->m_watchModes);
+                      counter++;
+                    }
+              }
+
+              if (counter != 0)
+                emitEvent (e, Created, e->path+'/'+path);
+
+              kDebug(7001).nospace() << counter << " instance(s) monitoring the new "
+                << (isDir ? "dir " : "file ") << tpath;
+            }
           }
 
           if (!rescan_timer.isActive())
@@ -309,11 +348,16 @@ void KDirWatchPrivate::Entry::propagate_dirty()
 /* A KDirWatch instance is interested in getting events for
  * this file/Dir entry.
  */
-void KDirWatchPrivate::Entry::addClient(KDirWatch* instance)
+void KDirWatchPrivate::Entry::addClient(KDirWatch* instance,
+                                        KDirWatch::WatchModes watchModes)
 {
+  if (instance == 0)
+    return;
+  
   foreach(Client* client, m_clients) {
     if (client->instance == instance) {
       client->count++;
+      client->m_watchModes = watchModes;
       return;
     }
   }
@@ -323,6 +367,7 @@ void KDirWatchPrivate::Entry::addClient(KDirWatch* instance)
   client->count = 1;
   client->watchingStopped = instance->isStopped();
   client->pending = NoChange;
+  client->m_watchModes = watchModes;
 
   m_clients.append(client);
 }
@@ -362,7 +407,7 @@ KDirWatchPrivate::Entry* KDirWatchPrivate::entry(const QString& _path)
     return 0;
   }
 
-  QString path = _path;
+  QString path (_path);
 
   if ( path.length() > 1 && path.endsWith( QLatin1Char( '/' ) ) )
     path.truncate( path.length() - 1 );
@@ -383,7 +428,7 @@ void KDirWatchPrivate::useFreq(Entry* e, int newFreq)
   if (e->freq < freq) {
     freq = e->freq;
     if (timer.isActive()) timer.start(freq);
-    kDebug(7001) << "Global Poll Freq is now " << freq << " msec" << endl;
+    kDebug(7001) << "Global Poll Freq is now" << freq << "msec";
   }
 }
 
@@ -414,9 +459,8 @@ bool KDirWatchPrivate::useFAM(Entry* e)
 	use_fam=false;
 	return false;
       }
-      kDebug(7001) << " Setup FAM (Req "
-		    << FAMREQUEST_GETREQNUM(&(e->fr))
-		    << ") for " << e->path << endl;
+      kDebug(7001).nospace() << " Setup FAM (Req " << FAMREQUEST_GETREQNUM(&(e->fr))
+                   << ") for " << e->path;
     }
   }
   else {
@@ -433,9 +477,8 @@ bool KDirWatchPrivate::useFAM(Entry* e)
 	return false;
       }
 
-      kDebug(7001) << " Setup FAM (Req "
-		    << FAMREQUEST_GETREQNUM(&(e->fr))
-		    << ") for " << e->path << endl;
+      kDebug(7001).nospace() << " Setup FAM (Req " << FAMREQUEST_GETREQNUM(&(e->fr))
+                   << ") for " << e->path;
     }
   }
 
@@ -451,6 +494,8 @@ bool KDirWatchPrivate::useFAM(Entry* e)
 // setup INotify notification, returns false if not possible
 bool KDirWatchPrivate::useINotify( Entry* e )
 {
+  kDebug (7001) << "trying to use inotify for monitoring";
+
   e->wd = 0;
   e->dirty = false;
 
@@ -476,7 +521,10 @@ bool KDirWatchPrivate::useINotify( Entry* e )
 
   if ( ( e->wd = inotify_add_watch( m_inotify_fd,
                                     QFile::encodeName( e->path ), mask) ) > 0)
+  {
+    kDebug (7001) << "inotify successfully used for monitoring";
     return true;
+  }
 
   return false;
 }
@@ -484,7 +532,9 @@ bool KDirWatchPrivate::useINotify( Entry* e )
 
 bool KDirWatchPrivate::useStat(Entry* e)
 {
-  if (KIO::probably_slow_mounted(e->path))
+  KMountPoint::Ptr mp = KMountPoint::currentMountPoints().findByPath(e->path);
+  const bool slow = mp ? mp->probablySlow() : false;
+  if (slow)
     useFreq(e, m_nfsPollInterval);
   else
     useFreq(e, m_PollInterval);
@@ -496,12 +546,11 @@ bool KDirWatchPrivate::useStat(Entry* e)
     if ( statEntries == 1 ) {
       // if this was first STAT entry (=timer was stopped)
       timer.start(freq);      // then start the timer
-      kDebug(7001) << " Started Polling Timer, freq " << freq << endl;
+      kDebug(7001) << " Started Polling Timer, freq " << freq;
     }
   }
 
-  kDebug(7001) << " Setup Stat (freq " << e->freq
-		<< ") for " << e->path << endl;
+  kDebug(7001) << " Setup Stat (freq " << e->freq << ") for " << e->path;
 
   return true;
 }
@@ -513,9 +562,9 @@ bool KDirWatchPrivate::useStat(Entry* e)
  * this entry needs another entry to watch himself (when notExistent).
  */
 void KDirWatchPrivate::addEntry(KDirWatch* instance, const QString& _path,
-				Entry* sub_entry, bool isDir)
+                Entry* sub_entry, bool isDir, KDirWatch::WatchModes watchModes)
 {
-  QString path = _path;
+  QString path (_path);
   if (path.startsWith("/dev/") || (path == "/dev"))
     return; // Don't even go there.
 
@@ -528,7 +577,7 @@ void KDirWatchPrivate::addEntry(KDirWatch* instance, const QString& _path,
     if (sub_entry) {
        (*it).m_entries.append(sub_entry);
        kDebug(7001) << "Added already watched Entry " << path
-		     << " (for " << sub_entry->path << ")" << endl;
+                    << " (for " << sub_entry->path << ")";
 #ifdef HAVE_SYS_INOTIFY
        Entry* e = &(*it);
        if( (e->m_mode == INotifyMode) && (e->wd > 0) ) {
@@ -539,15 +588,16 @@ void KDirWatchPrivate::addEntry(KDirWatch* instance, const QString& _path,
            mask |= IN_ONLYDIR;
 
          inotify_rm_watch (m_inotify_fd, e->wd);
-         e->wd = inotify_add_watch( m_inotify_fd, QFile::encodeName( e->path ), mask);
+         e->wd = inotify_add_watch( m_inotify_fd, QFile::encodeName( e->path ),
+                                    mask);
        }
 #endif
     }
     else {
-       (*it).addClient(instance);
-       kDebug(7001) << "Added already watched Entry " << path
-		     << " (now " <<  (*it).clients() << " clients)"
-		     << QString(" [%1]").arg(instance->objectName()) << endl;
+       (*it).addClient(instance, watchModes);
+       kDebug(7001) << "Added already watched Entry" << path
+		     << "(now" <<  (*it).clients() << "clients)"
+		     << QString("[%1]").arg(instance->objectName());
     }
     return;
   }
@@ -555,7 +605,7 @@ void KDirWatchPrivate::addEntry(KDirWatch* instance, const QString& _path,
   // we have a new path to watch
 
   KDE_struct_stat stat_buf;
-  QByteArray tpath = QFile::encodeName(path);
+  QByteArray tpath (QFile::encodeName(path));
   bool exists = (KDE_stat(tpath, &stat_buf) == 0);
 
   Entry newEntry;
@@ -571,6 +621,13 @@ void KDirWatchPrivate::addEntry(KDirWatch* instance, const QString& _path,
     else if (!e->isDir && isDir)
       qWarning("KDirWatch: %s is a file. Use addFile!", qPrintable(path));
 
+    if (!e->isDir && ( watchModes != KDirWatch::WatchDirOnly)) {
+      QString msg ("KDirWatch: %s is a file. You can't use recursive or "
+                   "watchFiles options");
+      qWarning(msg.toAscii(), qPrintable(path));
+      watchModes = KDirWatch::WatchDirOnly;
+    }
+
     e->m_ctime = stat_buf.st_ctime;
     e->m_status = Normal;
     e->m_nlink = stat_buf.st_nlink;
@@ -584,16 +641,14 @@ void KDirWatchPrivate::addEntry(KDirWatch* instance, const QString& _path,
 
   e->path = path;
   if (sub_entry)
-     e->m_entries.append(sub_entry);
+    e->m_entries.append(sub_entry);
   else
-    e->addClient(instance);
-
-  kDebug(7001) << "Added " << (e->isDir ? "Dir ":"File ") << path
-		<< (e->m_status == NonExistent ? " NotExisting" : "")
-		<< (sub_entry ? QString(" for %1").arg(sub_entry->path) : QString(""))
-		<< (instance ? QString(" [%1]").arg(instance->objectName()) : QString(""))
-		<< endl;
+    e->addClient(instance, watchModes);
 
+  kDebug(7001).nospace() << "Added " << (e->isDir ? "Dir " : "File ") << path
+    << (e->m_status == NonExistent ? " NotExisting" : "")
+    << " for " << (sub_entry ? sub_entry->path : "")
+    << " [" << (instance ? instance->objectName() : "") << "]";
 
   // now setup the notification method
   e->m_mode = UnknownMode;
@@ -602,25 +657,76 @@ void KDirWatchPrivate::addEntry(KDirWatch* instance, const QString& _path,
   if ( isNoisyFile( tpath ) )
     return;
 
-#if defined(HAVE_FAM)
-  if (useFAM(e)) return;
-#endif
+  if (exists && e->isDir && (watchModes != KDirWatch::WatchDirOnly)) {
+    QFlags<QDir::Filter> filters = QDir::NoDotAndDotDot;
 
+    if ((watchModes & KDirWatch::WatchSubDirs) &&
+        (watchModes & KDirWatch::WatchFiles)) {
+      filters |= (QDir::Dirs|QDir::Files);
+    } else if (watchModes & KDirWatch::WatchSubDirs) {
+      filters |= QDir::Dirs;
+    } else if (watchModes & KDirWatch::WatchFiles) {
+      filters |= QDir::Files;
+    }
+ 
+    QDir basedir (e->path);
+    QFileInfoList contents = basedir.entryInfoList(filters);
+    for (QFileInfoList::iterator iter = contents.begin();
+         iter != contents.end(); iter++)
+    {
+      QFileInfo fileInfo = *iter;
+      bool isDir = fileInfo.isDir();
+      addEntry (instance, fileInfo.absoluteFilePath(), 0, isDir,
+                isDir ? watchModes : KDirWatch::WatchDirOnly);
+    }
+  }
+  
+  // Now I've put inotify check before famd one, otherwise famd will be used
+  // also when inotify is available. Since inotify works
+  // better than famd, it is preferred to the last one
+ 
+  //First try to use the preferred method, if that fails use the usual order:
+  //inotify,fam,stat
+  bool entryAdded = false;
+  if (m_preferredMethod == Fam)
+  {
+#if defined(HVE_FAM)
+    entryAdded = useFAM(e);
+#endif
+  }else if (m_preferredMethod == INotify)
+  {
 #if defined(HAVE_SYS_INOTIFY_H)
-  if (useINotify(e)) return;
+    entryAdded = useINotify(e);
 #endif
+  }else if (m_preferredMethod == Stat)
+  {
+    entryAdded = useStat(e);
+  }
 
-  useStat(e);
+  if (!entryAdded)
+  {
+#if defined(HAVE_SYS_INOTIFY_H)
+    if (useINotify(e)) return;
+#endif
+  
+#if defined(HAVE_FAM)
+    if (useFAM(e)) return;
+#endif
+  
+    useStat(e);
+  }
 }
 
 
 void KDirWatchPrivate::removeEntry( KDirWatch* instance,
 				    const QString& _path, Entry* sub_entry )
 {
-  kDebug(7001) << "KDirWatchPrivate::removeEntry for '" << _path << "' sub_entry: " << sub_entry << endl;
+  kDebug(7001)  << "KDirWatchPrivate::removeEntry for" << _path
+                << "sub_entry:" << sub_entry;
   Entry* e = entry(_path);
   if (!e) {
-    kWarning(7001) << "KDirWatch::removeDir can't handle '" << _path << "'" << endl;
+    kWarning(7001)  << "KDirWatch::removeDir can't handle"
+                    << _path;
     return;
   }
 
@@ -644,9 +750,8 @@ void KDirWatchPrivate::removeEntry( KDirWatch* instance,
   if (e->m_mode == FAMMode) {
     if ( e->m_status == Normal) {
       FAMCancelMonitor(&fc, &(e->fr) );
-      kDebug(7001) << "Cancelled FAM (Req "
-		    << FAMREQUEST_GETREQNUM(&(e->fr))
-		    << ") for " << e->path << endl;
+      kDebug(7001).nospace()  << "Cancelled FAM (Req " << FAMREQUEST_GETREQNUM(&(e->fr))
+                    << ") for " << e->path;
     }
     else {
       if (e->isDir)
@@ -661,9 +766,8 @@ void KDirWatchPrivate::removeEntry( KDirWatch* instance,
   if (e->m_mode == INotifyMode) {
     if ( e->m_status == Normal ) {
       (void) inotify_rm_watch( m_inotify_fd, e->wd );
-      kDebug(7001) << "Cancelled INotify (fd " <<
-        m_inotify_fd << ", "  << e->wd <<
-        ") for " << e->path << endl;
+      kDebug(7001).nospace() << "Cancelled INotify (fd " << m_inotify_fd << ", "
+                             << e->wd << ") for " << e->path;
     }
     else {
       if (e->isDir)
@@ -678,14 +782,13 @@ void KDirWatchPrivate::removeEntry( KDirWatch* instance,
     statEntries--;
     if ( statEntries == 0 ) {
       timer.stop(); // stop timer if lists are empty
-      kDebug(7001) << " Stopped Polling Timer" << endl;
+      kDebug(7001) << " Stopped Polling Timer";
     }
   }
 
-  kDebug(7001) << "Removed " << (e->isDir ? "Dir ":"File ") << e->path
-		<< (sub_entry ? QString(" for %1").arg(sub_entry->path) : QString(""))
-		<< (instance ? QString(" [%1]").arg(instance->objectName()) : QString(""))
-		<< endl;
+  kDebug(7001).nospace() << "Removed " << (e->isDir ? "Dir ":"File ") << e->path
+     << " for " << (sub_entry ? sub_entry->path : "")
+     << " [" << (instance ? instance->objectName() : "") << "]";
   m_mapEntries.remove( e->path ); // <e> not valid any more
 }
 
@@ -723,7 +826,7 @@ void KDirWatchPrivate::removeEntries( KDirWatch* instance )
     // we can decrease the global polling frequency
     freq = minfreq;
     if (timer.isActive()) timer.start(freq);
-    kDebug(7001) << "Poll Freq now " << freq << " msec" << endl;
+    kDebug(7001) << "Poll Freq now" << freq << "msec";
   }
 }
 
@@ -738,13 +841,13 @@ bool KDirWatchPrivate::stopEntryScan( KDirWatch* instance, Entry* e)
       stillWatching += client->count;
   }
 
-  kDebug(7001) << (instance ? instance->objectName() : "all") << " stopped scanning " << e->path
-		<< " (now " << stillWatching << " watchers)" << endl;
+  kDebug(7001)  << (instance ? instance->objectName() : "all")
+                << "stopped scanning" << e->path << "(now"
+                << stillWatching << "watchers)";
 
   if (stillWatching == 0) {
     // if nobody is interested, we don't watch
-    if ( e->m_mode != INotifyMode )
-    {
+    if ( e->m_mode != INotifyMode ) {
       e->m_ctime = invalid_ctime; // invalid
       e->m_status = NonExistent;
     }
@@ -769,8 +872,9 @@ bool KDirWatchPrivate::restartEntryScan( KDirWatch* instance, Entry* e,
   if (newWatching == 0)
     return false;
 
-  kDebug(7001) << (instance ? instance->objectName() : "all") << " restarted scanning " << e->path
-		<< " (now " << wasWatching+newWatching << " watchers)" << endl;
+  kDebug(7001)  << (instance ? instance->objectName() : "all")
+                << "restarted scanning" << e->path
+                << "(now" << wasWatching+newWatching << "watchers)";
 
   // restart watching and emit pending events
 
@@ -780,13 +884,13 @@ bool KDirWatchPrivate::restartEntryScan( KDirWatch* instance, Entry* e,
       KDE_struct_stat stat_buf;
       bool exists = (KDE_stat(QFile::encodeName(e->path), &stat_buf) == 0);
       if (exists) {
-	e->m_ctime = stat_buf.st_ctime;
-	e->m_status = Normal;
+        e->m_ctime = stat_buf.st_ctime;
+        e->m_status = Normal;
         e->m_nlink = stat_buf.st_nlink;
       }
       else {
-	e->m_ctime = invalid_ctime;
-	e->m_status = NonExistent;
+        e->m_ctime = invalid_ctime;
+        e->m_status = NonExistent;
         e->m_nlink = 0;
       }
     }
@@ -808,7 +912,7 @@ void KDirWatchPrivate::stopScan(KDirWatch* instance)
 
 
 void KDirWatchPrivate::startScan(KDirWatch* instance,
-				 bool notify, bool skippedToo )
+                                 bool notify, bool skippedToo )
 {
   if (!notify)
     resetList(instance,skippedToo);
@@ -822,15 +926,14 @@ void KDirWatchPrivate::startScan(KDirWatch* instance,
 
 
 // clear all pending events, also from stopped
-void KDirWatchPrivate::resetList( KDirWatch* /*instance*/,
-				  bool skippedToo )
+void KDirWatchPrivate::resetList( KDirWatch* /*instance*/, bool skippedToo )
 {
   EntryMap::Iterator it = m_mapEntries.begin();
   for( ; it != m_mapEntries.end(); ++it ) {
 
     foreach(Client* client, (*it).m_clients) {
       if (!client->watchingStopped || skippedToo)
-	client->pending = NoChange;
+        client->pending = NoChange;
     }
   }
 }
@@ -880,8 +983,8 @@ int KDirWatchPrivate::scanEntry(Entry* e)
     }
 
     if ( (e->m_ctime != invalid_ctime) &&
-	 ((stat_buf.st_ctime != e->m_ctime) ||
-	  (stat_buf.st_nlink != (nlink_t) e->m_nlink)) ) {
+          ((stat_buf.st_ctime != e->m_ctime) ||
+          (stat_buf.st_nlink != (nlink_t) e->m_nlink)) ) {
       e->m_ctime = stat_buf.st_ctime;
       e->m_nlink = stat_buf.st_nlink;
       return Changed;
@@ -911,7 +1014,7 @@ int KDirWatchPrivate::scanEntry(Entry* e)
  */
 void KDirWatchPrivate::emitEvent(Entry* e, int event, const QString &fileName)
 {
-  QString path = e->path;
+  QString path (e->path);
   if (!fileName.isEmpty()) {
     if (!QDir::isRelativePath(fileName))
       path = fileName;
@@ -931,9 +1034,9 @@ void KDirWatchPrivate::emitEvent(Entry* e, int event, const QString &fileName)
     if (c->watchingStopped) {
       // add event to pending...
       if (event == Changed)
-	c->pending |= event;
+        c->pending |= event;
       else if (event == Created || event == Deleted)
-	c->pending = event;
+        c->pending = event;
       continue;
     }
     // not stopped
@@ -1065,10 +1168,11 @@ void KDirWatchPrivate::famEventReceived()
 
   delayRemove = true;
 
+  kDebug(7001) << "Fam event received";
+
   while(use_fam && FAMPending(&fc)) {
     if (FAMNextEvent(&fc, &fe) == -1) {
-      kWarning(7001) << "FAM connection problem, switching to polling."
-		      << endl;
+      kWarning(7001) << "FAM connection problem, switching to polling.";
       use_fam = false;
       delete sn; sn = 0;
 
@@ -1076,12 +1180,12 @@ void KDirWatchPrivate::famEventReceived()
       EntryMap::Iterator it;
       it = m_mapEntries.begin();
       for( ; it != m_mapEntries.end(); ++it )
-	if ((*it).m_mode == FAMMode && (*it).m_clients.count()>0) {
+        if ((*it).m_mode == FAMMode && (*it).m_clients.count()>0) {
 #ifdef HAVE_SYS_INOTIFY_H
-	  if (useINotify( &(*it) )) continue;
+          if (useINotify( &(*it) )) continue;
 #endif
-	  useStat( &(*it) );
-	}
+          useStat( &(*it) );
+        }
     }
     else
       checkFAMEvent(&fe);
@@ -1092,6 +1196,8 @@ void KDirWatchPrivate::famEventReceived()
 
 void KDirWatchPrivate::checkFAMEvent(FAMEvent* fe)
 {
+  kDebug(7001) << "checkFAMEvent";
+
   // Don't be too verbose ;-)
   if ((fe->code == FAMExists) ||
       (fe->code == FAMEndExist) ||
@@ -1112,29 +1218,28 @@ void KDirWatchPrivate::checkFAMEvent(FAMEvent* fe)
   // Entry* e = static_cast<Entry*>(fe->userdata);
 
 #if 0 // #88538
-  kDebug(7001) << "Processing FAM event ("
-		<< ((fe->code == FAMChanged) ? "FAMChanged" :
-		    (fe->code == FAMDeleted) ? "FAMDeleted" :
-		    (fe->code == FAMStartExecuting) ? "FAMStartExecuting" :
-		    (fe->code == FAMStopExecuting) ? "FAMStopExecuting" :
-		    (fe->code == FAMCreated) ? "FAMCreated" :
-		    (fe->code == FAMMoved) ? "FAMMoved" :
-		    (fe->code == FAMAcknowledge) ? "FAMAcknowledge" :
-		    (fe->code == FAMExists) ? "FAMExists" :
-		    (fe->code == FAMEndExist) ? "FAMEndExist" : "Unknown Code")
-		<< ", " << fe->filename
-		<< ", Req " << FAMREQUEST_GETREQNUM(&(fe->fr))
-		<< ")" << endl;
+  kDebug(7001)  << "Processing FAM event ("
+                << ((fe->code == FAMChanged) ? "FAMChanged" :
+                    (fe->code == FAMDeleted) ? "FAMDeleted" :
+                    (fe->code == FAMStartExecuting) ? "FAMStartExecuting" :
+                    (fe->code == FAMStopExecuting) ? "FAMStopExecuting" :
+                    (fe->code == FAMCreated) ? "FAMCreated" :
+                    (fe->code == FAMMoved) ? "FAMMoved" :
+                    (fe->code == FAMAcknowledge) ? "FAMAcknowledge" :
+                    (fe->code == FAMExists) ? "FAMExists" :
+                    (fe->code == FAMEndExist) ? "FAMEndExist" : "Unknown Code")
+                << ", " << fe->filename
+                << ", Req " << FAMREQUEST_GETREQNUM(&(fe->fr)) << ")";
 #endif
 
   if (!e) {
     // this happens e.g. for FAMAcknowledge after deleting a dir...
-    //    kDebug(7001) << "No entry for FAM event ?!" << endl;
+    //    kDebug(7001) << "No entry for FAM event ?!";
     return;
   }
 
   if (e->m_status == NonExistent) {
-    kDebug(7001) << "FAM event for nonExistent entry " << e->path << endl;
+    kDebug(7001) << "FAM event for nonExistent entry " << e->path;
     return;
   }
 
@@ -1155,9 +1260,9 @@ void KDirWatchPrivate::checkFAMEvent(FAMEvent* fe)
 
           e->m_status = NonExistent;
           FAMCancelMonitor(&fc, &(e->fr) ); // needed ?
-          kDebug(7001) << "Cancelled FAMReq "
+          kDebug(7001)  << "Cancelled FAMReq"
                         << FAMREQUEST_GETREQNUM(&(e->fr))
-                        << " for " << e->path << endl;
+                        << "for" << e->path;
           // Scan parent for a new creation
           addEntry(0, QDir::cleanPath( e->path+"/.."), e, true);
         }
@@ -1165,30 +1270,62 @@ void KDirWatchPrivate::checkFAMEvent(FAMEvent* fe)
 
       case FAMCreated: {
           // check for creation of a directory we have to watch
-          foreach(Entry *sub_entry, e->m_entries) {
-            if (sub_entry->path == e->path + '/' + (const char *)fe->filename
-                && sub_entry->isDir) {
-              QString path = e->path;
-              removeEntry(0,e->path,sub_entry); // <e> can be invalid here!!
-              sub_entry->m_status = Normal;
-              if (!useFAM(sub_entry))
+        QByteArray tpath (QFile::encodeName( e->path + '/' +
+            (const char *)fe->filename));
+
+        Entry* sub_entry = 0;
+        foreach(sub_entry, e->m_entries)
+          if (sub_entry->path == tpath) break;
+
+        if (sub_entry && sub_entry->isDir) {
+          QString path (e->path);
+          removeEntry(0,e->path,sub_entry); // <e> can be invalid here!!
+          sub_entry->m_status = Normal;
+          if (!useFAM(sub_entry)) {
 #ifdef HAVE_SYS_INOTIFY_H
-                if (!useINotify(sub_entry ))
+            if (!useINotify(sub_entry ))
 #endif
-                  useStat(sub_entry);
-              break;
+              useStat(sub_entry);
+          }
+        }
+        else if ((sub_entry == 0) && (!e->m_clients.empty())) {
+          Client* client = 0;
+
+          KDE_struct_stat stat_buf;
+          KDE_stat(tpath, &stat_buf);
+          bool isDir = S_ISDIR(stat_buf.st_mode);
+
+          KDirWatch::WatchModes flag;
+          flag = isDir ? KDirWatch::WatchSubDirs : KDirWatch::WatchFiles;
+
+          int counter = 0;
+          Q_FOREACH(client, e->m_clients) {
+            if (client->m_watchModes & flag) {
+              addEntry (client->instance, tpath, 0, isDir,
+                        client->m_watchModes);
+              counter++;
             }
           }
-          break;
 
+          if (counter != 0)
+            emitEvent (e, Created, tpath);
+
+          QString msg (QString::number(counter));
+          msg += " instance/s monitoring the new ";
+          msg += (isDir ? "dir " : "file ") + tpath;
+          kDebug(7001) << msg;
         }
-
+      }
+        break;
       default:
         break;
     }
 }
 #else
-void KDirWatchPrivate::famEventReceived() {}
+void KDirWatchPrivate::famEventReceived()
+{
+    kWarning (7001) << "Fam event received but FAM isn't supported";
+}
 #endif
 
 
@@ -1196,41 +1333,40 @@ void KDirWatchPrivate::statistics()
 {
   EntryMap::Iterator it;
 
-  kDebug(7001) << "Entries watched:" << endl;
+  kDebug(7001) << "Entries watched:";
   if (m_mapEntries.count()==0) {
-    kDebug(7001) << "  None." << endl;
+    kDebug(7001) << "  None.";
   }
   else {
     it = m_mapEntries.begin();
     for( ; it != m_mapEntries.end(); ++it ) {
       Entry* e = &(*it);
-      kDebug(7001) << "  " << e->path << " ("
-		    << ((e->m_status==Normal)?"":"Nonexistent ")
-		    << (e->isDir ? "Dir":"File") << ", using "
-		    << ((e->m_mode == FAMMode) ? "FAM" :
+      kDebug(7001)  << "  " << e->path << " ("
+                    << ((e->m_status==Normal)?"":"Nonexistent ")
+                    << (e->isDir ? "Dir":"File") << ", using "
+                    << ((e->m_mode == FAMMode) ? "FAM" :
                         (e->m_mode == INotifyMode) ? "INotify" :
-			(e->m_mode == DNotifyMode) ? "DNotify" :
-			(e->m_mode == StatMode) ? "Stat" : "Unknown Method")
-		    << ")" << endl;
+                        (e->m_mode == DNotifyMode) ? "DNotify" :
+                        (e->m_mode == StatMode) ? "Stat" : "Unknown Method")
+                    << ")";
 
       foreach(Client* c, e->m_clients) {
-	QString pending;
-	if (c->watchingStopped) {
-	  if (c->pending & Deleted) pending += "deleted ";
-	  if (c->pending & Created) pending += "created ";
-	  if (c->pending & Changed) pending += "changed ";
-	  if (!pending.isEmpty()) pending = " (pending: " + pending + ')';
-	  pending = ", stopped" + pending;
-	}
-	kDebug(7001) << "    by " << c->instance->objectName()
-		      << " (" << c->count << " times)"
-		      << pending << endl;
+        QString pending;
+        if (c->watchingStopped) {
+          if (c->pending & Deleted) pending += "deleted ";
+          if (c->pending & Created) pending += "created ";
+          if (c->pending & Changed) pending += "changed ";
+          if (!pending.isEmpty()) pending = " (pending: " + pending + ')';
+          pending = ", stopped" + pending;
+        }
+        kDebug(7001)  << "    by " << c->instance->objectName()
+                      << " (" << c->count << " times)" << pending;
       }
       if (e->m_entries.count()>0) {
-	kDebug(7001) << "    dependent entries:" << endl;
+        kDebug(7001) << "    dependent entries:";
         foreach(Entry *d, e->m_entries) {
-	  kDebug(7001) << "      " << d->path << endl;
-	}
+          kDebug(7001) << "      " << d->path;
+        }
       }
     }
   }
@@ -1241,34 +1377,25 @@ void KDirWatchPrivate::statistics()
 // Class KDirWatch
 //
 
-static KStaticDeleter<KDirWatch> sd_dw;
-KDirWatch* KDirWatch::s_pSelf = 0L;
-
+K_GLOBAL_STATIC(KDirWatch, s_pKDirWatchSelf)
 KDirWatch* KDirWatch::self()
 {
-  if ( !s_pSelf ) {
-    sd_dw.setObject( s_pSelf, new KDirWatch );
-  }
-
-  return s_pSelf;
+  return s_pKDirWatchSelf;
 }
 
 bool KDirWatch::exists()
 {
-  return s_pSelf != 0;
+  return s_pKDirWatchSelf != 0;
 }
 
 KDirWatch::KDirWatch (QObject* parent)
-  : QObject(parent)
+  : QObject(parent), d(createPrivate())
 {
   static int nameCounter = 0;
 
   nameCounter++;
   setObjectName(QString("KDirWatch-%1").arg(nameCounter) );
 
-  if (!dwp_self)
-    dwp_self = new KDirWatchPrivate;
-  d = dwp_self;
   d->ref();
 
   _isStopped = false;
@@ -1281,19 +1408,13 @@ KDirWatch::~KDirWatch()
   {
     // delete it if it's the last one
     delete d;
-    dwp_self = 0L;
+    dwp_self = 0;
   }
 }
 
-
-// TODO: add watchFiles/recursive support
-void KDirWatch::addDir( const QString& _path,
-			bool watchFiles, bool recursive)
+void KDirWatch::addDir( const QString& _path, WatchModes watchModes)
 {
-  if (watchFiles || recursive) {
-    kDebug(7001) << "addDir - recursive/watchFiles not supported yet in KDE 3.x" << endl;
-  }
-  if (d) d->addEntry(this, _path, 0, true);
+  if (d) d->addEntry(this, _path, 0, true, watchModes);
 }
 
 void KDirWatch::addFile( const QString& _path )
@@ -1349,6 +1470,11 @@ void KDirWatch::stopScan()
   _isStopped = true;
 }
 
+bool KDirWatch::isStopped()
+{
+  return _isStopped;
+}
+
 void KDirWatch::startScan( bool notify, bool skippedToo )
 {
   _isStopped = false;
@@ -1373,7 +1499,7 @@ bool KDirWatch::contains( const QString& _path ) const
 void KDirWatch::statistics()
 {
   if (!dwp_self) {
-    kDebug(7001) << "KDirWatch not used" << endl;
+    kDebug(7001) << "KDirWatch not used";
     return;
   }
   dwp_self->statistics();
@@ -1382,19 +1508,19 @@ void KDirWatch::statistics()
 
 void KDirWatch::setCreated( const QString & _file )
 {
-  kDebug(7001) << objectName() << " emitting created " << _file << endl;
+  kDebug(7001) << objectName() << "emitting created" << _file;
   emit created( _file );
 }
 
 void KDirWatch::setDirty( const QString & _file )
 {
-  kDebug(7001) << objectName() << " emitting dirty " << _file << endl;
+  kDebug(7001) << objectName() << "emitting dirty" << _file;
   emit dirty( _file );
 }
 
 void KDirWatch::setDeleted( const QString & _file )
 {
-  kDebug(7001) << objectName() << " emitting deleted " << _file << endl;
+  kDebug(7001) << objectName() << "emitting deleted" << _file;
   emit deleted( _file );
 }
 
