@@ -18,10 +18,10 @@
    Boston, MA 02110-1301, USA.
 */
 
-#include <config.h>
-
 #include "kfileitem.h"
 
+#include <config.h>
+
 #include <sys/time.h>
 #include <pwd.h>
 #include <grp.h>
@@ -31,10 +31,10 @@
 #include <assert.h>
 #include <unistd.h>
 
-#include <qdatetime.h>
-#include <qdir.h>
-#include <qfile.h>
-#include <qmap.h>
+#include <QtCore/QDate>
+#include <QtCore/QDir>
+#include <QtCore/QFile>
+#include <QtCore/QMap>
 #include <QTextDocument>
 
 #include <kdebug.h>
@@ -48,6 +48,8 @@
 #include <kmimetype.h>
 #include <krun.h>
 #include <kde_file.h>
+#include <kdesktopfile.h>
+#include <kmountpoint.h>
 
 class KFileItemPrivate : public QSharedData
 {
@@ -68,7 +70,7 @@ public:
           m_delayedMimeTypes( delayedMimeTypes ),
           m_hidden( Auto )
     {
-        if (!entry.isEmpty()) {
+        if (!entry.count()==0) {
             readUDSEntry( urlIsDirectory );
         } else {
             m_strName = url.fileName();
@@ -92,7 +94,7 @@ public:
     void init();
 
     KIO::filesize_t size() const;
-    time_t time( unsigned int which ) const;
+    KDateTime time( KFileItem::FileTimes which ) const;
     bool cmp( const KFileItemPrivate & item ) const;
 
     /**
@@ -170,16 +172,14 @@ public:
     QMap<const void*, void*> m_extra; // DEPRECATED
     mutable KFileMetaInfo m_metaInfo;
 
-    enum { Modification = 0, Access = 1, Creation = 2, NumFlags = 3 };
-    mutable time_t m_time[3]; // TODO remove, UDSEntry is fast now
+    enum { NumFlags = KFileItem::CreationTime + 1 };
+    mutable KDateTime m_time[3];
 };
 
 void KFileItemPrivate::init()
 {
     m_access.clear();
     //  metaInfo = KFileMetaInfo();
-    for ( int i = 0; i < NumFlags; i++ )
-        m_time[i] = (time_t) -1;
 
     // determine mode and/or permissions if unknown
     // TODO: delay this until requested
@@ -209,8 +209,8 @@ void KFileItemPrivate::init()
                         mode = (S_IFMT-1) | S_IRWXU | S_IRWXG | S_IRWXO;
                 }
                 // While we're at it, store the times
-                m_time[ Modification ] = buf.st_mtime;
-                m_time[ Access ] = buf.st_atime;
+                m_time[ KFileItem::ModificationTime ].setTime_t(buf.st_mtime);
+                m_time[ KFileItem::AccessTime ].setTime_t(buf.st_atime);
                 if ( m_fileMode == KFileItem::Unknown )
                     m_fileMode = mode & S_IFMT; // extract file type
                 if ( m_permissions == KFileItem::Unknown )
@@ -255,26 +255,26 @@ void KFileItemPrivate::readUDSEntry( bool _urlIsDirectory )
 {
     // extract fields from the KIO::UDS Entry
 
-    m_fileMode = m_entry.numberValue( KIO::UDS_FILE_TYPE );
-    m_permissions = m_entry.numberValue( KIO::UDS_ACCESS );
-    m_strName = m_entry.stringValue( KIO::UDS_NAME );
+    m_fileMode = m_entry.numberValue( KIO::UDSEntry::UDS_FILE_TYPE );
+    m_permissions = m_entry.numberValue( KIO::UDSEntry::UDS_ACCESS );
+    m_strName = m_entry.stringValue( KIO::UDSEntry::UDS_NAME );
     m_strText = KIO::decodeFileName( m_strName );
-    const QString urlStr = m_entry.stringValue( KIO::UDS_URL );
+    const QString urlStr = m_entry.stringValue( KIO::UDSEntry::UDS_URL );
     const bool UDS_URL_seen = !urlStr.isEmpty();
     if ( UDS_URL_seen ) {
         m_url = KUrl( urlStr );
         if ( m_url.isLocalFile() )
             m_bIsLocalUrl = true;
     }
-    const QString mimeTypeStr = m_entry.stringValue( KIO::UDS_MIME_TYPE );
+    const QString mimeTypeStr = m_entry.stringValue( KIO::UDSEntry::UDS_MIME_TYPE );
     m_bMimeTypeKnown = !mimeTypeStr.isEmpty();
     if ( m_bMimeTypeKnown )
         m_pMimeType = KMimeType::mimeType( mimeTypeStr );
 
-    m_guessedMimeType = m_entry.stringValue( KIO::UDS_GUESSED_MIME_TYPE );
-    m_bLink = !m_entry.stringValue( KIO::UDS_LINK_DEST ).isEmpty(); // we don't store the link dest
+    m_guessedMimeType = m_entry.stringValue( KIO::UDSEntry::UDS_GUESSED_MIME_TYPE );
+    m_bLink = !m_entry.stringValue( KIO::UDSEntry::UDS_LINK_DEST ).isEmpty(); // we don't store the link dest
 
-    const int hiddenVal = m_entry.numberValue( KIO::UDS_HIDDEN, -1 );
+    const int hiddenVal = m_entry.numberValue( KIO::UDSEntry::UDS_HIDDEN, -1 );
     m_hidden = hiddenVal == 1 ? Hidden : ( hiddenVal == 0 ? Shown : Auto );
 
     // avoid creating these QStrings again and again
@@ -283,10 +283,11 @@ void KFileItemPrivate::readUDSEntry( bool _urlIsDirectory )
         m_url.addPath( m_strName );
 }
 
+inline //because it is used only in one place
 KIO::filesize_t KFileItemPrivate::size() const
 {
     // Extract it from the KIO::UDSEntry
-    long long fieldVal = m_entry.numberValue( KIO::UDS_SIZE, -1 );
+    long long fieldVal = m_entry.numberValue( KIO::UDSEntry::UDS_SIZE, -1 );
     if ( fieldVal != -1 ) {
         return fieldVal;
     }
@@ -300,29 +301,26 @@ KIO::filesize_t KFileItemPrivate::size() const
     return 0;
 }
 
-time_t KFileItemPrivate::time( unsigned int which ) const
+KDateTime KFileItemPrivate::time( KFileItem::FileTimes mappedWhich ) const
 {
-    unsigned int mappedWhich = 0;
-
-    switch( which ) {
-    case KIO::UDS_MODIFICATION_TIME:
-        mappedWhich = KFileItemPrivate::Modification;
-        break;
-    case KIO::UDS_ACCESS_TIME:
-        mappedWhich = KFileItemPrivate::Access;
-        break;
-    case KIO::UDS_CREATION_TIME:
-        mappedWhich = KFileItemPrivate::Creation;
-        break;
-    }
-
-    if ( m_time[mappedWhich] != (time_t) -1 )
+    if ( !m_time[mappedWhich].isNull() )
         return m_time[mappedWhich];
 
     // Extract it from the KIO::UDSEntry
-    long long fieldVal = m_entry.numberValue( which, -1 );
+    long long fieldVal = -1;
+    switch ( mappedWhich ) {
+    case KFileItem::ModificationTime:
+        fieldVal = m_entry.numberValue( KIO::UDSEntry::UDS_MODIFICATION_TIME, -1 );
+        break;
+    case KFileItem::AccessTime:
+        fieldVal = m_entry.numberValue( KIO::UDSEntry::UDS_ACCESS_TIME, -1 );
+        break;
+    case KFileItem::CreationTime:
+        fieldVal = m_entry.numberValue( KIO::UDSEntry::UDS_CREATION_TIME, -1 );
+        break;
+    }
     if ( fieldVal != -1 ) {
-        m_time[mappedWhich] = static_cast<time_t>( fieldVal );
+        m_time[mappedWhich].setTime_t( fieldVal );
         return m_time[mappedWhich];
     }
 
@@ -332,35 +330,36 @@ time_t KFileItemPrivate::time( unsigned int which ) const
         KDE_struct_stat buf;
         if ( KDE_stat( QFile::encodeName(m_url.path(KUrl::RemoveTrailingSlash)), &buf ) == 0 )
         {
-            m_time[mappedWhich] = (which == KIO::UDS_MODIFICATION_TIME) ?
-                                     buf.st_mtime :
-                                     (which == KIO::UDS_ACCESS_TIME) ? buf.st_atime :
-                                     static_cast<time_t>(0); // We can't determine creation time for local files
+            m_time[KFileItem::ModificationTime].setTime_t(buf.st_mtime);
+            m_time[KFileItem::AccessTime].setTime_t(buf.st_atime);
+            m_time[KFileItem::CreationTime] = KDateTime();
             return m_time[mappedWhich];
         }
     }
-    return static_cast<time_t>(0);
+    return KDateTime();
 }
 
+inline //because it is used only in one place
 bool KFileItemPrivate::cmp( const KFileItemPrivate & item ) const
 {
     return ( m_strName == item.m_strName
              && m_bIsLocalUrl == item.m_bIsLocalUrl
              && m_fileMode == item.m_fileMode
              && m_permissions == item.m_permissions
-             && m_entry.stringValue( KIO::UDS_USER ) == item.m_entry.stringValue( KIO::UDS_USER )
-             && m_entry.stringValue( KIO::UDS_GROUP ) == item.m_entry.stringValue( KIO::UDS_GROUP )
+             && m_entry.stringValue( KIO::UDSEntry::UDS_USER ) == item.m_entry.stringValue( KIO::UDSEntry::UDS_USER )
+             && m_entry.stringValue( KIO::UDSEntry::UDS_GROUP ) == item.m_entry.stringValue( KIO::UDSEntry::UDS_GROUP )
              && m_bLink == item.m_bLink
              && m_hidden == item.m_hidden
              && size() == item.size()
-             && time(KIO::UDS_MODIFICATION_TIME) == item.time(KIO::UDS_MODIFICATION_TIME)
-             && m_entry.stringValue( KIO::UDS_ICON_NAME ) == item.m_entry.stringValue( KIO::UDS_ICON_NAME )
+             && time(KFileItem::ModificationTime) == item.time(KFileItem::ModificationTime)
+             && m_entry.stringValue( KIO::UDSEntry::UDS_ICON_NAME ) == item.m_entry.stringValue( KIO::UDSEntry::UDS_ICON_NAME )
         );
 
     // Don't compare the mimetypes here. They might not be known, and we don't want to
     // do the slow operation of determining them here.
 }
 
+inline //because it is used only in one place
 QString KFileItemPrivate::parsePermissions(mode_t perm) const
 {
     static char buffer[ 12 ];
@@ -413,7 +412,7 @@ QString KFileItemPrivate::parsePermissions(mode_t perm) const
     buffer[8] = ((( perm & S_IWOTH ) == S_IWOTH ) ? 'w' : '-' );
     buffer[9] = oxbit;
     // if (hasExtendedACL())
-    if (m_entry.find( KIO::UDS_EXTENDED_ACL ) != m_entry.end()) {
+    if (m_entry.contains(KIO::UDSEntry::UDS_EXTENDED_ACL)) {
         buffer[10] = '+';
         buffer[11] = 0;
     } else {
@@ -500,7 +499,7 @@ void KFileItem::setName( const QString& name )
 QString KFileItem::linkDest() const
 {
     // Extract it from the KIO::UDSEntry
-    const QString linkStr = d->m_entry.stringValue( KIO::UDS_LINK_DEST );
+    const QString linkStr = d->m_entry.stringValue( KIO::UDSEntry::UDS_LINK_DEST );
     if ( !linkStr.isEmpty() )
         return linkStr;
 
@@ -525,7 +524,7 @@ QString KFileItem::localPath() const
   }
 
   // Extract the local path from the KIO::UDSEntry
-  return d->m_entry.stringValue( KIO::UDS_LOCAL_PATH );
+  return d->m_entry.stringValue( KIO::UDSEntry::UDS_LOCAL_PATH );
 }
 
 KIO::filesize_t KFileItem::size() const
@@ -536,14 +535,14 @@ KIO::filesize_t KFileItem::size() const
 bool KFileItem::hasExtendedACL() const
 {
     // Check if the field exists; its value doesn't matter
-    return d->m_entry.find( KIO::UDS_EXTENDED_ACL ) != d->m_entry.end();
+    return d->m_entry.contains(KIO::UDSEntry::UDS_EXTENDED_ACL);
 }
 
 KACL KFileItem::ACL() const
 {
     if ( hasExtendedACL() ) {
         // Extract it from the KIO::UDSEntry
-        const QString fieldVal = d->m_entry.stringValue( KIO::UDS_ACL_STRING );
+        const QString fieldVal = d->m_entry.stringValue( KIO::UDSEntry::UDS_ACL_STRING );
         if ( !fieldVal.isEmpty() )
             return KACL( fieldVal );
     }
@@ -554,45 +553,68 @@ KACL KFileItem::ACL() const
 KACL KFileItem::defaultACL() const
 {
     // Extract it from the KIO::UDSEntry
-    const QString fieldVal = d->m_entry.stringValue( KIO::UDS_DEFAULT_ACL_STRING );
+    const QString fieldVal = d->m_entry.stringValue( KIO::UDSEntry::UDS_DEFAULT_ACL_STRING );
     if ( !fieldVal.isEmpty() )
         return KACL(fieldVal);
     else
         return KACL();
 }
 
-time_t KFileItem::time( unsigned int which ) const
+KDateTime KFileItem::time( FileTimes which ) const
 {
     return d->time(which);
 }
 
+time_t KFileItem::time( unsigned int which ) const
+{
+    switch (which) {
+    case KIO::UDSEntry::UDS_ACCESS_TIME:
+        return d->time(AccessTime).toTime_t();
+    case KIO::UDSEntry::UDS_CREATION_TIME:
+        return d->time(CreationTime).toTime_t();
+    case KIO::UDSEntry::UDS_MODIFICATION_TIME:
+    default:
+        return d->time(ModificationTime).toTime_t();
+    }
+}
+
 QString KFileItem::user() const
 {
-    QString userName = d->m_entry.stringValue( KIO::UDS_USER );
+    QString userName = d->m_entry.stringValue( KIO::UDSEntry::UDS_USER );
     if ( userName.isEmpty() && d->m_bIsLocalUrl )
     {
+#ifdef Q_WS_WIN
+        QFileInfo a(d->m_url.path( KUrl::RemoveTrailingSlash ));
+        userName = a.owner();
+        d->m_entry.insert( KIO::UDSEntry::UDS_USER, userName );
+#else
         KDE_struct_stat buff;
         if ( KDE_lstat( QFile::encodeName(d->m_url.path( KUrl::RemoveTrailingSlash )), &buff ) == 0) // get uid/gid of the link, if it's a link
         {
             struct passwd *pwuser = getpwuid( buff.st_uid );
             if ( pwuser != 0 ) {
                 userName = QString::fromLocal8Bit(pwuser->pw_name);
-                d->m_entry.insert( KIO::UDS_USER, userName );
+                d->m_entry.insert( KIO::UDSEntry::UDS_USER, userName );
             }
         }
+#endif
     }
     return userName;
 }
 
 QString KFileItem::group() const
 {
-    QString groupName = d->m_entry.stringValue( KIO::UDS_GROUP );
+    QString groupName = d->m_entry.stringValue( KIO::UDSEntry::UDS_GROUP );
     if (groupName.isEmpty() && d->m_bIsLocalUrl )
     {
+#ifdef Q_WS_WIN
+        QFileInfo a(d->m_url.path( KUrl::RemoveTrailingSlash ));
+        groupName = a.group();
+        d->m_entry.insert( KIO::UDSEntry::UDS_GROUP, groupName );
+#else
         KDE_struct_stat buff;
         if ( KDE_lstat( QFile::encodeName(d->m_url.path( KUrl::RemoveTrailingSlash )), &buff ) == 0) // get uid/gid of the link, if it's a link
         {
-#ifdef Q_OS_UNIX
             struct group *ge = getgrgid( buff.st_gid );
             if ( ge != 0 ) {
                 groupName = QString::fromLocal8Bit(ge->gr_name);
@@ -600,10 +622,10 @@ QString KFileItem::group() const
                     groupName.sprintf("%d",ge->gr_gid);
             }
             else
-#endif
                 groupName.sprintf("%d",buff.st_gid);
-            d->m_entry.insert( KIO::UDS_GROUP, groupName );
+            d->m_entry.insert( KIO::UDSEntry::UDS_GROUP, groupName );
         }
+#endif
     }
     return groupName;
 }
@@ -623,7 +645,7 @@ KMimeType::Ptr KFileItem::determineMimeType() const
 
         d->m_pMimeType = KMimeType::findByUrl( url, d->m_fileMode, isLocalUrl );
         Q_ASSERT(d->m_pMimeType);
-        //kDebug() << "finding mimetype for " << url.url() << " : " << d->m_pMimeType->name() << endl;
+        //kDebug() << "finding mimetype for " << url.url() << " : " << d->m_pMimeType->name();
         d->m_bMimeTypeKnown = true;
     }
 
@@ -645,74 +667,134 @@ QString KFileItem::mimeComment() const
     bool isLocalUrl;
     KUrl url = mostLocalUrl(isLocalUrl);
 
+    KMimeType::Ptr mime = mimeTypePtr();
+    if (isLocalUrl && mime->is("application/x-desktop")) {
+        KDesktopFile cfg( url.path() );
+        QString comment = cfg.desktopGroup().readEntry( "Comment" );
+        if (!comment.isEmpty())
+            return comment;
+    }
+
     QString comment = mType->comment( url );
-    //kDebug() << "finding comment for " << url.url() << " : " << d->m_pMimeType->name() << endl;
+    //kDebug() << "finding comment for " << url.url() << " : " << d->m_pMimeType->name();
     if (!comment.isEmpty())
         return comment;
     else
         return mType->name();
 }
 
+static QString iconFromDesktopFile(const QString& path)
+{
+    KDesktopFile cfg( path );
+    const KConfigGroup group = cfg.desktopGroup();
+    const QString icon = cfg.readIcon();
+    const QString type = cfg.readPath();
+
+    if ( type == "FSDevice" )
+    {
+        const QString unmount_icon = group.readEntry( "UnmountIcon" );
+        const QString dev = cfg.readDevice();
+        if ( !icon.isEmpty() && !unmount_icon.isEmpty() && !dev.isEmpty() )
+        {
+            KMountPoint::Ptr mountPoint = KMountPoint::currentMountPoints().findByDevice(dev);
+            if (!mountPoint) // not mounted?
+                return unmount_icon;
+        }
+    } else if ( type == "Link" ) {
+        const QString emptyIcon = group.readEntry( "EmptyIcon" );
+        if ( !emptyIcon.isEmpty() ) {
+            const QString u = group.readPathEntry( "URL" );
+            const KUrl url( u );
+            if ( url.protocol() == "trash" ) {
+                // We need to find if the trash is empty, preferrably without using a KIO job.
+                // So instead kio_trash leaves an entry in its config file for us.
+                KConfig trashConfig( "trashrc", KConfig::OnlyLocal );
+                if ( trashConfig.group("Status").readEntry( "Empty", true ) ) {
+                    return emptyIcon;
+                }
+            }
+        }
+    }
+    return icon;
+}
+
 QString KFileItem::iconName() const
 {
-    const QString iconName = d->m_entry.stringValue( KIO::UDS_ICON_NAME );
+    const QString iconName = d->m_entry.stringValue( KIO::UDSEntry::UDS_ICON_NAME );
     if (!iconName.isEmpty())
         return iconName;
 
     bool isLocalUrl;
     KUrl url = mostLocalUrl(isLocalUrl);
 
-    //kDebug() << "finding icon for " << url.url() << " : " << mimeTypePtr()->name() << endl;
-    return mimeTypePtr()->iconName(url);
+    KMimeType::Ptr mime = mimeTypePtr();
+    if (isLocalUrl && mime->is("application/x-desktop")) {
+        QString icon = iconFromDesktopFile(url.path());
+        if (!icon.isEmpty())
+            return icon;
+    }
+
+    //kDebug() << "finding icon for " << url.url() << " : " << mimeTypePtr()->name();
+    return mime->iconName(url);
 }
 
-int KFileItem::overlays() const
+QStringList KFileItem::overlays() const
 {
-    int _state = 0;
-    if ( d->m_bLink )
-        _state |= K3Icon::LinkOverlay;
+    QStringList names;
+    if ( d->m_bLink ) {
+        names.append("link");
+    }
 
     if ( !S_ISDIR( d->m_fileMode ) // Locked dirs have a special icon, use the overlay for files only
-         && !isReadable())
-        _state |= K3Icon::LockOverlay;
+         && !isReadable()) {
+        names.append("lock");
+    }
 
-    if ( isHidden() )
-        _state |= K3Icon::HiddenOverlay;
+    if ( isHidden() ) {
+        names.append("hidden");
+    }
 
     if( S_ISDIR( d->m_fileMode ) && d->m_bIsLocalUrl)
     {
         if (KSambaShare::instance()->isDirectoryShared( d->m_url.path() ) ||
             KNFSShare::instance()->isDirectoryShared( d->m_url.path() ))
         {
-            //kDebug()<<"KFileShare::isDirectoryShared : "<<d->m_url.path()<<endl;
-            _state |= K3Icon::ShareOverlay;
+            //kDebug()<<"KFileShare::isDirectoryShared : "<<d->m_url.path();
+            names.append("share");
         }
     }
 
-    if ( d->m_pMimeType && d->m_pMimeType->is("application/x-gzip") && d->m_url.fileName().endsWith( QLatin1String( ".gz" ) ) )
-        _state |= K3Icon::ZipOverlay;
-    return _state;
+    if ( d->m_pMimeType && d->m_pMimeType->is("application/x-gzip") && d->m_url.fileName().endsWith( QLatin1String( ".gz" ) ) ) {
+        names.append("zio");
+    }
+
+    return names;
 }
 
 QPixmap KFileItem::pixmap( int _size, int _state ) const
 {
-    const QString iconName = d->m_entry.stringValue( KIO::UDS_ICON_NAME );
+    const QString iconName = d->m_entry.stringValue( KIO::UDSEntry::UDS_ICON_NAME );
     if ( !iconName.isEmpty() )
         return DesktopIcon(iconName, _size, _state);
 
     if ( !d->m_pMimeType )
     {
-        static const QString & defaultFolderIcon =
-            KGlobal::staticQString(KMimeType::mimeType( "inode/directory" )->iconName());
-
-        if ( S_ISDIR( d->m_fileMode ) )
-            return DesktopIcon( defaultFolderIcon, _size, _state );
+        if ( S_ISDIR( d->m_fileMode ) ) {
+            static const QString * defaultFolderIcon = 0;
+            if ( !defaultFolderIcon ) {
+                const KMimeType::Ptr mimeType = KMimeType::mimeType( "inode/directory" );
+                if ( mimeType )
+                    defaultFolderIcon = &KGlobal::staticQString( mimeType->iconName() );
+               else
+                    kWarning(7000) << "No mimetype for inode/directory could be found. Check your installation.";
+            }
+            if ( defaultFolderIcon )
+                return DesktopIcon( *defaultFolderIcon, _size, _state );
 
+        }
         return DesktopIcon( "unknown", _size, _state );
     }
 
-    _state |= overlays();
-
     KMimeType::Ptr mime;
     // Use guessed mimetype if the main one hasn't been determined for sure
     if ( !d->m_bMimeTypeKnown && !d->m_guessedMimeType.isEmpty() )
@@ -726,7 +808,7 @@ QPixmap KFileItem::pixmap( int _size, int _state ) const
     {
         KUrl sf;
         sf.setPath( d->m_url.path().left( d->m_url.path().length() - 3 ) );
-        //kDebug() << "KFileItem::pixmap subFileName=" << subFileName << endl;
+        //kDebug() << "KFileItem::pixmap subFileName=" << subFileName;
         mime = KMimeType::findByUrl( sf, 0, d->m_bIsLocalUrl );
     }
 
@@ -734,9 +816,9 @@ QPixmap KFileItem::pixmap( int _size, int _state ) const
     KUrl url = mostLocalUrl(isLocalUrl);
 
     QPixmap p = KIconLoader::global()->loadMimeTypeIcon( mime->iconName( url ), K3Icon::Desktop, _size, _state );
-    //kDebug() << "finding pixmap for " << url.url() << " : " << mime->name() << endl;
+    //kDebug() << "finding pixmap for " << url.url() << " : " << mime->name();
     if (p.isNull())
-        kWarning() << "Pixmap not found for mimetype " << d->m_pMimeType->name() << endl;
+        kWarning() << "Pixmap not found for mimetype " << d->m_pMimeType->name();
 
     return p;
 }
@@ -798,7 +880,7 @@ bool KFileItem::isDir() const
 {
     if ( d->m_fileMode == KFileItem::Unknown )
     {
-        kDebug() << " KFileItem::isDir can't say -> false " << endl;
+        kDebug() << " KFileItem::isDir can't say -> false ";
         return false; // can't say for sure, so no
     }
     return (S_ISDIR(d->m_fileMode));
@@ -812,6 +894,11 @@ bool KFileItem::isDir() const
   } else return true;*/
 }
 
+bool KFileItem::isFile() const
+{
+    return !isDir();
+}
+
 bool KFileItem::acceptsDrops() const
 {
     // A directory ?
@@ -827,7 +914,7 @@ bool KFileItem::acceptsDrops() const
         return true;
 
     // Executable, shell script ... ?
-    if ( ::access( QFile::encodeName(d->m_url.path()), X_OK ) == 0 )
+    if ( QFileInfo(d->m_url.path()).isExecutable() )
         return true;
 
     return false;
@@ -836,35 +923,23 @@ bool KFileItem::acceptsDrops() const
 QString KFileItem::getStatusBarInfo() const
 {
     QString text = d->m_strText;
+    const QString comment = mimeComment();
 
     if ( d->m_bLink )
     {
-        QString comment = determineMimeType()->comment( d->m_url );
-        QString tmp;
+        text += ' ';
         if ( comment.isEmpty() )
-            tmp = i18n ( "Symbolic Link" );
+            text += i18n ( "(Symbolic Link to %1)", linkDest() );
         else
-            tmp = i18n("%1 (Link)", comment);
-        text += "->";
-        text += linkDest();
-        text += "  ";
-        text += tmp;
+            text += i18n("(%1, Link to %2)", comment, linkDest());
     }
     else if ( S_ISREG( d->m_fileMode ) )
     {
-        text += QString(" (%1)").arg( KIO::convertSize( size() ) );
-        text += "  ";
-        text += mimeComment();
-    }
-    else if ( S_ISDIR ( d->m_fileMode ) )
-    {
-        text += "/  ";
-        text += mimeComment();
+        text += QString(" (%1, %2)").arg( comment, KIO::convertSize( size() ) );
     }
     else
     {
-        text += "  ";
-        text += mimeComment();
+        text += QString(" (%1)").arg( comment );
     }
     return text;
 }
@@ -899,7 +974,7 @@ QString KFileItem::getToolTipText(int maxcount) const
                end;
 
     tip += start + i18n("Modified:") + mid +
-           timeString( KIO::UDS_MODIFICATION_TIME) + end
+           timeString( KFileItem::ModificationTime ) + end
 #ifndef Q_WS_WIN //TODO: show win32-specific permissions
            +start + i18n("Owner:") + mid + user() + " - " + group() + end +
            start + i18n("Permissions:") + mid +
@@ -907,7 +982,7 @@ QString KFileItem::getToolTipText(int maxcount) const
 #endif
            ;
 
-    if (info.isValid() && !info.isEmpty() )
+    if (info.isValid())
     {
         tip += "<tr><td colspan=2><center><s>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</s></center></td></tr>";
         QStringList keys = info.preferredKeys();
@@ -919,8 +994,8 @@ QString KFileItem::getToolTipText(int maxcount) const
             KFileMetaInfoItem item = info.item( *it );
             if ( item.isValid() )
             {
-                QString s = item.string();
-                if ( ( item.attributes() & KFileMimeTypeInfo::SqueezeText )
+                QString s = item.value().toString();
+                if ( ( item.properties().attributes() & PredicateProperties::SqueezeText )
                      && s.length() > 50) {
                     s.truncate(47);
                     s.append("...");
@@ -929,7 +1004,7 @@ QString KFileItem::getToolTipText(int maxcount) const
                 {
                     count++;
                     tip += start +
-                           Qt::escape( item.translatedKey() ) + ':' +
+                           Qt::escape( item.name() ) + ':' +
                            mid +
                            Qt::escape( s ) +
                            end;
@@ -941,7 +1016,7 @@ QString KFileItem::getToolTipText(int maxcount) const
     tip += "</table>";
 
     //kDebug() << "making this the tool tip rich text:\n";
-    //kDebug() << tip << endl;
+    //kDebug() << tip;
 
     return tip;
 }
@@ -956,6 +1031,17 @@ bool KFileItem::cmp( const KFileItem & item ) const
     return d->cmp(*item.d);
 }
 
+bool KFileItem::operator==(const KFileItem& other) const
+{
+    // is this enough?
+    return d == other.d;
+}
+
+bool KFileItem::operator!=(const KFileItem& other) const
+{
+    return d != other.d;
+}
+
 void KFileItem::setUDSEntry( const KIO::UDSEntry& _entry, const KUrl& _url,
                              bool _delayedMimeTypes, bool _urlIsDirectory )
 {
@@ -980,6 +1066,11 @@ void KFileItem::setUDSEntry( const KIO::UDSEntry& _entry, const KUrl& _url,
     d->init();
 }
 
+KFileItem::operator QVariant() const
+{
+    return qVariantFromValue(*this);
+}
+
 void KFileItem::setExtraData( const void *key, void *value )
 {
     if ( !key )
@@ -993,11 +1084,6 @@ const void * KFileItem::extraData( const void *key ) const
     return d->m_extra.value( key, 0 );
 }
 
-void * KFileItem::extraData( const void *key )
-{
-    return d->m_extra.value( key, 0 );
-}
-
 void KFileItem::removeExtraData( const void *key )
 {
     d->m_extra.remove( key );
@@ -1012,32 +1098,46 @@ QString KFileItem::permissionsString() const
 }
 
 // check if we need to cache this
-QString KFileItem::timeString( unsigned int which ) const
+QString KFileItem::timeString( FileTimes which ) const
 {
-    QDateTime t;
-    t.setTime_t( time(which) );
-    return KGlobal::locale()->formatDateTime( t );
+    return KGlobal::locale()->formatDateTime( d->time(which) );
 }
 
-void KFileItem::setMetaInfo( const KFileMetaInfo & info )
+QString KFileItem::timeString( unsigned int which ) const
+{
+    switch (which) {
+    case KIO::UDSEntry::UDS_ACCESS_TIME:
+        return timeString(AccessTime);
+    case KIO::UDSEntry::UDS_CREATION_TIME:
+        return timeString(CreationTime);
+    case KIO::UDSEntry::UDS_MODIFICATION_TIME:
+    default:
+        return timeString(ModificationTime);
+    }
+}
+
+void KFileItem::setMetaInfo( const KFileMetaInfo & info ) const
 {
     d->m_metaInfo = info;
 }
 
-const KFileMetaInfo & KFileItem::metaInfo(bool autoget, int) const
+KFileMetaInfo KFileItem::metaInfo(bool autoget, int) const
 {
-    bool isLocalUrl;
-    KUrl url = mostLocalUrl(isLocalUrl);
-
-    if ( autoget && !d->m_metaInfo.isValid() &&
-         KGlobalSettings::showFilePreview(url) )
+    if (autoget && !d->m_metaInfo.isValid())
     {
-        d->m_metaInfo = KFileMetaInfo( url, mimetype() );
+        bool isLocalUrl;
+        KUrl url(mostLocalUrl(isLocalUrl));
+        if (KGlobalSettings::showFilePreview(url))
+            d->m_metaInfo = KFileMetaInfo(url);//, mimetype() );
     }
-
     return d->m_metaInfo;
 }
 
+void KFileItem::assign( const KFileItem & item )
+{
+    *this = item;
+}
+
 KUrl KFileItem::mostLocalUrl(bool &local) const
 {
     QString local_path = localPath();
@@ -1056,9 +1156,6 @@ KUrl KFileItem::mostLocalUrl(bool &local) const
     }
 }
 
-void KFileItem::virtual_hook( int, void* )
-{ /*BASE::virtual_hook( id, data );*/ }
-
 QDataStream & operator<< ( QDataStream & s, const KFileItem & a )
 {
     // We don't need to save/restore anything that refresh() invalidates,
@@ -1080,7 +1177,7 @@ QDataStream & operator>> ( QDataStream & s, KFileItem & a )
     return s;
 }
 
-const KUrl & KFileItem::url() const
+KUrl KFileItem::url() const
 {
     return d->m_url;
 }
@@ -1105,12 +1202,12 @@ bool KFileItem::isLocalFile() const
     return d->m_bIsLocalUrl;
 }
 
-const QString& KFileItem::text() const
+QString KFileItem::text() const
 {
     return d->m_strText;
 }
 
-const QString& KFileItem::name( bool lowerCase ) const
+QString KFileItem::name( bool lowerCase ) const
 {
     if ( !lowerCase )
         return d->m_strName;
@@ -1137,22 +1234,24 @@ KMimeType::Ptr KFileItem::mimeTypePtr() const
     if (!d->m_pMimeType) {
         // On-demand fast (but not always accurate) mimetype determination
         Q_ASSERT(!d->m_url.isEmpty());
-        bool accurate = false;
         bool isLocalUrl;
         KUrl url = mostLocalUrl(isLocalUrl);
-
+        int accuracy;
         d->m_pMimeType = KMimeType::findByUrl( url, d->m_fileMode, isLocalUrl,
-                                               // use fast mode if not mimetype on demand
-                                               d->m_delayedMimeTypes, &accurate );
-        //kDebug() << "finding mimetype for " << url.url() << " : " << m_pMimeType->name() << endl;
+                                               // use fast mode if delayed mimetype determination can refine it later
+                                               d->m_delayedMimeTypes, &accuracy );
+        // Technically we could refine all files, given the >80 magic rules...
+        // But do we really need to?
+        const bool canDoBetter = d->m_delayedMimeTypes && accuracy < 80;
+        //kDebug() << "finding mimetype for " << url.url() << " : " << m_pMimeType->name();
         // if we didn't use fast mode, or if we got a result, then this is the mimetype
         // otherwise, determineMimeType will be able to do better.
-        d->m_bMimeTypeKnown = (!d->m_delayedMimeTypes) || accurate;
+        d->m_bMimeTypeKnown = !canDoBetter;
     }
     return d->m_pMimeType;
 }
 
-const KIO::UDSEntry & KFileItem::entry() const
+KIO::UDSEntry KFileItem::entry() const
 {
     return d->m_entry;
 }
@@ -1182,3 +1281,38 @@ bool KFileItem::isNull() const
 {
     return d == 0;
 }
+
+
+KFileItem* KFileItemList::findByName( const QString& fileName ) const
+{
+    const_iterator it = begin();
+    const const_iterator itend = end();
+    for ( ; it != itend ; ++it ) {
+        if ( (*it)->name() == fileName ) {
+            return *it;
+        }
+    }
+    return 0;
+}
+
+KFileItem* KFileItemList::findByUrl( const KUrl& url ) const {
+    const_iterator it = begin();
+    const const_iterator itend = end();
+    for ( ; it != itend ; ++it ) {
+        if ( (*it)->url() == url ) {
+            return *it;
+        }
+    }
+    return 0;
+}
+
+KUrl::List KFileItemList::urlList() const {
+    KUrl::List lst;
+    const_iterator it = begin();
+    const const_iterator itend = end();
+    for ( ; it != itend ; ++it ) {
+        lst.append( (*it)->url() );
+    }
+    return lst;
+}
+
