@@ -17,19 +17,20 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef __kfileitem_h__
-#define __kfileitem_h__
+#ifndef KFILEITEM_H
+#define KFILEITEM_H
 
-#include <qlist.h>
 #include <sys/stat.h>
 
 #include <kio/global.h>
+#include <kio/udsentry.h>
 #include <kurl.h>
 
 #include <kacl.h>
 #include <kmimetype.h>
 #include <kfilemetainfo.h>
-#include <qlist.h>
+#include <kdatetime.h>
+#include <QtCore/QList>
 
 class KFileItemPrivate;
 
@@ -46,8 +47,24 @@ class KIO_EXPORT KFileItem
 public:
     enum { Unknown = (mode_t) - 1 };
 
+    /**
+     * The timestamps associated with a file.
+     * - ModificationTime: the time the file's contents were last modified
+     * - AccessTime: the time the file was last accessed (last read or written to)
+     * - CreationTime: the time the file was created
+     */
+    enum FileTimes {
+        // warning: don't change without looking at the Private class
+        ModificationTime = 0,
+        AccessTime = 1,
+        CreationTime = 2
+        //ChangeTime
+    };
+
     /**
      * Null KFileItem. Doesn't represent any file, only exists for convenience.
+     *
+     * NOTE KDE 4.0 KFileItem* => KFileItem& conversion: '(KFileItem*)a==0'  maps to '(KFileItem)a==KFileItem()'
      */
     KFileItem();
 
@@ -104,7 +121,7 @@ public:
      * Destructs the KFileItem. Extra data set via setExtraData()
      * is not deleted.
      */
-    virtual ~KFileItem();
+    ~KFileItem();
 
     /**
      * Throw away and re-read (for local files) all information about the file.
@@ -122,7 +139,7 @@ public:
      * Returns the url of the file.
      * @return the url of the file
      */
-    const KUrl & url() const;
+    KUrl url() const;
 
     /**
      * Sets the item's URL. Do not call unless you know what you are doing!
@@ -204,7 +221,7 @@ public:
      * Returns true if this item represents a file (and not a a directory)
      * @return true if the item is a file
      */
-    bool isFile() const { return !isDir(); }
+    bool isFile() const;
 
     /**
      * Checks whether the file or directory is readable. In some cases
@@ -249,20 +266,22 @@ public:
 
     /**
      * Requests the modification, access or creation time, depending on @p which.
-     * @param which UDS_MODIFICATION_TIME, UDS_ACCESS_TIME or even UDS_CREATION_TIME
+     * @param which the timestamp
      * @return the time asked for, (time_t)0 if not available
      * @see timeString()
      */
-    time_t time( unsigned int which ) const;
+    KDateTime time( FileTimes which ) const;
+    KDE_DEPRECATED time_t time( unsigned int which ) const;
 
     /**
      * Requests the modification, access or creation time as a string, depending
      * on @p which.
-     * @param which UDS_MODIFICATION_TIME, UDS_ACCESS_TIME or even UDS_CREATION_TIME
+     * @param which the timestamp
      * @returns a formatted string of the requested time.
      * @see time
      */
-    QString timeString( unsigned int which = KIO::UDS_MODIFICATION_TIME ) const;
+    QString timeString( FileTimes which = ModificationTime ) const;
+    KDE_DEPRECATED QString timeString( unsigned int which) const;
 
     /**
      * Returns true if the file is a local file.
@@ -275,7 +294,7 @@ public:
      * It's not exactly the filename since some decoding happens ('%2F'->'/').
      * @return the text of the file item
      */
-    const QString& text() const;
+    QString text() const;
 
     /**
      * Return the name of the file item (without a path).
@@ -284,7 +303,7 @@ public:
      * which is useful to speed up sorting by name, case insensitively.
      * @return the file's name
      */
-    const QString& name( bool lowerCase = false ) const;
+    QString name( bool lowerCase = false ) const;
 
     /**
      * Returns the mimetype of the file item.
@@ -347,7 +366,7 @@ public:
      * a file can be modified.
      * @return the overlays of the pixmap
      */
-    int overlays() const;
+    QStringList overlays() const;
 
     /**
      * Returns the string to be displayed in the statusbar,
@@ -389,7 +408,7 @@ public:
      * by position.
      * @return the UDS entry
      */
-    const KIO::UDSEntry & entry() const;
+    KIO::UDSEntry entry() const;
 
     /**
      * Used when updating a directory. marked == seen when refreshing.
@@ -417,13 +436,16 @@ public:
      */
     bool cmp( const KFileItem & item ) const;
 
-    bool operator==(const KFileItem& other) const {
-        // is this enough?
-        return d == other.d;
-    }
-    bool operator!=(const KFileItem& other) const {
-        return d != other.d;
-    }
+    bool operator==(const KFileItem& other) const;
+
+    bool operator!=(const KFileItem& other) const;
+
+
+    /**
+     * Converts this KFileItem to a QVariant, this allows to use KFileItem
+     * in QVariant() constructor
+     */
+    operator QVariant() const;
 
     /**
      * This allows to associate some "extra" data to a KFileItem. As one
@@ -460,7 +482,7 @@ public:
      *
      * @deprecated use model/view (KDirModel) and you won't need this anymore
      */
-    virtual KDE_DEPRECATED void setExtraData( const void *key, void *value );
+    KDE_DEPRECATED void setExtraData( const void *key, void *value );
 
     /**
      * Retrieves the extra data with the given @p key.
@@ -471,18 +493,7 @@ public:
      *
      * @deprecated use model/view (KDirModel) and you won't need this anymore
      */
-    virtual KDE_DEPRECATED const void * extraData( const void *key ) const;
-
-    /**
-     * Retrieves the extra data with the given @p key.
-     * @param key the key of the extra data
-     * @return the extra data associated to an item with @p key via
-     * setExtraData. 0L if nothing was associated with @p key.
-     * @see extraData
-     *
-     * @deprecated use model/view (KDirModel) and you won't need this anymore
-     */
-    virtual KDE_DEPRECATED void * extraData( const void *key );
+    KDE_DEPRECATED const void * extraData( const void *key ) const;
 
     /**
      * Removes the extra data associated with an item via @p key.
@@ -490,28 +501,28 @@ public:
      *
      * @deprecated use model/view (KDirModel) and you won't need this anymore
      */
-    virtual KDE_DEPRECATED void removeExtraData( const void *key );
+    KDE_DEPRECATED void removeExtraData( const void *key );
 
     /**
      * Sets the metainfo of this item to @p info.
+     *
+     * Made const to avoid deep copy.
      * @param info the new meta info
      */
-    void setMetaInfo( const KFileMetaInfo & info );
+    void setMetaInfo( const KFileMetaInfo & info ) const;
 
     /**
      * Returns the metainfo of this item.
      * @param autoget if true, the metainfo will automatically be created
      * @param what ignored
      */
-    const KFileMetaInfo & metaInfo(bool autoget = true,
+    KFileMetaInfo metaInfo(bool autoget = true,
                                    int what = KFileMetaInfo::Fastest) const;
 
     /**
      * @deprecated simply use '='
      */
-    KDE_DEPRECATED void assign( const KFileItem & item ) {
-        *this = item;
-    }
+    KDE_DEPRECATED void assign( const KFileItem & item );
 
     /**
      * Reinitialize KFileItem with a new UDSEntry.
@@ -550,14 +561,13 @@ public:
 private:
     QSharedDataPointer<KFileItemPrivate> d;
 
-protected:
-    virtual void virtual_hook( int id, void* data );
-
 private:
     KIO_EXPORT friend QDataStream & operator<< ( QDataStream & s, const KFileItem & a );
     KIO_EXPORT friend QDataStream & operator>> ( QDataStream & s, KFileItem & a );
 };
 
+Q_DECLARE_METATYPE(KFileItem)
+
 /**
  * List of KFileItems
  * This class adds a few helper methods to QList<KFileItem *>
@@ -567,37 +577,14 @@ class KIO_EXPORT KFileItemList : public QList<KFileItem *> // TODO QList<KFileIt
 public:
   /// Find a KFileItem by name and return it.
   /// @return the item with the given name, or 0 if none was found
-  KFileItem* findByName( const QString& fileName ) const {
-    const_iterator it = begin();
-    const const_iterator itend = end();
-    for ( ; it != itend ; ++it ) {
-      if ( (*it)->name() == fileName )
-        return *it;
-    }
-    return 0;
-  }
+  KFileItem* findByName( const QString& fileName ) const;
 
   /// Find a KFileItem by URL and return it.
   /// @return the item with the given URL, or 0 if none was found
-  KFileItem* findByUrl( const KUrl& url ) const {
-    const_iterator it = begin();
-    const const_iterator itend = end();
-    for ( ; it != itend ; ++it ) {
-      if ( (*it)->url() == url )
-        return *it;
-    }
-    return 0;
-  }
+  KFileItem* findByUrl( const KUrl& url ) const;
 
   /// @return the list of URLs that those items represent
-  KUrl::List urlList() const {
-    KUrl::List lst;
-    const_iterator it = begin();
-    const const_iterator itend = end();
-    for ( ; it != itend ; ++it )
-      lst.append( (*it)->url() );
-    return lst;
-  }
+  KUrl::List urlList() const;
 };
 
 KIO_EXPORT QDataStream & operator<< ( QDataStream & s, const KFileItem & a );
