@@ -19,34 +19,44 @@
 
 #include "kfileshare.h"
 #include "kfileshare_p.h"
-#include <qdir.h>
-#include <qfile.h>
-#include <qprocess.h>
+#include <QtCore/QDir>
+#include <QtCore/QFile>
+#include <QtCore/Q_PID>
 #include <klocale.h>
-#include <kstaticdeleter.h>
 #include <kstandarddirs.h>
 #include <kdebug.h>
 #include <kdirwatch.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <errno.h>
-#include <ksimpleconfig.h>
+#include <kconfig.h>
 #include <kuser.h>
 
-KFileShare::Authorization KFileShare::s_authorization = NotInitialized;
-QStringList* KFileShare::s_shareList = 0L;
-static KStaticDeleter<QStringList> sdShareList;
-
-KFileShare::ShareMode KFileShare::s_shareMode;
-bool KFileShare::s_sambaEnabled;
-bool KFileShare::s_nfsEnabled;
-bool KFileShare::s_restricted;
-QString KFileShare::s_fileShareGroup;
-bool KFileShare::s_sharingEnabled;
-
+static KFileShare::Authorization s_authorization = KFileShare::NotInitialized;
+K_GLOBAL_STATIC(QStringList, s_shareList)
+static KFileShare::ShareMode s_shareMode;
+static bool s_sambaEnabled;
+static bool s_nfsEnabled;
+static bool s_restricted;
+static QString s_fileShareGroup;
+static bool s_sharingEnabled;
 
 #define FILESHARECONF "/etc/security/fileshare.conf"
 
+static QString findExe( const char* exeName )
+{
+   // Normally fileshareset and filesharelist are installed in kde4/libexec;
+   // allow distributions to move it somewhere else in the PATH or in /usr/sbin.
+   QString path = QString::fromLocal8Bit(getenv("PATH"));
+#ifndef Q_WS_WIN
+   path += QLatin1String(":/usr/sbin");
+#endif
+   QString exe = KStandardDirs::findExe( exeName, path );
+   if (exe.isEmpty())
+       kError() << exeName << " not found in " << path << endl;
+   return exe;
+}
+
 KFileSharePrivate::KFileSharePrivate()
 {
   KDirWatch::self()->addFile(FILESHARECONF);
@@ -63,14 +73,9 @@ KFileSharePrivate::~KFileSharePrivate()
   KDirWatch::self()->removeFile(FILESHARECONF);
 }
 
-KFileSharePrivate *KFileSharePrivate::_self=0L;
-
-static KStaticDeleter<KFileSharePrivate> kstFileShare;
-
 KFileSharePrivate* KFileSharePrivate::self()
 {
-   if (!_self)
-      _self = kstFileShare.setObject(_self, new KFileSharePrivate());
+   K_GLOBAL_STATIC(KFileSharePrivate, _self)
    return _self;
 }
 
@@ -86,11 +91,12 @@ void KFileShare::readConfig() // static
 {
     // Create KFileSharePrivate instance
     KFileSharePrivate::self();
-    KSimpleConfig config(QLatin1String(FILESHARECONF),true);
+    KConfig config(QLatin1String(FILESHARECONF));
+    KConfigGroup group( &config, QString() );
 
-    s_sharingEnabled = config.readEntry("FILESHARING", "yes") == "yes";
-    s_restricted = config.readEntry("RESTRICT", "yes") == "yes";
-    s_fileShareGroup = config.readEntry("FILESHAREGROUP", "fileshare");
+    s_sharingEnabled = group.readEntry("FILESHARING", "yes") == "yes";
+    s_restricted = group.readEntry("RESTRICT", "yes") == "yes";
+    s_fileShareGroup = group.readEntry("FILESHAREGROUP", "fileshare");
 
 
     if (!s_sharingEnabled)
@@ -107,14 +113,14 @@ void KFileShare::readConfig() // static
             s_authorization = UserNotAllowed;
     }
 
-    if (config.readEntry("SHARINGMODE", "simple") == "simple")
+    if (group.readEntry("SHARINGMODE", "simple") == "simple")
         s_shareMode = Simple;
     else
         s_shareMode = Advanced;
 
 
-    s_sambaEnabled = config.readEntry("SAMBA", "yes") == "yes";
-    s_nfsEnabled = config.readEntry("NFS", "yes") == "yes";
+    s_sambaEnabled = group.readEntry("SAMBA", "yes") == "yes";
+    s_nfsEnabled = group.readEntry("NFS", "yes") == "yes";
 }
 
 KFileShare::ShareMode KFileShare::shareMode() {
@@ -164,13 +170,9 @@ bool KFileShare::nfsEnabled() {
 void KFileShare::readShareList()
 {
     KFileSharePrivate::self();
-    if ( !s_shareList )
-        sdShareList.setObject( s_shareList, new QStringList );
-    else
-        s_shareList->clear();
+    s_shareList->clear();
 
-    // /usr/sbin on Mandrake, $PATH allows flexibility for other distributions
-    QString exe = findExe( "filesharelist" );
+    QString exe = ::findExe( "filesharelist" );
     if (exe.isEmpty()) {
         s_authorization = ErrorNotFound;
         return;
@@ -192,7 +194,7 @@ void KFileShare::readShareList()
             if ( line[length-1] != '/' )
                 line += '/';
             s_shareList->append(line);
-            kDebug(7000) << "Shared dir:" << line << endl;
+            kDebug(7000) << "Shared dir:" << line;
         }
     }
 }
@@ -206,7 +208,7 @@ bool KFileShare::isDirectoryShared( const QString& _path )
     QString path( _path );
     if ( path[path.length()-1] != '/' )
         path += '/';
-    return s_shareList && s_shareList->contains( path );
+    return s_shareList->contains( path );
 }
 
 KFileShare::Authorization KFileShare::authorization()
@@ -217,27 +219,14 @@ KFileShare::Authorization KFileShare::authorization()
     return s_authorization;
 }
 
-QString KFileShare::findExe( const char* exeName )
-{
-   // /usr/sbin on Mandrake, $PATH allows flexibility for other distributions
-   QString path = QString::fromLocal8Bit(getenv("PATH"));
-#ifndef Q_WS_WIN
-   path += QLatin1String(":/usr/sbin");
-#endif
-   QString exe = KStandardDirs::findExe( exeName, path );
-   if (exe.isEmpty())
-       kError() << exeName << " not found in " << path << endl;
-   return exe;
-}
-
 bool KFileShare::setShared( const QString& path, bool shared )
 {
     if (! KFileShare::sharingEnabled() ||
           KFileShare::shareMode() == Advanced)
        return false;
 
-    kDebug(7000) << "KFileShare::setShared " << path << "," << shared << endl;
-    QString exe = KFileShare::findExe( "fileshareset" );
+    kDebug(7000) << "KFileShare::setShared " << path << "," << shared;
+    QString exe = ::findExe( "fileshareset" );
     if (exe.isEmpty())
         return false;
 
@@ -247,7 +236,7 @@ bool KFileShare::setShared( const QString& path, bool shared )
     else
         args << "--remove";
     int ec = QProcess::execute( exe, args ); // should be ok, the perl script terminates fast
-    kDebug(7000) << "KFileSharePropsPlugin::setShared exitCode=" << ec << endl;
+    kDebug(7000) << "KFileSharePropsPlugin::setShared exitCode=" << ec;
     bool ok = !ec;
     switch (ec) {
         case 1:
@@ -285,6 +274,6 @@ bool KFileShare::setShared( const QString& path, bool shared )
     return ok;
 }
 
-#include "kfileshare.moc"
+//#include "kfileshare.moc"
 #include "kfileshare_p.moc"
 
