@@ -22,7 +22,7 @@
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kmimetype.h>
-#include <kprocess.h>
+#include <kshell.h>
 #include <krun.h>
 #include <ksycoca.h>
 
@@ -199,8 +199,8 @@ void KMimeTypeChooser::editMimeType()
 #ifndef Q_OS_WIN
                       + " --parent " + QString::number( (ulong)topLevelWidget()->winId())
 #endif
-                      + ' ' + KProcess::quote(mt),
-                      keditfiletype, keditfiletype /*unused*/);
+                      + ' ' + KShell::quoteArg(mt),
+                      keditfiletype, keditfiletype /*unused*/, topLevelWidget());
 }
 
 void KMimeTypeChooser::slotCurrentChanged(QTreeWidgetItem* i)
@@ -299,6 +299,11 @@ KMimeTypeChooserDialog::KMimeTypeChooserDialog(
   setMainWidget(m_chooser);
 }
 
+KMimeTypeChooser* KMimeTypeChooserDialog::chooser()
+{
+    return m_chooser;
+}
+
 void KMimeTypeChooserDialog::init()
 {
   setButtons( Cancel | Ok );
