@@ -19,6 +19,7 @@
 #ifndef KMIMETYPE_CHOOSER_H
 #define KMIMETYPE_CHOOSER_H
 
+#include <kio/kio_export.h>
 #include <kdialog.h>
 #include <kvbox.h>
 
@@ -59,6 +60,7 @@ class KIO_EXPORT KMimeTypeChooser : public KVBox
      *        groups are shown.
      * @param parent The parent widget to use
      */
+    explicit
     KMimeTypeChooser( const QString& text=QString(),
                       const QStringList &selectedMimeTypes=QStringList(),
                       const QString &defaultGroup=QString(),
@@ -148,6 +150,7 @@ class KIO_EXPORT KMimeTypeChooserDialog : public KDialog
      *        groups are shown.
      * @param parent The parent widget to use
      */
+    explicit
     KMimeTypeChooserDialog( const QString &caption=QString(),
                          const QString& text=QString(),
                          const QStringList &selectedMimeTypes=QStringList(),
@@ -170,7 +173,7 @@ class KIO_EXPORT KMimeTypeChooserDialog : public KDialog
     /**
      * @return a pointer to the KMimeTypeChooser widget
      */
-    KMimeTypeChooser* chooser() { return m_chooser; }
+    KMimeTypeChooser* chooser();
 
   private:
     void init();
