@@ -21,10 +21,9 @@
 #ifndef KMIMETYPERESOLVER_H
 #define KMIMETYPERESOLVER_H
 
-#include <QObject>
-#include <kdelibs_export.h>
+#include <QtCore/QObject>
+#include <kio/kio_export.h>
 class QModelIndex;
-class KFileItemList;
 class QAbstractItemView;
 class KDirModel;
 class KMimeTypeResolverPrivate;
