@@ -18,24 +18,27 @@
    Boston, MA 02110-1301, USA.
 */
 
+#include "kprotocolmanager.h"
+
 #include <string.h>
 #include <sys/utsname.h>
+#include <QtCore/QCoreApplication>
 #include <QtDBus/QtDBus>
 
+#include <kdeversion.h>
 #include <kdebug.h>
 #include <kglobal.h>
 #include <klocale.h>
-#include <kconfig.h>
+#include <kconfiggroup.h>
+#include <ksharedconfig.h>
 #include <kstandarddirs.h>
 #include <klibloader.h>
 #include <kstringhandler.h>
-#include <kstaticdeleter.h>
 #include <kurl.h>
 #include <kio/slaveconfig.h>
 #include <kio/ioslave_defaults.h>
 #include <kio/http_slave_defaults.h>
 
-#include "kprotocolmanager.h"
 #include <kprotocolinfofactory.h>
 
 class
@@ -46,9 +49,8 @@ public:
 
    ~KProtocolManagerPrivate();
 
-   KConfig *config;
-   KConfig *http_config;
-   bool init_busy;
+   KSharedConfig::Ptr config;
+   KSharedConfig::Ptr http_config;
    KUrl url;
    QString protocol;
    QString proxy;
@@ -56,19 +58,17 @@ public:
    QString useragent;
 };
 
-static KProtocolManagerPrivate* d = 0;
-static KStaticDeleter<KProtocolManagerPrivate> kpmpksd;
+K_GLOBAL_STATIC(KProtocolManagerPrivate, kProtocolManagerPrivate)
 
 KProtocolManagerPrivate::KProtocolManagerPrivate()
-                        :config(0), http_config(0), init_busy(false)
 {
-   kpmpksd.setObject(d, this);
+    // post routine since KConfig::sync() breaks if called too late
+    qAddPostRoutine(kProtocolManagerPrivate.destroy);
 }
 
 KProtocolManagerPrivate::~KProtocolManagerPrivate()
 {
-   delete config;
-   delete http_config;
+    qRemovePostRoutine(kProtocolManagerPrivate.destroy);
 }
 
 
@@ -77,69 +77,74 @@ KProtocolManagerPrivate::~KProtocolManagerPrivate()
 QString("Mozilla/5.0 (compatible; Konqueror/%1.%2%3) KHTML/%4.%5.%6 (like Gecko)") \
         .arg(KDE_VERSION_MAJOR).arg(KDE_VERSION_MINOR).arg(X).arg(KDE_VERSION_MAJOR).arg(KDE_VERSION_MINOR).arg(KDE_VERSION_RELEASE)
 
+#define PRIVATE_DATA \
+KProtocolManagerPrivate *d = kProtocolManagerPrivate
+
 void KProtocolManager::reparseConfiguration()
 {
-  kpmpksd.destructObject();
+    PRIVATE_DATA;
+    if (d->http_config) {
+        d->http_config->reparseConfiguration();
+    }
+    if (d->config) {
+        d->config->reparseConfiguration();
+    }
+    d->protocol = QString();
+    d->proxy = QString();
+    d->modifiers = QString();
+    d->useragent = QString();
+    d->url.clear();
 
   // Force the slave config to re-read its config...
   KIO::SlaveConfig::self()->reset ();
 }
 
-KConfig *KProtocolManager::config()
+KSharedConfig::Ptr KProtocolManager::config()
 {
-  if (!d)
-     d = new KProtocolManagerPrivate;
-
+    PRIVATE_DATA;
   if (!d->config)
   {
-     d->config = new KConfig("kioslaverc", true, false);
+     d->config = KSharedConfig::openConfig("kioslaverc", KConfig::NoGlobals);
   }
   return d->config;
 }
 
-KConfig *KProtocolManager::http_config()
+static KConfigGroup http_config()
 {
-  if (!d)
-     d = new KProtocolManagerPrivate;
-
-  if (!d->http_config)
-  {
-     d->http_config = new KConfig("kio_httprc", false, false);
+    PRIVATE_DATA;
+  if (!d->http_config) {
+     d->http_config = KSharedConfig::openConfig("kio_httprc", KConfig::NoGlobals);
   }
-  return d->http_config;
+  return KConfigGroup(d->http_config, QString());
 }
 
 /*=============================== TIMEOUT SETTINGS ==========================*/
 
 int KProtocolManager::readTimeout()
 {
-  KConfig *cfg = config();
-  cfg->setGroup( QString() );
-  int val = cfg->readEntry( "ReadTimeout", DEFAULT_READ_TIMEOUT );
+  KConfigGroup cg( config(), QString() );
+  int val = cg.readEntry( "ReadTimeout", DEFAULT_READ_TIMEOUT );
   return qMax(MIN_TIMEOUT_VALUE, val);
 }
 
 int KProtocolManager::connectTimeout()
 {
-  KConfig *cfg = config();
-  cfg->setGroup( QString() );
-  int val = cfg->readEntry( "ConnectTimeout", DEFAULT_CONNECT_TIMEOUT );
+  KConfigGroup cg( config(), QString() );
+  int val = cg.readEntry( "ConnectTimeout", DEFAULT_CONNECT_TIMEOUT );
   return qMax(MIN_TIMEOUT_VALUE, val);
 }
 
 int KProtocolManager::proxyConnectTimeout()
 {
-  KConfig *cfg = config();
-  cfg->setGroup( QString() );
-  int val = cfg->readEntry( "ProxyConnectTimeout", DEFAULT_PROXY_CONNECT_TIMEOUT );
+  KConfigGroup cg( config(), QString() );
+  int val = cg.readEntry( "ProxyConnectTimeout", DEFAULT_PROXY_CONNECT_TIMEOUT );
   return qMax(MIN_TIMEOUT_VALUE, val);
 }
 
 int KProtocolManager::responseTimeout()
 {
-  KConfig *cfg = config();
-  cfg->setGroup( QString() );
-  int val = cfg->readEntry( "ResponseTimeout", DEFAULT_RESPONSE_TIMEOUT );
+  KConfigGroup cg( config(), QString() );
+  int val = cg.readEntry( "ResponseTimeout", DEFAULT_RESPONSE_TIMEOUT );
   return qMax(MIN_TIMEOUT_VALUE, val);
 }
 
@@ -152,37 +157,32 @@ bool KProtocolManager::useProxy()
 
 bool KProtocolManager::useReverseProxy()
 {
-  KConfig *cfg = config();
-  cfg->setGroup( "Proxy Settings" );
-  return cfg->readEntry("ReversedException", false);
+  KConfigGroup cg(config(), "Proxy Settings" );
+  return cg.readEntry("ReversedException", false);
 }
 
 KProtocolManager::ProxyType KProtocolManager::proxyType()
 {
-  KConfig *cfg = config();
-  cfg->setGroup( "Proxy Settings" );
-  return static_cast<ProxyType>(cfg->readEntry( "ProxyType" , 0));
+  KConfigGroup cg(config(), "Proxy Settings" );
+  return static_cast<ProxyType>(cg.readEntry( "ProxyType" , 0));
 }
 
 KProtocolManager::ProxyAuthMode KProtocolManager::proxyAuthMode()
 {
-  KConfig *cfg = config();
-  cfg->setGroup( "Proxy Settings" );
-  return static_cast<ProxyAuthMode>(cfg->readEntry( "AuthMode" , 0));
+  KConfigGroup cg(config(), "Proxy Settings" );
+  return static_cast<ProxyAuthMode>(cg.readEntry( "AuthMode" , 0));
 }
 
 /*========================== CACHING =====================================*/
 
 bool KProtocolManager::useCache()
 {
-  KConfig *cfg = http_config();
-  return cfg->readEntry( "UseCache", true );
+  return http_config().readEntry( "UseCache", true );
 }
 
 KIO::CacheControl KProtocolManager::cacheControl()
 {
-  KConfig *cfg = http_config();
-  QString tmp = cfg->readEntry("cache");
+  QString tmp = http_config().readEntry("cache");
   if (tmp.isEmpty())
     return DEFAULT_CACHE_CONTROL;
   return KIO::parseCacheControl(tmp);
@@ -190,30 +190,24 @@ KIO::CacheControl KProtocolManager::cacheControl()
 
 QString KProtocolManager::cacheDir()
 {
-  KConfig *cfg = http_config();
-  return cfg->readPathEntry("CacheDir", KGlobal::dirs()->saveLocation("cache","http"));
+  return http_config().readPathEntry("CacheDir", KGlobal::dirs()->saveLocation("cache","http"));
 }
 
 int KProtocolManager::maxCacheAge()
 {
-  KConfig *cfg = http_config();
-  return cfg->readEntry( "MaxCacheAge", DEFAULT_MAX_CACHE_AGE ); // 14 days
+  return http_config().readEntry( "MaxCacheAge", DEFAULT_MAX_CACHE_AGE ); // 14 days
 }
 
 int KProtocolManager::maxCacheSize()
 {
-  KConfig *cfg = http_config();
-  return cfg->readEntry( "MaxCacheSize", DEFAULT_MAX_CACHE_SIZE ); // 5 MB
+  return http_config().readEntry( "MaxCacheSize", DEFAULT_MAX_CACHE_SIZE ); // 5 MB
 }
 
 QString KProtocolManager::noProxyFor()
 {
   KProtocolManager::ProxyType type = proxyType();
 
-  KConfig *cfg = config();
-  cfg->setGroup( "Proxy Settings" );
-
-  QString noProxy = cfg->readEntry( "NoProxyFor" );
+  QString noProxy = config()->group("Proxy Settings").readEntry( "NoProxyFor" );
   if (type == EnvVarProxy)
     noProxy = QString::fromLocal8Bit(getenv(noProxy.toLocal8Bit()));
 
@@ -229,9 +223,7 @@ QString KProtocolManager::proxyFor( const QString& protocol )
   else if (scheme == "webdavs")
     scheme = "https";
 
-  KConfig *cfg = config();
-  cfg->setGroup( "Proxy Settings" );
-  return cfg->readEntry( scheme + "Proxy", QString() );
+  return config()->group("Proxy Settings" ).readEntry( scheme + "Proxy", QString() );
 }
 
 QString KProtocolManager::proxyForUrl( const KUrl &url )
@@ -340,9 +332,7 @@ QString KProtocolManager::slaveProtocol(const KUrl &url, QString &proxy)
      return slaveProtocol(l, proxy);
   }
 
-  if (!d)
-    d = new KProtocolManagerPrivate;
-
+    PRIVATE_DATA;
   if (d->url == url)
   {
      proxy = d->proxy;
@@ -401,7 +391,7 @@ QString KProtocolManager::slaveProtocol(const KUrl &url, QString &proxy)
               else
               {
                 d->protocol = d->url.protocol();
-                kDebug () << "slaveProtocol: " << d->protocol << endl;
+                kDebug () << "slaveProtocol: " << d->protocol;
               }
 
               d->url = url;
@@ -444,9 +434,7 @@ QString KProtocolManager::defaultUserAgent( )
 
 QString KProtocolManager::defaultUserAgent( const QString &_modifiers )
 {
-  if (!d)
-     d = new KProtocolManagerPrivate;
-
+    PRIVATE_DATA;
   QString modifiers = _modifiers.toLower();
   if (modifiers.isEmpty())
      modifiers = DEFAULT_USER_AGENT_KEYS;
@@ -474,19 +462,7 @@ QString KProtocolManager::defaultUserAgent( const QString &_modifiers )
     }
     if( modifiers.contains('l') )
     {
-      static const QString & english = KGlobal::staticQString( "en" );
-
-      QStringList languageList = KGlobal::locale()->languageList();
-      int idx = languageList.indexOf( QLatin1String("C") );
-      if( idx != -1 )
-      {
-        if( languageList.contains( english ) )
-          languageList.removeAt( idx );
-        else
-          languageList[idx] = english;
-      }
-      if( languageList.count() )
-        supp += QString("; %1").arg(languageList.join(", "));
+      supp += QString("; %1").arg(acceptLanguagesHeader());
     }
   }
   d->modifiers = modifiers;
@@ -494,49 +470,84 @@ QString KProtocolManager::defaultUserAgent( const QString &_modifiers )
   return d->useragent;
 }
 
+QString KProtocolManager::acceptLanguagesHeader()
+{
+  static const QString &english = KGlobal::staticQString("en");
+
+  // User's desktop language preference.
+  QStringList languageList = KGlobal::locale()->languageList();
+
+  // Replace possible "C" in the language list with "en", unless "en" is
+  // already pressent. This is to keep user's priorities in order.
+  // If afterwards "en" is still not present, append it.
+  int idx = languageList.indexOf(QString::fromLatin1("C"));
+  if (idx != -1)
+  {
+    if (languageList.contains(english))
+      languageList.removeAt(idx);
+    else
+      languageList[idx] = english;
+  }
+  if (!languageList.contains(english))
+    languageList += english;
+
+  // Some languages may have web codes different from locale codes,
+  // read them from the config and insert in proper order.
+  KConfig acclangConf("accept-languages.codes", KConfig::NoGlobals);
+  KConfigGroup replacementCodes(&acclangConf, "ReplacementCodes");
+  QStringList languageListFinal;
+  foreach (const QString &lang, languageList)
+  {
+    QStringList langs = replacementCodes.readEntry(lang, QStringList());
+    if (langs.isEmpty())
+      languageListFinal += lang;
+    else
+      languageListFinal += langs;
+  }
+
+  // The header is composed of comma separated languages.
+  QString header = languageListFinal.join(", ");
+
+  // Some of the languages may have country specifier delimited by
+  // underscore, or modifier delimited by at-sign.
+  // The header should use dashes instead.
+  header.replace('_', '-');
+  header.replace('@', '-');
+
+  return header;
+}
+
 /*==================================== OTHERS ===============================*/
 
 bool KProtocolManager::markPartial()
 {
-  KConfig *cfg = config();
-  cfg->setGroup( QString() );
-  return cfg->readEntry( "MarkPartial", true );
+  return config()->group(QByteArray()).readEntry( "MarkPartial", true );
 }
 
 int KProtocolManager::minimumKeepSize()
 {
-  KConfig *cfg = config();
-  cfg->setGroup( QString() );
-  return cfg->readEntry( "MinimumKeepSize",
-                            DEFAULT_MINIMUM_KEEP_SIZE ); // 5000 byte
+    return config()->group(QByteArray()).readEntry( "MinimumKeepSize",
+                                                DEFAULT_MINIMUM_KEEP_SIZE ); // 5000 byte
 }
 
 bool KProtocolManager::autoResume()
 {
-  KConfig *cfg = config();
-  cfg->setGroup( QString() );
-  return cfg->readEntry( "AutoResume", false );
+  return config()->group(QByteArray()).readEntry( "AutoResume", false );
 }
 
 bool KProtocolManager::persistentConnections()
 {
-  KConfig *cfg = config();
-  cfg->setGroup( QString() );
-  return cfg->readEntry( "PersistentConnections", true );
+  return config()->group(QByteArray()).readEntry( "PersistentConnections", true );
 }
 
 bool KProtocolManager::persistentProxyConnection()
 {
-  KConfig *cfg = config();
-  cfg->setGroup( QString() );
-  return cfg->readEntry( "PersistentProxyConnection", false );
+  return config()->group(QByteArray()).readEntry( "PersistentProxyConnection", false );
 }
 
 QString KProtocolManager::proxyConfigScript()
 {
-  KConfig *cfg = config();
-  cfg->setGroup( "Proxy Settings" );
-  return cfg->readEntry( "Proxy Config Script" );
+  return config()->group("Proxy Settings").readEntry( "Proxy Config Script" );
 }
 
 /* =========================== PROTOCOL CAPABILITIES ============== */
@@ -729,3 +740,4 @@ QString KProtocolManager::defaultMimetype( const KUrl &url )
   return prot->m_defaultMimetype;
 }
 
+#undef PRIVATE_DATA
