@@ -17,16 +17,19 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
-#ifndef __kprotocolmanager_h__
-#define __kprotocolmanager_h__
+#ifndef KPROTOCOLMANAGER_H
+#define KPROTOCOLMANAGER_H
 
-#include <qstringlist.h>
+#include <QtCore/QStringList>
 
-#include <kapplication.h>
 #include <kio/global.h>
 #include "kprotocolinfo.h"
 
-class KConfig;
+class KSharedConfigPtr;
+namespace KIO
+{
+    class SlaveConfigPrivate;
+} // namespace KIO
 
 /**
  * Provides information about I/O (Internet, etc.) settings chosen/set
@@ -588,12 +591,20 @@ public:
    */
   static QString slaveProtocol(const KUrl &url, QString &proxy);
 
+  /**
+   * Return Accept-Languages header built up according to user's desktop
+   * language settings.
+   * @return Accept-Languages header string
+   */
+  static QString acceptLanguagesHeader();
+
+private:
+  friend class KIO::SlaveConfigPrivate;
+
   /**
    * @internal
    * (Shared with SlaveConfig)
    */
-  static KConfig *config();
-private:
-  static KConfig *http_config();
+  KDE_NO_EXPORT static KSharedConfigPtr config();
 };
 #endif
