@@ -16,11 +16,12 @@
    Boston, MA 02110-1301, USA.
 */
 
+#include "kremoteencoding.h"
+
 #include <config.h>
 
 #include <kdebug.h>
 #include <kstringhandler.h>
-#include "kremoteencoding.h"
 
 KRemoteEncoding::KRemoteEncoding(const char *name)
   : codec(0), d(0)
@@ -74,6 +75,16 @@ QByteArray KRemoteEncoding::fileName(const KUrl& url) const
   return encode(url.fileName());
 }
 
+const char *KRemoteEncoding::encoding() const
+{
+    return codec->name();
+}
+
+int KRemoteEncoding::encodingMib() const
+{
+    return codec->mibEnum();
+}
+
 void KRemoteEncoding::setEncoding(const char *name)
 {
   // don't delete codecs
@@ -88,7 +99,7 @@ void KRemoteEncoding::setEncoding(const char *name)
 
   Q_ASSERT(codec);
 
-  kDebug() << k_funcinfo << "setting encoding " << codec->name()
+  kDebug() << "setting encoding " << codec->name()
 	    << " for name=" << name << endl;
 }
 
