@@ -19,6 +19,7 @@
 */
 
 #include "krun.h"
+#include "krun_p.h"
 
 #include <config.h>
 
@@ -27,13 +28,13 @@
 #include <string.h>
 #include <unistd.h>
 #include <typeinfo>
+#include <sys/stat.h>
 
-#include <qwidget.h>
-#include <qpointer.h>
+#include <QtGui/QWidget>
+#include <QtCore/QPointer>
 
 #include "kmimetypetrader.h"
 #include "kmimetype.h"
-#include "kmimemagic.h"
 #include "kio/job.h"
 #include "kio/jobuidelegate.h"
 #include "kio/global.h"
@@ -41,7 +42,7 @@
 #include "kio/netaccess.h"
 #include "kfile/kopenwithdialog.h"
 #include "kfile/krecentdocument.h"
-#include "kdedesktopmimetype.h"
+#include "kdesktopfileactions.h"
 
 #include <kmessageboxwrapper.h>
 #include <kurl.h>
@@ -53,13 +54,12 @@
 #include <kprotocolmanager.h>
 #include <kstandarddirs.h>
 #include <kprocess.h>
-#include <qfile.h>
-#include <qfileinfo.h>
-#include <qtextstream.h>
-#include <qdatetime.h>
-#include <qregexp.h>
+#include <QtCore/QFile>
+#include <QtCore/QFileInfo>
+#include <QtCore/QTextIStream>
+#include <QtCore/QDate>
+#include <QtCore/QRegExp>
 #include <kdesktopfile.h>
-#include <kstartupinfo.h>
 #include <kmacroexpander.h>
 #include <kshell.h>
 #include <QTextDocument>
@@ -67,7 +67,7 @@
 #include <kconfiggroup.h>
 
 #ifdef Q_WS_X11
-#include <kwin.h>
+#include <kwindowsystem.h>
 #endif
 
 class KRun::KRunPrivate
@@ -83,6 +83,7 @@ public:
     QString m_localPath;
     QString m_suggestedFileName;
     QPointer <QWidget> m_window;
+    QByteArray m_asn;
 };
 
 bool KRun::isExecutableFile( const KUrl& url, const QString &mimetype )
@@ -101,7 +102,7 @@ bool KRun::isExecutableFile( const KUrl& url, const QString &mimetype )
 }
 
 // This is called by foundMimeType, since it knows the mimetype of the URL
-pid_t KRun::runUrl( const KUrl& u, const QString& _mimetype, QWidget* window, bool tempFile, bool runExecutables, const QString& suggestedFileName )
+bool KRun::runUrl( const KUrl& u, const QString& _mimetype, QWidget* window, bool tempFile, bool runExecutables, const QString& suggestedFileName, const QByteArray& asn )
 {
   bool noRun = false;
   bool noAuth = false;
@@ -109,12 +110,12 @@ pid_t KRun::runUrl( const KUrl& u, const QString& _mimetype, QWidget* window, bo
   {
     KMessageBoxWrapper::error( window,
             i18n("<qt>Unable to enter <b>%1</b>.\nYou do not have access rights to this location.</qt>", Qt::escape(u.prettyUrl())) );
-    return 0;
+    return false;
   }
   else if ( _mimetype == "application/x-desktop" )
   {
     if ( u.isLocalFile() && runExecutables )
-      return KDEDesktopMimeType::run( u, true );
+      return KDesktopFileActions::run( u, true );
   }
   else if ( isExecutableFile(u, _mimetype) )
   {
@@ -122,9 +123,7 @@ pid_t KRun::runUrl( const KUrl& u, const QString& _mimetype, QWidget* window, bo
     {
       if (KAuthorized::authorize("shell_access"))
       {
-        QString path = u.path();
-        shellQuote( path );
-        return (KRun::runCommand(path)); // just execute the url as a command
+        return (KRun::runCommand(KShell::quoteArg(u.path()), QString(), QString(), window, asn)); // just execute the url as a command
         // ## TODO implement deleting the file if tempFile==true
       }
       else
@@ -149,13 +148,13 @@ pid_t KRun::runUrl( const KUrl& u, const QString& _mimetype, QWidget* window, bo
     KMessageBox::sorry( window,
         i18n("<qt>The file <b>%1</b> is an executable program. "
              "For safety it will not be started.</qt>", Qt::escape(u.prettyUrl())));
-    return 0;
+    return false;
   }
   if ( noAuth )
   {
     KMessageBoxWrapper::error( window,
         i18n("<qt>You do not have permission to run <b>%1</b>.</qt>", Qt::escape(u.prettyUrl())) );
-    return 0;
+    return false;
   }
 
   KUrl::List lst;
@@ -168,13 +167,14 @@ pid_t KRun::runUrl( const KUrl& u, const QString& _mimetype, QWidget* window, bo
     // Open-with dialog
     // TODO : pass the mimetype as a parameter, to show it (comment field) in the dialog !
     // Hmm, in fact KOpenWithDialog::setServiceType already guesses the mimetype from the first URL of the list...
-    return displayOpenWithDialog( lst, window, tempFile, suggestedFileName );
+    return displayOpenWithDialog( lst, window, tempFile, suggestedFileName, asn );
   }
 
-  return KRun::run( *offer, lst, window, tempFile, suggestedFileName );
+  return KRun::run( *offer, lst, window, tempFile, suggestedFileName, asn );
 }
 
-bool KRun::displayOpenWithDialog( const KUrl::List& lst, QWidget* window, bool tempFiles, const QString& suggestedFileName )
+bool KRun::displayOpenWithDialog( const KUrl::List& lst, QWidget* window, bool tempFiles, const QString& suggestedFileName,
+    const QByteArray& asn )
 {
     if (!KAuthorized::authorizeKAction("openwith"))
     {
@@ -187,10 +187,10 @@ bool KRun::displayOpenWithDialog( const KUrl::List& lst, QWidget* window, bool t
     {
       KService::Ptr service = l.service();
       if ( !!service )
-        return KRun::run( *service, lst, window, tempFiles, suggestedFileName );
+        return KRun::run( *service, lst, window, tempFiles, suggestedFileName, asn );
 
-      kDebug(7010) << "No service set, running " << l.text() << endl;
-      return KRun::run( l.text(), lst, suggestedFileName ); // TODO handle tempFiles
+      kDebug(7010) << "No service set, running " << l.text();
+      return KRun::run( l.text(), lst, window, false, suggestedFileName, asn ); // TODO handle tempFiles
     }
     return false;
 }
@@ -234,7 +234,7 @@ KRunMX1::expandEscapedMacro( const QString &str, int pos, QStringList &ret )
       break;
    case 'm':
 //       ret << "-miniicon" << service.icon().replace( '%', "%%" );
-      kWarning() << k_funcinfo << "-miniicon isn't supported anymore (service "
+      kWarning() << "-miniicon isn't supported anymore (service "
                   << service.name() << ')' << endl;
       break;
    case 'u':
@@ -289,7 +289,7 @@ KRunMX2::subst( int option, const KUrl &url, QStringList &ret )
       break;
    case 'v':
       if (url.isLocalFile() && QFile::exists( url.path() ) )
-          ret << KDesktopFile( url.path(), true ).readEntry( "Dev" );
+          ret << KDesktopFile( url.path() ).desktopGroup().readEntry( "Dev" );
       break;
    }
    return;
@@ -307,9 +307,9 @@ KRunMX2::expandEscapedMacro( const QString &str, int pos, QStringList &ret )
    case 'v':
       if( urls.isEmpty() ) {
          if (!ignFile)
-            kDebug() << "KRun::processDesktopExec: No URLs supplied to single-URL service " << str << endl;
+            kDebug() << "KRun::processDesktopExec: No URLs supplied to single-URL service " << str;
       } else if( urls.count() > 1 )
-          kWarning() << "KRun::processDesktopExec: " << urls.count() << " URLs supplied to single-URL service " << str << endl;
+          kWarning() << "KRun::processDesktopExec: " << urls.count() << " URLs supplied to single-URL service " << str;
       else
          subst( option, urls.first(), ret );
       break;
@@ -334,7 +334,7 @@ QStringList KRun::processDesktopExec(const KService &_service, const KUrl::List&
 {
   QString exec = _service.exec();
   if ( exec.isEmpty() ) {
-      kWarning() << "KRun: no Exec field in `" << _service.desktopEntryPath() << "' !" << endl;
+      kWarning() << "KRun: no Exec field in `" << _service.desktopEntryPath() << "' !";
       return QStringList();
   }
 
@@ -417,7 +417,7 @@ QStringList KRun::processDesktopExec(const KService &_service, const KUrl::List&
     terminal += ' ';
     terminal += _service.terminalOptions();
     if( !mx1.expandMacrosShellQuote( terminal ) ) {
-      kWarning() << "KRun: syntax error in command `" << terminal << "', service `" << _service.name() << "'" << endl;
+      kWarning() << "KRun: syntax error in command `" << terminal << "', service `" << _service.name() << "'";
       return QStringList();
     }
     mx2.expandMacrosShellQuote( terminal );
@@ -425,7 +425,7 @@ QStringList KRun::processDesktopExec(const KService &_service, const KUrl::List&
     result << "-e";
   }
 
-  int err;
+  KShell::Errors err;
   if (_service.substituteUid()) {
     if (_service.terminal())
       result << "su";
@@ -434,8 +434,7 @@ QStringList KRun::processDesktopExec(const KService &_service, const KUrl::List&
     result << _service.username() << "-c";
     KShell::splitArgs(exec, KShell::AbortOnMeta | KShell::TildeExpand, &err);
     if (err == KShell::FoundMeta) {
-      shellQuote( exec );
-      exec.prepend( "/bin/sh -c " );
+      exec = "/bin/sh -c " + KShell::quoteArg(exec);
     } else if (err != KShell::NoError)
       goto synerr;
     result << exec;
@@ -445,12 +444,20 @@ QStringList KRun::processDesktopExec(const KService &_service, const KUrl::List&
       result << "/bin/sh" << "-c" << exec;
     else if (err != KShell::NoError)
       goto synerr;
+    else {
+      if (!result.isEmpty()) {
+        // resolve the executable according to the path, which also makes it possible to find kde4/libexec helpers.
+        const QString exePath = KStandardDirs::findExe(result[0]);
+        if (!exePath.isEmpty())
+          result[0] = exePath;
+      }
+    }
   }
 
   return result;
 
  synerr:
-  kWarning() << "KRun: syntax error in command `" << _service.exec() << "', service `" << _service.name() << "'" << endl;
+  kWarning() << "KRun: syntax error in command `" << _service.exec() << "', service `" << _service.name() << "'";
   return QStringList();
 }
 
@@ -466,25 +473,27 @@ QString KRun::binaryName( const QString & execLine, bool removePath )
   return QString();
 }
 
-static pid_t runCommandInternal( KProcess* proc, const KService* service, const QString& binName,
-    const QString &execName, const QString & iconName )
+static bool runCommandInternal( KProcess* proc, const KService* service, const QString& binName,
+    const QString &execName, const QString & iconName, QWidget* window, const QByteArray& asn )
 {
+  if( window != NULL )
+      window = window->topLevelWidget();
   if (service && !service->desktopEntryPath().isEmpty()
       && !KDesktopFile::isAuthorizedDesktopFile( service->desktopEntryPath() ))
   {
-     kWarning() << "No authorization to execute " << service->desktopEntryPath() << endl;
-     KMessageBox::sorry(0, i18n("You are not authorized to execute this file."));
-     return 0;
+     kWarning() << "No authorization to execute " << service->desktopEntryPath();
+     KMessageBox::sorry( window, i18n("You are not authorized to execute this file."));
+     return false;
   }
   QString bin = KRun::binaryName( binName, true );
 #ifdef Q_WS_X11 // Startup notification doesn't work with QT/E, service isn't needed without Startup notification
   bool silent;
   QByteArray wmclass;
   KStartupInfoId id;
-  bool startup_notify = KRun::checkStartupNotify( binName, service, &silent, &wmclass );
+  bool startup_notify = ( asn != "0" && KRun::checkStartupNotify( binName, service, &silent, &wmclass ));
   if( startup_notify )
   {
-      id.initId();
+      id.initId( asn );
       id.setupStartupEnv();
       KStartupInfoData data;
       data.setHostname();
@@ -502,10 +511,12 @@ static pid_t runCommandInternal( KProcess* proc, const KService* service, const
           data.setWMClass( wmclass );
       if( silent )
           data.setSilent( KStartupInfoData::Yes );
-      data.setDesktop( KWin::currentDesktop());
+      data.setDesktop( KWindowSystem::currentDesktop());
+      if( window )
+          data.setLaunchedBy( window->winId());
       KStartupInfo::sendStartup( id, data );
   }
-  pid_t pid = KProcessRunner::run( proc, binName, id );
+  int pid = KProcessRunner::run( proc, binName, id );
   if( startup_notify && pid )
   {
       KStartupInfoData data;
@@ -513,11 +524,11 @@ static pid_t runCommandInternal( KProcess* proc, const KService* service, const
       KStartupInfo::sendChange( id, data );
       KStartupInfo::resetStartupEnv();
   }
-  return pid;
+  return pid != 0;
 #else
   Q_UNUSED( execName );
   Q_UNUSED( iconName );
-  return KProcessRunner::run( proc, bin );
+  return KProcessRunner::run( proc, bin ) != 0;
 #endif
 }
 
@@ -560,10 +571,11 @@ bool KRun::checkStartupNotify( const QString& /*binName*/, const KService* servi
   return true;
 }
 
-static pid_t runTempService( const KService& _service, const KUrl::List& _urls, bool tempFiles, const QString& suggestedFileName )
+static bool runTempService( const KService& _service, const KUrl::List& _urls, QWidget* window,
+    bool tempFiles, const QString& suggestedFileName, const QByteArray& asn )
 {
   if (!_urls.isEmpty()) {
-    kDebug(7010) << "runTempService: first url " << _urls.first().url() << endl;
+    kDebug(7010) << "runTempService: first url " << _urls.first().url();
   }
 
   QStringList args;
@@ -579,7 +591,7 @@ static pid_t runTempService( const KService& _service, const KUrl::List& _urls,
       {
          KUrl::List singleUrl;
          singleUrl.append(*it);
-         runTempService( _service, singleUrl, tempFiles, suggestedFileName );
+         runTempService( _service, singleUrl, window, tempFiles, suggestedFileName, "" );
       }
       KUrl::List singleUrl;
       singleUrl.append(_urls.first());
@@ -589,7 +601,7 @@ static pid_t runTempService( const KService& _service, const KUrl::List& _urls,
   {
       args = KRun::processDesktopExec(_service, _urls, tempFiles, suggestedFileName );
   }
-  kDebug(7010) << "runTempService: KProcess args=" << args << endl;
+  kDebug(7010) << "runTempService: KProcess args=" << args;
 
   KProcess * proc = new KProcess;
   *proc << args;
@@ -598,7 +610,7 @@ static pid_t runTempService( const KService& _service, const KUrl::List& _urls,
      proc->setWorkingDirectory(_service.path());
 
   return runCommandInternal( proc, &_service, KRun::binaryName( _service.exec(), false ),
-                             _service.name(), _service.icon() );
+                             _service.name(), _service.icon(), window, asn );
 }
 
 // WARNING: don't call this from processDesktopExec, since klauncher uses that too...
@@ -624,21 +636,21 @@ static KUrl::List resolveURLs( const KUrl::List& _urls, const KService& _service
       }
     }
   }
-  kDebug(7010) << "supportedProtocols:" << supportedProtocols << endl;
+  kDebug(7010) << "supportedProtocols:" << supportedProtocols;
 
   KUrl::List urls( _urls );
   if ( !supportedProtocols.contains( "KIO" ) ) {
     for( KUrl::List::Iterator it = urls.begin(); it != urls.end(); ++it ) {
       const KUrl url = *it;
       bool supported = url.isLocalFile() || supportedProtocols.contains( url.protocol().toLower() );
-      kDebug(7010) << "Looking at url=" << url << " supported=" << supported << endl;
+      kDebug(7010) << "Looking at url=" << url << " supported=" << supported;
       if ( !supported && KProtocolInfo::protocolClass(url.protocol()) == ":local" )
       {
         // Maybe we can resolve to a local URL?
         KUrl localURL = KIO::NetAccess::mostLocalUrl( url, 0 );
         if ( localURL != url ) {
           *it = localURL;
-          kDebug(7010) << "Changed to " << localURL << endl;
+          kDebug(7010) << "Changed to " << localURL;
         }
       }
     }
@@ -646,14 +658,15 @@ static KUrl::List resolveURLs( const KUrl::List& _urls, const KService& _service
   return urls;
 }
 
-pid_t KRun::run( const KService& _service, const KUrl::List& _urls, QWidget* window, bool tempFiles, const QString& suggestedFileName )
+bool KRun::run( const KService& _service, const KUrl::List& _urls, QWidget* window,
+    bool tempFiles, const QString& suggestedFileName, const QByteArray& asn )
 {
   if (!_service.desktopEntryPath().isEmpty() &&
       !KDesktopFile::isAuthorizedDesktopFile( _service.desktopEntryPath()))
   {
-     kWarning() << "No authorization to execute " << _service.desktopEntryPath() << endl;
+     kWarning() << "No authorization to execute " << _service.desktopEntryPath();
      KMessageBox::sorry( window, i18n("You are not authorized to execute this service.") );
-     return 0;
+     return false;
   }
 
   if ( !tempFiles )
@@ -661,20 +674,20 @@ pid_t KRun::run( const KService& _service, const KUrl::List& _urls, QWidget* win
       // Remember we opened those urls, for the "recent documents" menu in kicker
       KUrl::List::ConstIterator it = _urls.begin();
       for(; it != _urls.end(); ++it) {
-          //kDebug(7010) << "KRecentDocument::adding " << (*it).url() << endl;
+          //kDebug(7010) << "KRecentDocument::adding " << (*it).url();
           KRecentDocument::add( *it, _service.desktopEntryName() );
       }
   }
 
   if ( tempFiles || _service.desktopEntryPath().isEmpty() || !suggestedFileName.isEmpty() )
   {
-     return runTempService( _service, _urls, tempFiles, suggestedFileName );
+     return runTempService( _service, _urls, window, tempFiles, suggestedFileName, asn );
   }
 
-  kDebug(7010) << "KRun::run " << _service.desktopEntryPath() << endl;
+  kDebug(7010) << "KRun::run " << _service.desktopEntryPath();
 
   if (!_urls.isEmpty()) {
-    kDebug(7010) << "First url " << _urls.first().url() << endl;
+    kDebug(7010) << "First url " << _urls.first().url();
   }
 
   // Resolve urls if needed, depending on what the app supports
@@ -683,56 +696,72 @@ pid_t KRun::run( const KService& _service, const KUrl::List& _urls, QWidget* win
   QString error;
   int pid = 0;
 
+  QByteArray myasn = asn;
+  // startServiceByDesktopPath() doesn't take QWidget*, add it to the startup info now
+  if( window != NULL )
+  {
+    if( myasn.isEmpty())
+        myasn = KStartupInfo::createNewStartupId();
+    if( myasn != "0" )
+    {
+        KStartupInfoId id;
+        id.initId( myasn );
+        KStartupInfoData data;
+        data.setLaunchedBy( window->winId());
+        KStartupInfo::sendChange( id, data );
+    }
+  }
+
   int i = KToolInvocation::startServiceByDesktopPath(
-        _service.desktopEntryPath(), urls.toStringList(), &error, 0L, &pid
+        _service.desktopEntryPath(), urls.toStringList(), &error, 0L, &pid, myasn
         );
 
   if (i != 0)
   {
-     kDebug(7010) << error << endl;
+     kDebug(7010) << error;
      KMessageBox::sorry( window, error );
-     return 0;
+     return false;
   }
 
-  kDebug(7010) << "startServiceByDesktopPath worked fine" << endl;
-  return (pid_t) pid;
+  kDebug(7010) << "startServiceByDesktopPath worked fine";
+  return true;
 }
 
 
-pid_t KRun::run( const QString& _exec, const KUrl::List& _urls, const QString& _name,
-                 const QString& _icon, QWidget* window )
+bool KRun::run( const QString& _exec, const KUrl::List& _urls, QWidget* window, const QString& _name,
+                 const QString& _icon, const QByteArray& asn )
 {
   KService::Ptr service(new KService(_name, _exec, _icon));
 
-  return run( *service, _urls, window );
+  return run( *service, _urls, window, false, QString(), asn );
 }
 
-pid_t KRun::runCommand( const QString &cmd )
+bool KRun::runCommand( const QString &cmd, QWidget* window )
 {
-  return KRun::runCommand( cmd, QString(), QString() );
+  return KRun::runCommand( cmd, QString(), QString(), window, "" );
 }
 
-pid_t KRun::runCommand( const QString& cmd, const QString &execName, const QString & iconName )
+bool KRun::runCommand( const QString& cmd, const QString &execName, const QString & iconName, QWidget* window, const QByteArray& asn )
 {
-  kDebug(7010) << "runCommand " << cmd << "," << execName << endl;
+  kDebug(7010) << "runCommand " << cmd << "," << execName;
   KProcess * proc = new KProcess;
-  proc->setUseShell(true);
-  *proc << cmd;
-  KService::Ptr service = KService::serviceByDesktopName( binaryName( execName, true ) );
-  return runCommandInternal( proc, service.data(), binaryName( execName, false ), execName, iconName );
+  proc->setShellCommand( cmd );
+  QString bin = binaryName( execName, true );
+  KService::Ptr service = KService::serviceByDesktopName( bin );
+  return runCommandInternal( proc, service.data(), bin, execName, iconName, window, asn );
 }
 
 KRun::KRun( const KUrl& url, QWidget* window, mode_t mode, bool isLocalFile,
-            bool showProgressInfo )
+            bool showProgressInfo, const QByteArray& asn )
      : m_timer(), d(new KRunPrivate)
 {
   m_timer.setObjectName( "KRun::timer" );
   m_timer.setSingleShot( true );
-  init (url, window, mode, isLocalFile, showProgressInfo);
+  init (url, window, mode, isLocalFile, showProgressInfo, asn );
 }
 
 void KRun::init ( const KUrl& url, QWidget* window, mode_t mode, bool isLocalFile,
-                  bool showProgressInfo )
+                  bool showProgressInfo, const QByteArray& asn )
 {
   m_bFault = false;
   m_bAutoDelete = true;
@@ -746,6 +775,7 @@ void KRun::init ( const KUrl& url, QWidget* window, mode_t mode, bool isLocalFil
   m_mode = mode;
   d->m_runExecutables = true;
   d->m_window = window;
+  d->m_asn = asn;
   setEnableExternalBrowser(true);
 
   // Start the timer. This means we will return to the event
@@ -754,14 +784,14 @@ void KRun::init ( const KUrl& url, QWidget* window, mode_t mode, bool isLocalFil
   m_bInit = true;
   connect( &m_timer, SIGNAL( timeout() ), this, SLOT( slotTimeout() ) );
   m_timer.start( 0 );
-  kDebug(7010) << " new KRun " << this << " " << url.prettyUrl() << " timer=" << &m_timer << endl;
+  kDebug(7010) << " new KRun " << this << " " << url.prettyUrl() << " timer=" << &m_timer;
 
   KGlobal::ref();
 }
 
 void KRun::init()
 {
-  kDebug(7010) << "INIT called" << endl;
+  kDebug(7010) << "INIT called";
   if ( !m_strURL.isValid() )
   {
     d->m_showingError = true;
@@ -813,12 +843,12 @@ void KRun::init()
 
     KMimeType::Ptr mime = KMimeType::findByUrl( m_strURL, m_mode, m_bIsLocalFile );
     assert( mime );
-    kDebug(7010) << "MIME TYPE is " << mime->name() << endl;
+    kDebug(7010) << "MIME TYPE is " << mime->name();
     foundMimeType( mime->name() );
     return;
   }
   else if ( !exec.isEmpty() || KProtocolInfo::isHelperProtocol( m_strURL ) ) {
-    kDebug(7010) << "Helper protocol" << endl;
+    kDebug(7010) << "Helper protocol";
 
     bool ok = false;
     KUrl::List urls;
@@ -831,14 +861,14 @@ void KRun::init()
           foundMimeType(KProtocolManager::defaultMimetype(m_strURL));
           return;
        }
-       run( exec, urls );
+       run( exec, urls, d->m_window, false, QString(), d->m_asn );
        ok = true;
     }
-    else if (exec.startsWith("!"))
+    else if (exec.startsWith('!'))
     {
        exec = exec.mid(1); // Literal command
        exec += " %u";
-       run( exec, urls );
+       run( exec, urls, d->m_window, false, QString(), d->m_asn );
        ok = true;
     }
     else
@@ -846,7 +876,7 @@ void KRun::init()
        KService::Ptr service = KService::serviceByStorageId( exec );
        if (service)
        {
-          run( *service, urls, d->m_window );
+          run( *service, urls, d->m_window, false, QString(), d->m_asn );
           ok = true;
        }
     }
@@ -871,36 +901,36 @@ void KRun::init()
 
   if ( !KProtocolManager::supportsListing( m_strURL ) )
   {
-    //kDebug(7010) << "Protocol has no support for listing" << endl;
+    //kDebug(7010) << "Protocol has no support for listing";
     // No support for listing => it can't be a directory (example: http)
     scanFile();
     return;
   }
 
-  kDebug(7010) << "Testing directory (stating)" << endl;
+  kDebug(7010) << "Testing directory (stating)";
 
   // It may be a directory or a file, let's stat
-  KIO::StatJob *job = KIO::stat( m_strURL, true, 0 /* no details */, m_bProgressInfo );
+  KIO::StatJob *job = KIO::stat( m_strURL, KIO::StatJob::SourceSide, 0 /* no details */, m_bProgressInfo );
   job->ui()->setWindow (d->m_window);
   connect( job, SIGNAL( result( KJob * ) ),
            this, SLOT( slotStatResult( KJob * ) ) );
   m_job = job;
-  kDebug(7010) << " Job " << job << " is about stating " << m_strURL.url() << endl;
+  kDebug(7010) << " Job " << job << " is about stating " << m_strURL.url();
 }
 
 KRun::~KRun()
 {
-  kDebug(7010) << "KRun::~KRun() " << this << endl;
+  kDebug(7010) << "KRun::~KRun() " << this;
   m_timer.stop();
   killJob();
   KGlobal::deref();
-  kDebug(7010) << "KRun::~KRun() done " << this << endl;
+  kDebug(7010) << "KRun::~KRun() done " << this;
   delete d;
 }
 
 void KRun::scanFile()
 {
-  kDebug(7010) << "###### KRun::scanFile " << m_strURL.url() << endl;
+  kDebug(7010) << "###### KRun::scanFile " << m_strURL.url();
   // First, let's check for well-known extensions
   // Not when there is a query in the URL, in any case.
   if ( m_strURL.query().isEmpty() )
@@ -909,7 +939,7 @@ void KRun::scanFile()
     assert( mime );
     if ( mime->name() != "application/octet-stream" || m_bIsLocalFile )
     {
-      kDebug(7010) << "Scanfile: MIME TYPE is " << mime->name() << endl;
+      kDebug(7010) << "Scanfile: MIME TYPE is " << mime->name();
       foundMimeType( mime->name() );
       return;
     }
@@ -927,7 +957,7 @@ void KRun::scanFile()
     m_timer.start( 0 );
     return;
   }
-  kDebug(7010) << this << " Scanning file " << m_strURL.url() << endl;
+  kDebug(7010) << this << " Scanning file " << m_strURL.url();
 
   KIO::TransferJob *job = KIO::get( m_strURL, false /*reload*/, m_bProgressInfo );
   job->ui()->setWindow (d->m_window);
@@ -936,12 +966,12 @@ void KRun::scanFile()
   connect(job, SIGNAL( mimetype(KIO::Job *, const QString &)),
           this, SLOT( slotScanMimeType(KIO::Job *, const QString &)));
   m_job = job;
-  kDebug(7010) << " Job " << job << " is about getting from " << m_strURL.url() << endl;
+  kDebug(7010) << " Job " << job << " is about getting from " << m_strURL.url();
 }
 
 void KRun::slotTimeout()
 {
-  kDebug(7010) << this << " slotTimeout called" << endl;
+  kDebug(7010) << this << " slotTimeout called";
   if ( m_bInit )
   {
     m_bInit = false;
@@ -986,7 +1016,7 @@ void KRun::slotStatResult( KJob * job )
     d->m_showingError = true;
     kError(7010) << this << " ERROR " << job->error() << " " << job->errorString() << endl;
     job->uiDelegate()->showErrorMessage();
-    //kDebug(7010) << this << " KRun returning from showErrorDialog, starting timer to delete us" << endl;
+    //kDebug(7010) << this << " KRun returning from showErrorDialog, starting timer to delete us";
     d->m_showingError = false;
 
     m_bFault = true;
@@ -997,21 +1027,21 @@ void KRun::slotStatResult( KJob * job )
 
   } else {
 
-    kDebug(7010) << "Finished" << endl;
+    kDebug(7010) << "Finished";
     if(!qobject_cast<KIO::StatJob*>(job))
-        kFatal() << "job is a " << typeid(*job).name() << " should be a StatJob" << endl;
+        kFatal() << "job is a " << typeid(*job).name() << " should be a StatJob";
 
     const KIO::UDSEntry entry = ((KIO::StatJob*)job)->statResult();
-    const mode_t mode = entry.numberValue( KIO::UDS_FILE_TYPE );
+    const mode_t mode = entry.numberValue( KIO::UDSEntry::UDS_FILE_TYPE );
     if ( S_ISDIR( mode ) )
         m_bIsDirectory = true; // it's a dir
     else
         m_bScanFile = true; // it's a file
 
-    d->m_localPath = entry.stringValue( KIO::UDS_LOCAL_PATH );
+    d->m_localPath = entry.stringValue( KIO::UDSEntry::UDS_LOCAL_PATH );
 
     // mimetype already known? (e.g. print:/manager)
-    const QString knownMimeType = entry.stringValue( KIO::UDS_MIME_TYPE ) ;
+    const QString knownMimeType = entry.stringValue( KIO::UDSEntry::UDS_MIME_TYPE ) ;
 
     if ( !knownMimeType.isEmpty() )
     {
@@ -1032,7 +1062,7 @@ void KRun::slotStatResult( KJob * job )
 void KRun::slotScanMimeType( KIO::Job *, const QString &mimetype )
 {
   if ( mimetype.isEmpty() )
-    kWarning(7010) << "KRun::slotScanFinished : MimetypeJob didn't find a mimetype! Probably a kioslave bug." << endl;
+    kWarning(7010) << "KRun::slotScanFinished : MimetypeJob didn't find a mimetype! Probably a kioslave bug.";
   foundMimeType( mimetype );
   m_job = 0;
 }
@@ -1045,7 +1075,7 @@ void KRun::slotScanFinished( KJob *job )
     d->m_showingError = true;
     kError(7010) << this << " ERROR (stat) : " << job->error() << " " << job->errorString() << endl;
     job->uiDelegate()->showErrorMessage();
-    //kDebug(7010) << this << " KRun returning from showErrorDialog, starting timer to delete us" << endl;
+    //kDebug(7010) << this << " KRun returning from showErrorDialog, starting timer to delete us";
     d->m_showingError = false;
 
     m_bFault = true;
@@ -1058,7 +1088,7 @@ void KRun::slotScanFinished( KJob *job )
 
 void KRun::foundMimeType( const QString& type )
 {
-  kDebug(7010) << "Resulting mime type is " << type << endl;
+  kDebug(7010) << "Resulting mime type is " << type;
 
 /*
   // Automatically unzip stuff
@@ -1067,7 +1097,7 @@ void KRun::foundMimeType( const QString& type )
 
   if ( type == "application/x-gzip"  ||
        type == "application/x-bzip"  ||
-       type == "application/x-bzip2"  )
+       type == "application/x-bzip"  )
   {
     KUrl::List lst = KUrl::split( m_strURL );
     if ( lst.isEmpty() )
@@ -1083,7 +1113,7 @@ void KRun::foundMimeType( const QString& type )
       lst.prepend( KUrl( "gzip:/decompress" ) );
     else if ( type == "application/x-bzip" )
       lst.prepend( KUrl( "bzip:/decompress" ) );
-    else if ( type == "application/x-bzip2" )
+    else if ( type == "application/x-bzip" )
       lst.prepend( KUrl( "bzip2:/decompress" ) );
     else if ( type == "application/x-tar" )
       lst.prepend( KUrl( "tar:/" ) );
@@ -1097,7 +1127,7 @@ void KRun::foundMimeType( const QString& type )
     // Create the new URL
     m_strURL = KUrl::join( lst );
 
-    kDebug(7010) << "Now trying with " << debugString(m_strURL.url()) << endl;
+    kDebug(7010) << "Now trying with " << debugString(m_strURL.url());
 
     killJob();
 
@@ -1124,17 +1154,17 @@ void KRun::foundMimeType( const QString& type )
 
   KMimeType::Ptr mime = KMimeType::mimeType( type );
   if ( !mime )
-      kWarning(7010) << "Unknown mimetype " << type << endl;
+      kWarning(7010) << "Unknown mimetype " << type;
 
   // Suport for preferred service setting, see setPreferredService
   if ( !d->m_preferredService.isEmpty() ) {
-      kDebug(7010) << "Attempting to open with preferred service: " << d->m_preferredService << endl;
+      kDebug(7010) << "Attempting to open with preferred service: " << d->m_preferredService;
       KService::Ptr serv = KService::serviceByDesktopName( d->m_preferredService );
       if ( serv && serv->hasMimeType( mime.data() ) )
       {
           KUrl::List lst;
           lst.append( m_strURL );
-          m_bFinished = KRun::run( *serv, lst, d->m_window );
+          m_bFinished = KRun::run( *serv, lst, d->m_window, false, QString(), d->m_asn );
           /// Note: the line above means that if that service failed, we'll
           /// go to runUrl to maybe find another service, even though a dialog
           /// box was displayed. That's good if runUrl tries another service,
@@ -1149,7 +1179,7 @@ void KRun::foundMimeType( const QString& type )
     m_strURL.setPath( d->m_localPath );
   }
 
-  if (!m_bFinished && KRun::runUrl( m_strURL, type, d->m_window, false /*tempfile*/, d->m_runExecutables, d->m_suggestedFileName )){
+  if (!m_bFinished && KRun::runUrl( m_strURL, type, d->m_window, false /*tempfile*/, d->m_runExecutables, d->m_suggestedFileName, d->m_asn )){
     m_bFinished = true;
   }
   else{
@@ -1164,7 +1194,7 @@ void KRun::killJob()
 {
   if ( m_job )
   {
-    kDebug(7010) << "KRun::killJob run=" << this << " m_job=" << m_job << endl;
+    kDebug(7010) << "KRun::killJob run=" << this << " m_job=" << m_job;
     m_job->kill();
     m_job = 0L;
   }
@@ -1172,7 +1202,7 @@ void KRun::killJob()
 
 void KRun::abort()
 {
-  kDebug(7010) << "KRun::abort " << this << " m_showingError=" << d->m_showingError << endl;
+  kDebug(7010) << "KRun::abort " << this << " m_showingError=" << d->m_showingError;
   killJob();
   // If we're showing an error message box, the rest will be done
   // after closing the msgbox -> don't autodelete nor emit signals now.
@@ -1187,6 +1217,26 @@ void KRun::abort()
   m_timer.start( 0 );
 }
 
+bool KRun::hasError() const
+{
+    return m_bFault;
+}
+
+bool KRun::hasFinished() const
+{
+    return m_bFinished;
+}
+
+bool KRun::autoDelete() const
+{
+    return m_bAutoDelete;
+}
+
+void KRun::setAutoDelete(bool b)
+{
+    m_bAutoDelete = b;
+}
+
 void KRun::setEnableExternalBrowser(bool b)
 {
    if (b)
@@ -1219,102 +1269,81 @@ bool KRun::isExecutable( const QString& serviceType )
 {
     return ( serviceType == "application/x-desktop" ||
              serviceType == "application/x-executable" ||
-             serviceType == "application/x-msdos-program" ||
+             serviceType == "application/x-ms-dos-executable" ||
              serviceType == "application/x-shellscript" );
 }
 
 /****************/
 
-pid_t
-KProcessRunner::run(KProcess * p, const QString & binName)
+#ifndef Q_WS_X11
+int KProcessRunner::run(KProcess * p, const QString & binName)
 {
-  return (new KProcessRunner(p, binName))->pid();
+    return (new KProcessRunner(p, binName))->pid();
 }
-
-#ifdef Q_WS_X11
-pid_t
-KProcessRunner::run(KProcess * p, const QString & binName, const KStartupInfoId& id )
+#else
+int KProcessRunner::run(KProcess * p, const QString & binName, const KStartupInfoId& id)
 {
-  return (new KProcessRunner(p, binName, id))->pid();
+    return (new KProcessRunner(p, binName, id))->pid();
 }
 #endif
 
-KProcessRunner::KProcessRunner(KProcess * p, const QString & _binName )
-  : QObject(),
-    process_(p),
-    binName( _binName )
-{
-  QObject::connect(
-      process_, SIGNAL(processExited(KProcess *)),
-      this,     SLOT(slotProcessExited(KProcess *)));
-
-  process_->start();
-  if ( !process_->pid() )
-      slotProcessExited( process_ );
-}
-
-#ifdef Q_WS_X11
-KProcessRunner::KProcessRunner(KProcess * p, const QString & _binName, const KStartupInfoId& id )
-  : QObject(),
-    process_(p),
-    binName( _binName ),
-    id_( id )
-{
-  QObject::connect(
-      process_, SIGNAL(processExited(KProcess *)),
-      this,     SLOT(slotProcessExited(KProcess *)));
-
-  process_->start();
-  if ( !process_->pid() )
-      slotProcessExited( process_ );
-}
+#ifndef Q_WS_X11
+KProcessRunner::KProcessRunner(KProcess * p, const QString & _binName)
+#else
+KProcessRunner::KProcessRunner(KProcess * p, const QString & _binName, const KStartupInfoId& _id) :
+    id(_id)
 #endif
+{
+    process = p;
+    binName = _binName;
+    connect(process, SIGNAL(finished(int, QProcess::ExitStatus)),
+            this, SLOT(slotProcessExited(int, QProcess::ExitStatus)));
+
+    process->start();
+    if (!process->waitForStarted()) {
+        slotProcessExited(127, QProcess::CrashExit);
+    }
+}
 
 KProcessRunner::~KProcessRunner()
 {
-  delete process_;
+    delete process;
 }
 
-  pid_t
-KProcessRunner::pid() const
+int KProcessRunner::pid() const
 {
-  return process_->pid();
+    return process ? process->pid() : 0;
 }
 
-  void
-KProcessRunner::slotProcessExited(KProcess * p)
+void
+KProcessRunner::slotProcessExited(int exitCode, QProcess::ExitStatus exitStatus)
 {
-  if (p != process_)
-    return; // Eh ?
-
-  kDebug(7010) << "slotProcessExited " << binName << endl;
-  kDebug(7010) << "normalExit " << process_->normalExit() << endl;
-  kDebug(7010) << "exitStatus " << process_->exitStatus() << endl;
-  bool showErr = process_->normalExit()
-                 && ( process_->exitStatus() == 127 || process_->exitStatus() == 1 );
-  if ( !binName.isEmpty() && ( showErr || process_->pid() == 0 ) )
-  {
-    // Often we get 1 (zsh, csh) or 127 (ksh, bash) because the binary doesn't exist.
-    // We can't just rely on that, but it's a good hint.
-    // Before assuming its really so, we'll try to find the binName
-    // relatively to current directory,  and then in the PATH.
-    if ( !QFile( binName ).exists() && KStandardDirs::findExe( binName ).isEmpty() )
-    {
-      KGlobal::ref();
-      KMessageBox::sorry( 0L, i18n("Could not find the program '%1'",  binName ) );
-      KGlobal::deref();
+    kDebug(7010) << "slotProcessExited " << binName;
+    kDebug(7010) << "normalExit " << (exitStatus == QProcess::NormalExit);
+    kDebug(7010) << "exitCode " << exitCode;
+    bool showErr = exitStatus == QProcess::NormalExit
+                   && (exitCode == 127 || exitCode == 1);
+    if (!binName.isEmpty() && (showErr || pid() == 0 )) {
+        // Often we get 1 (zsh, csh) or 127 (ksh, bash) because the binary doesn't exist.
+        // We can't just rely on that, but it's a good hint.
+        // Before assuming its really so, we'll try to find the binName
+        // relatively to current directory,  and then in the PATH.
+        if (!QFile(binName).exists() && KStandardDirs::findExe(binName).isEmpty()) {
+            KGlobal::ref();
+            KMessageBox::sorry(0L, i18n("Could not find the program '%1'", binName));
+            KGlobal::deref();
+        }
     }
-  }
 #ifdef Q_WS_X11
-  if( !id_.none())
-  {
-      KStartupInfoData data;
-      data.addPid( pid()); // announce this pid for the startup notification has finished
-      data.setHostname();
-      KStartupInfo::sendFinish( id_, data );
-  }
+    if (!id.none()) {
+        KStartupInfoData data;
+        data.addPid(pid()); // announce this pid for the startup notification has finished
+        data.setHostname();
+        KStartupInfo::sendFinish(id, data);
+    }
 #endif
-  deleteLater();
+    deleteLater();
 }
 
 #include "krun.moc"
+#include "krun_p.moc"
