@@ -19,24 +19,22 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef __k_run_h__
-#define __k_run_h__
+#ifndef KRUN_H
+#define KRUN_H
 
-#include <sys/stat.h>
+#include <kio/kio_export.h>
+
+#include <QtCore/QObject>
+#include <QtCore/QTimer>
+#include <QtCore/QString>
 #include <sys/types.h>
-
-#include <qobject.h>
-#include <qtimer.h>
-#include <qstring.h>
 #include <kurl.h>
-#include <kstartupinfo.h>
 
-class KProcess;
 class KService;
+class KStartupInfo;
 class KJob;
 namespace KIO {
    class Job;
-   class StatJob;
 }
 
 /**
@@ -62,11 +60,12 @@ class KIO_EXPORT KRun : public QObject
   Q_OBJECT
 public:
   /**
+   * @param url the URL of the file or directory to 'run'
+   *
    * @param window
    *        The top-level widget of the app that invoked this object.
    *        It is used to make sure private information like passwords
    *        are properly handled per application.
-   * @param url the URL of the file or directory to 'run'
    *
    * @param mode The @p st_mode field of <tt>struct stat</tt>. If
    *        you don't know this set it to 0.
@@ -83,9 +82,11 @@ public:
    *        Before you set this to false to avoid a dialog box, think about
    *        a very slow FTP server...
    *        It is always better to provide progress info in such cases.
+   * @param asn
+   *        Application startup notification id, if available (otherwise "").
    */
   KRun( const KUrl& url, QWidget* window, mode_t mode = 0,
-	bool isLocalFile = false, bool showProgressInfo = true );
+	bool isLocalFile = false, bool showProgressInfo = true, const QByteArray& asn = "" );
 
   /**
    * Destructor. Don't call it yourself, since a KRun object auto-deletes
@@ -106,14 +107,14 @@ public:
    * @return true when an error occurred
    * @see error()
    */
-  bool hasError() const { return m_bFault; }
+  bool hasError() const;
 
   /**
    * Returns true if the KRun instance has finished.
    * @return true if the KRun instance has finished
    * @see finished()
    */
-  bool hasFinished() const { return m_bFinished; }
+  bool hasFinished() const;
 
   /**
    * Checks whether auto delete is activated.
@@ -122,7 +123,7 @@ public:
    * By default auto deletion is on.
    * @return true if auto deletion is on, false otherwise
    */
-  bool autoDelete() const { return m_bAutoDelete; }
+  bool autoDelete() const;
 
   /**
    * Enables or disabled auto deletion.
@@ -132,7 +133,7 @@ public:
    * By default auto deletion is on.
    * @param b true to enable auto deletion, false to disable
    */
-  void setAutoDelete(bool b) { m_bAutoDelete = b; }
+  void setAutoDelete(bool b);
 
   /**
    * Set the preferred service for opening this URL, after
@@ -185,9 +186,11 @@ public:
    * @param tempFiles if true and urls are local files, they will be deleted
    *        when the application exits.
    * @param suggestedFileName see setSuggestedFileName
-   * @return the process id, or 0 on error
+   * @param asn Application startup notification id, if any (otherwise "").
+   * @return @c true on success, @c false on error
    */
-  static pid_t run( const KService& service, const KUrl::List& urls, QWidget* window, bool tempFiles = false, const QString& suggestedFileName = QString() );
+  static bool run( const KService& service, const KUrl::List& urls, QWidget* window,
+      bool tempFiles = false, const QString& suggestedFileName = QString(), const QByteArray& asn = "" );
 
   /**
    * Open a list of URLs with.
@@ -195,16 +198,17 @@ public:
    * @param exec the name of the executable, for example
    *        "/usr/bin/netscape".
    * @param urls  the list of URLs to open, can be empty (app launched without argument)
+   * @param window The top-level widget of the app that invoked this object.
    * @param name the logical name of the application, for example
    *        "Netscape 4.06".
    * @param icon the icon which should be used by the application.
-   * @param window The top-level widget of the app that invoked this object.
-   * @return the process id, or 0 on error
+   * @param asn Application startup notification id, if any (otherwise "").
+   * @return @c true on success, @c false on error
    */
-  static pid_t run( const QString& exec, const KUrl::List& urls,
+  static bool run( const QString& exec, const KUrl::List& urls, QWidget* window,
                     const QString& name = QString(),
                     const QString& icon = QString(),
-                    QWidget* window = 0 );
+                    const QByteArray& asn = "" );
 
   /**
    * Open the given URL.
@@ -221,9 +225,11 @@ public:
    *        executables and shell scripts will not be run.
    *        See also isExecutable().
    * @param suggestedFileName see setSuggestedFileName
-   * @return the process id, or 0 on error
+   * @param asn Application startup notification id, if any (otherwise "").
+   * @return @c true on success, @c false on error
    */
-  static pid_t runUrl( const KUrl& url, const QString& mimetype, QWidget* window, bool tempFile = false , bool runExecutables = true, const QString& suggestedFileName = QString() );
+  static bool runUrl( const KUrl& url, const QString& mimetype, QWidget* window,
+      bool tempFile = false , bool runExecutables = true, const QString& suggestedFileName = QString(), const QByteArray& asn = "" );
 
   /**
    * Run the given shell command and notifies kicker of the starting
@@ -235,11 +241,11 @@ public:
    *
    * @p cmd must be a shell command. You must not append "&"
    * to it, since the function will do that for you.
+   * @param window The top-level widget of the app that invoked this object.
    *
-   * @return PID of running command, 0 if it could not be started, 0 - (PID
-   * of running command) if command was unsafe for map notification.
+   * @return @c true on success, @c false on error
    */
-  static pid_t runCommand( const QString &cmd );
+  static bool runCommand( const QString &cmd, QWidget* window );
 
   /**
    * Same as the other runCommand(), but it also takes the name of the
@@ -249,10 +255,11 @@ public:
    * to it, since the function will do that for you.
    * @param execName the name of the executable
    * @param icon icon for app starting notification
-   * @return PID of running command, 0 if it could not be started, 0 - (PID
-   * of running command) if command was unsafe for map notification.
+   * @param window The top-level widget of the app that invoked this object.
+   * @param asn Application startup notification id, if any (otherwise "").
+   * @return @c true on success, @c false on error
    */
-  static pid_t runCommand( const QString& cmd, const QString & execName, const QString & icon );
+  static bool runCommand( const QString& cmd, const QString & execName, const QString & icon, QWidget* window, const QByteArray& asn = "" );
 
   /**
    * Display the Open-With dialog for those URLs, and run the chosen application.
@@ -261,15 +268,23 @@ public:
    * @param tempFiles if true and lst are local files, they will be deleted
    *        when the application exits.
    * @param suggestedFileName see setSuggestedFileName
+   * @param asn Application startup notification id, if any (otherwise "").
    * @return false if the dialog was canceled
    */
-  static bool displayOpenWithDialog( const KUrl::List& lst, QWidget* window, bool tempFiles = false, const QString& suggestedFileName = QString() );
+  static bool displayOpenWithDialog( const KUrl::List& lst, QWidget* window,
+      bool tempFiles = false, const QString& suggestedFileName = QString(), const QByteArray& asn = "" );
 
   /**
    * Quotes a string for the shell.
+   * An empty string will @em not be quoted.
+   *
+   * @deprecated Use KShell::quoteArg() instead. @em Note that this function
+   *  behaves differently for empty arguments and returns the result
+   *  differently.
+   *
    * @param str the string to quote. The quoted string will be written here
    */
-  static void shellQuote( QString &str );
+  static KDE_DEPRECATED void shellQuote( QString &str );
 
   /**
    * Processes a Exec= line as found in .desktop files.
@@ -279,7 +294,7 @@ public:
    *        when the application exits.
    * @param suggestedFileName see setSuggestedFileName
    *
-   * @return a list of arguments suitable for either system() or exec().
+   * @return a list of arguments suitable for KProcess::setProgram().
    */
   static QStringList processDesktopExec(const KService &_service, const KUrl::List &_urls, bool tempFiles = false, const QString& suggestedFileName = QString() );
 
@@ -299,7 +314,7 @@ public:
   static bool isExecutable( const QString& serviceType );
 
   /**
-   * Returns wether the @p url of @p mimetype is executable.
+   * Returns whether the @p url of @p mimetype is executable.
    * To be executable the file must pass the following rules:
    * -# Must reside on the local filesystem.
    * -# Must be marked as executable for the user by the filesystem.
@@ -342,7 +357,7 @@ protected:
 
   /**
    * Called if the mimetype has been detected. The function checks
-   * whether the document and appends the gzip protocol to the
+   * whether the document <XXX - what?> and appends the gzip protocol to the
    * URL. Otherwise runUrl is called to finish the job.
    */
   virtual void foundMimeType( const QString& type );
@@ -365,7 +380,7 @@ protected:
   bool m_bIsDirectory;
 
   /**
-   * USed to indicate that the next action is to initialize.
+   * Used to indicate that the next action is to initialize.
    * This action is invoked from slotTimeout
    */
   bool m_bInit;
@@ -375,50 +390,10 @@ protected:
 
 private:
   void init (const KUrl& url, QWidget* window, mode_t mode,
-             bool isLocalFile, bool showProgressInfo);
+             bool isLocalFile, bool showProgressInfo, const QByteArray& asn);
 private:
   class KRunPrivate;
   KRunPrivate* const d;
 };
 
-/**
- * @internal
- * This class watches a process launched by KRun.
- * It sends a notification when the process exits (for the taskbar)
- * and it will show an error message if necessary (e.g. "program not found").
- */
-class KIO_EXPORT KProcessRunner : public QObject
-{
-  Q_OBJECT
-
-  public:
-
-    static pid_t run(KProcess *, const QString & binName);
-#ifdef Q_WS_X11 // We don't have KStartupInfo in Qt/Embedded
-    static pid_t run(KProcess *, const QString & binName, const KStartupInfoId& id );
-#endif
-
-    virtual ~KProcessRunner();
-
-    pid_t pid() const;
-
-  protected Q_SLOTS:
-
-    void slotProcessExited(KProcess *);
-
-  private:
-
-    KProcessRunner(KProcess *, const QString & binName);
-#ifdef Q_WS_X11 // We don't have KStartupInfo in Qt/Embedded
-    KProcessRunner(KProcess *, const QString & binName, const KStartupInfoId& id );
-#endif
-    KProcessRunner();
-
-    KProcess * process_;
-    QString binName;
-#ifdef Q_WS_X11 // We don't have KStartupInfo in Qt/Embedded
-    KStartupInfoId id_;
-#endif
-};
-
 #endif
