@@ -20,6 +20,7 @@
 #ifndef KSCAN_H
 #define KSCAN_H
 
+#include <kio/kio_export.h>
 #include <kpagedialog.h>
 #include <kcomponentdata.h>
 #include <klibloader.h>
@@ -40,7 +41,7 @@ class QImage;
  *
  * \code
  * if ( !m_scanDialog ) {
- *     m_scanDialog = KScanDialog::getScanDialog( this, "scandialog" );
+ *     m_scanDialog = KScanDialog::getScanDialog( this );
  *     if ( !m_scanDialog ) // no scanning support installed?
  *         return;
  *
@@ -101,8 +102,9 @@ protected:
      * @param parent The QWidget's parent, or 0
      * @see KPageDialog
      */
-    KScanDialog( int dialogFace = Tabbed, int buttonMask = Close|Help,
-		 QWidget *parent = 0 );
+    explicit KScanDialog( int dialogFace = Tabbed,
+                          int buttonMask = Close|Help,
+                          QWidget *parent = 0 );
 
     /**
      * Returns the current id for an image. You can use that in your subclass
@@ -115,7 +117,7 @@ protected:
      * @see preview
      * @see textRecognized
      */
-    int id() const { return m_currentId; }
+    int id() const;
 
     /**
      * Returns the id for the next image. You can use that in your subclass
@@ -128,7 +130,7 @@ protected:
      * @see textRecognized
      *
      */
-    int nextId() { return ++m_currentId; }
+    int nextId();
 
 Q_SIGNALS:
     /**
@@ -159,12 +161,9 @@ Q_SIGNALS:
      */
     void textRecognized( const QString &text, int id );
 
-private:
-    int m_currentId;
-
 private:
     class KScanDialogPrivate;
-    KScanDialogPrivate *d;
+    KScanDialogPrivate *const d;
 };
 
 
@@ -201,21 +200,17 @@ protected:
      * Creates a new instance with the given name.
      * @param componentName the name of the instance
      */
-    void setName(const QByteArray &componentName)
-    {
-        m_componentData = KComponentData(componentName);
-    }
+    void setName(const QByteArray &componentName);
 
     /**
      * Returns the instance.
      * @return the KComponentData
      */
-    const KComponentData &componentData() const { return m_componentData; }
+    const KComponentData &componentData() const;
 
 private:
-    KComponentData m_componentData;
-private:
-    class KScanDialogFactoryPrivate* d;
+    class KScanDialogFactoryPrivate;
+    KScanDialogFactoryPrivate * const d;
 };
 
 /**
@@ -248,8 +243,8 @@ protected:
      * @param parent the QWidget's parent, or 0
      * @param modal if true the dialog is model
      */
-    KOCRDialog( int dialogFace=Tabbed, int buttonMask = Close|Help,
-		 QWidget *parent=0L, bool modal=false );
+    explicit KOCRDialog( int dialogFace=Tabbed, int buttonMask = Close|Help,
+                         QWidget *parent=0L, bool modal=false );
 
     /**
      * Returns the current id for an image. You can use that in your subclass
@@ -260,7 +255,7 @@ protected:
      * @see nextId
      * @see textRecognized
      */
-    int id() const { return m_currentId; }
+    int id() const;
 
     /**
      * Returns the id for the next image. You can use that in your subclass
@@ -270,7 +265,7 @@ protected:
      * @see id
      * @see textRecognized
      */
-    int nextId() { return ++m_currentId; }
+    int nextId();
 
 Q_SIGNALS:
     /**
@@ -283,12 +278,9 @@ Q_SIGNALS:
      */
     void textRecognized( const QString &text, int id );
 
-private:
-    int m_currentId;
-
 private:
     class KOCRDialogPrivate;
-    KOCRDialogPrivate *d;
+    KOCRDialogPrivate * const d;
 };
 
 
@@ -327,21 +319,17 @@ protected:
      * Creates a new instance with the given name.
      * @param componentName the name of the instance
      */
-    void setName(const QByteArray &componentName)
-    {
-        m_componentData = KComponentData(componentName);
-    }
+    void setName(const QByteArray &componentName);
 
     /**
      * Returns the instance.
      * @return the KComponentData
      */
-    const KComponentData &componentData() const { return m_componentData; }
+    const KComponentData &componentData() const;
 
 private:
-    KComponentData m_componentData;
-private:
-    class KOCRDialogFactory* d;
+    class KOCRDialogFactoryPrivate;
+    KOCRDialogFactoryPrivate * const d;
 };
 
 
