@@ -17,12 +17,14 @@
    Boston, MA 02110-1301, USA.
 */
 
+#include "ktar.h"
+
 #include <stdlib.h> // strtol
 #include <time.h> // time()
 #include <assert.h>
 
-#include <qdir.h>
-#include <qfile.h>
+#include <QtCore/QDir>
+#include <QtCore/QFile>
 #include <kdebug.h>
 #include <kmimetype.h>
 #include <ktemporaryfile.h>
@@ -30,7 +32,6 @@
 #include <kfilterdev.h>
 #include <kfilterbase.h>
 
-#include "ktar.h"
 #include <kstandarddirs.h>
 
 ////////////////////////////////////////////////////////////////////////
@@ -73,17 +74,19 @@ bool KTar::createDevice( QIODevice::OpenMode mode )
             d->mimetype = KMimeType::findByFileContent( fileName() )->name();
         else
             d->mimetype = KMimeType::findByPath( fileName(), 0, true )->name();
-        kDebug(7041) << "KTar::KTar mimetype = " << d->mimetype << endl;
+        kDebug(7041) << "KTar::KTar mimetype = " << d->mimetype;
 
-        if ( d->mimetype == "application/x-tgz" || d->mimetype == "application/x-targz" || // the latter is deprecated but might still be around
-             d->mimetype == "application/x-webarchive" )
+        if ( d->mimetype == "application/x-compressed-tar"
+             || d->mimetype == "application/x-tgz" // old deprecated name
+             || d->mimetype == "application/x-targz" // old deprecated name
+             || d->mimetype == "application/x-webarchive" )
         {
             // that's a gzipped tar file, so ask for gzip filter
             d->mimetype = "application/x-gzip";
         }
-        else if ( d->mimetype == "application/x-tbz" ) // that's a bzipped2 tar file, so ask for bz2 filter
+        else if ( d->mimetype == "application/x-bzip-compressed-tar" ) // that's a bzipped2 tar file, so ask for bz2 filter
         {
-            d->mimetype = "application/x-bzip2";
+            d->mimetype = "application/x-bzip";
         }
         else
         {
@@ -95,15 +98,15 @@ bool KTar::createDevice( QIODevice::OpenMode mode )
                 if ( file.getChar( &firstByte ) &&
                      file.getChar( &secondByte ) &&
                      file.getChar( &thirdByte ) ) {
-                    if ( firstByte == 0037 && secondByte == static_cast<char>(0213) )
+                    if ( firstByte == 0037 && static_cast<uchar>(secondByte) == static_cast<uchar>(0213) )
                         d->mimetype = "application/x-gzip";
                     else if ( firstByte == 'B' && secondByte == 'Z' && thirdByte == 'h' )
-                        d->mimetype = "application/x-bzip2";
+                        d->mimetype = "application/x-bzip";
                     else if ( firstByte == 'P' && secondByte == 'K' && thirdByte == 3 )
                     {
                         char fourthByte;
                         if ( file.getChar(&fourthByte) && fourthByte == 4 )
-                            d->mimetype = "application/x-zip";
+                            d->mimetype = "application/zip";
                     }
                 }
             }
@@ -132,7 +135,7 @@ bool KTar::createDevice( QIODevice::OpenMode mode )
         d->tmpFile->setPrefix("ktar-");
         d->tmpFile->setSuffix(".tar");
         d->tmpFile->open();
-        kDebug( 7041 ) << "KTar::createDevice creating TempFile: " << d->tmpFile->fileName() << endl;
+        kDebug( 7041 ) << "KTar::createDevice creating TempFile: " << d->tmpFile->fileName();
 
         setDevice( d->tmpFile );
         return true;
@@ -198,7 +201,7 @@ qint64 KTar::readRawHeader( char *buffer ) {
 
 bool KTar::readLonglink(char *buffer,QByteArray &longlink) {
   qint64 n = 0;
-  //kDebug() << k_funcinfo << "reading longlink from pos " << device()->pos()  << endl;
+  //kDebug() << "reading longlink from pos " << device()->pos();
   QIODevice *dev = device();
   // read size of longlink from size field in header
   // size is in bytes including the trailing null (which we ignore)
@@ -264,11 +267,11 @@ bool KTar::KTarPrivate::fillTempFile( const QString & fileName) {
     if ( ! tmpFile )
         return true;
 
-    kDebug( 7041 ) << "KTar::openArchive: filling tmpFile of mimetype '" << mimetype << "'" << endl;
+    kDebug( 7041 ) << "KTar::openArchive: filling tmpFile of mimetype '" << mimetype << "'";
 
     bool forced = false;
     if( "application/x-gzip" == mimetype
-    || "application/x-bzip2" == mimetype)
+    || "application/x-bzip" == mimetype)
         forced = true;
 
     QIODevice *filterDev = KFilterDev::deviceForFile( fileName, mimetype, forced );
@@ -306,9 +309,9 @@ bool KTar::KTarPrivate::fillTempFile( const QString & fileName) {
         Q_ASSERT(file->openMode() & QIODevice::ReadOnly);
     }
     else
-        kDebug( 7041 ) << "KTar::openArchive: no filterdevice found!" << endl;
+        kDebug( 7041 ) << "KTar::openArchive: no filterdevice found!";
 
-    //kDebug( 7041 ) << "KTar::openArchive: filling tmpFile finished." << endl;
+    //kDebug( 7041 ) << "KTar::openArchive: filling tmpFile finished.";
     return true;
 }
 
@@ -386,7 +389,7 @@ bool KTar::openArchive( QIODevice::OpenMode mode ) {
                 isdir = false;
                 isDumpDir = true;
             }
-            //kDebug(7041) << "typeflag=" << typeflag << " islink=" << ( typeflag == '1' || typeflag == '2' ) << endl;
+            //kDebug(7041) << "typeflag=" << typeflag << " islink=" << ( typeflag == '1' || typeflag == '2' );
 
             if (isdir)
                 access |= S_IFDIR; // f*cking broken tar files
@@ -394,7 +397,7 @@ bool KTar::openArchive( QIODevice::OpenMode mode ) {
             KArchiveEntry* e;
             if ( isdir )
             {
-                //kDebug(7041) << "KTar::openArchive directory " << nm << endl;
+                //kDebug(7041) << "KTar::openArchive directory " << nm;
                 e = new KArchiveDirectory( this, nm, access, time, user, group, symlink );
             }
             else
@@ -402,12 +405,12 @@ bool KTar::openArchive( QIODevice::OpenMode mode ) {
                 // read size
                 QByteArray sizeBuffer( buffer + 0x7c, 12 );
                 qint64 size = sizeBuffer.trimmed().toLongLong( 0, 8 /*octal*/ );
-                //kDebug(7041) << "sizeBuffer='" << sizeBuffer << "' -> size=" << size << endl;
+                //kDebug(7041) << "sizeBuffer='" << sizeBuffer << "' -> size=" << size;
 
                 // for isDumpDir we will skip the additional info about that dirs contents
                 if ( isDumpDir )
                 {
-                    //kDebug(7041) << "KTar::openArchive " << nm << " isDumpDir" << endl;
+                    //kDebug(7041) << "KTar::openArchive " << nm << " isDumpDir";
                     e = new KArchiveDirectory( this, nm, access, time, user, group, symlink );
                 }
                 else
@@ -416,11 +419,11 @@ bool KTar::openArchive( QIODevice::OpenMode mode ) {
                     // Let's hack around hard links. Our classes don't support that, so make them symlinks
                     if ( typeflag == '1' )
                     {
-                        kDebug(7041) << "HARD LINK, setting size to 0 instead of " << size << endl;
+                        kDebug(7041) << "HARD LINK, setting size to 0 instead of " << size;
                         size = 0; // no contents
                     }
 
-                    //kDebug(7041) << "KTar::openArchive file " << nm << " size=" << size << endl;
+                    //kDebug(7041) << "KTar::openArchive file " << nm << " size=" << size;
                     e = new KArchiveFile( this, nm, access, time, user, group, symlink,
                                           dev->pos(), size );
                 }
@@ -428,9 +431,9 @@ bool KTar::openArchive( QIODevice::OpenMode mode ) {
                 // Skip contents + align bytes
                 int rest = size % 0x200;
                 int skip = size + (rest ? 0x200 - rest : 0);
-                //kDebug(7041) << "KTar::openArchive, pos()=" << dev->pos() << " rest=" << rest << " skipping " << skip << endl;
+                //kDebug(7041) << "KTar::openArchive, pos()=" << dev->pos() << " rest=" << rest << " skipping " << skip;
                 if (! dev->seek( dev->pos() + skip ) )
-                    kWarning(7041) << "KTar::openArchive skipping " << skip << " failed" << endl;
+                    kWarning(7041) << "KTar::openArchive skipping " << skip << " failed";
             }
 
             if ( pos == -1 )
@@ -472,12 +475,12 @@ bool KTar::KTarPrivate::writeBackTempFile( const QString & fileName ) {
     if ( ! tmpFile )
         return true;
 
-    kDebug(7041) << "Write temporary file to compressed file" << endl;
-    kDebug(7041) << fileName << " " << mimetype << endl;
+    kDebug(7041) << "Write temporary file to compressed file";
+    kDebug(7041) << fileName << " " << mimetype;
 
     bool forced = false;
     if( "application/x-gzip" == mimetype
-        || "application/x-bzip2" == mimetype)
+        || "application/x-bzip" == mimetype)
         forced = true;
 
     // #### TODO this should use KSaveFile to avoid problems on disk full
@@ -508,7 +511,7 @@ bool KTar::KTarPrivate::writeBackTempFile( const QString & fileName ) {
         delete dev;
     }
 
-    kDebug(7041) << "Write temporary file to compressed file done." << endl;
+    kDebug(7041) << "Write temporary file to compressed file done.";
     return true;
 }
 
@@ -707,7 +710,7 @@ bool KTar::doPrepareWriting(const QString &name, const QString &user,
     // zero out the rest (except for what gets filled anyways)
     memset(buffer+0x9d, 0, 0x200 - 0x9d);
 
-    QByteArray permstr = QByteArray::number( perm, 8 );
+    QByteArray permstr = QByteArray::number( (unsigned int)perm, 8 );
     permstr = permstr.rightJustified(6, ' ');
     fillBuffer(buffer, permstr, size, mtime, 0x30, uname, gname);
 
@@ -760,7 +763,7 @@ bool KTar::doWriteDir(const QString &name, const QString &user,
     // zero out the rest (except for what gets filled anyways)
     memset(buffer+0x9d, 0, 0x200 - 0x9d);
 
-    QByteArray permstr = QByteArray::number( perm, 8 );
+    QByteArray permstr = QByteArray::number( (unsigned int)perm, 8 );
     permstr = permstr.rightJustified(6, ' ');
     fillBuffer( buffer, permstr, 0, mtime, 0x35, uname, gname);
 
@@ -817,7 +820,7 @@ bool KTar::doWriteSymLink(const QString &name, const QString &target,
     // zero out the rest
     memset(buffer+0x9d+100, 0, 0x200 - 100 - 0x9d);
 
-    QByteArray permstr = QByteArray::number( perm, 8 );
+    QByteArray permstr = QByteArray::number( (unsigned int)perm, 8 );
     permstr = permstr.rightJustified(6, ' ');
     fillBuffer(buffer, permstr, 0, mtime, 0x32, uname, gname);
 
