@@ -18,6 +18,8 @@
  *  Boston, MA 02110-1301, USA.
  **/
 
+#include "kurifilter.h"
+
 #include <config.h>
 #include <QPixmap>
 
@@ -26,105 +28,113 @@
 #include <kservicetypetrader.h>
 #include <kmimetype.h>
 #include <klibloader.h>
-#include <kstaticdeleter.h>
-
-#include "kurifilter.h"
 
 typedef QList<KUriFilterPlugin *> KUriFilterPluginList;
 
-KUriFilterPlugin::KUriFilterPlugin( const QString & name, QObject *parent )
-    : QObject( parent )
-{
-    setObjectName( name );
-}
-
-void KUriFilterPlugin::setFilteredUri( KUriFilterData& data, const KUrl& uri ) const
-{
-    if ( data.uri() != uri )
-    {
-        data.m_pURI = uri;
-        data.m_bChanged = true;
-    }
-}
-
 class KUriFilterDataPrivate
 {
 public:
-    KUriFilterDataPrivate() {}
+    explicit KUriFilterDataPrivate( const KUrl& url, const QString& typedUrl ) :
+        bCheckForExecutables(true),
+        bChanged(true),
+        pURI(url),
+        iType(KUriFilterData::UNKNOWN),
+        typedString(typedUrl)
+    {
+    }
+    void setData( const KUrl& url, const QString& typedUrl )
+    {
+        bCheckForExecutables = true;
+        bChanged = true;
+        strErrMsg.clear();
+        strIconName.clear();
+        pURI = url;
+        iType = KUriFilterData::UNKNOWN;
+        typedString = typedUrl;
+    }
+    KUriFilterDataPrivate( KUriFilterDataPrivate * data )
+    {
+        iType = data->iType;
+        pURI = data->pURI;
+        strErrMsg = data->strErrMsg;
+        strIconName = data->strIconName;
+        bChanged = data->bChanged;
+        bCheckForExecutables = data->bCheckForExecutables;
+        abs_path = data->abs_path;
+        typedString = data->typedString;
+        args = data->args;
+    }
+    bool bCheckForExecutables;
+    bool bChanged;
+
+    QString strErrMsg;
+    QString strIconName;
+
+    KUrl pURI;
+    KUriFilterData::UriTypes iType;
+
     QString abs_path;
     QString args;
     QString typedString;
 };
 
+KUriFilterData::KUriFilterData()
+    : d( new KUriFilterDataPrivate( KUrl(), QString() ) )
+{
+}
+
+KUriFilterData::KUriFilterData( const KUrl& url )
+    : d( new KUriFilterDataPrivate( url, url.url() ) )
+{
+}
+
+KUriFilterData::KUriFilterData( const QString& url )
+    : d( new KUriFilterDataPrivate( KUrl(url), url ) )
+{
+    d->typedString = url;
+}
+
+
 KUriFilterData::KUriFilterData( const KUriFilterData& data )
+    : d( new KUriFilterDataPrivate( data.d ) )
 {
-    m_iType = data.m_iType;
-    m_pURI = data.m_pURI;
-    m_strErrMsg = data.m_strErrMsg;
-    m_strIconName = data.m_strIconName;
-    m_bChanged = data.m_bChanged;
-    m_bCheckForExecutables = data.m_bCheckForExecutables;
-    d = new KUriFilterDataPrivate;
-    d->abs_path = data.absolutePath();
-    d->typedString = data.typedString();
-    d->args = data.argsAndOptions();
 }
 
 KUriFilterData::~KUriFilterData()
 {
     delete d;
-    d = 0;
 }
 
-void KUriFilterData::init( const KUrl& url )
+KUrl KUriFilterData::uri() const
 {
-    m_iType = KUriFilterData::UNKNOWN;
-    m_pURI = url;
-    m_strErrMsg.clear();
-    m_strIconName.clear();
-    m_bCheckForExecutables = true;
-    m_bChanged = true;
-    d = new KUriFilterDataPrivate;
-    d->typedString = url.url();
+    return d->pURI;
 }
 
-void KUriFilterData::init( const QString& url )
+QString KUriFilterData::errorMsg() const
 {
-    m_iType = KUriFilterData::UNKNOWN;
-    m_pURI = url; // QString -> KUrl
-    m_strErrMsg.clear();
-    m_strIconName.clear();
-    m_bCheckForExecutables = true;
-    m_bChanged = true;
-    d = new KUriFilterDataPrivate;
-    d->typedString = url;
+    return d->strErrMsg;
 }
 
-QString KUriFilterData::typedString() const
+KUriFilterData::UriTypes KUriFilterData::uriType() const
 {
-    return d->typedString;
+    return d->iType;
 }
 
-void KUriFilterData::setCheckForExecutables( bool check )
+void KUriFilterData::setData( const KUrl& url )
 {
-    m_bCheckForExecutables = check;
+    d->setData(url, url.url());
 }
 
-bool KUriFilterData::hasArgsAndOptions() const
+void KUriFilterData::setData( const QString& url )
 {
-    return !d->args.isEmpty();
-}
-
-bool KUriFilterData::hasAbsolutePath() const
-{
-    return !d->abs_path.isEmpty();
+    d->setData(KUrl(url), url);
 }
 
 bool KUriFilterData::setAbsolutePath( const QString& absPath )
 {
     // Since a malformed URL could possibly be a relative
     // URL we tag it as a possible local resource...
-    if( (m_pURI.protocol().isEmpty() || m_pURI.isLocalFile()) )
+    if( (d->pURI.protocol().isEmpty() || d->pURI.isLocalFile()) )
     {
         d->abs_path = absPath;
         return true;
@@ -137,90 +147,175 @@ QString KUriFilterData::absolutePath() const
     return d->abs_path;
 }
 
+bool KUriFilterData::hasAbsolutePath() const
+{
+    return !d->abs_path.isEmpty();
+}
+
 QString KUriFilterData::argsAndOptions() const
 {
     return d->args;
 }
 
+bool KUriFilterData::hasArgsAndOptions() const
+{
+    return !d->args.isEmpty();
+}
+
 QString KUriFilterData::iconName()
 {
-    if( m_bChanged )
+    if( d->bChanged )
     {
-        switch ( m_iType )
+        switch ( d->iType )
         {
             case KUriFilterData::LOCAL_FILE:
             case KUriFilterData::LOCAL_DIR:
             case KUriFilterData::NET_PROTOCOL:
             {
-                m_strIconName = KMimeType::iconNameForUrl( m_pURI );
+                d->strIconName = KMimeType::iconNameForUrl( d->pURI );
                 break;
             }
             case KUriFilterData::EXECUTABLE:
             {
-                QString exeName = m_pURI.url();
+                QString exeName = d->pURI.url();
                 exeName = exeName.mid( exeName.lastIndexOf( '/' ) + 1 ); // strip path if given
                 KService::Ptr service = KService::serviceByDesktopName( exeName );
                 if (service && service->icon() != QLatin1String( "unknown" ))
-                    m_strIconName = service->icon();
+                    d->strIconName = service->icon();
                 // Try to find an icon with the same name as the binary (useful for non-kde apps)
-                else if ( !KIconLoader::global()->loadIcon( exeName, K3Icon::NoGroup, 16, K3Icon::DefaultState, 0, true ).isNull() )
-                    m_strIconName = exeName;
+                else if ( !KIconLoader::global()->loadIcon( exeName, K3Icon::NoGroup, 16, K3Icon::DefaultState, QStringList(), 0, true ).isNull() )
+                    d->strIconName = exeName;
                 else
                     // not found, use default
-                    m_strIconName = QLatin1String("exec");
+                    d->strIconName = QLatin1String("exec");
                 break;
             }
             case KUriFilterData::HELP:
             {
-                m_strIconName = QLatin1String("khelpcenter");
+                d->strIconName = QLatin1String("khelpcenter");
                 break;
             }
             case KUriFilterData::SHELL:
             {
-                m_strIconName = QLatin1String("konsole");
+                d->strIconName = QLatin1String("konsole");
                 break;
             }
             case KUriFilterData::ERROR:
             case KUriFilterData::BLOCKED:
             {
-                m_strIconName = QLatin1String("error");
+                d->strIconName = QLatin1String("error");
                 break;
             }
             default:
-                m_strIconName.clear();
+                d->strIconName.clear();
                 break;
         }
-        m_bChanged = false;
+        d->bChanged = false;
     }
-    return m_strIconName;
+    return d->strIconName;
 }
 
-//********************************************  KUriFilterPlugin **********************************************
-void KUriFilterPlugin::setArguments( KUriFilterData& data, const QString& args ) const
+void KUriFilterData::setCheckForExecutables( bool check )
+{
+    d->bCheckForExecutables = check;
+}
+
+bool KUriFilterData::checkForExecutables() const
+{
+    return d->bCheckForExecutables;
+}
+
+QString KUriFilterData::typedString() const
+{
+    return d->typedString;
+}
+
+KUriFilterData& KUriFilterData::operator=( const KUrl& url )
+{
+    d->setData(url, url.url());
+    return *this;
+}
+
+KUriFilterData& KUriFilterData::operator=( const QString& url )
+{
+    d->setData(KUrl(url), url);
+    return *this;
+}
+
+/*************************  KUriFilterPlugin ******************************/
+
+KUriFilterPlugin::KUriFilterPlugin( const QString & name, QObject *parent )
+    : QObject( parent ), d( 0 )
+{
+    setObjectName( name );
+}
+
+KCModule *KUriFilterPlugin::configModule( QWidget*, const char* ) const
+{
+    return 0;
+}
+
+QString KUriFilterPlugin::configName() const
+{
+    return objectName();
+}
+
+void KUriFilterPlugin::setFilteredUri( KUriFilterData& data, const KUrl& uri ) const
+{
+    if ( data.uri() != uri )
+    {
+        data.d->pURI = uri;
+        data.d->bChanged = true;
+    }
+}
+
+void KUriFilterPlugin::setErrorMsg ( KUriFilterData& data,
+                                     const QString& errmsg ) const
+{
+    data.d->strErrMsg = errmsg;
+}
+
+void KUriFilterPlugin::setUriType ( KUriFilterData& data,
+                                    KUriFilterData::UriTypes type) const
+{
+    data.d->iType = type;
+    data.d->bChanged = true;
+}
+
+void KUriFilterPlugin::setArguments( KUriFilterData& data,
+                                     const QString& args ) const
 {
     data.d->args = args;
 }
 
-//********************************************  KUriFilter **********************************************
-KUriFilter *KUriFilter::m_self;
-static KStaticDeleter<KUriFilter> kurifiltersd;
+/*******************************  KUriFilter ******************************/
+
+class KUriFilterPrivate
+{
+public:
+    KUriFilterPrivate() {}
+    ~KUriFilterPrivate()
+    {
+        qDeleteAll(lstPlugins);
+    }
+    QList<KUriFilterPlugin *> lstPlugins;
+};
 
 KUriFilter *KUriFilter::self()
 {
-    if (!m_self)
-        m_self = kurifiltersd.setObject(m_self, new KUriFilter);
+    K_GLOBAL_STATIC(KUriFilter, m_self)
     return m_self;
 }
 
 KUriFilter::KUriFilter()
+    : d(new KUriFilterPrivate())
 {
     loadPlugins();
 }
 
 KUriFilter::~KUriFilter()
 {
-    qDeleteAll(m_lstPlugins);
-    m_self = 0;
+    delete d;
 }
 
 static KUriFilterPlugin* findPluginByName( const KUriFilterPluginList& lst, const QString& name )
@@ -240,24 +335,24 @@ bool KUriFilter::filterUri( KUriFilterData& data, const QStringList& filters )
     // If we have a filter list, only include the once
     // explicitly specified by it. Otherwise, use all available filters...
     if( filters.isEmpty() )
-        use_plugins = m_lstPlugins;  // Use everything that is loaded...
+        use_plugins = d->lstPlugins;  // Use everything that is loaded...
     else {
-        //kDebug() << "Named plugins requested..."  << endl;
+        //kDebug() << "Named plugins requested...";
         for( QStringList::ConstIterator lst = filters.begin(); lst != filters.end(); ++lst ) {
-            KUriFilterPlugin* plugin = findPluginByName( m_lstPlugins, *lst );
+            KUriFilterPlugin* plugin = findPluginByName( d->lstPlugins, *lst );
             if (plugin) {
-                //kDebug() << "Will use filter plugin named: " << plugin->name() << endl;
+                //kDebug() << "Will use filter plugin named: " << plugin->name();
                 use_plugins.append(plugin);
             }
         }
     }
 
     //kDebug() << "Using " << use_plugins.count() << " out of the "
-    //          << m_lstPlugins.count() << " available plugins" << endl;
+    //          << d->lstPlugins.count() << " available plugins" << endl;
     bool filtered = false;
     for ( KUriFilterPluginList::const_iterator it = use_plugins.begin(), end = use_plugins.end();
           it != end; ++it ) {
-        //kDebug() << "Using a filter plugin named: " << (*it)->name() << endl;
+        //kDebug() << "Using a filter plugin named: " << (*it)->name();
         if( (*it)->filterUri( data ))
             filtered = true;
     }
@@ -266,7 +361,7 @@ bool KUriFilter::filterUri( KUriFilterData& data, const QStringList& filters )
 
 bool KUriFilter::filterUri( KUrl& uri, const QStringList& filters )
 {
-    KUriFilterData data = uri;
+    KUriFilterData data(uri);
     bool filtered = filterUri( data, filters );
     if( filtered ) uri = data.uri();
     return filtered;
@@ -274,7 +369,7 @@ bool KUriFilter::filterUri( KUrl& uri, const QStringList& filters )
 
 bool KUriFilter::filterUri( QString& uri, const QStringList& filters )
 {
-    KUriFilterData data = uri;
+    KUriFilterData data(uri);
     bool filtered = filterUri( data, filters );
     if( filtered )  uri = data.uri().url();
     return filtered;
@@ -282,14 +377,14 @@ bool KUriFilter::filterUri( QString& uri, const QStringList& filters )
 
 KUrl KUriFilter::filteredUri( const KUrl &uri, const QStringList& filters )
 {
-    KUriFilterData data = uri;
+    KUriFilterData data(uri);
     filterUri( data, filters );
     return data.uri();
 }
 
 QString KUriFilter::filteredUri( const QString &uri, const QStringList& filters )
 {
-    KUriFilterData data = uri;
+    KUriFilterData data(uri);
     filterUri( data, filters );
     return data.uri().url();
 }
@@ -297,7 +392,7 @@ QString KUriFilter::filteredUri( const QString &uri, const QStringList& filters
 QStringList KUriFilter::pluginNames() const
 {
     QStringList list;
-    Q_FOREACH( KUriFilterPlugin* plugin, m_lstPlugins )
+    Q_FOREACH( KUriFilterPlugin* plugin, d->lstPlugins )
         list.append(plugin->objectName());
     return list;
 }
@@ -317,7 +412,7 @@ void KUriFilter::loadPlugins()
             // plugins set their name already
             //plugin->setObjectName( (*it)->desktopEntryName() );
             Q_ASSERT( !plugin->objectName().isEmpty() );
-            m_lstPlugins.append( plugin );
+            d->lstPlugins.append( plugin );
         }
     }
 
@@ -327,7 +422,7 @@ void KUriFilter::loadPlugins()
 
     // TODO: Config dialog to differentiate "system"
     // plugins from "user-defined" ones...
-    // m_lstPlugins.sort();
+    // d->lstPlugins.sort();
 }
 
 #include "kurifilter.moc"
