@@ -22,11 +22,12 @@
  *  Boston, MA 02110-1301, USA.
  **/
 
-#ifndef __kurifilter_h__
-#define __kurifilter_h__
+#ifndef KURIFILTER_H
+#define KURIFILTER_H
 
-#include <qobject.h>
-#include <qstringlist.h>
+#include <kio/kio_export.h>
+#include <QtCore/QObject>
+#include <QtCore/QStringList>
 
 #include <kurl.h>
 
@@ -34,7 +35,6 @@
 #undef ERROR
 #endif
 
-class KUriFilterPrivate;
 class KUriFilterDataPrivate;
 
 class KCModule;
@@ -102,21 +102,21 @@ public:
      *
      * Creates a UriFilterData object.
      */
-    KUriFilterData() { init(); }
+    KUriFilterData();
 
     /**
      * Creates a UriFilterData object from the given URL.
      *
      * @param url is the URL to be filtered.
      */
-    KUriFilterData( const KUrl& url ) { init( url); }
+    explicit KUriFilterData( const KUrl& url );
 
     /**
      * Creates a UriFilterData object from the given string.
      *
      * @param url is the string to be filtered.
      */
-    KUriFilterData( const QString& url ) { init( url ); }
+    explicit KUriFilterData( const QString& url );
 
     /**
      * Copy constructor.
@@ -126,7 +126,7 @@ public:
      *
      * @param data the uri filter data to be copied.
      */
-    KUriFilterData( const KUriFilterData& data);
+    KUriFilterData( const KUriFilterData& data );
 
     /**
      * Destructor.
@@ -144,7 +144,7 @@ public:
      *
      * @return the filtered or original url.
      */
-    KUrl uri() const { return m_pURI; }
+    KUrl uri() const;
 
     /**
      * Returns an error message.
@@ -156,7 +156,7 @@ public:
      *
      * @return the error message or a NULL when there is none.
      */
-    QString errorMsg() const { return m_strErrMsg; }
+    QString errorMsg() const;
 
     /**
      * Returns the URI type.
@@ -165,18 +165,7 @@ public:
      * if the given URL was not filtered.
      * @return the type of the URI
      */
-    UriTypes uriType() const { return m_iType; }
-
-    /**
-     * Sets the URL to be filtered.
-     *
-     * Use this function to set the string to be
-     * filtered when you construct an empty filter
-     * object.
-     *
-     * @param url the string to be filtered.
-     */
-    void setData( const QString& url ) { init( url ); }
+    UriTypes uriType() const;
 
     /**
      * Same as above except the argument is a URL.
@@ -187,7 +176,18 @@ public:
      *
      * @param url the URL to be filtered.
      */
-    void setData( const KUrl& url ) { init( url ); }
+    void setData( const KUrl& url );
+
+    /**
+     * Sets the URL to be filtered.
+     *
+     * Use this function to set the string to be
+     * filtered when you construct an empty filter
+     * object.
+     *
+     * @param url the string to be filtered.
+     */
+    void setData( const QString& url );
 
     /**
      * Sets the absolute path to be used whenever the supplied
@@ -261,7 +261,7 @@ public:
      * @return true if the filters should attempt to check whether the
      * supplied uri is an executable. False otherwise.
      */
-    bool checkForExecutables() const { return m_bCheckForExecutables; }
+    bool checkForExecutables() const;
 
     /**
      * @return the string as typed by the user, before any URL processing is done
@@ -276,7 +276,7 @@ public:
      *
      * @return an instance of a KUriFilterData object.
      */
-    KUriFilterData& operator=( const KUrl& url ) { init( url ); return *this; }
+    KUriFilterData& operator=( const KUrl& url );
 
     /**
      * Overloaded assigenment operator.
@@ -286,32 +286,10 @@ public:
      *
      * @return an instance of a KUriFilterData object.
      */
-    KUriFilterData& operator=( const QString& url ) { init( url ); return *this; }
-
-protected:
-
-    /**
-     * Initializes the KUriFilterData on construction.
-     * @param url the URL to initialize the object with
-     */
-    void init( const KUrl& url);
-
-    /**
-     * Initializes the KUriFilterData on construction.
-     * @param url the URL to initialize the object with
-     */
-    void init( const QString& url = QString() );
+    KUriFilterData& operator=( const QString& url );
 
 private:
-    bool m_bCheckForExecutables;
-    bool m_bChanged;
-
-    QString m_strErrMsg;
-    QString m_strIconName;
-
-    KUrl m_pURI;
-    UriTypes m_iType;
-    KUriFilterDataPrivate *d;
+    KUriFilterDataPrivate * const d;
 };
 
 
@@ -339,7 +317,7 @@ public:
      * @param parent the parent object, or 0 for no parent
      * @param name the name of the plugin, mandatory
      */
-    KUriFilterPlugin( const QString &name, QObject *parent = 0 );
+    explicit KUriFilterPlugin( const QString &name, QObject *parent = 0 );
 
     /**
      * Filters a URI.
@@ -357,14 +335,14 @@ public:
      *
      * @return A configuration module, 0 if the filter isn't configurable.
      */
-    virtual KCModule *configModule( QWidget*, const char* ) const { return 0; }
+    virtual KCModule *configModule( QWidget*, const char* ) const;
 
     /**
      * Returns the name of the configuration module for the filter.
      *
      * @return the name of a configuration module or QString() if none.
      */
-    virtual QString configName() const { return objectName(); }
+    virtual QString configName() const;
 
 protected:
 
@@ -376,17 +354,12 @@ protected:
     /**
      * Sets the error message in @p data to @p errormsg.
      */
-    void setErrorMsg ( KUriFilterData& data, const QString& errmsg ) const {
-        data.m_strErrMsg = errmsg;
-    }
+    void setErrorMsg ( KUriFilterData& data, const QString& errmsg ) const;
 
     /**
      * Sets the URI type in @p data to @p type.
      */
-    void setUriType ( KUriFilterData& data, KUriFilterData::UriTypes type) const {
-        data.m_iType = type;
-        data.m_bChanged = true;
-    }
+    void setUriType ( KUriFilterData& data, KUriFilterData::UriTypes type) const;
 
     /**
      * Sets the arguments and options string in @p data
@@ -395,10 +368,11 @@ protected:
     void setArguments( KUriFilterData& data, const QString& args ) const;
 
 private:
-    class KUriFilterPluginPrivate *d;
+    class KUriFilterPluginPrivate * const d;
 };
 
 
+class KUriFilterPrivate;
 /**
  * Manages the filtering of URIs.
  *
@@ -575,9 +549,7 @@ protected:
     void loadPlugins();
 
 private:
-    static KUriFilter *m_self;
-    QList<KUriFilterPlugin *> m_lstPlugins;
-    KUriFilterPrivate *d;
+    KUriFilterPrivate * const d;
 };
 
 #endif
