@@ -31,14 +31,14 @@
 #include <assert.h>
 #include <limits.h>
 
-#include <qstringlist.h>
-#include <qregexp.h>
-#include <qtimer.h>
-#include <qdir.h>
-#include <qfile.h>
-#include <qtextstream.h>
-#include <qthread.h>
-#include <qevent.h>
+#include <QtCore/QMutableStringListIterator>
+#include <QtCore/QRegExp>
+#include <QtCore/QTimer>
+#include <QtCore/QDir>
+#include <QtCore/QFile>
+#include <QtCore/QTextIStream>
+#include <QtCore/QThread>
+#include <QtGui/QActionEvent>
 
 #include <kapplication.h>
 #include <kauthorized.h>
@@ -207,7 +207,7 @@ void DirectoryListThread::run()
 		if ( !dir ) {
 			dir = ::opendir( QFile::encodeName( *it ) );
 			if ( ! dir ) {
-				kDebug() << "Failed to open dir: " << *it << endl;
+				kDebug() << "Failed to open dir: " << *it;
 				return;
 			}
 		}
@@ -276,7 +276,7 @@ void DirectoryListThread::run()
 
 					}
 					else {
-						kDebug() << "Could not stat file " << file << endl;
+						kDebug() << "Could not stat file " << file;
 						continue;
 					}
 				}
@@ -570,7 +570,7 @@ void KUrlCompletion::setReplaceHome( bool replace )
  */
 QString KUrlCompletion::makeCompletion(const QString &text)
 {
-	//kDebug() << "KUrlCompletion::makeCompletion: " << text << " d->cwd=" << d->cwd << endl;
+	//kDebug() << "KUrlCompletion::makeCompletion: " << text << " d->cwd=" << d->cwd;
 
 	MyURL url(text, d->cwd);
 
@@ -842,7 +842,7 @@ bool KUrlCompletion::exeCompletion(const MyURL &url, QString *pMatch)
 	}
 
 	// No hidden files unless the user types "."
-	bool no_hidden_files = url.file().at(0) != QLatin1Char('.');
+	bool no_hidden_files = url.file().isEmpty() || url.file().at(0) != QLatin1Char('.');
 
 	// List files if needed
 	//
@@ -895,7 +895,7 @@ bool KUrlCompletion::fileCompletion(const MyURL &url, QString *pMatch)
 		}
 	}
 
-	//kDebug() << "fileCompletion " << url.url() << " dir=" << dir << endl;
+	//kDebug() << "fileCompletion " << url.url() << " dir=" << dir;
 
 	// Find directories to search for completions, either
 	//
@@ -953,7 +953,7 @@ bool KUrlCompletion::fileCompletion(const MyURL &url, QString *pMatch)
 
 bool KUrlCompletion::urlCompletion(const MyURL &url, QString *pMatch)
 {
-	//kDebug() << "urlCompletion: url = " << *url.kurl() << endl;
+	//kDebug() << "urlCompletion: url = " << *url.kurl();
 	if (d->onlyLocalProto && KProtocolInfo::protocolClass(url.protocol()) != QLatin1String(":local"))
 		return false;
 
@@ -1061,7 +1061,7 @@ QString KUrlCompletion::listDirectories(
 
 	if ( !::getenv("KURLCOMPLETION_LOCAL_KIO") ) {
 
-		//kDebug() << "Listing (listDirectories): " << dirList << " filter=" << filter << " without KIO" << endl;
+		//kDebug() << "Listing (listDirectories): " << dirList << " filter=" << filter << " without KIO";
 
 		// Don't use KIO
 
@@ -1090,7 +1090,7 @@ QString KUrlCompletion::listDirectories(
 	}
 
 	// Use KIO
-	//kDebug() << "Listing (listDirectories): " << dirList << " with KIO" << endl;
+	//kDebug() << "Listing (listDirectories): " << dirList << " with KIO";
 
 	QList<KUrl*> url_list;
 
@@ -1128,7 +1128,7 @@ void KUrlCompletion::listUrls(
 	d->list_urls_only_exe = only_exe;
 	d->list_urls_no_hidden = no_hidden;
 
-//	kDebug() << "Listing URLs: " << urls[0]->prettyUrl() << ",..." << endl;
+//	kDebug() << "Listing URLs: " << urls[0]->prettyUrl() << ",...";
 
 	// Start it off by calling slotIOFinished
 	//
@@ -1158,19 +1158,19 @@ void KUrlCompletion::slotEntries(KIO::Job*, const KIO::UDSEntryList& entries)
 	//
 	for (; it != end; ++it) {
 		const KIO::UDSEntry& entry = *it;
-		const QString url = entry.stringValue( KIO::UDS_URL );
+		const QString url = entry.stringValue( KIO::UDSEntry::UDS_URL );
 
 		QString entry_name;
 		if (!url.isEmpty()) {
-			// kDebug() << "KUrlCompletion::slotEntries url: " << url << endl;
+			// kDebug() << "KUrlCompletion::slotEntries url: " << url;
 			entry_name = KUrl(url).fileName();
 		} else {
-			entry_name = entry.stringValue( KIO::UDS_NAME );
+			entry_name = entry.stringValue( KIO::UDSEntry::UDS_NAME );
 		}
 
-		// kDebug() << "KUrlCompletion::slotEntries name: " << name << endl;
+		// kDebug() << "KUrlCompletion::slotEntries name: " << name;
 
-		if ( entry_name.at(0) == QLatin1Char('.') &&
+		if ( (!entry_name.isEmpty() && entry_name.at(0) == QLatin1Char('.')) &&
 		     ( d->list_urls_no_hidden ||
 		        entry_name.length() == 1 ||
 		          ( entry_name.length() == 2 && entry_name.at(1) == QLatin1Char('.') ) ) )
@@ -1185,7 +1185,7 @@ void KUrlCompletion::slotEntries(KIO::Job*, const KIO::UDSEntryList& entries)
 			if ( isDir )
 				entry_name.append( QLatin1Char( '/' ) );
 
-			const bool isExe = entry.numberValue( KIO::UDS_ACCESS ) & MODE_EXE;
+			const bool isExe = entry.numberValue( KIO::UDSEntry::UDS_ACCESS ) & MODE_EXE;
 			if ( isExe || !d->list_urls_only_exe )
 				matchList.append( entry_name );
 		}
@@ -1204,7 +1204,7 @@ void KUrlCompletion::slotEntries(KIO::Job*, const KIO::UDSEntryList& entries)
  */
 void KUrlCompletion::slotIOFinished( KJob * job )
 {
-//	kDebug() << "slotIOFinished() " << endl;
+//	kDebug() << "slotIOFinished() ";
 
 	assert( job == d->list_job );
 
@@ -1221,7 +1221,7 @@ void KUrlCompletion::slotIOFinished( KJob * job )
 
 //		d->list_urls.removeAll( kurl );
 
-//		kDebug() << "Start KIO: " << kurl->prettyUrl() << endl;
+//		kDebug() << "Start KIO: " << kurl->prettyUrl();
 
 		d->list_job = KIO::listDir( *kurl, false );
 		d->list_job->addMetaData("no-auth-prompt", "true");
@@ -1253,7 +1253,7 @@ void KUrlCompletion::slotIOFinished( KJob * job )
  */
 void KUrlCompletion::postProcessMatch( QString *pMatch ) const
 {
-//	kDebug() << "KUrlCompletion::postProcess: " << *pMatch << endl;
+//	kDebug() << "KUrlCompletion::postProcess: " << *pMatch;
 
 	if ( !pMatch->isEmpty() ) {
 
@@ -1274,7 +1274,7 @@ void KUrlCompletion::postProcessMatch( QString *pMatch ) const
 			if ( QDir::isRelativePath(copy) )
 				copy.prepend( d->cwd + QLatin1Char('/') );
 
-//			kDebug() << "postProcess: stating " << copy << endl;
+//			kDebug() << "postProcess: stating " << copy;
 
 			KDE_struct_stat sbuff;
 
@@ -1285,7 +1285,7 @@ void KUrlCompletion::postProcessMatch( QString *pMatch ) const
 					pMatch->append( QLatin1Char( '/' ) );
 			}
 			else {
-				kDebug() << "Could not stat file " << copy << endl;
+				kDebug() << "Could not stat file " << copy;
 			}
 		}
 	}
@@ -1373,7 +1373,7 @@ static bool expandEnv( QString &text )
 
 		// Skip escaped '$'
 		//
-		if ( pos >= 0 && text.at(pos-1) == QLatin1Char('\\') ) {
+		if ( pos > 0 && text.at(pos-1) == QLatin1Char('\\') ) {
 			pos++;
 		}
 		// Variable found => expand
