@@ -27,7 +27,7 @@ QPixmap KUrlPixmapProvider::pixmapFor( const QString& url, int size ) {
 	    u.setPath( url );
 	else
 	    u = url;
-	return KIO::pixmapForURL( u, 0, K3Icon::Desktop, size );
+	return KIO::pixmapForUrl( u, 0, K3Icon::Desktop, size );
     }
 
 void KUrlPixmapProvider::virtual_hook( int id, void* data )
