@@ -18,29 +18,35 @@
     Boston, MA 02110-1301, USA.
  */
 
+#include "metainfojob.h"
+
 #include <kfileitem.h>
 #include <kdebug.h>
 #include <kfilemetainfo.h>
 #include <kservicetypetrader.h>
 
-#include <qtimer.h>
+#include <QtCore/QTimer>
 
-#include "metainfojob.moc"
+#include "jobuidelegate.h"
+#include "job_p.h"
 
 using namespace KIO;
 
-struct KIO::MetaInfoJobPrivate
+class KIO::MetaInfoJobPrivate: public KIO::JobPrivate
 {
-    KFileItemList          items;       // all the items we got
+public:
+    QList<KFileItem>       items;       // all the items we got
     int                    currentItem;
-    bool                   deleteItems; // Delete the KFileItems when done?
     bool                   succeeded;   // if the current item is ok
+
+    Q_DECLARE_PUBLIC(MetaInfoJob)
 };
 
-MetaInfoJob::MetaInfoJob(const KFileItemList &items, bool deleteItems)
-    : KIO::Job(false /* no GUI */),d(new MetaInfoJobPrivate)
+MetaInfoJob::MetaInfoJob(const QList<KFileItem>& items, KFileMetaInfo::WhatFlags,
+     int, int, const QStringList&, const QStringList&)
+    : KIO::Job(*new MetaInfoJobPrivate)
 {
-    d->deleteItems  = deleteItems;
+    Q_D(MetaInfoJob);
     d->succeeded    = false;
     d->items        = items;
     d->currentItem  = 0;
@@ -61,9 +67,6 @@ MetaInfoJob::MetaInfoJob(const KFileItemList &items, bool deleteItems)
 
 MetaInfoJob::~MetaInfoJob()
 {
-    if ( d->deleteItems )
-        qDeleteAll( d->items );
-    delete d;
 }
 
 void MetaInfoJob::start()
@@ -71,8 +74,9 @@ void MetaInfoJob::start()
     getMetaInfo();
 }
 
-void MetaInfoJob::removeItem(const KFileItem* item)
+void MetaInfoJob::removeItem(const KFileItem& item)
 {
+    Q_D(MetaInfoJob);
     if (d->items.at( d->currentItem ) == item)
     {
         KJob* job = subjobs().first();
@@ -81,11 +85,12 @@ void MetaInfoJob::removeItem(const KFileItem* item)
         determineNextFile();
     }
 
-    d->items.removeAll(const_cast<KFileItem *>(item));
+    d->items.removeAll(item);
 }
 
 void MetaInfoJob::determineNextFile()
 {
+    Q_D(MetaInfoJob);
     if (d->currentItem >= d->items.count() - 1)
     {
         kDebug(7007) << "finished MetaInfoJob\n";
@@ -97,8 +102,8 @@ void MetaInfoJob::determineNextFile()
     d->succeeded = false;
 
     // does the file item already have the needed info? Then shortcut
-    KFileItem* item = d->items.at( d->currentItem );
-    if (item->metaInfo(false).isValid())
+    KFileItem item = d->items.at( d->currentItem );
+    if (item.metaInfo(false).isValid())
     {
 //        kDebug(7007) << "Is already valid *************************\n";
         emit gotMetaInfo(item);
@@ -119,12 +124,13 @@ void MetaInfoJob::slotResult( KJob *job )
 
 void MetaInfoJob::getMetaInfo()
 {
-    KFileItem* item = d->items.at( d->currentItem );
-    Q_ASSERT(item);
+    Q_D(MetaInfoJob);
+    KFileItem item = d->items.at( d->currentItem );
+    Q_ASSERT(!item.isNull());
 
     KUrl URL;
     URL.setProtocol("metainfo");
-    URL.setPath(item->url().path());
+    URL.setPath(item.url().path());
 
     KIO::TransferJob* job = KIO::get(URL, false, false);
     addSubjob(job);
@@ -132,51 +138,39 @@ void MetaInfoJob::getMetaInfo()
     connect(job,  SIGNAL(data(KIO::Job *, const QByteArray &)),
             this, SLOT(slotMetaInfo(KIO::Job *, const QByteArray &)));
 
-    job->addMetaData("mimeType", item->mimetype());
+    job->addMetaData("mimeType", item.mimetype());
 }
 
 
 void MetaInfoJob::slotMetaInfo(KIO::Job*, const QByteArray &data)
 {
+    Q_D(MetaInfoJob);
     KFileMetaInfo info;
     QDataStream s(data);
 
     s >> info;
 
-    KFileItem* item = d->items.at( d->currentItem );
-    item->setMetaInfo(info);
+    KFileItem item = d->items.at( d->currentItem );
+    item.setMetaInfo(info);
     emit gotMetaInfo(item);
     d->succeeded = true;
 }
 
-QStringList MetaInfoJob::availablePlugins()
+KIO_EXPORT MetaInfoJob *KIO::fileMetaInfo( const QList<KFileItem>& items)
 {
-    QStringList result;
-    const KService::List plugins = KServiceTypeTrader::self()->query("KFilePlugin");
-    for (KService::List::ConstIterator it = plugins.begin(); it != plugins.end(); ++it)
-        result.append((*it)->desktopEntryName());
-    return result;
-}
-
-QStringList MetaInfoJob::supportedMimeTypes()
-{
-    QStringList result;
-    const KService::List plugins = KServiceTypeTrader::self()->query("KFilePlugin");
-    for (KService::List::ConstIterator it = plugins.begin(); it != plugins.end(); ++it)
-        result += (*it)->property("MimeTypes").toStringList();
-    return result;
-}
-
-KIO_EXPORT MetaInfoJob *KIO::fileMetaInfo( const KFileItemList &items)
-{
-    return new MetaInfoJob(items, false);
+    return new MetaInfoJob(items);
 }
 
 KIO_EXPORT MetaInfoJob *KIO::fileMetaInfo( const KUrl::List &items)
 {
-    KFileItemList fileItems;
-    for (KUrl::List::ConstIterator it = items.begin(); it != items.end(); ++it)
-        fileItems.append(new KFileItem(KFileItem::Unknown, KFileItem::Unknown, *it, true));
-    return new MetaInfoJob(fileItems, true);
+    QList<KFileItem> fileItems;
+    foreach (const KUrl& url, items) {
+        fileItems.append(KFileItem(KFileItem::Unknown, KFileItem::Unknown, url,
+            true));
+    }
+    MetaInfoJob *job = new MetaInfoJob(fileItems);
+    job->setUiDelegate(new JobUiDelegate());
+    return job;
 }
 
+#include "metainfojob.moc"
