@@ -20,6 +20,8 @@
     Boston, MA 02110-1301, USA.
 */
 
+#include "netaccess.h"
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <signal.h>
@@ -27,11 +29,11 @@
 
 #include <cstring>
 
-#include <qstring.h>
-#include <qapplication.h>
-#include <qfile.h>
-#include <qmetaobject.h>
-#include <qtextstream.h>
+#include <QtCore/QCharRef>
+#include <QtGui/QApplication>
+#include <QtCore/QFile>
+#include <QtCore/QMetaClassInfo>
+#include <QtCore/QTextIStream>
 
 #include <kapplication.h>
 #include <klocale.h>
@@ -39,19 +41,56 @@
 #include <kdebug.h>
 #include <kurl.h>
 #include <kstandarddirs.h>
-#include <kio/job.h>
-#include <kio/copyjob.h>
-#include <kio/deletejob.h>
-#include <kio/jobuidelegate.h>
-#include <kio/scheduler.h>
 
-#include "kio/netaccess.h"
+#include "job.h"
+#include "copyjob.h"
+#include "deletejob.h"
+#include "jobuidelegate.h"
+#include "scheduler.h"
+
+namespace KIO
+{
+    class NetAccessPrivate
+    {
+    public:
+        NetAccessPrivate()
+            : m_metaData(0)
+            , bJobOK(true)
+        {}
+        UDSEntry m_entry;
+        QString m_mimetype;
+        QByteArray m_data;
+        KUrl m_url;
+        QMap<QString, QString> *m_metaData;
+
+        /**
+         * Whether the download succeeded or not
+         */
+        bool bJobOK;
+    };
+
+} // namespace KIO
 
 using namespace KIO;
 
-QString * NetAccess::lastErrorMsg;
-int NetAccess::lastErrorCode = 0;
-QStringList* NetAccess::tmpfiles;
+
+/**
+ * List of temporary files
+ */
+static QStringList* tmpfiles;
+
+static QString* lastErrorMsg = 0;
+static int lastErrorCode = 0;
+
+NetAccess::NetAccess() :
+    d( new NetAccessPrivate )
+{
+}
+
+NetAccess::~NetAccess()
+{
+    delete d;
+}
 
 bool NetAccess::download(const KUrl& u, QString & target, QWidget* window)
 {
@@ -107,7 +146,14 @@ bool NetAccess::upload(const QString& src, const KUrl& target, QWidget* window)
 
 bool NetAccess::file_copy( const KUrl & src, const KUrl & target, QWidget* window )
 {
-  return NetAccess::file_copy( src, target, -1, false /*not overwrite*/, false, window );
+  NetAccess kioNet;
+  return kioNet.filecopyInternal( src, target, -1, false /*not overwrite*/, false /*resume*/,
+                                  window, false /*copy*/ );
+}
+
+bool NetAccess::copy( const KUrl& src, const KUrl& target, QWidget* window )
+{
+    return file_copy( src, target, window );
 }
 
 bool NetAccess::file_copy( const KUrl& src, const KUrl& target, int permissions,
@@ -144,7 +190,8 @@ bool NetAccess::move( const KUrl& src, const KUrl& target, QWidget* window )
 {
   KUrl::List srcList;
   srcList.append( src );
-  return NetAccess::move( srcList, target, window );
+  NetAccess kioNet;
+  return kioNet.dircopyInternal( srcList, target, window, true /*move*/ );
 }
 
 bool NetAccess::move( const KUrl::List& srcList, const KUrl& target, QWidget* window )
@@ -158,15 +205,24 @@ bool NetAccess::exists( const KUrl & url, bool source, QWidget* window )
   if ( url.isLocalFile() )
     return QFile::exists( url.path() );
   NetAccess kioNet;
-  return kioNet.statInternal( url, 0 /*no details*/, source, window );
+  return kioNet.statInternal( url, 0 /*no details*/,
+                              source ? SourceSide : DestinationSide, window );
+}
+
+bool NetAccess::exists( const KUrl & url, StatSide side, QWidget* window )
+{
+  if ( url.isLocalFile() )
+    return QFile::exists( url.path() );
+  NetAccess kioNet;
+  return kioNet.statInternal( url, 0 /*no details*/, side, window );
 }
 
 bool NetAccess::stat( const KUrl & url, KIO::UDSEntry & entry, QWidget* window )
 {
   NetAccess kioNet;
-  bool ret = kioNet.statInternal( url, 2 /*all details*/, true /*source*/, window );
+  bool ret = kioNet.statInternal( url, 2 /*all details*/, SourceSide, window );
   if (ret)
-    entry = kioNet.m_entry;
+    entry = kioNet.d->m_entry;
   return ret;
 }
 
@@ -183,7 +239,7 @@ KUrl NetAccess::mostLocalUrl(const KUrl & url, QWidget* window)
     return url;
   }
 
-  const QString path = entry.stringValue( KIO::UDS_LOCAL_PATH );
+  const QString path = entry.stringValue( KIO::UDSEntry::UDS_LOCAL_PATH );
   if ( !path.isEmpty() )
   {
     KUrl new_url;
@@ -206,7 +262,7 @@ bool NetAccess::mkdir( const KUrl & url, QWidget* window, int permissions )
   return kioNet.mkdirInternal( url, permissions, window );
 }
 
-QString NetAccess::fish_execute( const KUrl & url, const QString command, QWidget* window )
+QString NetAccess::fish_execute( const KUrl & url, const QString &command, QWidget* window )
 {
   NetAccess kioNet;
   return kioNet.fish_executeInternal( url, command, window );
@@ -225,6 +281,16 @@ QString NetAccess::mimetype( const KUrl& url, QWidget* window )
   return kioNet.mimetypeInternal( url, window );
 }
 
+QString NetAccess::lastErrorString()
+{
+    return lastErrorMsg ? *lastErrorMsg : QString();
+}
+
+int NetAccess::lastError()
+{
+    return lastErrorCode;
+}
+
 void NetAccess::removeTempFile(const QString& name)
 {
   if (!tmpfiles)
@@ -239,7 +305,7 @@ void NetAccess::removeTempFile(const QString& name)
 bool NetAccess::filecopyInternal(const KUrl& src, const KUrl& target, int permissions,
                                  bool overwrite, bool resume, QWidget* window, bool move)
 {
-  bJobOK = true; // success unless further error occurs
+  d->bJobOK = true; // success unless further error occurs
 
   KIO::Scheduler::checkSlaveOnHold(true);
   KIO::Job * job = move
@@ -250,13 +316,13 @@ bool NetAccess::filecopyInternal(const KUrl& src, const KUrl& target, int permis
            this, SLOT( slotResult (KJob *) ) );
 
   enter_loop();
-  return bJobOK;
+  return d->bJobOK;
 }
 
 bool NetAccess::dircopyInternal(const KUrl::List& src, const KUrl& target,
                                 QWidget* window, bool move)
 {
-  bJobOK = true; // success unless further error occurs
+  d->bJobOK = true; // success unless further error occurs
 
   KIO::Job * job = move
                    ? KIO::move( src, target )
@@ -266,50 +332,50 @@ bool NetAccess::dircopyInternal(const KUrl::List& src, const KUrl& target,
            this, SLOT( slotResult (KJob *) ) );
 
   enter_loop();
-  return bJobOK;
+  return d->bJobOK;
 }
 
-bool NetAccess::statInternal( const KUrl & url, int details, bool source,
+bool NetAccess::statInternal( const KUrl & url, int details, StatSide side,
                               QWidget* window )
 {
-  bJobOK = true; // success unless further error occurs
+  d->bJobOK = true; // success unless further error occurs
   KIO::StatJob * job = KIO::stat( url, !url.isLocalFile() );
   job->ui()->setWindow (window);
   job->setDetails( details );
-  job->setSide( source );
+  job->setSide( side == SourceSide ? StatJob::SourceSide : StatJob::DestinationSide );
   connect( job, SIGNAL( result (KJob *) ),
            this, SLOT( slotResult (KJob *) ) );
   enter_loop();
-  return bJobOK;
+  return d->bJobOK;
 }
 
 bool NetAccess::delInternal( const KUrl & url, QWidget* window )
 {
-  bJobOK = true; // success unless further error occurs
+  d->bJobOK = true; // success unless further error occurs
   KIO::Job * job = KIO::del( url );
   job->ui()->setWindow (window);
   connect( job, SIGNAL( result (KJob *) ),
            this, SLOT( slotResult (KJob *) ) );
   enter_loop();
-  return bJobOK;
+  return d->bJobOK;
 }
 
 bool NetAccess::mkdirInternal( const KUrl & url, int permissions,
                                QWidget* window )
 {
-  bJobOK = true; // success unless further error occurs
+  d->bJobOK = true; // success unless further error occurs
   KIO::Job * job = KIO::mkdir( url, permissions );
   job->ui()->setWindow (window);
   connect( job, SIGNAL( result (KJob *) ),
            this, SLOT( slotResult (KJob *) ) );
   enter_loop();
-  return bJobOK;
+  return d->bJobOK;
 }
 
 QString NetAccess::mimetypeInternal( const KUrl & url, QWidget* window )
 {
-  bJobOK = true; // success unless further error occurs
-  m_mimetype = QLatin1String("unknown");
+  d->bJobOK = true; // success unless further error occurs
+  d->m_mimetype = QLatin1String("unknown");
   KIO::Job * job = KIO::mimetype( url );
   job->ui()->setWindow (window);
   connect( job, SIGNAL( result (KJob *) ),
@@ -317,15 +383,15 @@ QString NetAccess::mimetypeInternal( const KUrl & url, QWidget* window )
   connect( job, SIGNAL( mimetype (KIO::Job *, const QString &) ),
            this, SLOT( slotMimetype (KIO::Job *, const QString &) ) );
   enter_loop();
-  return m_mimetype;
+  return d->m_mimetype;
 }
 
 void NetAccess::slotMimetype( KIO::Job *, const QString & type  )
 {
-  m_mimetype = type;
+  d->m_mimetype = type;
 }
 
-QString NetAccess::fish_executeInternal(const KUrl & url, const QString command, QWidget* window)
+QString NetAccess::fish_executeInternal(const KUrl & url, const QString &command, QWidget* window)
 {
   QString target, remoteTempFileName, resultData;
   KUrl tempPathUrl;
@@ -342,7 +408,7 @@ QString NetAccess::fish_executeInternal(const KUrl & url, const QString command,
     int pos = remoteTempFileName.lastIndexOf('/');
     remoteTempFileName = "/tmp/fishexec_" + remoteTempFileName.mid(pos + 1);
     tempPathUrl.setPath( remoteTempFileName );
-    bJobOK = true; // success unless further error occurs
+    d->bJobOK = true; // success unless further error occurs
     QByteArray packedArgs;
     QDataStream stream( &packedArgs, QIODevice::WriteOnly );
 
@@ -380,9 +446,9 @@ bool NetAccess::synchronousRunInternal( Job* job, QWidget* window, QByteArray* d
 {
   if ( job->ui() ) job->ui()->setWindow( window );
 
-  m_metaData = metaData;
-  if ( m_metaData ) {
-      for ( QMap<QString, QString>::iterator it = m_metaData->begin(); it != m_metaData->end(); ++it ) {
+  d->m_metaData = metaData;
+  if ( d->m_metaData ) {
+      for ( QMap<QString, QString>::iterator it = d->m_metaData->begin(); it != d->m_metaData->end(); ++it ) {
           job->addMetaData( it.key(), it.value() );
       }
   }
@@ -390,7 +456,7 @@ bool NetAccess::synchronousRunInternal( Job* job, QWidget* window, QByteArray* d
   if ( finalURL ) {
       SimpleJob *sj = qobject_cast<SimpleJob*>( job );
       if ( sj ) {
-          m_url = sj->url();
+          d->m_url = sj->url();
       }
   }
 
@@ -414,11 +480,11 @@ bool NetAccess::synchronousRunInternal( Job* job, QWidget* window, QByteArray* d
   enter_loop();
 
   if ( finalURL )
-      *finalURL = m_url;
+      *finalURL = d->m_url;
   if ( data )
-      *data = m_data;
+      *data = d->m_data;
 
-  return bJobOK;
+  return d->bJobOK;
 }
 
 void NetAccess::enter_loop()
@@ -432,8 +498,8 @@ void NetAccess::enter_loop()
 void NetAccess::slotResult( KJob * job )
 {
   lastErrorCode = job->error();
-  bJobOK = !job->error();
-  if ( !bJobOK )
+  d->bJobOK = !job->error();
+  if ( !d->bJobOK )
   {
     if ( !lastErrorMsg )
       lastErrorMsg = new QString;
@@ -441,11 +507,11 @@ void NetAccess::slotResult( KJob * job )
   }
   KIO::StatJob* statJob = qobject_cast<KIO::StatJob *>( job );
   if ( statJob )
-    m_entry = statJob->statResult();
+    d->m_entry = statJob->statResult();
 
   KIO::Job* kioJob = qobject_cast<KIO::Job *>( job );
-  if ( kioJob && m_metaData )
-    *m_metaData = kioJob->metaData();
+  if ( kioJob && d->m_metaData )
+    *d->m_metaData = kioJob->metaData();
 
   emit leaveModality();
 }
@@ -455,14 +521,14 @@ void NetAccess::slotData( KIO::Job*, const QByteArray& data )
   if ( data.isEmpty() )
     return;
 
-  unsigned offset = m_data.size();
-  m_data.resize( offset + data.size() );
-  std::memcpy( m_data.data() + offset, data.data(), data.size() );
+  unsigned offset = d->m_data.size();
+  d->m_data.resize( offset + data.size() );
+  std::memcpy( d->m_data.data() + offset, data.data(), data.size() );
 }
 
 void NetAccess::slotRedirection( KIO::Job*, const KUrl& url )
 {
-  m_url = url;
+  d->m_url = url;
 }
 
 #include "netaccess.moc"
