@@ -20,12 +20,13 @@
     Boston, MA 02110-1301, USA.
 */
 
-#ifndef __kio_netaccess_h
-#define __kio_netaccess_h
+#ifndef KIO_NETACCESS_h
+#define KIO_NETACCESS_h
 
-#include <qobject.h>
-#include <qstring.h>
+#include <QtCore/QObject>
+#include <QtCore/QString>
 #include <kio/global.h>
+#include <kio/udsentry.h>
 #include <kurl.h>
 
 class QStringList;
@@ -38,6 +39,7 @@ namespace KIO {
 
   class Job;
 
+  class NetAccessPrivate;
   /**
    * Net Transparency.
    *
@@ -63,6 +65,11 @@ class KIO_EXPORT NetAccess : public QObject
   Q_OBJECT
 
 public:
+    enum StatSide {
+        SourceSide,
+        DestinationSide
+    };
+
     /**
      * Downloads a file from an arbitrary URL (@p src) to a
      * temporary file on the local filesystem (@p target).
@@ -154,9 +161,7 @@ public:
      * Alternative to upload for copying over the network.
      * Overwrite is false, so this will fail if @p target exists.
      *
-     * This one takes two URLs and is a direct equivalent
-     * of KIO::file_copy (not KIO::copy!).
-     * It will be renamed file_copy in KDE4, so better use file_copy.
+     * This one takes two URLs and is a direct equivalent of KIO::file_copy.
      *
      * @param src URL Referencing the file to upload.
      * @param target URL containing the final location of the file.
@@ -170,24 +175,23 @@ public:
      */
     static bool file_copy( const KUrl& src, const KUrl& target, QWidget* window = 0 );
     /// @deprecated, use file_copy instead
-    static KDE_DEPRECATED bool copy( const KUrl& src, const KUrl& target, QWidget* window = 0 ) {
-        return file_copy( src, target, window );
-    }
-
-    // KDE4: I want to just get rid of the "Full-fledged equivalents" methods now that we have synchronousRun().
+    static KDE_DEPRECATED bool copy( const KUrl& src, const KUrl& target,
+                                     QWidget* window = 0 );
 
     /**
      * Full-fledged equivalent of KIO::file_copy
+     * @deprecated use KIO::file_copy and then KIO::NetAccess::synchronousRun
      */
-    static bool file_copy( const KUrl& src, const KUrl& dest, int permissions /*=-1*/,
-                            bool overwrite=false, bool resume=false, QWidget* window = 0L );
+    static KDE_DEPRECATED bool file_copy( const KUrl& src, const KUrl& dest, int permissions /*=-1*/,
+                                          bool overwrite=false, bool resume=false, QWidget* window = 0L );
 
     /**
      * Full-fledged equivalent of KIO::file_move.
      * Moves or renames *one file*.
+     * @deprecated use KIO::file_move and then KIO::NetAccess::synchronousRun
      */
-    static bool file_move( const KUrl& src, const KUrl& target, int permissions = -1,
-                           bool overwrite=false, bool resume=false, QWidget* window = 0 );
+    static KDE_DEPRECATED bool file_move( const KUrl& src, const KUrl& target, int permissions = -1,
+                                          bool overwrite=false, bool resume=false, QWidget* window = 0 );
 
 
     /**
@@ -210,24 +214,26 @@ public:
      *               prompted for passwords as needed.
      * @return true if successful, false for failure
      */
-    static bool dircopy( const KUrl& src, const KUrl& target, QWidget* window );
+    static bool dircopy( const KUrl& src, const KUrl& target, QWidget* window ); // TODO deprecate in favor of KIO::copy + synchronousRun
 
     /**
      * Overloaded method, which takes a list of source URLs
      */
-    static bool dircopy( const KUrl::List& src, const KUrl& target, QWidget* window = 0L );
+    static bool dircopy( const KUrl::List& src, const KUrl& target, QWidget* window = 0L ); // TODO deprecate in favor of KIO::copy + synchronousRun
 
     /**
      * Full-fledged equivalent of KIO::move.
      * Moves or renames one file or directory.
+     * @deprecated use KIO::move and then KIO::NetAccess::synchronousRun
      */
-    static bool move( const KUrl& src, const KUrl& target, QWidget* window = 0L );
+    static KDE_DEPRECATED bool move( const KUrl& src, const KUrl& target, QWidget* window = 0L );
 
     /**
      * Full-fledged equivalent of KIO::move.
      * Moves or renames a list of files or directories.
+     * @deprecated use KIO::move and then KIO::NetAccess::synchronousRun
      */
-    static bool move( const KUrl::List& src, const KUrl& target, QWidget* window = 0L );
+    static KDE_DEPRECATED bool move( const KUrl::List& src, const KUrl& target, QWidget* window = 0L );
 
     /**
      * Tests whether a URL exists.
@@ -244,7 +250,23 @@ public:
      * @return true if the URL exists and we can do the operation specified by
      *              @p source, false otherwise
      */
-    static bool exists(const KUrl& url, bool source, QWidget* window);
+    static KDE_DEPRECATED bool exists(const KUrl& url, bool source, QWidget* window);
+
+    /**
+     * Tests whether a URL exists.
+     *
+     * @param url the URL we are testing
+     * @param statSide determines if we want to read or write.
+     * IMPORTANT: see documentation for KIO::stat for more details about this.
+     * @param window main window associated with this job. This is used to
+     *               automatically cache and discard authentication information
+     *               as needed. If NULL, authentication information will be
+     *               cached only for a short duration after which the user will
+     *               again be prompted for passwords as needed.
+     * @return true if the URL exists and we can do the operation specified by
+     *              @p source, false otherwise
+     */
+    static bool exists(const KUrl& url, StatSide statSide, QWidget* window);
 
     /**
      * Tests whether a URL exists and return information on it.
@@ -333,7 +355,7 @@ public:
      *               again be prompted for passwords as needed.
      * @return The resulting output of the @p command that is executed.
      */
-    static QString fish_execute( const KUrl & url, const QString command, QWidget* window );
+    static QString fish_execute( const KUrl & url, const QString &command, QWidget* window );
 
     /**
      * This function executes a job in a synchronous way.
@@ -346,7 +368,7 @@ public:
      * metaData.insert( "PropagateHttpHeader", "true" );
      * if ( NetAccess::synchronousRun( job, 0, &data, &url, &metaData ) ) {
      *   QString responseHeaders = metaData[ "HTTP-Headers" ];
-     *   kDebug()<<"Response header = "<< responseHeaders << endl;
+     *   kDebug()<<"Response header = "<< responseHeaders;
      * }
      * </code>
      *
@@ -371,10 +393,6 @@ public:
                                 KUrl* finalURL=0, QMap<QString,QString>* metaData=0 );
 
     /**
-     * @internal
-     * This function is not implemented!?
-     * (only mimetypeInternal)
-     *
      * Determines the mimetype of a given URL.
      *
      * This is a convenience function for KIO::mimetype.  You
@@ -400,13 +418,13 @@ public:
      * Note that this is already translated.
      * @return the last error string, or QString()
      */
-    static QString lastErrorString() { return lastErrorMsg ? *lastErrorMsg : QString(); }
+    static QString lastErrorString();
 
     /**
      * Returns the error code for the last job, in case it failed.
      * @return the last error code
      */
-    static int lastError() { return lastErrorCode; }
+    static int lastError();
 
 Q_SIGNALS:
     void leaveModality();
@@ -414,12 +432,12 @@ private:
     /**
      * Private constructor
      */
-    NetAccess() : m_metaData(0), d(0) {}
+    NetAccess();
 
     /**
      * Private destructor
      */
-    ~NetAccess() {}
+    ~NetAccess();
 
     /**
      * Internal methods
@@ -428,25 +446,17 @@ private:
                           bool overwrite, bool resume, QWidget* window, bool move);
     bool dircopyInternal(const KUrl::List& src, const KUrl& target,
                          QWidget* window, bool move);
-    bool statInternal(const KUrl & url, int details, bool source, QWidget* window = 0);
+    bool statInternal(const KUrl & url, int details, StatSide side, QWidget* window = 0);
 
     bool delInternal(const KUrl & url, QWidget* window = 0);
     bool mkdirInternal(const KUrl & url, int permissions, QWidget* window = 0);
-    QString fish_executeInternal(const KUrl & url, const QString command, QWidget* window = 0);
+    QString fish_executeInternal(const KUrl & url, const QString &command, QWidget* window = 0);
     bool synchronousRunInternal( Job* job, QWidget* window, QByteArray* data,
                                  KUrl* finalURL, QMap<QString,QString>* metaData );
 
     QString mimetypeInternal(const KUrl & url, QWidget* window = 0);
     void enter_loop();
 
-    /**
-     * List of temporary files
-     */
-    static QStringList* tmpfiles;
-
-    static QString* lastErrorMsg;
-    static int lastErrorCode;
-
     friend class I_like_this_class;
 
 private Q_SLOTS:
@@ -456,19 +466,7 @@ private Q_SLOTS:
     void slotRedirection( KIO::Job*, const KUrl& );
 
 private:
-    UDSEntry m_entry;
-    QString m_mimetype;
-    QByteArray m_data;
-    KUrl m_url;
-    QMap<QString, QString> *m_metaData;
-
-    /**
-     * Whether the download succeeded or not
-     */
-    bool bJobOK;
-
-private:
-    class NetAccessPrivate* const d;//notreallyneeded,thectorisprivatealready.
+    NetAccessPrivate * const d;
 };
 
 }
