@@ -16,19 +16,12 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef KDE_USE_FINAL
-#undef QT3_SUPPORT
-#endif
-#undef QT_MOC_COMPAT //win32/msvc uses '-include' option, so this is a temporary fix
-#define QT_MOC_COMPAT
-
 #include "paste.h"
 #include "pastedialog.h"
 
 #include "kio/copyjob.h"
 #include "kio/global.h"
 #include "kio/netaccess.h"
-#include "kio/observer.h"
 #include "kio/renamedialog.h"
 #include "kio/kprotocolmanager.h"
 
@@ -40,10 +33,10 @@
 #include <kmimetype.h>
 #include <ktemporaryfile.h>
 
-#include <qapplication.h>
-#include <qclipboard.h>
+#include <QtGui/QApplication>
+#include <QtGui/QClipboard>
 #include <QMimeData>
-#include <qtextstream.h>
+#include <QtCore/QTextIStream>
 
 static KUrl getNewFileName( const KUrl &u, const QString& text )
 {
@@ -58,14 +51,14 @@ static KUrl getNewFileName( const KUrl &u, const QString& text )
   KUrl myurl(u);
   myurl.addPath( file );
 
-  if (KIO::NetAccess::exists(myurl, false, 0))
+  if (KIO::NetAccess::exists(myurl, KIO::NetAccess::DestinationSide, 0))
   {
-      kDebug(7007) << "Paste will overwrite file.  Prompting..." << endl;
+      kDebug(7007) << "Paste will overwrite file.  Prompting...";
       KIO::RenameDialog_Result res = KIO::R_OVERWRITE;
 
       QString newPath;
       // Ask confirmation about resuming previous transfer
-      res = KIO::open_RenameDialog(
+      res = KIO::RenameDialog::open(
                           i18n("File Already Exists"),
                           u.pathOrUrl(),
                           myurl.pathOrUrl(),
@@ -119,7 +112,7 @@ static KIO::CopyJob* chooseAndPaste( const KUrl& u, const QMimeData* mimeData,
     QString dialogText( text );
     if ( dialogText.isEmpty() )
         dialogText = i18n( "Filename for clipboard content:" );
-    //using QString() instead of QString::null didn't compile (with gcc 3.2.3), because the ctor was mistaken as a function declaration, Alex
+    //using QString() instead of QString::null didn't compile (with gcc 3.2.3), because the ctor was mistaken as a function declaration, Alex //krazy:exclude=nullstrassign
     KIO::PasteDialog dlg( QString::null, dialogText, QString(), formatLabels, widget, clipboard ); //krazy:exclude=nullstrassign
 
     if ( dlg.exec() != KDialog::Accepted )
@@ -136,7 +129,7 @@ static KIO::CopyJob* chooseAndPaste( const KUrl& u, const QMimeData* mimeData,
     const QString result = dlg.lineEditText();
     const QString chosenFormat = formats[ dlg.comboItem() ];
 
-    kDebug() << " result=" << result << " chosenFormat=" << chosenFormat << endl;
+    kDebug() << " result=" << result << " chosenFormat=" << chosenFormat;
     KUrl newUrl( u );
     newUrl.addPath( result );
     // if "data" came from QClipboard, then it was deleted already - by a nice 0-seconds timer
