@@ -34,11 +34,11 @@
 #include <sys/shm.h>
 #endif
 
-#include <qdir.h>
-#include <qfile.h>
-#include <qimage.h>
-#include <qtimer.h>
-#include <qregexp.h>
+#include <QtCore/QDir>
+#include <QtCore/QFile>
+#include <QtGui/QImage>
+#include <QtCore/QTimer>
+#include <QtCore/QRegExp>
 
 #include <kfileitem.h>
 #include <kapplication.h>
@@ -48,27 +48,31 @@
 #include <kglobal.h>
 #include <kstandarddirs.h>
 #include <kservice.h>
-#include <qlinkedlist.h>
+#include <QtCore/QLinkedList>
 #include <kconfiggroup.h>
 
-#include "previewjob.moc"
+#include "jobuidelegate.h"
+#include "job_p.h"
 
 namespace KIO { struct PreviewItem; }
 using namespace KIO;
 
 struct KIO::PreviewItem
 {
-    KFileItem *item;
+    KFileItem item;
     KService::Ptr plugin;
 };
 
-struct KIO::PreviewJobPrivate
+class KIO::PreviewJobPrivate: public KIO::JobPrivate
 {
+public:
     enum { STATE_STATORIG, // if the thumbnail exists
            STATE_GETORIG, // if we create it
            STATE_CREATETHUMB // thumbnail:/ slave
     } state;
-    KFileItemList initialItems;
+    PreviewJob *q;
+
+    QList<KFileItem> initialItems;
     const QStringList *enabledPlugins;
     // Our todo list :)
     // We remove the first item at every step, so use QLinkedList
@@ -94,6 +98,8 @@ struct KIO::PreviewJobPrivate
     bool bScale;
     // Whether we should save the thumbnail
     bool bSave;
+    bool ignoreMaximumSize;
+    bool succeeded;
     // If the file to create a thumb for was a temp file, this is its name
     QString tempName;
     // Over that, it's too much
@@ -102,24 +108,32 @@ struct KIO::PreviewJobPrivate
     int iconSize;
     // the transparency of the blended mimetype icon
     int iconAlpha;
-	// Shared memory segment Id. The segment is allocated to a size
-	// of extent x extent x 4 (32 bit image) on first need.
-	int shmid;
-	// And the data area
-	uchar *shmaddr;
-    // Delete the KFileItems when done?
-    bool deleteItems;
-    bool succeeded;
+    // Shared memory segment Id. The segment is allocated to a size
+    // of extent x extent x 4 (32 bit image) on first need.
+    int shmid;
+    // And the data area
+    uchar *shmaddr;
     // Root of thumbnail cache
     QString thumbRoot;
-    bool ignoreMaximumSize;
+
+    void getOrCreateThumbnail();
+    bool statResultThumbnail();
+    void createThumbnail( const QString& );
+    void determineNextFile();
+    void emitPreview(const QImage &thumb);
+
+    void startPreview();
+    void slotThumbData(KIO::Job *, const QByteArray &);
+
+    Q_DECLARE_PUBLIC(PreviewJob)
 };
 
-PreviewJob::PreviewJob( const KFileItemList &items, int width, int height,
+PreviewJob::PreviewJob( const QList<KFileItem> &items, int width, int height,
     int iconSize, int iconAlpha, bool scale, bool save,
-    const QStringList *enabledPlugins, bool deleteItems )
-    : KIO::Job( false /* no GUI */ ),d(new PreviewJobPrivate)
+    const QStringList *enabledPlugins )
+    : KIO::Job(*new PreviewJobPrivate)
 {
+    Q_D(PreviewJob);
     d->tOrig = 0;
     d->shmid = -1;
     d->shmaddr = 0;
@@ -131,11 +145,9 @@ PreviewJob::PreviewJob( const KFileItemList &items, int width, int height,
     d->cacheHeight = d->height;
     d->iconSize = iconSize;
     d->iconAlpha = iconAlpha;
-    d->deleteItems = deleteItems;
     d->bScale = scale;
     d->bSave = save && scale;
     d->succeeded = false;
-    d->currentItem.item = 0;
     d->thumbRoot = QDir::homePath() + "/.thumbnails/";
     d->ignoreMaximumSize = false;
 
@@ -146,22 +158,23 @@ PreviewJob::PreviewJob( const KFileItemList &items, int width, int height,
 PreviewJob::~PreviewJob()
 {
 #ifdef Q_OS_UNIX
+    Q_D(PreviewJob);
     if (d->shmaddr) {
         shmdt((char*)d->shmaddr);
         shmctl(d->shmid, IPC_RMID, 0);
     }
 #endif
-    delete d;
 }
 
-void PreviewJob::startPreview()
+void PreviewJobPrivate::startPreview()
 {
+    Q_Q(PreviewJob);
     // Load the list of plugins to determine which mimetypes are supported
     const KService::List plugins = KServiceTypeTrader::self()->query("ThumbCreator");
     QMap<QString, KService::Ptr> mimeMap;
 
     for (KService::List::ConstIterator it = plugins.begin(); it != plugins.end(); ++it)
-        if (!d->enabledPlugins || d->enabledPlugins->contains((*it)->desktopEntryName()))
+        if (!enabledPlugins || enabledPlugins->contains((*it)->desktopEntryName()))
     {
         const QStringList mimeTypes = (*it)->property("MimeTypes").toStringList();
         for (QStringList::ConstIterator mt = mimeTypes.begin(); mt != mimeTypes.end(); ++mt)
@@ -170,13 +183,13 @@ void PreviewJob::startPreview()
 
     // Look for images and store the items in our todo list :)
     bool bNeedCache = false;
-    KFileItemList::const_iterator kit = d->initialItems.begin();
-    const KFileItemList::const_iterator kend = d->initialItems.end();
+    QList<KFileItem>::const_iterator kit = initialItems.begin();
+    const QList<KFileItem>::const_iterator kend = initialItems.end();
     for ( ; kit != kend; ++kit )
     {
         PreviewItem item;
         item.item = *kit;
-        const QString mimeType = item.item->mimetype();
+        const QString mimeType = item.item.mimetype();
         QMap<QString, KService::Ptr>::ConstIterator plugin = mimeMap.find(mimeType);
         if (plugin == mimeMap.end())
         {
@@ -186,21 +199,24 @@ void PreviewJob::startPreview()
 
             if (plugin == mimeMap.end())
             {
-                // check mime type inheritance
-                const KMimeType::Ptr mimeInfo = KMimeType::mimeType(mimeType);
-                QString parentMimeType = mimeInfo->parentMimeType();
-                while (!parentMimeType.isEmpty())
-                {
-                    plugin = mimeMap.find(parentMimeType);
-                    if (plugin != mimeMap.end()) break;
+                // check mime type inheritance, resolve aliases
+                const KMimeType::Ptr mimeInfo = KMimeType::mimeType(mimeType, KMimeType::ResolveAliases);
+                if (mimeInfo) {
+                    QString parentMimeType = mimeInfo->parentMimeType();
+                    while (!parentMimeType.isEmpty())
+                    {
+                        plugin = mimeMap.find(parentMimeType);
+                        if (plugin != mimeMap.end()) break;
 
-                    KMimeType::Ptr parentMimeInfo = KMimeType::mimeType(parentMimeType);
-                    if (!parentMimeInfo) break;
+                        KMimeType::Ptr parentMimeInfo = KMimeType::mimeType(parentMimeType);
+                        if (!parentMimeInfo) break;
 
-                    parentMimeType = parentMimeInfo->parentMimeType();
+                        parentMimeType = parentMimeInfo->parentMimeType();
+                    }
                 }
             }
-
+#if 0 // KDE4: should be covered by inheritance above, all text mimetypes inherit from text/plain
+            // if that's not enough, we need to invent something else
             if (plugin == mimeMap.end())
             {
                 // check X-KDE-Text property
@@ -218,99 +234,98 @@ void PreviewJob::startPreview()
                     }
                 }
             }
+#endif
         }
 
         if (plugin != mimeMap.end())
         {
             item.plugin = *plugin;
-            d->items.append(item);
-            if (!bNeedCache && d->bSave &&
-                ((*kit)->url().protocol() != "file" ||
-                 !(*kit)->url().directory( KUrl::AppendTrailingSlash ).startsWith(d->thumbRoot)) &&
+            items.append(item);
+            if (!bNeedCache && bSave &&
+                ((*kit).url().protocol() != "file" ||
+                 !(*kit).url().directory( KUrl::AppendTrailingSlash ).startsWith(thumbRoot)) &&
                 (*plugin)->property("CacheThumbnail").toBool())
                 bNeedCache = true;
         }
         else
         {
-            emitFailed( *kit );
-            if (d->deleteItems)
-                delete *kit;
+            emit q->failed( *kit );
         }
     }
 
   // Read configuration value for the maximum allowed size
     KConfigGroup cg( KGlobal::config(), "PreviewSettings" );
-    d->maximumSize = cg.readEntry( "MaximumSize", 1024*1024LL /* 1MB */ );
+    maximumSize = cg.readEntry( "MaximumSize", 1024*1024LL /* 1MB */ );
 
     if (bNeedCache)
     {
-        if (d->width <= 128 && d->height <= 128) d->cacheWidth = d->cacheHeight = 128;
-        else d->cacheWidth = d->cacheHeight = 256;
-        d->thumbPath = d->thumbRoot + (d->cacheWidth == 128 ? "normal/" : "large/");
-        KStandardDirs::makeDir(d->thumbPath, 0700);
+        if (width <= 128 && height <= 128) cacheWidth = cacheHeight = 128;
+        else cacheWidth = cacheHeight = 256;
+        thumbPath = thumbRoot + (cacheWidth == 128 ? "normal/" : "large/");
+        KStandardDirs::makeDir(thumbPath, 0700);
     }
     else
-        d->bSave = false;
+        bSave = false;
 
-    d->initialItems.clear();
+    initialItems.clear();
     determineNextFile();
 }
 
-void PreviewJob::removeItem( const KFileItem *item )
+void PreviewJob::removeItem( const KUrl& url )
 {
+    Q_D(PreviewJob);
     for (QLinkedList<PreviewItem>::Iterator it = d->items.begin(); it != d->items.end(); ++it)
-        if ((*it).item == item)
+        if ((*it).item.url() == url)
         {
             d->items.erase(it);
             break;
         }
 
-    if (d->currentItem.item == item)
+    if (d->currentItem.item.url() == url)
     {
         KJob* job = subjobs().first();
         job->kill();
         removeSubjob( job );
-        determineNextFile();
+        d->determineNextFile();
     }
 }
 
 void PreviewJob::setIgnoreMaximumSize(bool ignoreSize)
 {
-    d->ignoreMaximumSize = ignoreSize;
+    d_func()->ignoreMaximumSize = ignoreSize;
 }
 
-void PreviewJob::determineNextFile()
+void PreviewJobPrivate::determineNextFile()
 {
-    if (d->currentItem.item)
+    Q_Q(PreviewJob);
+    if (!currentItem.item.isNull())
     {
-        if (!d->succeeded)
-            emitFailed();
-        if (d->deleteItems) {
-            delete d->currentItem.item;
-            d->currentItem.item = 0L;
-        }
+        if (!succeeded)
+            emit q->failed( currentItem.item );
     }
     // No more items ?
-    if ( d->items.isEmpty() )
+    if ( items.isEmpty() )
     {
-        emitResult();
+        q->emitResult();
         return;
     }
     else
     {
         // First, stat the orig file
-        d->state = PreviewJobPrivate::STATE_STATORIG;
-        d->currentItem = d->items.first();
-        d->succeeded = false;
-        d->items.removeFirst();
-        KIO::Job *job = KIO::stat( d->currentItem.item->url(), false );
+        state = PreviewJobPrivate::STATE_STATORIG;
+        currentItem = items.first();
+        succeeded = false;
+        items.removeFirst();
+        KIO::Job *job = KIO::stat( currentItem.item.url(), false );
         job->addMetaData( "no-auth-prompt", "true" );
-        addSubjob(job);
+        q->addSubjob(job);
     }
 }
 
 void PreviewJob::slotResult( KJob *job )
 {
+    Q_D(PreviewJob);
+
     removeSubjob(job);
     Q_ASSERT ( !hasSubjobs() ); // We should have only one job at a time ...
     switch ( d->state )
@@ -320,16 +335,16 @@ void PreviewJob::slotResult( KJob *job )
             if (job->error()) // that's no good news...
             {
                 // Drop this one and move on to the next one
-                determineNextFile();
+                d->determineNextFile();
                 return;
             }
             const KIO::UDSEntry entry = static_cast<KIO::StatJob*>(job)->statResult();
-            d->tOrig = entry.numberValue( KIO::UDS_MODIFICATION_TIME, 0 );
+            d->tOrig = entry.numberValue( KIO::UDSEntry::UDS_MODIFICATION_TIME, 0 );
             if ( !d->ignoreMaximumSize &&
-                 entry.numberValue( KIO::UDS_SIZE, 0 ) > d->maximumSize &&
+                 entry.numberValue( KIO::UDSEntry::UDS_SIZE, 0 ) > d->maximumSize &&
                  !d->currentItem.plugin->property("IgnoreMaximumSize").toBool()
                 ) {
-                determineNextFile();
+                d->determineNextFile();
                 return;
             }
 
@@ -337,25 +352,25 @@ void PreviewJob::slotResult( KJob *job )
             {
                 // This preview will not be cached, no need to look for a saved thumbnail
                 // Just create it, and be done
-                getOrCreateThumbnail();
+                d->getOrCreateThumbnail();
                 return;
             }
 
-            if ( statResultThumbnail() )
+            if ( d->statResultThumbnail() )
                 return;
 
-            getOrCreateThumbnail();
+            d->getOrCreateThumbnail();
             return;
         }
         case PreviewJobPrivate::STATE_GETORIG:
         {
             if (job->error())
             {
-                determineNextFile();
+                d->determineNextFile();
                 return;
             }
 
-            createThumbnail( static_cast<KIO::FileCopyJob*>(job)->destUrl().path() );
+            d->createThumbnail( static_cast<KIO::FileCopyJob*>(job)->destUrl().path() );
             return;
         }
         case PreviewJobPrivate::STATE_CREATETHUMB:
@@ -365,113 +380,115 @@ void PreviewJob::slotResult( KJob *job )
                 QFile::remove(d->tempName);
                 d->tempName.clear();
             }
-            determineNextFile();
+            d->determineNextFile();
             return;
         }
     }
 }
 
-bool PreviewJob::statResultThumbnail()
+bool PreviewJobPrivate::statResultThumbnail()
 {
-    if ( d->thumbPath.isEmpty() )
+    if ( thumbPath.isEmpty() )
         return false;
 
-    KUrl url = d->currentItem.item->url();
+    KUrl url = currentItem.item.url();
     // Don't include the password if any
     url.setPass(QString());
-    d->origName = url.url();
+    origName = url.url();
 
-    KMD5 md5( QFile::encodeName( d->origName ) );
-    d->thumbName = QFile::encodeName( md5.hexDigest() ) + ".png";
+    KMD5 md5( QFile::encodeName( origName ) );
+    thumbName = QFile::encodeName( md5.hexDigest() ) + ".png";
 
     QImage thumb;
-    if ( !thumb.load( d->thumbPath + d->thumbName ) ) return false;
+    if ( !thumb.load( thumbPath + thumbName ) ) return false;
 
-    if ( thumb.text( "Thumb::URI", 0 ) != d->origName ||
-         thumb.text( "Thumb::MTime", 0 ).toInt() != d->tOrig ) return false;
+    if ( thumb.text( "Thumb::URI", 0 ) != origName ||
+         thumb.text( "Thumb::MTime", 0 ).toInt() != tOrig ) return false;
 
     // Found it, use it
     emitPreview( thumb );
-    d->succeeded = true;
+    succeeded = true;
     determineNextFile();
     return true;
 }
 
 
-void PreviewJob::getOrCreateThumbnail()
+void PreviewJobPrivate::getOrCreateThumbnail()
 {
+    Q_Q(PreviewJob);
     // We still need to load the orig file ! (This is getting tedious) :)
-    const KFileItem* item = d->currentItem.item;
-    const QString localPath = item->localPath();
+    const KFileItem& item = currentItem.item;
+    const QString localPath = item.localPath();
     if ( !localPath.isEmpty() )
         createThumbnail( localPath );
     else
     {
-        d->state = PreviewJobPrivate::STATE_GETORIG;
+        state = PreviewJobPrivate::STATE_GETORIG;
         KTemporaryFile localFile;
         localFile.setAutoRemove(false);
         localFile.open();
         KUrl localURL;
-        localURL.setPath( d->tempName = localFile.fileName() );
-        const KUrl currentURL = item->url();
+        localURL.setPath( tempName = localFile.fileName() );
+        const KUrl currentURL = item.url();
         KIO::Job * job = KIO::file_copy( currentURL, localURL, -1, true,
                                          false, false /* No GUI */ );
         job->addMetaData("thumbnail","1");
-        addSubjob(job);
+        q->addSubjob(job);
     }
 }
 
-void PreviewJob::createThumbnail( const QString &pixPath )
+void PreviewJobPrivate::createThumbnail( const QString &pixPath )
 {
-    d->state = PreviewJobPrivate::STATE_CREATETHUMB;
+    Q_Q(PreviewJob);
+    state = PreviewJobPrivate::STATE_CREATETHUMB;
     KUrl thumbURL;
     thumbURL.setProtocol("thumbnail");
     thumbURL.setPath(pixPath);
     KIO::TransferJob *job = KIO::get(thumbURL, false, false);
-    addSubjob(job);
-    connect(job, SIGNAL(data(KIO::Job *, const QByteArray &)), SLOT(slotThumbData(KIO::Job *, const QByteArray &)));
-    bool save = d->bSave && d->currentItem.plugin->property("CacheThumbnail").toBool();
-    job->addMetaData("mimeType", d->currentItem.item->mimetype());
-    job->addMetaData("width", QString().setNum(save ? d->cacheWidth : d->width));
-    job->addMetaData("height", QString().setNum(save ? d->cacheHeight : d->height));
-    job->addMetaData("iconSize", QString().setNum(save ? 64 : d->iconSize));
-    job->addMetaData("iconAlpha", QString().setNum(d->iconAlpha));
-    job->addMetaData("plugin", d->currentItem.plugin->library());
+    q->addSubjob(job);
+    q->connect(job, SIGNAL(data(KIO::Job *, const QByteArray &)), SLOT(slotThumbData(KIO::Job *, const QByteArray &)));
+    bool save = bSave && currentItem.plugin->property("CacheThumbnail").toBool();
+    job->addMetaData("mimeType", currentItem.item.mimetype());
+    job->addMetaData("width", QString().setNum(save ? cacheWidth : width));
+    job->addMetaData("height", QString().setNum(save ? cacheHeight : height));
+    job->addMetaData("iconSize", QString().setNum(save ? 64 : iconSize));
+    job->addMetaData("iconAlpha", QString().setNum(iconAlpha));
+    job->addMetaData("plugin", currentItem.plugin->library());
 #ifdef Q_OS_UNIX
-    if (d->shmid == -1)
+    if (shmid == -1)
     {
-        if (d->shmaddr) {
-            shmdt((char*)d->shmaddr);
-            shmctl(d->shmid, IPC_RMID, 0);
+        if (shmaddr) {
+            shmdt((char*)shmaddr);
+            shmctl(shmid, IPC_RMID, 0);
         }
-        d->shmid = shmget(IPC_PRIVATE, d->cacheWidth * d->cacheHeight * 4, IPC_CREAT|0600);
-        if (d->shmid != -1)
+        shmid = shmget(IPC_PRIVATE, cacheWidth * cacheHeight * 4, IPC_CREAT|0600);
+        if (shmid != -1)
         {
-            d->shmaddr = (uchar *)(shmat(d->shmid, 0, SHM_RDONLY));
-            if (d->shmaddr == (uchar *)-1)
+            shmaddr = (uchar *)(shmat(shmid, 0, SHM_RDONLY));
+            if (shmaddr == (uchar *)-1)
             {
-                shmctl(d->shmid, IPC_RMID, 0);
-                d->shmaddr = 0;
-                d->shmid = -1;
+                shmctl(shmid, IPC_RMID, 0);
+                shmaddr = 0;
+                shmid = -1;
             }
         }
         else
-            d->shmaddr = 0;
+            shmaddr = 0;
     }
-    if (d->shmid != -1)
-        job->addMetaData("shmid", QString().setNum(d->shmid));
+    if (shmid != -1)
+        job->addMetaData("shmid", QString().setNum(shmid));
 #endif
 }
 
-void PreviewJob::slotThumbData(KIO::Job *, const QByteArray &data)
+void PreviewJobPrivate::slotThumbData(KIO::Job *, const QByteArray &data)
 {
-    bool save = d->bSave &&
-                d->currentItem.plugin->property("CacheThumbnail").toBool() &&
-                (d->currentItem.item->url().protocol() != "file" ||
-                 !d->currentItem.item->url().directory( KUrl::AppendTrailingSlash ).startsWith(d->thumbRoot));
+    bool save = bSave &&
+                currentItem.plugin->property("CacheThumbnail").toBool() &&
+                (currentItem.item.url().protocol() != "file" ||
+                 !currentItem.item.url().directory( KUrl::AppendTrailingSlash ).startsWith(thumbRoot));
     QImage thumb;
 #ifdef Q_OS_UNIX
-    if (d->shmaddr)
+    if (shmaddr)
     {
         // Keep this in sync with kdebase/kioslave/thumbnail.cpp
         QDataStream str(data);
@@ -479,7 +496,7 @@ void PreviewJob::slotThumbData(KIO::Job *, const QByteArray &data)
         quint8 iFormat;
         str >> width >> height >> iFormat;
         QImage::Format format = static_cast<QImage::Format>( iFormat );
-        thumb = QImage(d->shmaddr, width, height, format );
+        thumb = QImage(shmaddr, width, height, format );
     }
     else
 #endif
@@ -487,40 +504,34 @@ void PreviewJob::slotThumbData(KIO::Job *, const QByteArray &data)
 
     if (save)
     {
-        thumb.setText("Thumb::URI", d->origName);
-        thumb.setText("Thumb::MTime", QString::number(d->tOrig));
-        thumb.setText("Thumb::Size", number(d->currentItem.item->size()));
-        thumb.setText("Thumb::Mimetype", d->currentItem.item->mimetype());
+        thumb.setText("Thumb::URI", origName);
+        thumb.setText("Thumb::MTime", QString::number(tOrig));
+        thumb.setText("Thumb::Size", number(currentItem.item.size()));
+        thumb.setText("Thumb::Mimetype", currentItem.item.mimetype());
         thumb.setText("Software", "KDE Thumbnail Generator");
         KTemporaryFile temp;
-        temp.setPrefix(d->thumbPath + "kde-tmp-");
+        temp.setPrefix(thumbPath + "kde-tmp-");
         temp.setSuffix(".png");
         temp.setAutoRemove(false);
         if (temp.open()) //Only try to write out the thumbnail if we
         {                //actually created the temp file.
             thumb.save(temp.fileName(), "PNG");
-            rename(QFile::encodeName(temp.fileName()), QFile::encodeName(d->thumbPath + d->thumbName));
+            rename(QFile::encodeName(temp.fileName()), QFile::encodeName(thumbPath + thumbName));
         }
     }
     emitPreview( thumb );
-    d->succeeded = true;
+    succeeded = true;
 }
 
-void PreviewJob::emitPreview(const QImage &thumb)
+void PreviewJobPrivate::emitPreview(const QImage &thumb)
 {
+    Q_Q(PreviewJob);
     QPixmap pix;
-    if (thumb.width() > d->width || thumb.height() > d->height)
+    if (thumb.width() > width || thumb.height() > height)
         pix = QPixmap::fromImage( thumb.scaled(thumb.size(), Qt::KeepAspectRatio, Qt::SmoothTransformation) );
     else
         pix = QPixmap::fromImage( thumb );
-    emit gotPreview(d->currentItem.item, pix);
-}
-
-void PreviewJob::emitFailed(const KFileItem *item)
-{
-    if (!item)
-        item = d->currentItem.item;
-    emit failed(item);
+    emit q->gotPreview(currentItem.item, pix);
 }
 
 QStringList PreviewJob::availablePlugins()
@@ -542,7 +553,7 @@ QStringList PreviewJob::supportedMimeTypes()
     return result;
 }
 
-PreviewJob *KIO::filePreview( const KFileItemList &items, int width, int height,
+PreviewJob *KIO::filePreview( const QList<KFileItem> &items, int width, int height,
     int iconSize, int iconAlpha, bool scale, bool save,
     const QStringList *enabledPlugins )
 {
@@ -554,10 +565,13 @@ PreviewJob *KIO::filePreview( const KUrl::List &items, int width, int height,
     int iconSize, int iconAlpha, bool scale, bool save,
     const QStringList *enabledPlugins )
 {
-    KFileItemList fileItems;
-    for (KUrl::List::ConstIterator it = items.begin(); it != items.end(); ++it)
-        fileItems.append(new KFileItem(KFileItem::Unknown, KFileItem::Unknown, *it, true));
+    QList<KFileItem> fileItems;
+    for (KUrl::List::ConstIterator it = items.begin(); it != items.end(); ++it) {
+        Q_ASSERT( (*it).isValid() ); // please call us with valid urls only
+        fileItems.append(KFileItem(KFileItem::Unknown, KFileItem::Unknown, *it, true));
+    }
     return new PreviewJob(fileItems, width, height, iconSize, iconAlpha,
-                          scale, save, enabledPlugins, true);
+                          scale, save, enabledPlugins);
 }
 
+#include "previewjob.moc"
