@@ -24,12 +24,12 @@
 #include <stdio.h>
 #include <assert.h>
 
-#include <qdatetime.h>
-#include <qfileinfo.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qlineedit.h>
-#include <qdir.h>
+#include <QtCore/QDate>
+#include <QtCore/QFileInfo>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtGui/QLineEdit>
+#include <QtCore/QDir>
 
 #include <kmessagebox.h>
 #include <kpushbutton.h>
@@ -163,7 +163,7 @@ RenameDialog::RenameDialog(QWidget *parent, const QString & _caption,
         if(!plugin_offers.isEmpty() ){
             RenameDialogPlugin::FileItem src( _src, d->mimeSrc, sizeSrc, ctimeSrc, mtimeSrc );
             RenameDialogPlugin::FileItem dst( _dest,d->mimeDest, sizeDest, ctimeDest, mtimeDest );
-            kDebug(7024) << "Offers" << endl;
+            kDebug(7024) << "Offers";
             KService::List::ConstIterator it = plugin_offers.begin();
             const KService::List::ConstIterator end = plugin_offers.end();
             for( ; it != end; ++it ){
@@ -176,7 +176,7 @@ RenameDialog::RenameDialog(QWidget *parent, const QString & _caption,
                     d->plugin = true;
                     plugin->handle( _mode, src, dst );
                     pLayout->addWidget(plugin );
-                    kDebug(7024) << "RenameDialogPlugin" << endl;
+                    kDebug(7024) << "RenameDialogPlugin";
                     break;
                 } else {
                     delete plugin;
@@ -505,12 +505,12 @@ void RenameDialog::pluginHandling()
   d->mimeSrc = mime( d->src );
   d->mimeDest = mime(d->dest );
 
-  kDebug(7024) << "Source Mimetype: "<< d->mimeSrc << endl;
-  kDebug(7024) << "Dest Mimetype: "<< d->mimeDest << endl;
+  kDebug(7024) << "Source Mimetype: "<< d->mimeSrc;
+  kDebug(7024) << "Dest Mimetype: "<< d->mimeDest;
 }
 
 
-RenameDialog_Result KIO::open_RenameDialog( const QString & _caption,
+RenameDialog_Result RenameDialog::open( const QString & _caption,
                                       const KUrl & _src, const KUrl & _dest,
                                       RenameDialog_Mode _mode,
                                       QString& _new,
