@@ -17,22 +17,24 @@
    Boston, MA 02110-1301, USA.
 */
 
-#include "kio/sessiondata.h"
-#include "kio/slaveconfig.h"
-#include "kio/scheduler.h"
-#include "kio/authinfo.h"
-#include "kio/slave.h"
+#include "scheduler.h"
+
+#include "sessiondata.h"
+#include "slaveconfig.h"
+#include "authinfo.h"
+#include "slave.h"
+#include "connection.h"
+#include "job_p.h"
 
 #include <kdebug.h>
 #include <kglobal.h>
 #include <kprotocolmanager.h>
 #include <kprotocolinfo.h>
 #include <assert.h>
-#include <kstaticdeleter.h>
 #include <kdesu/client.h>
 
-#include <qhash.h>
-#include <qwidget.h>
+#include <QtCore/QHash>
+#include <QtGui/QWidget>
 #include <QtDBus/QtDBus>
 
 // Slaves may be idle for MAX_SLAVE_IDLE time before they are being returned
@@ -41,14 +43,160 @@
 
 using namespace KIO;
 
-template class QHash<QString, KIO::Scheduler::ProtocolInfo*>;
-
-Scheduler *Scheduler::instance = 0;
-
-class KIO::SlaveList : public QList<Slave *>
+static inline Slave *jobSlave(SimpleJob *job)
 {
+    return SimpleJobPrivate::get(job)->m_slave;
+}
+
+static inline int jobCommand(SimpleJob *job)
+{
+    return SimpleJobPrivate::get(job)->m_command;
+}
+
+static inline void startJob(SimpleJob *job, Slave *slave)
+{
+    SimpleJobPrivate::get(job)->start(slave);
+}
+
+typedef QList<Slave *> SlaveList;
+
+class KIO::SchedulerPrivate
+{
+public:
+    class JobData;
+    class ProtocolInfo;
+    class ProtocolInfoDict : public QHash<QString, ProtocolInfo*>
+    {
+    public:
+        ProtocolInfoDict() { }
+
+        ProtocolInfo *get(const QString &protocol);
+    };
+
+    typedef QHash<KIO::SimpleJob*, JobData> ExtraJobData;
+    typedef QList<SimpleJob *> JobList;
+    typedef QMap<Slave*, JobList *> CoSlaveMap;
+
+    SchedulerPrivate() :
+        q(new Scheduler),
+        busy( false ),
+        slaveOnHold( 0 ),
+        slaveConfig( SlaveConfig::self() ),
+        sessionData( new SessionData ),
+        checkOnHold( true ) // !! Always check with KLauncher for the first request
+    {
+        slaveTimer.setObjectName( "Scheduler::slaveTimer" );
+        slaveTimer.setSingleShot( true );
+        q->connect(&slaveTimer, SIGNAL(timeout()), SLOT(startStep()));
+        coSlaveTimer.setObjectName( "Scheduler::coSlaveTimer" );
+        coSlaveTimer.setSingleShot( true );
+        q->connect(&coSlaveTimer, SIGNAL(timeout()), SLOT(slotScheduleCoSlave()));
+        cleanupTimer.setObjectName( "Scheduler::cleanupTimer" );
+        cleanupTimer.setSingleShot( true );
+        q->connect(&cleanupTimer, SIGNAL(timeout()), SLOT(slotCleanIdleSlaves()));
+    }
+    ~SchedulerPrivate()
+    {
+        delete q; q = 0;
+        qDeleteAll( protInfoDict );
+        qDeleteAll( slaveList );
+    }
+    Scheduler *q;
+
+    QTimer slaveTimer;
+    QTimer coSlaveTimer;
+    QTimer cleanupTimer;
+    bool busy;
+
+    SlaveList slaveList;
+    SlaveList idleSlaves;
+    SlaveList coIdleSlaves;
+
+    ProtocolInfoDict protInfoDict;
+    Slave *slaveOnHold;
+    KUrl urlOnHold;
+    JobList newJobs;
+
+    CoSlaveMap coSlaves;
+    ExtraJobData extraJobData;
+    SlaveConfig *slaveConfig;
+    SessionData *sessionData;
+    bool checkOnHold;
+    QMap<QObject *,WId> m_windowList;
+
+    void doJob(SimpleJob *job);
+    void scheduleJob(SimpleJob *job);
+    void cancelJob(SimpleJob *job);
+    void jobFinished(KIO::SimpleJob *job, KIO::Slave *slave);
+    void scheduleCleanup();
+    void putSlaveOnHold(KIO::SimpleJob *job, const KUrl &url);
+    void removeSlaveOnHold();
+    Slave *getConnectedSlave(const KUrl &url, const KIO::MetaData &metaData );
+    bool assignJobToSlave(KIO::Slave *slave, KIO::SimpleJob *job);
+    bool disconnectSlave(KIO::Slave *slave);
+    void checkSlaveOnHold(bool b);
+    void publishSlaveOnHold();
+    void registerWindow(QWidget *wid);
+
+    Slave *findIdleSlave(ProtocolInfo *protInfo, SimpleJob *job, bool &exact);
+    Slave *createSlave(ProtocolInfo *protInfo, SimpleJob *job, const KUrl &url);
+
+    void debug_info();
+
+    void setupSlave(KIO::Slave *slave, const KUrl &url, const QString &protocol, const QString &proxy , bool newSlave, const KIO::MetaData *config=0);
+    bool startJobScheduled(ProtocolInfo *protInfo);
+    bool startJobDirect();
+
+    void slotSlaveDied(KIO::Slave *slave);
+    void slotSlaveStatus(pid_t pid, const QByteArray &protocol,
+                         const QString &host, bool connected);
+
+    void slotReparseSlaveConfiguration(const QString &);
+
+    void startStep();
+    void slotCleanIdleSlaves();
+    void slotSlaveConnected();
+    void slotSlaveError(int error, const QString &errorMsg);
+    void slotScheduleCoSlave();
+    void slotUnregisterWindow(QObject *);
 };
 
+class KIO::SchedulerPrivate::ProtocolInfo
+{
+public:
+    ProtocolInfo() : maxSlaves(1), skipCount(0)
+    {
+    }
+
+    QList<SimpleJob *> joblist;
+    SlaveList activeSlaves;
+    int maxSlaves;
+    int skipCount;
+    QString protocol;
+};
+
+KIO::SchedulerPrivate::ProtocolInfo *
+KIO::SchedulerPrivate::ProtocolInfoDict::get(const QString &protocol)
+{
+    ProtocolInfo *info = value(protocol, 0);
+    if (!info)
+    {
+        info = new ProtocolInfo;
+        info->protocol = protocol;
+        info->maxSlaves = KProtocolInfo::maxSlaves( protocol );
+
+        insert(protocol, info);
+    }
+    return info;
+}
+
+K_GLOBAL_STATIC(SchedulerPrivate, schedulerPrivate)
+Scheduler* Scheduler::self()
+{
+    return schedulerPrivate->q;
+}
+
+
 //
 // There are two kinds of protocol:
 // (1) The protocol of the url
@@ -64,7 +212,7 @@ class KIO::SlaveList : public QList<Slave *>
 // We schedule slaves based on (2) but tell the slave about (1) via
 // Slave::setProtocol().
 
-class KIO::Scheduler::JobData
+class KIO::SchedulerPrivate::JobData
 {
 public:
     JobData() : checkOnHold(false) { }
@@ -75,114 +223,134 @@ public:
     bool checkOnHold;
 };
 
-class KIO::Scheduler::ExtraJobData: public QHash<KIO::SimpleJob*, KIO::Scheduler::JobData>
-{
-public:
-    ExtraJobData() {}
-    ~ExtraJobData() {}
-};
-
-class KIO::Scheduler::ProtocolInfo
-{
-public:
-    ProtocolInfo() : maxSlaves(1), skipCount(0)
-    {
-    }
-
-    QList<SimpleJob *> joblist;
-    SlaveList activeSlaves;
-    int maxSlaves;
-    int skipCount;
-    QString protocol;
-};
-
-class KIO::Scheduler::ProtocolInfoDict : public QHash<QString, KIO::Scheduler::ProtocolInfo*>
-{
-  public:
-    ProtocolInfoDict() { }
-
-    KIO::Scheduler::ProtocolInfo *get( const QString &protocol);
-};
-
-KIO::Scheduler::ProtocolInfo *
-KIO::Scheduler::ProtocolInfoDict::get(const QString &protocol)
-{
-    ProtocolInfo *info = value(protocol, 0);
-    if (!info)
-    {
-        info = new ProtocolInfo;
-        info->protocol = protocol;
-        info->maxSlaves = KProtocolInfo::maxSlaves( protocol );
-
-        insert(protocol, info);
-    }
-    return info;
-}
-
 
 Scheduler::Scheduler()
-    : QObject()
+    : QObject(), d(0)
 {
     setObjectName( "scheduler" );
 
     const QString dbusPath = "/KIO/Scheduler";
     const QString dbusInterface = "org.kde.KIO.Scheduler";
     QDBusConnection dbus = QDBusConnection::sessionBus();
-    dbus.registerObject("/KIO/Scheduler", this, QDBusConnection::ExportScriptableSlots);
+    dbus.registerObject( "/KIO/Scheduler", this, QDBusConnection::ExportScriptableSlots |
+                                                 QDBusConnection::ExportScriptableSignals );
     dbus.connect(QString(), dbusPath, dbusInterface, "reparseSlaveConfiguration",
                  this, SLOT(slotReparseSlaveConfiguration(QString)));
-#ifdef __GNUC__
-#warning TODO adaptor, or wait for ExportSignals with Qt-4.2
-#endif
-
-    slaveTimer.setObjectName( "Scheduler::slaveTimer" );
-    slaveTimer.setSingleShot( true );
-    coSlaveTimer.setObjectName( "Scheduler::coSlaveTimer" );
-    coSlaveTimer.setSingleShot( true );
-    cleanupTimer.setObjectName( "Scheduler::cleanupTimer" );
-    cleanupTimer.setSingleShot( true );
-    checkOnHold = true; // !! Always check with KLauncher for the first request.
-    slaveOnHold = 0;
-    protInfoDict = new ProtocolInfoDict;
-    slaveList = new SlaveList;
-    idleSlaves = new SlaveList;
-    coIdleSlaves = new SlaveList;
-    extraJobData = new ExtraJobData;
-    sessionData = new SessionData;
-    slaveConfig = SlaveConfig::self();
-    connect(&slaveTimer, SIGNAL(timeout()), SLOT(startStep()));
-    connect(&coSlaveTimer, SIGNAL(timeout()), SLOT(slotScheduleCoSlave()));
-    connect(&cleanupTimer, SIGNAL(timeout()), SLOT(slotCleanIdleSlaves()));
-    busy = false;
 }
 
 Scheduler::~Scheduler()
 {
-    qDeleteAll( *protInfoDict );
-    delete protInfoDict; protInfoDict = 0;
-    delete idleSlaves; idleSlaves = 0;
-    delete coIdleSlaves; coIdleSlaves = 0;
-    qDeleteAll( *slaveList );
-    delete slaveList; slaveList = 0;
-    delete extraJobData; extraJobData = 0;
-    delete sessionData; sessionData = 0;
-    instance = 0;
+}
+
+void Scheduler::doJob(SimpleJob *job)
+{
+    schedulerPrivate->doJob(job);
+}
+
+void Scheduler::scheduleJob(SimpleJob *job)
+{
+    schedulerPrivate->scheduleJob(job);
+}
+
+void Scheduler::cancelJob(SimpleJob *job)
+{
+    schedulerPrivate->cancelJob(job);
+}
+
+void Scheduler::jobFinished(KIO::SimpleJob *job, KIO::Slave *slave)
+{
+    schedulerPrivate->jobFinished(job, slave);
+}
+
+void Scheduler::putSlaveOnHold(KIO::SimpleJob *job, const KUrl &url)
+{
+    schedulerPrivate->putSlaveOnHold(job, url);
+}
+
+void Scheduler::removeSlaveOnHold()
+{
+    schedulerPrivate->removeSlaveOnHold();
+}
+
+void Scheduler::publishSlaveOnHold()
+{
+    schedulerPrivate->publishSlaveOnHold();
+}
+
+KIO::Slave *Scheduler::getConnectedSlave(const KUrl &url,
+        const KIO::MetaData &config )
+{
+    return schedulerPrivate->getConnectedSlave(url, config);
+}
+
+bool Scheduler::assignJobToSlave(KIO::Slave *slave, KIO::SimpleJob *job)
+{
+    return schedulerPrivate->assignJobToSlave(slave, job);
+}
+
+bool Scheduler::disconnectSlave(KIO::Slave *slave)
+{
+    return schedulerPrivate->disconnectSlave(slave);
+}
+
+void Scheduler::registerWindow(QWidget *wid)
+{
+    schedulerPrivate->registerWindow(wid);
+}
+
+void Scheduler::unregisterWindow(QObject *wid)
+{
+    schedulerPrivate->slotUnregisterWindow(wid);
+}
+
+bool Scheduler::connect( const char *signal, const QObject *receiver,
+                         const char *member)
+{
+    return QObject::connect(self(), signal, receiver, member);
+}
+
+bool Scheduler::connect( const QObject* sender, const char* signal,
+                         const QObject* receiver, const char* member )
+{
+    return QObject::connect(sender, signal, receiver, member);
+}
+
+bool Scheduler::disconnect( const QObject* sender, const char* signal,
+                            const QObject* receiver, const char* member )
+{
+    return QObject::disconnect(sender, signal, receiver, member);
+}
+
+bool Scheduler::connect( const QObject *sender, const char *signal,
+                         const char *member )
+{
+    return QObject::connect(sender, signal, member);
+}
+
+void Scheduler::checkSlaveOnHold(bool b)
+{
+    schedulerPrivate->checkSlaveOnHold(b);
+}
+
+void Scheduler::emitReparseSlaveConfiguration()
+{
+    self()->reparseSlaveConfiguration( QString() );
 }
 
 void
-Scheduler::debug_info()
+SchedulerPrivate::debug_info()
 {
 }
 
-void Scheduler::slotReparseSlaveConfiguration(const QString &proto)
+void SchedulerPrivate::slotReparseSlaveConfiguration(const QString &proto)
 {
-    kDebug( 7006 ) << "reparseSlaveConfiguration( " << proto << " )" << endl;
+    kDebug( 7006 ) << "reparseSlaveConfiguration( " << proto << " )";
     KProtocolManager::reparseConfiguration();
     slaveConfig->reset();
     sessionData->reset();
     NetRC::self()->reload();
 
-    foreach( Slave *slave, *slaveList )
+    foreach( Slave *slave, slaveList )
     {
         if ( slave->slaveProtocol() == proto || proto.isEmpty() )
         {
@@ -192,49 +360,49 @@ void Scheduler::slotReparseSlaveConfiguration(const QString &proto)
     }
 }
 
-void Scheduler::_doJob(SimpleJob *job) {
+void SchedulerPrivate::doJob(SimpleJob *job) {
     JobData jobData;
     jobData.protocol = KProtocolManager::slaveProtocol(job->url(), jobData.proxy);
-//    kDebug(7006) << "Scheduler::_doJob protocol=" << jobData->protocol << endl;
-    if (job->command() == CMD_GET)
+//    kDebug(7006) << "SchedulerPrivate::doJob protocol=" << jobData->protocol;
+    if (jobCommand(job) == CMD_GET)
     {
        jobData.checkOnHold = checkOnHold;
        checkOnHold = false;
     }
-    extraJobData->insert(job, jobData);
+    extraJobData.insert(job, jobData);
     newJobs.append(job);
     slaveTimer.start(0);
 #ifndef NDEBUG
     if (newJobs.count() > 150)
-	kDebug() << "WARNING - KIO::Scheduler got more than 150 jobs! This shows a misuse in your app (yes, a job is a QObject)." << endl;
+	kDebug() << "WARNING - KIO::Scheduler got more than 150 jobs! This shows a misuse in your app (yes, a job is a QObject).";
 #endif
 }
 
-void Scheduler::_scheduleJob(SimpleJob *job) {
+void SchedulerPrivate::scheduleJob(SimpleJob *job) {
     newJobs.removeAll(job);
-    JobData jobData = extraJobData->value(job);
+    JobData jobData = extraJobData.value(job);
 
     QString protocol = jobData.protocol;
-//    kDebug(7006) << "Scheduler::_scheduleJob protocol=" << protocol << endl;
-    ProtocolInfo *protInfo = protInfoDict->get(protocol);
+//    kDebug(7006) << "SchedulerPrivate::scheduleJob protocol=" << protocol;
+    ProtocolInfo *protInfo = protInfoDict.get(protocol);
     protInfo->joblist.append(job);
 
     slaveTimer.start(0);
 }
 
-void Scheduler::_cancelJob(SimpleJob *job) {
-//    kDebug(7006) << "Scheduler: canceling job " << job << endl;
-    Slave *slave = job->slave();
+void SchedulerPrivate::cancelJob(SimpleJob *job) {
+//    kDebug(7006) << "Scheduler: canceling job " << job;
+    Slave *slave = jobSlave(job);
     if ( !slave  )
     {
         // was not yet running (don't call this on a finished job!)
-        JobData jobData = extraJobData->value(job);
+        JobData jobData = extraJobData.value(job);
         newJobs.removeAll(job);
-        ProtocolInfo *protInfo = protInfoDict->get(jobData.protocol);
+        ProtocolInfo *protInfo = protInfoDict.get(jobData.protocol);
         protInfo->joblist.removeAll(job);
 
         // Search all slaves to see if job is in the queue of a coSlave
-        foreach( Slave* coSlave, *slaveList )
+        foreach( Slave* coSlave, slaveList )
         {
            JobList *list = coSlaves.value(slave);
            if (list && list->removeAll(job)) {
@@ -245,31 +413,30 @@ void Scheduler::_cancelJob(SimpleJob *job) {
         }
         if (!slave)
         {
-           extraJobData->remove(job);
+           extraJobData.remove(job);
            return; // Job was not yet running and not in a coSlave queue.
         }
     }
-    kDebug(7006) << "Scheduler: killing slave " << slave->slave_pid() << endl;
+    kDebug(7006) << "Scheduler: killing slave " << slave->slave_pid();
     slave->kill();
-    _jobFinished( job, slave );
-    slotSlaveDied( slave);
+    jobFinished( job, slave );
+    slotSlaveDied(slave);
 }
 
-void Scheduler::startStep()
+void SchedulerPrivate::startStep()
 {
-    while(newJobs.count())
-    {
+    while (newJobs.count()) {
        (void) startJobDirect();
     }
 
-    QHashIterator<QString, KIO::Scheduler::ProtocolInfo*> it(*protInfoDict);
+    QHashIterator<QString, ProtocolInfo*> it(protInfoDict);
     while(it.hasNext()) {
        it.next();
        if (startJobScheduled(it.value())) return;
     }
 }
 
-void Scheduler::setupSlave(KIO::Slave *slave, const KUrl &url, const QString &protocol, const QString &proxy , bool newSlave, const KIO::MetaData *config)
+void SchedulerPrivate::setupSlave(KIO::Slave *slave, const KUrl &url, const QString &protocol, const QString &proxy , bool newSlave, const KIO::MetaData *config)
 {
     QString host = url.host();
     int port = url.port();
@@ -319,12 +486,12 @@ void Scheduler::setupSlave(KIO::Slave *slave, const KUrl &url, const QString &pr
     }
 }
 
-bool Scheduler::startJobScheduled(ProtocolInfo *protInfo)
+bool SchedulerPrivate::startJobScheduled(ProtocolInfo *protInfo)
 {
     if (protInfo->joblist.isEmpty())
        return false;
 
-//       kDebug(7006) << "Scheduling job" << endl;
+//       kDebug(7006) << "Scheduling job";
     debug_info();
     bool newSlave = false;
 
@@ -382,33 +549,33 @@ bool Scheduler::startJobScheduled(ProtocolInfo *protInfo)
 
     if (!slave)
     {
-//          kDebug(7006) << "No slaves available" << endl;
-//          kDebug(7006) << " -- active: " << protInfo->activeSlaves.count() << endl;
+//          kDebug(7006) << "No slaves available";
+//          kDebug(7006) << " -- active: " << protInfo->activeSlaves.count();
        return false;
     }
 
     protInfo->activeSlaves.append(slave);
-    idleSlaves->removeAll(slave);
+    idleSlaves.removeAll(slave);
     protInfo->joblist.removeAll(job);
-//       kDebug(7006) << "scheduler: job started " << job << endl;
+//       kDebug(7006) << "scheduler: job started " << job;
 
 
-    JobData jobData = extraJobData->value(job);
+    SchedulerPrivate::JobData jobData = extraJobData.value(job);
     setupSlave(slave, job->url(), jobData.protocol, jobData.proxy, newSlave);
-    job->start(slave);
+    startJob(job, slave);
 
     slaveTimer.start(0);
     return true;
 }
 
-bool Scheduler::startJobDirect()
+bool SchedulerPrivate::startJobDirect()
 {
     debug_info();
     SimpleJob *job = newJobs.takeFirst();
-    JobData jobData = extraJobData->value(job);
+    SchedulerPrivate::JobData jobData = extraJobData.value(job);
 
     QString protocol = jobData.protocol;
-    ProtocolInfo *protInfo = protInfoDict->get(protocol);
+    ProtocolInfo *protInfo = protInfoDict.get(protocol);
 
     bool newSlave = false;
     bool dummy;
@@ -425,15 +592,15 @@ bool Scheduler::startJobDirect()
     if (!slave)
        return false;
 
-    idleSlaves->removeAll(slave);
-//       kDebug(7006) << "scheduler: job started " << job << endl;
+    idleSlaves.removeAll(slave);
+//       kDebug(7006) << "scheduler: job started " << job;
 
     setupSlave(slave, job->url(), protocol, jobData.proxy, newSlave);
-    job->start(slave);
+    startJob(job, slave);
     return true;
 }
 
-static Slave *searchIdleList(SlaveList *idleSlaves, const KUrl &url, const QString &protocol, bool &exact)
+static Slave *searchIdleList(SlaveList &idleSlaves, const KUrl &url, const QString &protocol, bool &exact)
 {
     QString host = url.host();
     int port = url.port();
@@ -442,7 +609,7 @@ static Slave *searchIdleList(SlaveList *idleSlaves, const KUrl &url, const QStri
     QString user = url.user();
     exact = true;
 
-    foreach( Slave *slave, *idleSlaves )
+    foreach( Slave *slave, idleSlaves )
     {
        if ((protocol == slave->slaveProtocol()) &&
            (host == slave->host()) &&
@@ -454,7 +621,7 @@ static Slave *searchIdleList(SlaveList *idleSlaves, const KUrl &url, const QStri
     exact = false;
 
     // Look for slightly matching slave
-    foreach( Slave *slave, *idleSlaves )
+    foreach( Slave *slave, idleSlaves )
     {
        if (protocol == slave->slaveProtocol())
           return slave;
@@ -462,10 +629,10 @@ static Slave *searchIdleList(SlaveList *idleSlaves, const KUrl &url, const QStri
     return 0;
 }
 
-Slave *Scheduler::findIdleSlave(ProtocolInfo *, SimpleJob *job, bool &exact)
+Slave *SchedulerPrivate::findIdleSlave(ProtocolInfo *, SimpleJob *job, bool &exact)
 {
     Slave *slave = 0;
-    JobData jobData = extraJobData->value(job);
+    JobData jobData = extraJobData.value(job);
 
     if (jobData.checkOnHold)
     {
@@ -476,30 +643,30 @@ Slave *Scheduler::findIdleSlave(ProtocolInfo *, SimpleJob *job, bool &exact)
     if (slaveOnHold)
     {
        // Make sure that the job wants to do a GET or a POST, and with no offset
-       bool bCanReuse = (job->command() == CMD_GET);
+       bool bCanReuse = (jobCommand(job) == CMD_GET);
        KIO::TransferJob * tJob = qobject_cast<KIO::TransferJob *>(job);
        if ( tJob )
        {
-          bCanReuse = (job->command() == CMD_GET || job->command() == CMD_SPECIAL);
+          bCanReuse = (jobCommand(job) == CMD_GET || jobCommand(job) == CMD_SPECIAL);
           if ( bCanReuse )
           {
             KIO::MetaData outgoing = tJob->outgoingMetaData();
             QString resume = (!outgoing.contains("resume")) ? QString() : outgoing["resume"];
-            kDebug(7006) << "Resume metadata is '" << resume << "'" << endl;
+            kDebug(7006) << "Resume metadata is '" << resume << "'";
             bCanReuse = (resume.isEmpty() || resume == "0");
           }
        }
-//       kDebug(7006) << "bCanReuse = " << bCanReuse << endl;
+//       kDebug(7006) << "bCanReuse = " << bCanReuse;
        if (bCanReuse)
        {
           if (job->url() == urlOnHold)
           {
-             kDebug(7006) << "HOLD: Reusing held slave for " << urlOnHold.prettyUrl() << endl;
+             kDebug(7006) << "HOLD: Reusing held slave for " << urlOnHold.prettyUrl();
              slave = slaveOnHold;
           }
           else
           {
-             kDebug(7006) << "HOLD: Discarding held slave (" << urlOnHold.prettyUrl() << ")" << endl;
+             kDebug(7006) << "HOLD: Discarding held slave (" << urlOnHold.prettyUrl() << ")";
              slaveOnHold->kill();
           }
           slaveOnHold = 0;
@@ -512,19 +679,19 @@ Slave *Scheduler::findIdleSlave(ProtocolInfo *, SimpleJob *job, bool &exact)
     return searchIdleList(idleSlaves, job->url(), jobData.protocol, exact);
 }
 
-Slave *Scheduler::createSlave(ProtocolInfo *protInfo, SimpleJob *job, const KUrl &url)
+Slave *SchedulerPrivate::createSlave(ProtocolInfo *protInfo, SimpleJob *job, const KUrl &url)
 {
    int error;
    QString errortext;
    Slave *slave = Slave::createSlave(protInfo->protocol, url, error, errortext);
    if (slave)
    {
-      slaveList->append(slave);
-      idleSlaves->append(slave);
-      connect(slave, SIGNAL(slaveDied(KIO::Slave *)),
-                SLOT(slotSlaveDied(KIO::Slave *)));
-      connect(slave, SIGNAL(slaveStatus(pid_t,const QByteArray&,const QString &, bool)),
-                SLOT(slotSlaveStatus(pid_t,const QByteArray&, const QString &, bool)));
+      slaveList.append(slave);
+      idleSlaves.append(slave);
+      q->connect(slave, SIGNAL(slaveDied(KIO::Slave *)),
+                 SLOT(slotSlaveDied(KIO::Slave *)));
+      q->connect(slave, SIGNAL(slaveStatus(pid_t,const QByteArray&,const QString &, bool)),
+                 SLOT(slotSlaveStatus(pid_t,const QByteArray&, const QString &, bool)));
    }
    else
    {
@@ -532,22 +699,22 @@ Slave *Scheduler::createSlave(ProtocolInfo *protInfo, SimpleJob *job, const KUrl
       if (job)
       {
          protInfo->joblist.removeAll(job);
-         extraJobData->remove(job);
+         extraJobData.remove(job);
          job->slotError( error, errortext );
       }
    }
    return slave;
 }
 
-void Scheduler::slotSlaveStatus(pid_t, const QByteArray&, const QString &, bool)
+void SchedulerPrivate::slotSlaveStatus(pid_t, const QByteArray&, const QString &, bool)
 {
 }
 
-void Scheduler::_jobFinished(SimpleJob *job, Slave *slave)
+void SchedulerPrivate::jobFinished(SimpleJob *job, Slave *slave)
 {
-    JobData jobData = extraJobData->take(job);
+    JobData jobData = extraJobData.take(job);
 
-    ProtocolInfo *protInfo = protInfoDict->get(jobData.protocol);
+    ProtocolInfo *protInfo = protInfoDict.get(jobData.protocol);
     slave->disconnect(job);
     protInfo->activeSlaves.removeAll(slave);
     if (slave->isAlive())
@@ -556,8 +723,8 @@ void Scheduler::_jobFinished(SimpleJob *job, Slave *slave)
        if (list)
        {
           assert(slave->isConnected());
-          assert(!coIdleSlaves->contains(slave));
-          coIdleSlaves->append(slave);
+          assert(!coIdleSlaves.contains(slave));
+          coIdleSlaves.append(slave);
           if (!list->isEmpty())
              coSlaveTimer.start(0);
           return;
@@ -565,9 +732,9 @@ void Scheduler::_jobFinished(SimpleJob *job, Slave *slave)
        else
        {
           assert(!slave->isConnected());
-          idleSlaves->append(slave);
+          idleSlaves.append(slave);
           slave->setIdle();
-          _scheduleCleanup();
+          scheduleCleanup();
 //          slave->send( CMD_SLAVE_STATUS );
        }
     }
@@ -577,17 +744,17 @@ void Scheduler::_jobFinished(SimpleJob *job, Slave *slave)
     }
 }
 
-void Scheduler::slotSlaveDied(KIO::Slave *slave)
+void SchedulerPrivate::slotSlaveDied(KIO::Slave *slave)
 {
     assert(!slave->isAlive());
-    ProtocolInfo *protInfo = protInfoDict->get(slave->slaveProtocol());
+    ProtocolInfo *protInfo = protInfoDict.get(slave->slaveProtocol());
     protInfo->activeSlaves.removeAll(slave);
     if (slave == slaveOnHold)
     {
        slaveOnHold = 0;
        urlOnHold = KUrl();
     }
-    idleSlaves->removeAll(slave);
+    idleSlaves.removeAll(slave);
     JobList *list = coSlaves.value(slave);
     if (list)
     {
@@ -595,24 +762,24 @@ void Scheduler::slotSlaveDied(KIO::Slave *slave)
        disconnectSlave(slave);
     }
 
-    if (!slaveList->removeAll(slave))
-        kDebug(7006) << "Scheduler: BUG!! Slave " << slave << "/" << slave->slave_pid() << " died, but is NOT in slaveList!!!\n" << endl;
+    if (!slaveList.removeAll(slave))
+        kDebug(7006) << "Scheduler: BUG!! Slave " << slave << "/" << slave->slave_pid() << " died, but is NOT in slaveList!!!\n";
     else
         slave->deref(); // Delete slave
 }
 
-void Scheduler::slotCleanIdleSlaves()
+void SchedulerPrivate::slotCleanIdleSlaves()
 {
-    SlaveList::iterator it = idleSlaves->begin();
-    for( ; it != idleSlaves->end(); )
+    SlaveList::iterator it = idleSlaves.begin();
+    for( ; it != idleSlaves.end(); )
     {
         Slave *slave = *it;
         if (slave->idleTime() >= MAX_SLAVE_IDLE)
         {
-           // kDebug(7006) << "Removing idle slave: " << slave->slaveProtocol() << " " << slave->host() << endl;
+           // kDebug(7006) << "Removing idle slave: " << slave->slaveProtocol() << " " << slave->host();
            Slave *removeSlave = slave;
-           it = idleSlaves->erase( it );
-           slaveList->removeAll( removeSlave );
+           it = idleSlaves.erase( it );
+           slaveList.removeAll( removeSlave );
            removeSlave->connection()->close();
            removeSlave->deref();
         }
@@ -621,21 +788,21 @@ void Scheduler::slotCleanIdleSlaves()
             ++it;
         }
     }
-    _scheduleCleanup();
+    scheduleCleanup();
 }
 
-void Scheduler::_scheduleCleanup()
+void SchedulerPrivate::scheduleCleanup()
 {
-    if (idleSlaves->count())
+    if (idleSlaves.count())
     {
         if (!cleanupTimer.isActive())
             cleanupTimer.start( MAX_SLAVE_IDLE*1000 );
     }
 }
 
-void Scheduler::_putSlaveOnHold(KIO::SimpleJob *job, const KUrl &url)
+void SchedulerPrivate::putSlaveOnHold(KIO::SimpleJob *job, const KUrl &url)
 {
-    Slave *slave = job->slave();
+    Slave *slave = jobSlave(job);
     slave->disconnect(job);
 
     if (slaveOnHold)
@@ -647,7 +814,7 @@ void Scheduler::_putSlaveOnHold(KIO::SimpleJob *job, const KUrl &url)
     slaveOnHold->suspend();
 }
 
-void Scheduler::_publishSlaveOnHold()
+void SchedulerPrivate::publishSlaveOnHold()
 {
     if (!slaveOnHold)
        return;
@@ -655,7 +822,7 @@ void Scheduler::_publishSlaveOnHold()
     slaveOnHold->hold(urlOnHold);
 }
 
-void Scheduler::_removeSlaveOnHold()
+void SchedulerPrivate::removeSlaveOnHold()
 {
     if (slaveOnHold)
     {
@@ -666,7 +833,7 @@ void Scheduler::_removeSlaveOnHold()
 }
 
 Slave *
-Scheduler::_getConnectedSlave(const KUrl &url, const KIO::MetaData &config )
+SchedulerPrivate::getConnectedSlave(const KUrl &url, const KIO::MetaData &config )
 {
     QString proxy;
     QString protocol = KProtocolManager::slaveProtocol(url, proxy);
@@ -674,32 +841,32 @@ Scheduler::_getConnectedSlave(const KUrl &url, const KIO::MetaData &config )
     Slave *slave = searchIdleList(idleSlaves, url, protocol, dummy);
     if (!slave)
     {
-       ProtocolInfo *protInfo = protInfoDict->get(protocol);
+       ProtocolInfo *protInfo = protInfoDict.get(protocol);
        slave = createSlave(protInfo, 0, url);
     }
     if (!slave)
        return 0; // Error
-    idleSlaves->removeAll(slave);
+    idleSlaves.removeAll(slave);
 
     setupSlave(slave, url, protocol, proxy, true, &config);
 
     slave->send( CMD_CONNECT );
-    connect(slave, SIGNAL(connected()),
-                SLOT(slotSlaveConnected()));
-    connect(slave, SIGNAL(error(int, const QString &)),
-                SLOT(slotSlaveError(int, const QString &)));
+    q->connect(slave, SIGNAL(connected()),
+               SLOT(slotSlaveConnected()));
+    q->connect(slave, SIGNAL(error(int, const QString &)),
+               SLOT(slotSlaveError(int, const QString &)));
 
     coSlaves.insert(slave, new JobList);
-//    kDebug(7006) << "_getConnectedSlave( " << slave << ")" << endl;
+//    kDebug(7006) << "_getConnectedSlave( " << slave << ")";
     return slave;
 }
 
 void
-Scheduler::slotScheduleCoSlave()
+SchedulerPrivate::slotScheduleCoSlave()
 {
     slaveConfig = SlaveConfig::self();
-    SlaveList::iterator it = coIdleSlaves->begin();
-    for( ; it != coIdleSlaves->end(); )
+    SlaveList::iterator it = coIdleSlaves.begin();
+    for( ; it != coIdleSlaves.end(); )
     {
         Slave* slave = *it;
         JobList *list = coSlaves.value(slave);
@@ -707,8 +874,8 @@ Scheduler::slotScheduleCoSlave()
         if (list && !list->isEmpty())
         {
            SimpleJob *job = list->takeFirst();
-           it = coIdleSlaves->erase( it );
-//           kDebug(7006) << "scheduler: job started " << job << endl;
+           it = coIdleSlaves.erase( it );
+//           kDebug(7006) << "scheduler: job started " << job;
 
            KUrl url =job->url();
            QString host = url.host();
@@ -730,7 +897,7 @@ Scheduler::slotScheduleCoSlave()
            assert(slave->protocol() == url.protocol());
            assert(slave->host() == host);
            assert(slave->port() == port);
-           job->start(slave);
+           startJob(job, slave);
         } else {
             ++it;
         }
@@ -738,40 +905,40 @@ Scheduler::slotScheduleCoSlave()
 }
 
 void
-Scheduler::slotSlaveConnected()
+SchedulerPrivate::slotSlaveConnected()
 {
-    Slave *slave = (Slave *)sender();
-//    kDebug(7006) << "slotSlaveConnected( " << slave << ")" << endl;
+    Slave *slave = static_cast<Slave *>(q->sender());
+//    kDebug(7006) << "slotSlaveConnected( " << slave << ")";
     slave->setConnected(true);
-    disconnect(slave, SIGNAL(connected()),
-               this, SLOT(slotSlaveConnected()));
-    emit slaveConnected(slave);
-    assert(!coIdleSlaves->contains(slave));
-    coIdleSlaves->append(slave);
+    q->disconnect(slave, SIGNAL(connected()),
+                  q, SLOT(slotSlaveConnected()));
+    emit q->slaveConnected(slave);
+    assert(!coIdleSlaves.contains(slave));
+    coIdleSlaves.append(slave);
     coSlaveTimer.start(0);
 }
 
 void
-Scheduler::slotSlaveError(int errorNr, const QString &errorMsg)
+SchedulerPrivate::slotSlaveError(int errorNr, const QString &errorMsg)
 {
-    Slave *slave = (Slave *)sender();
-    if (!slave->isConnected() || coIdleSlaves->contains(slave))
+    Slave *slave = static_cast<Slave *>(q->sender());
+    if (!slave->isConnected() || coIdleSlaves.contains(slave))
     {
        // Only forward to application if slave is idle or still connecting.
-       emit slaveError(slave, errorNr, errorMsg);
+       emit q->slaveError(slave, errorNr, errorMsg);
     }
 }
 
 bool
-Scheduler::_assignJobToSlave(KIO::Slave *slave, SimpleJob *job)
+SchedulerPrivate::assignJobToSlave(KIO::Slave *slave, SimpleJob *job)
 {
-//    kDebug(7006) << "_assignJobToSlave( " << job << ", " << slave << ")" << endl;
+//    kDebug(7006) << "_assignJobToSlave( " << job << ", " << slave << ")";
     QString dummy;
     if ((slave->slaveProtocol() != KProtocolManager::slaveProtocol( job->url(), dummy ))
         ||
         (!newJobs.removeAll(job)))
     {
-        kDebug(7006) << "_assignJobToSlave(): ERROR, nonmatching or unknown job." << endl;
+        kDebug(7006) << "_assignJobToSlave(): ERROR, nonmatching or unknown job.";
         job->kill();
         return false;
     }
@@ -780,7 +947,7 @@ Scheduler::_assignJobToSlave(KIO::Slave *slave, SimpleJob *job)
     assert(list);
     if (!list)
     {
-        kDebug(7006) << "_assignJobToSlave(): ERROR, unknown slave." << endl;
+        kDebug(7006) << "_assignJobToSlave(): ERROR, unknown slave.";
         job->kill();
         return false;
     }
@@ -793,9 +960,9 @@ Scheduler::_assignJobToSlave(KIO::Slave *slave, SimpleJob *job)
 }
 
 bool
-Scheduler::_disconnectSlave(KIO::Slave *slave)
+SchedulerPrivate::disconnectSlave(KIO::Slave *slave)
 {
-//    kDebug(7006) << "_disconnectSlave( " << slave << ")" << endl;
+//    kDebug(7006) << "_disconnectSlave( " << slave << ")";
     CoSlaveMap::iterator coSlaveIt = coSlaves.find( slave );
     assert( coSlaveIt != coSlaves.end() );
     JobList *list = *coSlaveIt;
@@ -810,31 +977,31 @@ Scheduler::_disconnectSlave(KIO::Slave *slave)
        job->kill();
     }
     delete list;
-    coIdleSlaves->removeAll(slave);
-    assert(!coIdleSlaves->contains(slave));
-    disconnect(slave, SIGNAL(connected()),
-               this, SLOT(slotSlaveConnected()));
-    disconnect(slave, SIGNAL(error(int, const QString &)),
-               this, SLOT(slotSlaveError(int, const QString &)));
+    coIdleSlaves.removeAll(slave);
+    assert(!coIdleSlaves.contains(slave));
+    QObject::disconnect(slave, SIGNAL(connected()),
+                        q, SLOT(slotSlaveConnected()));
+    QObject::disconnect(slave, SIGNAL(error(int, const QString &)),
+                        q, SLOT(slotSlaveError(int, const QString &)));
     if (slave->isAlive())
     {
-       idleSlaves->append(slave);
+       idleSlaves.append(slave);
        slave->send( CMD_DISCONNECT );
        slave->setIdle();
        slave->setConnected(false);
-       _scheduleCleanup();
+       scheduleCleanup();
     }
     return true;
 }
 
 void
-Scheduler::_checkSlaveOnHold(bool b)
+SchedulerPrivate::checkSlaveOnHold(bool b)
 {
     checkOnHold = b;
 }
 
 void
-Scheduler::_registerWindow(QWidget *wid)
+SchedulerPrivate::registerWindow(QWidget *wid)
 {
    if (!wid)
       return;
@@ -847,15 +1014,15 @@ Scheduler::_registerWindow(QWidget *wid)
       // access QWidget::winId() (already destructed)
       WId windowId = wid->winId();
       m_windowList.insert(obj, windowId);
-      connect(wid, SIGNAL(destroyed(QObject *)),
-              this, SLOT(slotUnregisterWindow(QObject*)));
+      q->connect(wid, SIGNAL(destroyed(QObject *)),
+                 SLOT(slotUnregisterWindow(QObject*)));
       QDBusInterface("org.kde.kded", "/kded", "org.kde.kded").
           call(QDBus::NoBlock, "registerWindowId", qlonglong(windowId));
    }
 }
 
 void
-Scheduler::slotUnregisterWindow(QObject *obj)
+SchedulerPrivate::slotUnregisterWindow(QObject *obj)
 {
    if (!obj)
       return;
@@ -864,20 +1031,11 @@ Scheduler::slotUnregisterWindow(QObject *obj)
    if (it == m_windowList.end())
       return;
    WId windowId = it.value();
-   disconnect( it.key(), SIGNAL(destroyed(QObject *)),
-              this, SLOT(slotUnregisterWindow(QObject*)));
+   q->disconnect(it.key(), SIGNAL(destroyed(QObject *)),
+                 q, SLOT(slotUnregisterWindow(QObject*)));
    m_windowList.erase( it );
    QDBusInterface("org.kde.kded", "/kded", "org.kde.kded").
        call(QDBus::NoBlock, "unregisterWindowId", qlonglong(windowId));
 }
 
-static KStaticDeleter<Scheduler> kioSchedulerSd;
-
-Scheduler* Scheduler::self() {
-    if ( !instance ) {
-        kioSchedulerSd.setObject( instance, new Scheduler );
-    }
-    return instance;
-}
-
 #include "scheduler.moc"
