@@ -24,18 +24,18 @@
 
 #include "kio/job.h"
 #include "kio/jobclasses.h"
-#include <qtimer.h>
-#include <qmap.h>
-#include <qwindowdefs.h>
+#include <QtCore/QTimer>
+#include <QtCore/QMap>
+#include <QtGui/QWidgetList>
 #include <sys/types.h> // pid_t
 
 namespace KIO {
 
     class Slave;
-    class SlaveList;
     class SlaveConfig;
     class SessionData;
 
+    class SchedulerPrivate;
     /**
      * The KIO::Scheduler manages io-slaves for the application.
      * It also queues jobs and assigns the job to a slave when one
@@ -112,22 +112,13 @@ namespace KIO {
         Q_OBJECT
 
     public:
-        typedef QList<SimpleJob *> JobList;
-
-        // InfoDict needs Info, so we can't declare it private
-        class ProtocolInfo;
-        class JobData;
-
-        ~Scheduler();
-
         /**
          * Register @p job with the scheduler.
          * The default is to create a new slave for the job if no slave
          * is available. This can be changed by calling scheduleJob.
 	 * @param job the job to register
          */
-        static void doJob(SimpleJob *job)
-        { self()->_doJob(job); }
+        static void doJob(SimpleJob *job);
 
         /**
          * Calling ths function makes that @p job gets scheduled for later
@@ -135,23 +126,20 @@ namespace KIO {
          * other jobs to finish.
 	 * @param job the job to schedule
          */
-        static void scheduleJob(SimpleJob *job)
-        { self()->_scheduleJob(job); }
+        static void scheduleJob(SimpleJob *job);
 
         /**
          * Stop the execution of a job.
 	 * @param job the job to cancel
          */
-        static void cancelJob(SimpleJob *job)
-        { self()->_cancelJob(job); }
+        static void cancelJob(SimpleJob *job);
 
         /**
          * Called when a job is done.
 	 * @param job the finished job
 	 * @param slave the slave that executed the @p job
          */
-        static void jobFinished(KIO::SimpleJob *job, KIO::Slave *slave)
-        { self()->_jobFinished(job, slave); }
+        static void jobFinished(KIO::SimpleJob *job, KIO::Slave *slave);
 
         /**
          * Puts a slave on notice. A next job may reuse this slave if it
@@ -164,23 +152,20 @@ namespace KIO {
 	 * @param job the job that should be stopped
 	 * @param url the URL that is handled by the @p url
          */
-        static void putSlaveOnHold(KIO::SimpleJob *job, const KUrl &url)
-        { self()->_putSlaveOnHold(job, url); }
+        static void putSlaveOnHold(KIO::SimpleJob *job, const KUrl &url);
 
         /**
          * Removes any slave that might have been put on hold. If a slave
          * was put on hold it will be killed.
          */
-        static void removeSlaveOnHold()
-        { self()->_removeSlaveOnHold(); }
+        static void removeSlaveOnHold();
 
         /**
          * Send the slave that was put on hold back to KLauncher. This
          * allows another process to take over the slave and resume the job
          * that was started.
          */
-        static void publishSlaveOnHold()
-        { self()->_publishSlaveOnHold(); }
+        static void publishSlaveOnHold();
 
         /**
          * Requests a slave for use in connection-oriented mode.
@@ -193,8 +178,8 @@ namespace KIO {
          * @see assignJobToSlave()
          * @see disconnectSlave()
          */
-        static KIO::Slave *getConnectedSlave(const KUrl &url, const KIO::MetaData &config = MetaData() )
-        { return self()->_getConnectedSlave(url, config); }
+        static KIO::Slave *getConnectedSlave(const KUrl &url,
+                const KIO::MetaData &config = MetaData() );
 
         /*
          * Uses @p slave to do @p job.
@@ -212,8 +197,7 @@ namespace KIO {
          * @see slaveConnected()
          * @see slaveError()
          */
-        static bool assignJobToSlave(KIO::Slave *slave, KIO::SimpleJob *job)
-        { return self()->_assignJobToSlave(slave, job); }
+        static bool assignJobToSlave(KIO::Slave *slave, KIO::SimpleJob *job);
 
         /*
          * Disconnects @p slave.
@@ -227,8 +211,7 @@ namespace KIO {
          * @see getConnectedSlave
          * @see assignJobToSlave
          */
-        static bool disconnectSlave(KIO::Slave *slave)
-        { return self()->_disconnectSlave(slave); }
+        static bool disconnectSlave(KIO::Slave *slave);
 
         /**
          * Send the slave that was put on hold back to KLauncher. This
@@ -239,15 +222,13 @@ namespace KIO {
          * void KIO::Job::setWindow(QWidget*).
 	 * @param wid the window to register
          */
-        static void registerWindow(QWidget *wid)
-        { self()->_registerWindow(wid); }
+        static void registerWindow(QWidget *wid);
 
         /**
          * @internal
          * Unregisters the window registered by registerWindow().
          */
-        static void unregisterWindow(QObject *wid)
-        { self()->slotUnregisterWindow(wid); }
+        static void unregisterWindow(QObject *wid);
 
         /**
          * Function to connect signals emitted by the scheduler.
@@ -256,111 +237,56 @@ namespace KIO {
          * @see slaveError()
          */
         static bool connect( const char *signal, const QObject *receiver,
-                             const char *member)
-        { return QObject::connect(self(), signal, receiver, member); }
+                             const char *member);
 
         static bool connect( const QObject* sender, const char* signal,
-                             const QObject* receiver, const char* member )
-        { return QObject::connect(sender, signal, receiver, member); }
+                             const QObject* receiver, const char* member );
 
         static bool disconnect( const QObject* sender, const char* signal,
-                                const QObject* receiver, const char* member )
-        { return QObject::disconnect(sender, signal, receiver, member); }
+                                const QObject* receiver, const char* member );
 
         bool connect( const QObject *sender, const char *signal,
-                      const char *member )
-        { return QObject::connect(sender, signal, member); }
+                      const char *member );
 
         /**
          * When true, the next job will check whether KLauncher has a slave
          * on hold that is suitable for the job.
 	 * @param b true when KLauncher has a job on hold
          */
-        static void checkSlaveOnHold(bool b) { self()->_checkSlaveOnHold(b); }
+        static void checkSlaveOnHold(bool b);
 
-        static void emitReparseSlaveConfiguration() {
-            emit self()->reparseSlaveConfiguration( QString() );
-        }
-
-        void debug_info();
-
-    public Q_SLOTS:
-        void slotSlaveDied(KIO::Slave *slave);
-        void slotSlaveStatus(pid_t pid, const QByteArray &protocol,
-                             const QString &host, bool connected);
-
-        // connected to D-Bus signal:
-        void slotReparseSlaveConfiguration(const QString &);
+        static void emitReparseSlaveConfiguration();
 
     Q_SIGNALS:
         void slaveConnected(KIO::Slave *slave);
         void slaveError(KIO::Slave *slave, int error, const QString &errorMsg);
 
-        // DBUS (TODO: adaptor, or Qt-4.2 ExportSignals)
-        void reparseSlaveConfiguration(const QString &);
+        // DBUS
+        Q_SCRIPTABLE void reparseSlaveConfiguration(const QString &);
 
-    protected:
-        void setupSlave(KIO::Slave *slave, const KUrl &url, const QString &protocol, const QString &proxy , bool newSlave, const KIO::MetaData *config=0);
-        bool startJobScheduled(ProtocolInfo *protInfo);
-        bool startJobDirect();
+    private:
+        Q_DISABLE_COPY(Scheduler)
         Scheduler();
+        ~Scheduler();
 
-    protected Q_SLOTS:
-        void startStep();
-        void slotCleanIdleSlaves();
-        void slotSlaveConnected();
-        void slotSlaveError(int error, const QString &errorMsg);
-        void slotScheduleCoSlave();
-        void slotUnregisterWindow(QObject *);
-
-    private:
-        class ProtocolInfoDict;
-        class ExtraJobData;
-
-        Scheduler(const Scheduler&);
         static Scheduler *self();
-        static Scheduler *instance;
-        void _doJob(SimpleJob *job);
-        void _scheduleJob(SimpleJob *job);
-        void _cancelJob(SimpleJob *job);
-        void _jobFinished(KIO::SimpleJob *job, KIO::Slave *slave);
-        void _scheduleCleanup();
-        void _putSlaveOnHold(KIO::SimpleJob *job, const KUrl &url);
-        void _removeSlaveOnHold();
-        Slave *_getConnectedSlave(const KUrl &url, const KIO::MetaData &metaData );
-        bool _assignJobToSlave(KIO::Slave *slave, KIO::SimpleJob *job);
-        bool _disconnectSlave(KIO::Slave *slave);
-        void _checkSlaveOnHold(bool b);
-        void _publishSlaveOnHold();
-        void _registerWindow(QWidget *wid);
 
-        Slave *findIdleSlave(ProtocolInfo *protInfo, SimpleJob *job, bool &exact);
-        Slave *createSlave(ProtocolInfo *protInfo, SimpleJob *job, const KUrl &url);
+        Q_PRIVATE_SLOT(schedulerPrivate, void slotSlaveDied(KIO::Slave *slave))
+        Q_PRIVATE_SLOT(schedulerPrivate, void slotSlaveStatus(pid_t pid, const QByteArray &protocol,
+                                               const QString &host, bool connected))
 
+        // connected to D-Bus signal:
+        Q_PRIVATE_SLOT(schedulerPrivate, void slotReparseSlaveConfiguration(const QString &))
 
-        QTimer slaveTimer;
-        QTimer coSlaveTimer;
-        QTimer cleanupTimer;
-        bool busy;
-
-        SlaveList *slaveList;
-        SlaveList *idleSlaves;
-        SlaveList *coIdleSlaves;
-
-        ProtocolInfoDict *protInfoDict;
-        Slave *slaveOnHold;
-        KUrl urlOnHold;
-        JobList newJobs;
-
-        typedef QMap<Slave*, JobList *> CoSlaveMap;
-        CoSlaveMap coSlaves;
-        ExtraJobData *extraJobData;
-        SlaveConfig *slaveConfig;
-        SessionData *sessionData;
-        bool checkOnHold;
-        QMap<QObject *,WId> m_windowList;
+        Q_PRIVATE_SLOT(schedulerPrivate, void startStep())
+        Q_PRIVATE_SLOT(schedulerPrivate, void slotCleanIdleSlaves())
+        Q_PRIVATE_SLOT(schedulerPrivate, void slotSlaveConnected())
+        Q_PRIVATE_SLOT(schedulerPrivate, void slotSlaveError(int error, const QString &errorMsg))
+        Q_PRIVATE_SLOT(schedulerPrivate, void slotScheduleCoSlave())
+        Q_PRIVATE_SLOT(schedulerPrivate, void slotUnregisterWindow(QObject *))
     private:
-	class SchedulerPrivate* d;
+        friend class SchedulerPrivate;
+        SchedulerPrivate * const d;
 };
 
 }
