@@ -18,12 +18,13 @@
    Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "sessiondata.h"
+#include "sessiondata.moc"
 
-#include <qlist.h>
-#include <qtextcodec.h>
+#include <config.h>
+
+#include <QtCore/QList>
+#include <QtCore/QTextCodec>
 
 #include <kdebug.h>
 #include <kconfig.h>
@@ -37,9 +38,6 @@
 #include <kio/slaveconfig.h>
 #include <kio/http_slave_defaults.h>
 
-#include "sessiondata.h"
-#include "sessiondata.moc"
-
 namespace KIO {
 
 /***************************** SessionData::AuthData ************************/
@@ -68,6 +66,7 @@ public:
   bool persist;
 };
 
+#if 0
 /************************* SessionData::AuthDataList ****************************/
 class SessionData::AuthDataList : public QList<SessionData::AuthData*>
 {
@@ -203,6 +202,7 @@ void SessionData::AuthDataList::purgeCachedData()
         unregisterAuthData( (*it) );
   }
 }
+#endif
 
 /********************************* SessionData ****************************/
 
@@ -223,14 +223,12 @@ public:
 SessionData::SessionData()
 	:d(new SessionDataPrivate)
 {
-  authData = 0;
+//  authData = 0;
 }
 
 SessionData::~SessionData()
 {
   delete d;
-  delete authData;
-  authData = 0L;
 }
 
 void SessionData::configDataFor( MetaData &configData, const QString &proto,
@@ -264,27 +262,11 @@ void SessionData::reset()
 {
     d->initDone = true;
     // Get Cookie settings...
-    KConfig* cfg = new KConfig("kcookiejarrc", true, false);
-    cfg->setGroup( "Cookie Policy" );
-    d->useCookie = cfg->readEntry("Cookies", true);
-    delete cfg;
+    d->useCookie = KConfig("kcookiejarrc", KConfig::NoGlobals).
+                   group("Cookie Policy" ).
+                   readEntry("Cookies", true);
 
-    static const QString & english = KGlobal::staticQString( "en" );
-
-    // Get language settings... (see KProtocolManager::defaultUserAgent)
-    QStringList languageList = KGlobal::locale()->languagesTwoAlpha();
-    int idx = languageList.indexOf( QString::fromLatin1("C") );
-    if ( idx != -1 )
-    {
-        if ( languageList.contains( english ) )
-          languageList.removeAt( idx );
-        else
-          languageList[idx] = english;
-    }
-    if ( !languageList.contains( english ) )
-       languageList.append( english );
-
-    d->language = languageList.join( ", " );
+    d->language = KProtocolManager::acceptLanguagesHeader();
 
     d->charsets = QString::fromLatin1(QTextCodec::codecForLocale()->name()).toLower();
     KProtocolManager::reparseConfiguration();
