@@ -3,6 +3,7 @@
  *  Copyright (c) 2000 Waldo Bastian <bastian@kde.org>
  *  Copyright (c) 2000 David Faure <faure@kde.org>
  *  Copyright (c) 2000 Stephan Kulow <coolo@kde.org>
+ *  Copyright (c) 2007 Thiago Macieira <thiago@kde.org>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -25,11 +26,7 @@
 #include <config.h>
 
 #include <sys/time.h>
-#ifdef HAVE_SYS_SELECT_H
-#include <sys/select.h>		// Needed on some systems.
-#endif
 
-#include <assert.h>
 #include <kdebug.h>
 #include <stdlib.h>
 #include <errno.h>
@@ -37,10 +34,9 @@
 #include <signal.h>
 #include <time.h>
 
-#include <qfile.h>
-#include <qlist.h>
+#include <QtCore/QFile>
+#include <QtCore/QList>
 #include <QtDBus/QtDBus>
-#include "uiserveriface.h"
 
 #include <kapplication.h>
 #include <kcrash.h>
@@ -48,15 +44,13 @@
 #include <kconfigdata.h>
 #include <kdesu/client.h>
 #include <klocale.h>
-#include <ksocks.h>
-#include <kstreamsocket.h>
+#include <k3streamsocket.h>
 
 #include "kremoteencoding.h"
 
-#include "kio/slavebase.h"
-#include "kio/connection.h"
-#include "kio/ioslave_defaults.h"
-#include "kio/slaveinterface.h"
+#include "connection.h"
+#include "ioslave_defaults.h"
+#include "slaveinterface.h"
 
 #ifndef NDEBUG
 #ifdef HAVE_BACKTRACE
@@ -120,9 +114,11 @@ public:
     bool needSendCanResume:1;
     bool onHold:1;
     bool wasKilled:1;
+    bool inOpenLoop:1;
     bool exit_loop:1;
     MetaData configData;
     SlaveBaseConfig *config;
+    KConfigGroup* configGroup;
     KUrl onHoldUrl;
 
     struct timeval last_tv;
@@ -143,12 +139,13 @@ static volatile bool slaveWriteError = false;
 static const char *s_protocol;
 
 #ifdef Q_OS_UNIX
+extern "C" {
 static void genericsig_handler(int sigNumber)
 {
    signal(sigNumber,SIG_IGN);
    //WABA: Don't do anything that requires malloc, we can deadlock on it since
    //a SIGTERM signal can come in while we are in malloc/free.
-   //kDebug()<<"kioslave : exiting due to signal "<<sigNumber<<endl;
+   //kDebug()<<"kioslave : exiting due to signal "<<sigNumber;
    //set the flag which will be checked in dispatchLoop() and which *should* be checked
    //in lengthy operations in the various slaves
    if (globalSlave!=0)
@@ -156,6 +153,7 @@ static void genericsig_handler(int sigNumber)
    signal(SIGALRM,SIG_DFL);
    alarm(5);  //generate an alarm signal in 5 seconds, in this time the slave has to exit
 }
+}
 #endif
 
 //////////////
@@ -222,6 +220,7 @@ SlaveBase::SlaveBase( const QByteArray &protocol,
     d->resume = false;
     d->needSendCanResume = false;
     d->config = new SlaveBaseConfig(this);
+    d->configGroup = new KConfigGroup(d->config, QString());
     d->onHold = false;
     d->wasKilled=false;
     d->last_tv.tv_sec = 0;
@@ -233,109 +232,90 @@ SlaveBase::SlaveBase( const QByteArray &protocol,
     connectSlave(mAppSocket);
 
     d->remotefile = 0;
+    d->inOpenLoop = false;
     d->exit_loop = false;
 }
 
 SlaveBase::~SlaveBase()
 {
+    delete d->configGroup;
+    delete d->config;
     delete d;
     s_protocol = "";
 }
 
 void SlaveBase::dispatchLoop()
 {
-    fd_set rfds;
-    int retval;
+    while (!d->exit_loop) {
+        if (d->timeout && (d->timeout < time(0))) {
+            QByteArray data = d->timeoutData;
+            d->timeout = 0;
+            d->timeoutData = QByteArray();
+            special(data);
+        }
 
-    while (!d->exit_loop)
-    {
-       if (d->timeout && (d->timeout < time(0)))
-       {
-          QByteArray data = d->timeoutData;
-          d->timeout = 0;
-          d->timeoutData = QByteArray();
-          special(data);
-       }
-       FD_ZERO(&rfds);
+        Q_ASSERT(appconn->inited());
 
-       assert(appconn->inited());
-       FD_SET(appconn->fd_from(), &rfds);
+        int ms = -1;
+        if (d->timeout)
+            ms = 1000 * qMax<time_t>(d->timeout - time(0), 1);
 
-       if (!d->timeout) // we can wait forever
-       {
-          retval = select(appconn->fd_from()+ 1, &rfds, NULL, NULL, NULL);
-       }
-       else
-       {
-          struct timeval tv;
-          tv.tv_sec = qMax(d->timeout-time(0),(time_t) 1);
-          tv.tv_usec = 0;
-          retval = select(appconn->fd_from()+ 1, &rfds, NULL, NULL, &tv);
-       }
-       if ((retval>0) && FD_ISSET(appconn->fd_from(), &rfds))
-       { // dispatch application messages
-          int cmd;
-          QByteArray data;
-          int ret = appconn->read(&cmd, data);
-#ifdef Q_WS_WIN
-          if ( ret == -2 ) //win32: WSAEWOULDBLOCK condition
-          	continue;
-#endif
-          if ( ret != -1 )
-          {
-             dispatch(cmd, data);
-          }
-          else // some error occurred, perhaps no more application
-          {
-             // When the app exits, should the slave be put back in the pool ?
-             if (!d->exit_loop && mConnectedToApp && !mPoolSocket.isEmpty())
-             {
+        int ret = -1;
+        if (appconn->hasTaskAvailable() || appconn->waitForIncomingTask(ms)) {
+            // dispatch application messages
+            int cmd;
+            QByteArray data;
+            ret = appconn->read(&cmd, data);
+
+            if (d->inOpenLoop)
+                dispatchOpenCommand(cmd, data);
+            else
+                dispatch(cmd, data);
+        }
+
+        if (ret == -1) { // some error occurred, perhaps no more applicationi
+            // When the app exits, should the slave be put back in the pool ?
+            if (!d->exit_loop && mConnectedToApp && !mPoolSocket.isEmpty()) {
                 disconnectSlave();
                 mConnectedToApp = false;
                 closeConnection();
                 connectSlave(mPoolSocket);
-             }
-             else
-             {
+            } else {
                 return;
-             }
-          }
-       }
-       else if ((retval<0) && (errno != EINTR))
-       {
-          kDebug(7019) << "dispatchLoop(): select returned " << retval << " "
-            << (errno==EBADF?"EBADF":errno==EINTR?"EINTR":errno==EINVAL?"EINVAL":errno==ENOMEM?"ENOMEM":"unknown")
-            << " (" << errno << ")" << endl;
-          return;
-       }
-       //I think we get here when we were killed in dispatch() and not in select()
-       if (wasKilled())
-       {
-          kDebug(7019)<<" dispatchLoop() slave was killed, returning"<<endl;
-          return;
-       }
+            }
+        }
+
+        //I think we get here when we were killed in dispatch() and not in select()
+        if (wasKilled()) {
+            kDebug(7019)<<" dispatchLoop() slave was killed, returning";
+            return;
+        }
     }
 }
 
-void SlaveBase::connectSlave(const QString& path)
+void SlaveBase::setConnection( Connection* connection )
 {
-#ifdef Q_WS_WIN
-    // @TODO: localhost does not work yet
-    KNetwork::KStreamSocket *sock = new KNetwork::KStreamSocket(getenv("COMPUTERNAME"),
-#else
-    KNetwork::KStreamSocket *sock = new KNetwork::KStreamSocket(QString(),
-#endif
-						QFile::encodeName(path));
-    appconn->init(sock);
+    m_pConnection = connection;
+}
+
+Connection *SlaveBase::connection() const
+{
+    return m_pConnection;
+}
+
+void SlaveBase::connectSlave(const QString &address)
+{
+    appconn->connectToRemote(address);
 
     if (!appconn->inited())
     {
-        kDebug(7019) << "SlaveBase: failed to connect to " << path << endl
-		      << "Reason: " << sock->errorString() << endl;
+        kDebug(7019) << "SlaveBase: failed to connect to " << address << endl
+		      << "Reason: " << appconn->errorString() << endl;
         exit();
         return;
     }
 
+    d->inOpenLoop = false;
     setConnection(appconn);
 }
 
@@ -358,6 +338,11 @@ QString SlaveBase::metaData(const QString &key) const
    return QString();
 }
 
+MetaData SlaveBase::allMetaData() const
+{
+    return mIncomingMetaData;
+}
+
 bool SlaveBase::hasMetaData(const QString &key) const
 {
    if (mIncomingMetaData.contains(key))
@@ -367,9 +352,9 @@ bool SlaveBase::hasMetaData(const QString &key) const
    return false;
 }
 
-KConfigBase *SlaveBase::config()
+KConfigGroup *SlaveBase::config()
 {
-   return d->config;
+   return d->configGroup;
 }
 
 void SlaveBase::sendMetaData()
@@ -412,6 +397,7 @@ void SlaveBase::opened()
    if (!mOutgoingMetaData.isEmpty())
       sendMetaData();
    send( MSG_OPENED );
+   d->inOpenLoop = true;
 }
 
 void SlaveBase::error( int _errid, const QString &_text )
@@ -425,6 +411,7 @@ void SlaveBase::error( int _errid, const QString &_text )
     listEntryCurrentSize = 100;
     d->sentListEntries=0;
     d->totalSize=0;
+    d->inOpenLoop=false;
 }
 
 void SlaveBase::connected()
@@ -443,6 +430,7 @@ void SlaveBase::finished()
     listEntryCurrentSize = 100;
     d->sentListEntries=0;
     d->totalSize=0;
+    d->inOpenLoop=false;
 }
 
 void SlaveBase::needSubUrlData()
@@ -450,11 +438,19 @@ void SlaveBase::needSubUrlData()
     send( MSG_NEED_SUBURL_DATA );
 }
 
+/*
+ * Map pid_t to a signed integer type that makes sense for QByteArray;
+ * only the most common sizes 16 bit and 32 bit are special-cased.
+ */
+template<int T> struct PIDType { typedef pid_t PID_t; } ;
+template<> struct PIDType<2> { typedef qint16 PID_t; } ;
+template<> struct PIDType<4> { typedef qint32 PID_t; } ;
+
 void SlaveBase::slaveStatus( const QString &host, bool connected )
 {
     pid_t pid = getpid();
     qint8 b = connected ? 1 : 0;
-    KIO_DATA << pid << mProtocol << host << b;
+    KIO_DATA << (PIDType<sizeof(pid_t)>::PID_t)pid << mProtocol << host << b;
     if (d->onHold)
        stream << d->onHoldUrl;
     send( MSG_SLAVE_STATUS, data );
@@ -527,7 +523,7 @@ void SlaveBase::position( KIO::filesize_t _pos )
 
 void SlaveBase::processedPercent( float /* percent */ )
 {
-  kDebug(7019) << "SlaveBase::processedPercent: STUB" << endl;
+  kDebug(7019) << "SlaveBase::processedPercent: STUB";
 }
 
 
@@ -562,14 +558,14 @@ static bool isSubCommand(int cmd)
 
 void SlaveBase::mimeType( const QString &_type)
 {
-  // kDebug(7019) << "(" << getpid() << ") SlaveBase::mimeType '" << _type << "'" << endl;
+  // kDebug(7019) << "(" << getpid() << ") SlaveBase::mimeType '" << _type << "'";
   int cmd;
   do
   {
     // Send the meta-data each time we send the mime-type.
     if (!mOutgoingMetaData.isEmpty())
     {
-      // kDebug(7019) << "(" << getpid() << ") mimeType: emitting meta data" << endl;
+      // kDebug(7019) << "(" << getpid() << ") mimeType: emitting meta data";
       KIO_DATA << mOutgoingMetaData;
       send( INF_META_DATA, data );
     }
@@ -578,15 +574,16 @@ void SlaveBase::mimeType( const QString &_type)
     while(true)
     {
        cmd = 0;
-       int ret = m_pConnection->read( &cmd, data );
-       if ( ret == -1 ) {
-           kDebug(7019) << "SlaveBase: mimetype: read error" << endl;
+       int ret = -1;
+       if (m_pConnection->hasTaskAvailable() || m_pConnection->waitForIncomingTask(-1)) {
+           ret = m_pConnection->read( &cmd, data );
+       }
+       if (ret == -1) {
+           kDebug(7019) << "SlaveBase: mimetype: read error";
            exit();
            return;
        }
-       if ( ret == -2 ) // win32: WSAEWOULDBLOCK condition
-          continue;
-       // kDebug(7019) << "(" << getpid() << ") Slavebase: mimetype got " << cmd << endl;
+       // kDebug(7019) << "(" << getpid() << ") Slavebase: mimetype got " << cmd;
        if ( cmd == CMD_HOST) // Ignore.
           continue;
        if ( isSubCommand(cmd) )
@@ -740,7 +737,7 @@ static void sigpipe_handler (int)
     // Don't add anything else here, especially no debug output
 }
 
-void SlaveBase::setHost(QString const &, int, QString const &, QString const &)
+void SlaveBase::setHost(QString const &, quint16, QString const &, QString const &)
 {
 }
 
@@ -758,8 +755,16 @@ void SlaveBase::listDir(KUrl const &)
 { error(  ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(mProtocol, CMD_LISTDIR)); }
 void SlaveBase::get(KUrl const & )
 { error(  ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(mProtocol, CMD_GET)); }
-void SlaveBase::open(KUrl const &, int )
+void SlaveBase::open(KUrl const &, QIODevice::OpenMode)
 { error(  ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(mProtocol, CMD_OPEN)); }
+void SlaveBase::read(KIO::filesize_t)
+{ error(  ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(mProtocol, CMD_READ)); }
+void SlaveBase::write(const QByteArray &)
+{ error(  ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(mProtocol, CMD_WRITE)); }
+void SlaveBase::seek(KIO::filesize_t)
+{ error(  ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(mProtocol, CMD_SEEK)); }
+void SlaveBase::close()
+{ error(  ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(mProtocol, CMD_CLOSE)); }
 void SlaveBase::mimetype(KUrl const &url)
 { get(url); }
 void SlaveBase::rename(KUrl const &, KUrl const &, bool)
@@ -776,6 +781,10 @@ void SlaveBase::mkdir(KUrl const &, int)
 { error(  ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(mProtocol, CMD_MKDIR)); }
 void SlaveBase::chmod(KUrl const &, int)
 { error(  ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(mProtocol, CMD_CHMOD)); }
+void SlaveBase::setModificationTime(KUrl const &, const QDateTime&)
+{ error(  ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(mProtocol, CMD_SETMODIFICATIONTIME)); }
+void SlaveBase::chown(KUrl const &, const QString &, const QString &)
+{ error(  ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(mProtocol, CMD_CHOWN)); }
 void SlaveBase::setSubUrl(KUrl const &)
 { error(  ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(mProtocol, CMD_SUBURL)); }
 void SlaveBase::multiGet(const QByteArray &)
@@ -789,37 +798,13 @@ void SlaveBase::reparseConfiguration()
 {
 }
 
-bool SlaveBase::dispatch()
-{
-    assert( m_pConnection );
-
-    int cmd;
-    QByteArray data;
-    int ret = m_pConnection->read( &cmd, data );
-    if ( ret == -1 )
-    {
-        kDebug(7019) << "SlaveBase::dispatch() has read error." << endl;
-        return false;
-    }
-    if ( ret == -2 ) // win32: WSAEWOULDBLOCK condition
-      return true;
-
-    dispatch( cmd, data );
-    return true;
-}
-
 bool SlaveBase::openPasswordDialog( AuthInfo& info, const QString &errorMsg )
 {
     AuthInfo authResult;
     const long windowId = metaData("window-id").toLong();
     const unsigned long userTimestamp = metaData("user-timestamp").toULong();
 
-    org::kde::KIO::UIServer uiserver("org.kde.kuiserver", "/UIServer", QDBusConnection::sessionBus());
-    const long progressId = metaData("progress-id").toLong();
-    if (progressId)
-        uiserver.setJobVisible(progressId, false);
-
-    kDebug(7019) << "SlaveBase::openPasswordDialog window-id=" << windowId << endl;
+    kDebug(7019) << "SlaveBase::openPasswordDialog window-id=" << windowId;
 
     QDBusInterface kps( "org.kde.kded", "/modules/kpasswdserver", "org.kde.KPasswdServer" );
 
@@ -837,13 +822,11 @@ bool SlaveBase::openPasswordDialog( AuthInfo& info, const QString &errorMsg )
        reply = kps.call("queryAuthInfo", data, errorMsg, qlonglong(windowId), s_seqNr, qlonglong(userTimestamp));
 
     bool callOK = reply.type() == QDBusMessage::ReplyMessage;
-    //if (progressId)
-    //    uiserver.setJobVisible(progressId, true);
 
     if (!callOK)
     {
-       kWarning(7019) << "Can't communicate with kded_kpasswdserver (for queryAuthInfo)!" << endl;
-       kDebug(7019) << reply.arguments().at(0).toString() << endl;
+       kWarning(7019) << "Can't communicate with kded_kpasswdserver (for queryAuthInfo)!";
+       kDebug(7019) << reply.arguments().at(0).toString();
        return false;
     }
 
@@ -856,8 +839,8 @@ bool SlaveBase::openPasswordDialog( AuthInfo& info, const QString &errorMsg )
 
     info = authResult;
 
-    kDebug(7019) << "SlaveBase::openPasswordDialog: username=" << info.username << endl;
-    kDebug(7019) << "SlaveBase::openPasswordDialog: password=[hidden]" << endl;
+    kDebug(7019) << "SlaveBase::openPasswordDialog: username=" << info.username;
+    kDebug(7019) << "SlaveBase::openPasswordDialog: password=[hidden]";
 
     return true;
 }
@@ -871,7 +854,7 @@ int SlaveBase::messageBox( MessageBoxType type, const QString &text, const QStri
 int SlaveBase::messageBox( const QString &text, MessageBoxType type, const QString &caption,
                            const QString &buttonYes, const QString &buttonNo, const QString &dontAskAgainName )
 {
-    kDebug(7019) << "messageBox " << type << " " << text << " - " << caption << buttonYes << buttonNo << endl;
+    kDebug(7019) << "messageBox " << type << " " << text << " - " << caption << buttonYes << buttonNo;
     KIO_DATA << (qint32)type << text << caption << buttonYes << buttonNo << dontAskAgainName;
     send( INF_MESSAGEBOX, data );
     if ( waitForAnswer( CMD_MESSAGEBOXANSWER, 0, data ) != -1 )
@@ -879,7 +862,7 @@ int SlaveBase::messageBox( const QString &text, MessageBoxType type, const QStri
         QDataStream stream( data );
         int answer;
         stream >> answer;
-        kDebug(7019) << "got messagebox answer" << answer << endl;
+        kDebug(7019) << "got messagebox answer" << answer;
         return answer;
     } else
         return 0; // communication failure
@@ -887,7 +870,7 @@ int SlaveBase::messageBox( const QString &text, MessageBoxType type, const QStri
 
 bool SlaveBase::canResume( KIO::filesize_t offset )
 {
-    kDebug(7019) << "SlaveBase::canResume offset=" << KIO::number(offset) << endl;
+    kDebug(7019) << "SlaveBase::canResume offset=" << KIO::number(offset);
     d->needSendCanResume = false;
     KIO_DATA << KIO_FILESIZE_T(offset);
     send( MSG_RESUME, data );
@@ -896,7 +879,7 @@ bool SlaveBase::canResume( KIO::filesize_t offset )
         int cmd;
         if ( waitForAnswer( CMD_RESUMEANSWER, CMD_NONE, data, &cmd ) != -1 )
         {
-            kDebug(7019) << "SlaveBase::canResume returning " << (cmd == CMD_RESUMEANSWER) << endl;
+            kDebug(7019) << "SlaveBase::canResume returning " << (cmd == CMD_RESUMEANSWER);
             return cmd == CMD_RESUMEANSWER;
         } else
             return false;
@@ -909,17 +892,16 @@ bool SlaveBase::canResume( KIO::filesize_t offset )
 
 int SlaveBase::waitForAnswer( int expected1, int expected2, QByteArray & data, int *pCmd )
 {
-    int cmd, result;
+    int cmd, result = -1;
     for (;;)
     {
-        result = m_pConnection->read( &cmd, data );
-        if ( result == -1 )
-        {
-            kDebug(7019) << "SlaveBase::waitForAnswer has read error." << endl;
+        if (m_pConnection->hasTaskAvailable() || m_pConnection->waitForIncomingTask(-1)) {
+            result = m_pConnection->read( &cmd, data );
+        }
+        if (result == -1) {
+            kDebug(7019) << "SlaveBase::waitForAnswer has read error.";
             return -1;
         }
-        if ( result == -2 ) // win32: WSAEWOULDBLOCK condition
-          continue;
 
         if ( cmd == expected1 || cmd == expected2 )
         {
@@ -932,7 +914,7 @@ int SlaveBase::waitForAnswer( int expected1, int expected2, QByteArray & data, i
         }
         else
         {
-            kWarning() << "Got cmd " << cmd << " while waiting for an answer!" << endl;
+            kWarning() << "Got cmd " << cmd << " while waiting for an answer!";
         }
     }
 }
@@ -941,7 +923,7 @@ int SlaveBase::waitForAnswer( int expected1, int expected2, QByteArray & data, i
 int SlaveBase::readData( QByteArray &buffer)
 {
    int result = waitForAnswer( MSG_DATA, 0, buffer );
-   //kDebug(7019) << "readData: length = " << result << " " << endl;
+   //kDebug(7019) << "readData: length = " << result << " ";
    return result;
 }
 
@@ -970,8 +952,9 @@ void SlaveBase::dispatch( int command, const QByteArray &data )
         s_seqNr = 0;
         QString passwd;
         QString host, user;
-        stream >> host >> i >> user >> passwd;
-        setHost( host, i, user, passwd );
+        quint16 port;
+        stream >> host >> port >> user >> passwd;
+        setHost( host, port, user, passwd );
     }
     break;
     case CMD_CONNECT:
@@ -1010,13 +993,15 @@ void SlaveBase::dispatch( int command, const QByteArray &data )
         reparseConfiguration();
         break;
     case CMD_CONFIG:
+    {
         stream >> d->configData;
-#ifdef Q_OS_UNIX //TODO: not yet available on WIN32
-        KSocks::setConfig(d->config);
+#if 0 //TODO: decide what to do in KDE 4.1
+        KSocks::setConfig(d->configGroup);
 #endif
 	delete d->remotefile;
 	d->remotefile = 0;
         break;
+    }
     case CMD_GET:
     {
         stream >> url;
@@ -1025,7 +1010,8 @@ void SlaveBase::dispatch( int command, const QByteArray &data )
     case CMD_OPEN:
     {
         stream >> url >> i;
-        open( url, i );
+        QIODevice::OpenMode mode = QFlag(i);
+        open(url, mode);
     } break;
     case CMD_PUT:
     {
@@ -1093,11 +1079,24 @@ void SlaveBase::dispatch( int command, const QByteArray &data )
         stream >> url >> i;
         chmod( url, i);
         break;
+    case CMD_CHOWN:
+    {
+        QString owner, group;
+        stream >> url >> owner >> group;
+        chown(url, owner, group);
+        break;
+    }
+    case CMD_SETMODIFICATIONTIME:
+    {
+        QDateTime dt;
+        stream >> url >> dt;
+        setModificationTime(url, dt);
+    } break;
     case CMD_SPECIAL:
         special( data );
         break;
     case CMD_META_DATA:
-        //kDebug(7019) << "(" << getpid() << ") Incoming meta-data..." << endl;
+        //kDebug(7019) << "(" << getpid() << ") Incoming meta-data...";
         stream >> mIncomingMetaData;
         break;
     case CMD_SUBURL:
@@ -1123,7 +1122,7 @@ bool SlaveBase::checkCachedAuthentication( AuthInfo& info )
     long windowId = metaData("window-id").toLong();
     unsigned long userTimestamp = metaData("user-timestamp").toULong();
 
-    kDebug(7019) << "SlaveBase::checkCachedAuthInfo window = " << windowId << " url = " << info.url.url() << endl;
+    kDebug(7019) << "SlaveBase::checkCachedAuthInfo window = " << windowId << " url = " << info.url.url();
 
     QDBusInterface kps( "org.kde.kded", "/modules/kpasswdserver", "org.kde.KPasswdServer" );
 
@@ -1136,8 +1135,8 @@ bool SlaveBase::checkCachedAuthentication( AuthInfo& info )
 
     if ( !reply.isValid() )
     {
-       kWarning(7019) << "Can't communicate with kded_kpasswdserver (for checkAuthInfo)!" << endl;
-       kDebug(7019) << reply.error().message() << endl;
+       kWarning(7019) << "Can't communicate with kded_kpasswdserver (for checkAuthInfo)!";
+       kDebug(7019) << reply.error().message();
        return false;
     }
 
@@ -1155,6 +1154,38 @@ bool SlaveBase::checkCachedAuthentication( AuthInfo& info )
     return true;
 }
 
+void SlaveBase::dispatchOpenCommand( int command, const QByteArray &data )
+{
+    QDataStream stream( data );
+
+    switch( command ) {
+    case CMD_READ: {
+        KIO::filesize_t bytes;
+        stream >> bytes;
+        read(bytes);
+        break;
+    }
+    case CMD_WRITE: {
+        write(data);
+        break;
+    }
+    case CMD_SEEK: {
+        KIO::filesize_t offset;
+        stream >> offset;
+        seek(offset);
+    }
+    case CMD_NONE:
+        break;
+    case CMD_CLOSE:
+        close();                // must call finish(), which will set d->inOpenLoop=false
+        break;
+    default:
+        // Some command we don't understand.
+        // Just ignore it, it may come from some future version of KDE.
+        break;
+    }
+}
+
 bool SlaveBase::cacheAuthentication( const AuthInfo& info )
 {
     QByteArray params;
