@@ -17,15 +17,16 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef __slavebase_h
-#define __slavebase_h
+#ifndef SLAVEBASE_H
+#define SLAVEBASE_H
 
 #include <kio/global.h>
+#include <kio/udsentry.h>
 #include <kio/authinfo.h>
 
-#include <qbytearray.h>
+#include <QtCore/QByteArray>
 
-class KConfigBase;
+class KConfigGroup;
 class KRemoteEncoding;
 class KUrl;
 
@@ -63,11 +64,11 @@ public:
     /**
      * @internal
      */
-    void setConnection( Connection* connection ) { m_pConnection = connection; }
+    void setConnection( Connection* connection );
     /**
      * @internal
      */
-    Connection *connection() const { return m_pConnection; }
+    Connection *connection() const;
 
 
     ///////////
@@ -303,7 +304,7 @@ public:
      * @internal for ForwardingSlaveBase
      * Contains all metadata (but no config) sent by the application to the slave.
      */
-    MetaData allMetaData() const { return mIncomingMetaData; }
+    MetaData allMetaData() const;
 
     /**
      * Returns a configuration object to query config/meta-data information
@@ -312,7 +313,7 @@ public:
      * The application provides the slave with all configuration information
      * relevant for the current protocol and host.
      */
-    KConfigBase* config();
+    KConfigGroup* config();
 
     /**
      * Returns an object that can translate remote filenames into proper
@@ -337,7 +338,7 @@ public:
      *
      * This method is called whenever a change in host, port or user occurs.
      */
-    virtual void setHost(const QString& host, int port, const QString& user, const QString& pass);
+    virtual void setHost(const QString& host, quint16 port, const QString& user, const QString& pass);
 
     /**
      * Prepare slave for streaming operation
@@ -377,9 +378,14 @@ public:
      * open.
      * @param url the full url for this request. Host, port and user of the URL
      *        can be assumed to be the same as in the last setHost() call.
-     * @param access 1 - rdonly, 2 - wronly or 3 - rdwr
+     * @param mode see \ref QIODevice::OpenMode
      */
-    virtual void open( const KUrl& url, int access );
+    virtual void open( const KUrl &url, QIODevice::OpenMode mode );
+
+    virtual void read( KIO::filesize_t size );
+    virtual void write( const QByteArray &data );
+    virtual void seek( KIO::filesize_t offset );
+    virtual void close();
 
     /**
      * put, i.e. write data into a file.
@@ -457,13 +463,25 @@ public:
     virtual void symlink( const QString& target, const KUrl& dest, bool overwrite );
 
     /**
-     * Change permissions on @p path
+     * Change permissions on @p url
      * The slave emits ERR_DOES_NOT_EXIST or ERR_CANNOT_CHMOD
      */
     virtual void chmod( const KUrl& url, int permissions );
 
-    // KDE4 TODO: add a setTime (utime?) to set the mtime on dirs at the end of a copy,
-    // or to set the mtime on a file at any moment (unused)
+    /**
+     * Change ownership of @p url
+     * The slave emits ERR_DOES_NOT_EXIST or ERR_CANNOT_CHOWN
+     */
+    virtual void chown( const KUrl& url, const QString& owner, const QString& group );
+
+    /**
+     * Sets the modification time for @url
+     * For instance this is what CopyJob uses to set mtime on dirs at the end of a copy.
+     * It could also be used to set the mtime on any file, in theory.
+     * The usual implementation on unix is to call utime(path, &myutimbuf).
+     * The slave emits ERR_DOES_NOT_EXIST or ERR_CANNOT_SETTIME
+     */
+    virtual void setModificationTime( const KUrl& url, const QDateTime& mtime );
 
     /**
      * Copy @p src into @p dest.
@@ -573,11 +591,12 @@ public:
     /**
      * @internal
      */
-    virtual bool dispatch();
+    virtual void dispatch( int command, const QByteArray &data );
+
     /**
      * @internal
      */
-    virtual void dispatch( int command, const QByteArray &data );
+    virtual void dispatchOpenCommand( int command, const QByteArray &data );
 
     /**
      * Read data send by the job, after a dataReq
