@@ -16,9 +16,11 @@
    Boston, MA 02110-1301, USA.
 */
 
-#include "kio/slaveinterface.h"
-#include "kio/slavebase.h"
-#include "kio/connection.h"
+#include "slaveinterface.h"
+#include "slaveinterface_p.h"
+
+#include "slavebase.h"
+#include "connection.h"
 #include <errno.h>
 #include <assert.h>
 #include <kdebug.h>
@@ -26,99 +28,42 @@
 #include <sys/time.h>
 #include <unistd.h>
 #include <signal.h>
-#include <kio/observer.h>
+#include <klocale.h>
 #include <kapplication.h>
+#include <ksslinfodialog.h>
+#include <ksslcertificate.h>
+#include <ksslcertchain.h>
+#include <kmessagebox.h>
 #include <time.h>
-#include <qtimer.h>
 #include <QtDBus/QtDBus>
 #include <QPointer>
 
 using namespace KIO;
 
-QDataStream &operator <<(QDataStream &s, const KIO::UDSEntry &e )
+
+SlaveInterface::SlaveInterface(SlaveInterfacePrivate &dd, QObject *parent)
+    : QObject(parent), d_ptr(&dd)
 {
-    s << e.size();
-    KIO::UDSEntry::ConstIterator it = e.begin();
-    const KIO::UDSEntry::ConstIterator end = e.end();
-    for( ; it != end; ++it )
-    {
-        const quint32 uds = it.key();
-        s << uds;
-        if ( uds & KIO::UDS_STRING )
-            s << it.value().toString();
-        else if ( uds & KIO::UDS_NUMBER )
-            s << it.value().toNumber();
-        else
-            Q_ASSERT( 0 );
-    }
-    return s;
-}
-
-QDataStream &operator >>(QDataStream &s, KIO::UDSEntry &e )
-{
-    e.clear();
-    quint32 size;
-    s >> size;
-    for( quint32 i = 0; i < size; ++i )
-    {
-        quint32 uds;
-        s >> uds;
-        if (uds & KIO::UDS_STRING) {
-            QString str;
-            s >> str;
-            e.insert( uds, str );
-        } else if (uds & KIO::UDS_NUMBER) {
-            long long val;
-            s >> val;
-            e.insert( uds, val );
-        } else
-            Q_ASSERT( 0 );
-    }
-    return s;
-}
-
-static const unsigned int max_nums = 8;
-
-class KIO::SlaveInterfacePrivate
-{
-public:
-  SlaveInterfacePrivate() {
-    slave_calcs_speed = false;
-    start_time.tv_sec = 0;
-    start_time.tv_usec = 0;
-    last_time = 0;
-    nums = 0;
-    filesize = 0;
-    offset = 0;
-  }
-  bool slave_calcs_speed;
-  struct timeval start_time;
-  uint nums;
-  long times[max_nums];
-  KIO::filesize_t sizes[max_nums];
-  size_t last_time;
-  KIO::filesize_t filesize, offset;
-
-  QTimer speed_timer;
-};
-
-//////////////
-
-SlaveInterface::SlaveInterface( Connection * connection )
-	:d(new SlaveInterfacePrivate)
-{
-    m_pConnection = connection;
-    m_progressId = 0;
-
-    connect(&d->speed_timer, SIGNAL(timeout()), SLOT(calcSpeed()));
+    connect(&d_ptr->speed_timer, SIGNAL(timeout()), SLOT(calcSpeed()));
 }
 
 SlaveInterface::~SlaveInterface()
 {
     // Note: no kDebug() here (scheduler is deleted very late)
-    m_pConnection = 0; // a bit like the "wasDeleted" of QObject...
 
-    delete d;
+    delete d_ptr;
+}
+
+void SlaveInterface::setConnection( Connection* connection )
+{
+    Q_D(SlaveInterface);
+    d->connection = connection;
+}
+
+Connection *SlaveInterface::connection() const
+{
+    const Q_D(SlaveInterface);
+    return d->connection;
 }
 
 static KIO::filesize_t readFilesize_t(QDataStream &stream)
@@ -130,22 +75,22 @@ static KIO::filesize_t readFilesize_t(QDataStream &stream)
 
 bool SlaveInterface::dispatch()
 {
-    assert( m_pConnection );
+    Q_D(SlaveInterface);
+    assert( d->connection );
 
     int cmd;
     QByteArray data;
 
-    int ret = m_pConnection->read( &cmd, data );
+    int ret = d->connection->read( &cmd, data );
     if (ret == -1)
       return false;
-    else if (ret == -2) // win32: WSAEWOULDBLOCK condition
-      return true;
 
     return dispatch( cmd, data );
 }
 
 void SlaveInterface::calcSpeed()
 {
+  Q_D(SlaveInterface);
   if (d->slave_calcs_speed) {
     d->speed_timer.stop();
     return;
@@ -189,9 +134,18 @@ void SlaveInterface::calcSpeed()
   }
 }
 
+/*
+ * Map pid_t to a signed integer type that makes sense for QByteArray;
+ * only the most common sizes 16 bit and 32 bit are special-cased.
+ */
+template<int T> struct PIDType { typedef pid_t PID_t; } ;
+template<> struct PIDType<2> { typedef qint16 PID_t; } ;
+template<> struct PIDType<4> { typedef qint32 PID_t; } ;
+
 bool SlaveInterface::dispatch( int _cmd, const QByteArray &rawdata )
 {
-    //kDebug(7007) << "dispatch " << _cmd << endl;
+    Q_D(SlaveInterface);
+    //kDebug(7007) << "dispatch " << _cmd;
 
     QDataStream stream( rawdata );
 
@@ -212,7 +166,7 @@ bool SlaveInterface::dispatch( int _cmd, const QByteArray &rawdata )
 	break;
     }
     case MSG_FINISHED:
-	//kDebug(7007) << "Finished [this = " << this << "]" << endl;
+	//kDebug(7007) << "Finished [this = " << this << "]";
         d->offset = 0;
         d->speed_timer.stop();
 	emit finished();
@@ -251,14 +205,16 @@ bool SlaveInterface::dispatch( int _cmd, const QByteArray &rawdata )
         break;
     case MSG_ERROR:
 	stream >> i >> str1;
-	kDebug(7007) << "error " << i << " " << str1 << endl;
+	kDebug(7007) << "error " << i << " " << str1;
 	emit error( i, str1 );
 	break;
     case MSG_SLAVE_STATUS:
         {
+           PIDType<sizeof(pid_t)>::PID_t stream_pid;
            pid_t pid;
            QByteArray protocol;
-           stream >> pid >> protocol >> str1 >> b;
+           stream >> stream_pid >> protocol >> str1 >> b;
+           pid = stream_pid;
            emit slaveStatus(pid, protocol, str1, (b != 0));
         }
         break;
@@ -323,8 +279,8 @@ bool SlaveInterface::dispatch( int _cmd, const QByteArray &rawdata )
 	stream >> str1;
 
 	emit mimeType( str1 );
-        if (!m_pConnection->suspended())
-            m_pConnection->sendnow( CMD_NONE, QByteArray() );
+        if (!d->connection->suspended())
+            d->connection->sendnow( CMD_NONE, QByteArray() );
 	break;
     case INF_WARNING:
 	stream >> str1;
@@ -332,7 +288,7 @@ bool SlaveInterface::dispatch( int _cmd, const QByteArray &rawdata )
 	emit warning( str1 );
 	break;
     case INF_MESSAGEBOX: {
-	kDebug(7007) << "needs a msg box" << endl;
+	kDebug(7007) << "needs a msg box";
 	QString text, caption, buttonYes, buttonNo, dontAskAgainName;
         int type;
 	stream >> type >> text >> caption >> buttonYes >> buttonNo;
@@ -353,6 +309,7 @@ bool SlaveInterface::dispatch( int _cmd, const QByteArray &rawdata )
     case INF_META_DATA: {
         MetaData meta_data;
         stream >> meta_data;
+        d->m_incomingMetaData += meta_data;
         metaData(meta_data);
         break;
     }
@@ -375,7 +332,7 @@ bool SlaveInterface::dispatch( int _cmd, const QByteArray &rawdata )
         break;
     }
     default:
-        kWarning(7007) << "Slave sends unknown command (" << _cmd << "), dropping slave" << endl;
+        kWarning(7007) << "Slave sends unknown command (" << _cmd << "), dropping slave";
         return false;
     }
     return true;
@@ -383,29 +340,36 @@ bool SlaveInterface::dispatch( int _cmd, const QByteArray &rawdata )
 
 void SlaveInterface::setOffset( KIO::filesize_t o)
 {
+    Q_D(SlaveInterface);
     d->offset = o;
 }
 
-KIO::filesize_t SlaveInterface::offset() const { return d->offset; }
+KIO::filesize_t SlaveInterface::offset() const
+{
+    const Q_D(SlaveInterface);
+    return d->offset;
+}
 
 void SlaveInterface::requestNetwork(const QString &host, const QString &slaveid)
 {
-    kDebug(7007) << "requestNetwork " << host << slaveid << endl;
+    Q_D(SlaveInterface);
+    kDebug(7007) << "requestNetwork " << host << slaveid;
     QByteArray packedArgs;
     QDataStream stream( &packedArgs, QIODevice::WriteOnly );
     stream << true;
-    m_pConnection->sendnow( INF_NETWORK_STATUS, packedArgs );
+    d->connection->sendnow( INF_NETWORK_STATUS, packedArgs );
 }
 
 void SlaveInterface::dropNetwork(const QString &host, const QString &slaveid)
 {
-    kDebug(7007) << "dropNetwork " << host << slaveid << endl;
+    kDebug(7007) << "dropNetwork " << host << slaveid;
 }
 
 void SlaveInterface::sendResumeAnswer( bool resume )
 {
-    kDebug(7007) << "SlaveInterface::sendResumeAnswer ok for resuming :" << resume << endl;
-    m_pConnection->sendnow( resume ? CMD_RESUMEANSWER : CMD_NONE, QByteArray() );
+    Q_D(SlaveInterface);
+    kDebug(7007) << "SlaveInterface::sendResumeAnswer ok for resuming :" << resume;
+    d->connection->sendnow( resume ? CMD_RESUMEANSWER : CMD_NONE, QByteArray() );
 }
 
 void SlaveInterface::messageBox( int type, const QString &text, const QString &_caption,
@@ -414,32 +378,105 @@ void SlaveInterface::messageBox( int type, const QString &text, const QString &_
     messageBox( type, text, _caption, buttonYes, buttonNo, QString() );
 }
 
-void SlaveInterface::messageBox( int type, const QString &text, const QString &_caption,
+void SlaveInterface::messageBox( int type, const QString &text, const QString &caption,
                                  const QString &buttonYes, const QString &buttonNo, const QString &dontAskAgainName )
 {
-    kDebug(7007) << "messageBox " << type << " " << text << " - " << _caption << " " << dontAskAgainName << endl;
+    Q_D(SlaveInterface);
+    kDebug(7007) << "messageBox " << type << " " << text << " - " << caption << " " << dontAskAgainName;
     QByteArray packedArgs;
     QDataStream stream( &packedArgs, QIODevice::WriteOnly );
 
-    QString caption( _caption );
-    if ( type == KIO::SlaveBase::SSLMessageBox )
-#ifdef __GNUC__
-# warning FIXME This will never work
-#endif
-        caption = QDBusConnection::sessionBus().baseService(); // hack, see observer.cpp
-
-    emit needProgressId();
-    kDebug(7007) << "SlaveInterface::messageBox m_progressId=" << m_progressId << endl;
     QPointer<SlaveInterface> me = this;
-    if (m_pConnection) m_pConnection->suspend();
-    int result = Observer::/*self()->*/messageBox( m_progressId, type, text, caption, buttonYes, buttonNo, dontAskAgainName );
-    if ( me && m_pConnection ) // Don't do anything if deleted meanwhile
+    if (d->connection) d->connection->suspend();
+    int result = d->messageBox( type, text, caption, buttonYes, buttonNo, dontAskAgainName );
+    if ( me && d->connection ) // Don't do anything if deleted meanwhile
     {
-        m_pConnection->resume();
-        kDebug(7007) << this << " SlaveInterface result=" << result << endl;
+        d->connection->resume();
+        kDebug(7007) << this << " SlaveInterface result=" << result;
         stream << result;
-        m_pConnection->sendnow( CMD_MESSAGEBOXANSWER, packedArgs );
+        d->connection->sendnow( CMD_MESSAGEBOXANSWER, packedArgs );
     }
 }
 
+int SlaveInterfacePrivate::messageBox(int type, const QString &text,
+                                      const QString &caption, const QString &buttonYes,
+                                      const QString &buttonNo, const QString &dontAskAgainName)
+{
+    kDebug() << "Observer::messageBox " << type << " " << text << " - " << caption;
+    int result = -1;
+    KConfig *config = new KConfig("kioslaverc");
+    KMessageBox::setDontShowAskAgainConfig(config);
+
+    switch (type) {
+        case KIO::SlaveBase::QuestionYesNo:
+            result = KMessageBox::questionYesNo(0L, // parent ?
+                                               text, caption, KGuiItem(buttonYes), KGuiItem(buttonNo), dontAskAgainName);
+            break;
+        case KIO::SlaveBase::WarningYesNo:
+            result = KMessageBox::warningYesNo(0L, // parent ?
+                                              text, caption, KGuiItem(buttonYes), KGuiItem(buttonNo), dontAskAgainName);
+            break;
+        case KIO::SlaveBase::WarningContinueCancel:
+            result = KMessageBox::warningContinueCancel(0L, // parent ?
+                                              text, caption, KGuiItem(buttonYes), KStandardGuiItem::cancel(), dontAskAgainName);
+            break;
+        case KIO::SlaveBase::WarningYesNoCancel:
+            result = KMessageBox::warningYesNoCancel(0L, // parent ?
+                                              text, caption, KGuiItem(buttonYes), KGuiItem(buttonNo), KStandardGuiItem::cancel(), dontAskAgainName);
+            break;
+        case KIO::SlaveBase::Information:
+            KMessageBox::information(0L, // parent ?
+                                      text, caption, dontAskAgainName);
+            result = 1; // whatever
+            break;
+        case KIO::SlaveBase::SSLMessageBox:
+        {
+            KIO::MetaData meta = m_incomingMetaData;
+            KSSLInfoDialog *kid = new KSSLInfoDialog(meta["ssl_in_use"].toUpper()=="TRUE", 0L /*parent?*/, 0L, true);
+            KSSLCertificate *x = KSSLCertificate::fromString(meta["ssl_peer_certificate"].toLocal8Bit());
+            if (x) {
+               // Set the chain back onto the certificate
+               const QStringList cl = meta["ssl_peer_chain"].split('\n', QString::SkipEmptyParts);
+               QList<KSSLCertificate *> ncl;
+               for (QStringList::const_iterator it = cl.begin(); it != cl.end(); ++it) {
+                  KSSLCertificate *y = KSSLCertificate::fromString((*it).toLocal8Bit());
+                  if (y) ncl.append(y);
+               }
+
+               if (!ncl.isEmpty()) {
+                  x->chain().setChain(ncl);
+                  qDeleteAll(ncl);
+               }
+
+               kid->setup(x,
+                           meta["ssl_peer_ip"],
+                           text, // the URL
+                           meta["ssl_cipher"],
+                           meta["ssl_cipher_desc"],
+                           meta["ssl_cipher_version"],
+                           meta["ssl_cipher_used_bits"].toInt(),
+                           meta["ssl_cipher_bits"].toInt(),
+                           KSSLCertificate::KSSLValidation(meta["ssl_cert_state"].toInt()));
+               kDebug(7024) << "Showing SSL Info dialog";
+               kid->exec();
+               delete x;
+               kDebug(7024) << "SSL Info dialog closed";
+            } else {
+               KMessageBox::information(0L, // parent ?
+                                         i18n("The peer SSL certificate appears to be corrupt."), i18n("SSL"));
+            }
+            // This doesn't have to get deleted.  It deletes on it's own.
+            result = 1; // whatever
+            break;
+        }
+        default:
+            kWarning() << "Observer::messageBox: unknown type " << type;
+            result = 0;
+            break;
+    }
+    KMessageBox::setDontShowAskAgainConfig(0);
+    delete config;
+    return result;
+}
+
 #include "slaveinterface.moc"
