@@ -23,9 +23,10 @@
 #include <unistd.h>
 #include <sys/types.h>
 
-#include <qobject.h>
+#include <QtCore/QObject>
 
 #include <kio/global.h>
+#include <kio/udsentry.h>
 #include <kio/authinfo.h>
 
 class KUrl;
@@ -68,17 +69,17 @@ class SlaveInterfacePrivate;
    MSG_ERROR,
    MSG_CONNECTED,
    MSG_FINISHED,
-   MSG_STAT_ENTRY,
+   MSG_STAT_ENTRY, // 105
    MSG_LIST_ENTRIES,
    MSG_RENAMED, // unused
    MSG_RESUME,
    MSG_SLAVE_STATUS,
-   MSG_SLAVE_ACK,
+   MSG_SLAVE_ACK, // 110
    MSG_NET_REQUEST,
    MSG_NET_DROP,
    MSG_NEED_SUBURL_DATA,
    MSG_CANRESUME,
-   MSG_AUTH_KEY, // deprecated.
+   MSG_AUTH_KEY, // 115 // deprecated.
    MSG_DEL_AUTH_KEY, // deprecated.
    MSG_OPENED,
    MSG_WRITTEN
@@ -96,15 +97,13 @@ class KIO_EXPORT SlaveInterface : public QObject
 {
     Q_OBJECT
 
+protected:
+    SlaveInterface(SlaveInterfacePrivate &dd, QObject *parent = 0);
 public:
-    SlaveInterface( Connection *connection );
     virtual ~SlaveInterface();
 
-    void setConnection( Connection* connection ) { m_pConnection = connection; }
-    Connection *connection() const { return m_pConnection; }
-
-    void setProgressId( int id ) { m_progressId = id; }
-    int progressId() const { return m_progressId; }
+    void setConnection( Connection* connection );
+    Connection *connection() const;
 
     // Send our answer to the MSG_RESUME (canResume) request
     // (to tell the "put" job whether to resume or not)
@@ -127,7 +126,6 @@ Q_SIGNALS:
     void listEntries( const KIO::UDSEntryList& );
     void statEntry( const KIO::UDSEntry& );
     void needSubUrlData();
-    void needProgressId();
 
     void canResume( KIO::filesize_t );
 
@@ -172,17 +170,14 @@ protected Q_SLOTS:
     void calcSpeed();
 
 protected:
-    Connection * m_pConnection;
-
-private:
-    int m_progressId;
-private:
-    SlaveInterfacePrivate* const d;
+    SlaveInterfacePrivate* const d_ptr;
+    Q_DECLARE_PRIVATE(SlaveInterface)
 };
 
 }
 
-KIO_EXPORT QDataStream &operator <<(QDataStream &s, const KIO::UDSEntry &e );
-KIO_EXPORT QDataStream &operator >>(QDataStream &s, KIO::UDSEntry &e );
+// moved to udesentry.cpp!!!
+// KIO_EXPORT QDataStream &operator <<(QDataStream &s, const KIO::UDSEntry &e );
+// KIO_EXPORT QDataStream &operator >>(QDataStream &s, KIO::UDSEntry &e );
 
 #endif
