@@ -20,11 +20,11 @@
 #ifndef KNTLM_H
 #define KNTLM_H
 
-#include <qglobal.h>
-#include <QByteArray>
-#include <QString>
+#include <QtCore/QBool>
+#include <QtCore/QByteRef>
+#include <QtCore/QString>
 
-#include <kdelibs_export.h>
+#include "kntlm_export.h"
 
 /**
  * @short KNTLM class implements the NTLM authentication protocol.
