@@ -1,3 +1,4 @@
+//krazy:excludeall=license (it's a program, not a library)
 /*
    Copyright (c) 2001 Malte Starostik <malte@kde.org>
    based on kmailservice.cpp,
@@ -26,38 +27,34 @@
 #include <kcmdlineargs.h>
 #include <kdebug.h>
 #include <klocale.h>
-#include <ksimpleconfig.h>
-
-static const KCmdLineOptions options[] =
-{
-	{"+url", 0, 0},
-	KCmdLineLastOption
-};
+#include <kconfig.h>
 
 int main(int argc, char **argv)
 {
-	KLocale::setMainCatalog("kdelibs");
-	KCmdLineArgs::init(argc, argv, "ktelnetservice", I18N_NOOP("telnet service"),
-			   I18N_NOOP("telnet protocol handler"), "unknown");
-	KCmdLineArgs::addCmdLineOptions(options);
+    KCmdLineOptions options;
+    options.add("+url");
 
-	KApplication app;
+    KCmdLineArgs::init(argc, argv, "ktelnetservice", "kdelibs4", ki18n("telnet service"),
+               "unknown", ki18n("telnet protocol handler"));
+    KCmdLineArgs::addCmdLineOptions(options);
 
-	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
-	
-	if (args->count() != 1)
-		return 1;
-	
-	KConfig *config = new KConfig("kdeglobals", true);
-	config->setGroup("General");
-	QString terminal = config->readPathEntry("TerminalApplication", "konsole");
+    KApplication app;
 
-	KUrl url(args->arg(0));
-	QStringList cmd;
-	if (terminal == "konsole")
-	    cmd << "--noclose";
+    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
-	cmd << "-e";
+    if (args->count() != 1)
+        return 1;
+
+    KConfig config("kdeglobals");
+    KConfigGroup cg(&config, "General");
+    QString terminal = cg.readPathEntry("TerminalApplication", "konsole");
+
+    KUrl url(args->arg(0));
+    QStringList cmd;
+    if (terminal == "konsole")
+        cmd << "--noclose";
+
+    cmd << "-e";
         if ( url.protocol() == "telnet" )
             cmd << "telnet";
         else if ( url.protocol() == "ssh" )
@@ -68,19 +65,19 @@ int main(int argc, char **argv)
             kError() << "Invalid protocol " << url.protocol() << endl;
             return 2;
         }
-        
+
         if (!KAuthorized::authorize("shell_access"))
         {
-            KMessageBox::sorry(0, 
-            	i18n("You do not have permission to access the %1 protocol.", url.protocol()));
+            KMessageBox::sorry(0,
+                i18n("You do not have permission to access the %1 protocol.", url.protocol()));
             return 3;
         }
-        
-	if (!url.user().isEmpty())
-	{
-		cmd << "-l";
-		cmd << url.user();
-	}
+
+    if (!url.user().isEmpty())
+    {
+        cmd << "-l";
+        cmd << url.user();
+    }
 
         QString host;
         if (!url.host().isEmpty())
@@ -88,7 +85,7 @@ int main(int argc, char **argv)
         else if (!url.path().isEmpty())
            host = url.path(); // telnet:host
 
-        if (host.isEmpty() || host.startsWith("-"))
+        if (host.isEmpty() || host.startsWith('-'))
         {
             kError() << "Invalid hostname " << host << endl;
             return 2;
@@ -96,16 +93,14 @@ int main(int argc, char **argv)
 
         cmd << host;
 
-	if (url.port() > 0){
+    if (url.port() > 0){
             if ( url.protocol() == "ssh" )
-		cmd << "-p" << QString::number(url.port());
-	    else
-		cmd << QString::number(url.port());
-	}
+        cmd << "-p" << QString::number(url.port());
+        else
+        cmd << QString::number(url.port());
+    }
 
-	KToolInvocation::kdeinitExec(terminal, cmd);
+    KToolInvocation::kdeinitExec(terminal, cmd);
 
-	return 0;
+    return 0;
 }
-
-// vim: ts=4 sw=4 noet
