@@ -21,14 +21,16 @@
 
 */
 
+#include "kwalletd.h"
+
 #include "kbetterthankdialog.h"
 #include "kwalletwizard.h"
-#include "kwalletd.h"
 #include "ktimeout.h"
 
 #include <kapplication.h>
 #include <ktoolinvocation.h>
 #include <kconfig.h>
+#include <kconfiggroup.h>
 #include <kdebug.h>
 #include <kdirwatch.h>
 #include <kglobal.h>
@@ -38,14 +40,14 @@
 #include <knewpassworddialog.h>
 #include <kstandarddirs.h>
 #include <kwalletentry.h>
-#include <kwin.h>
+#include <kwindowsystem.h>
 
-#include <qdir.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qpushbutton.h>
-#include <qregexp.h>
-#include <QTextDocument>
+#include <QtCore/QDir>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtGui/QPushButton>
+#include <QtCore/QRegExp>
+#include <QtGui/QTextDocument>
 
 #include <assert.h>
 
@@ -79,7 +81,6 @@ KWalletD::KWalletD()
 : KDEDModule(), _failed(0) {
 	srand(time(0));
 	_showingFailureNotify = false;
-	_transactions.setAutoDelete(true);
 	_timeouts = new KTimeout();
 	_closeIdle = false;
 	_idleTime = 0;
@@ -89,7 +90,7 @@ KWalletD::KWalletD()
 	// register another name
 	QDBusConnection::sessionBus().registerService("org.kde.kwalletd");
 #ifdef Q_WS_X11
-	kdesktop = new QDBusInterface("org.kde.kdesktop", "/Screensaver", "org.kde.kdesktop.Screensaver");
+	screensaver = new QDBusInterface("org.freedesktop.ScreenSaver", "/ScreenSaver", "org.freedesktop.ScreenSaver");
 #endif
 	reconfigure();
 	KGlobal::dirs()->addResourceType("kwallet", "share/apps/kwallet");
@@ -107,11 +108,11 @@ KWalletD::~KWalletD() {
 	delete _timeouts;
 	_timeouts = 0;
 #ifdef Q_WS_X11
-	delete kdesktop;
-	kdesktop = 0;
+	delete screensaver;
+	screensaver = 0;
 #endif
 	closeAllWallets();
-	_transactions.clear();
+	qDeleteAll(_transactions);
 }
 
 
@@ -121,11 +122,23 @@ int KWalletD::generateHandle() {
 	// ASSUMPTION: RAND_MAX is fairly large.
 	do {
 		rc = rand();
-	} while (_wallets.find(rc) || rc == 0);
+	} while (_wallets.contains(rc) || rc == 0);
 
 	return rc;
 }
 
+QPair<int, KWallet::Backend*> KWalletD::findWallet(const QString& walletName) const
+{
+	Wallets::const_iterator it = _wallets.begin();
+	const Wallets::const_iterator end = _wallets.end();
+	for (; it != end; ++it) {
+		if (it.value()->walletName() == walletName) {
+			return qMakePair(it.key(), it.value());
+		}
+	}
+    return qMakePair(-1, static_cast<KWallet::Backend*>(0));
+}
+
 void KWalletD::processTransactions() {
 	static bool processing = false;
 
@@ -151,19 +164,15 @@ void KWalletD::processTransactions() {
 				// should not produce multiple password
 				// dialogs on a failure
 				if (res < 0) {
-					Q3PtrListIterator<KWalletTransaction> it(_transactions);
-					KWalletTransaction *x;
-					while ((x = it.current()) && x != xact) {
-						++it;
-					}
-					if (x) {
-						++it;
-					}
-					while ((x = it.current())) {
-						if (xact->appid == x->appid && x->tType == KWalletTransaction::Open && x->wallet == xact->wallet && x->wId == xact->wId) {
+					QList<KWalletTransaction *>::iterator it = _transactions.begin();
+					Q_ASSERT(*it == xact);
+					++it;
+					for (; it != _transactions.end(); ++it) {
+						KWalletTransaction *x = *it;
+						if (xact->appid == x->appid && x->tType == KWalletTransaction::Open
+							&& x->wallet == xact->wallet && x->wId == xact->wId) {
 							x->tType = KWalletTransaction::OpenFail;
 						}
-						++it;
 					}
 				}
 				break;
@@ -174,14 +183,14 @@ void KWalletD::processTransactions() {
 				doTransactionChangePassword(xact->appid, xact->wallet, xact->wId);
 				// fall through - no return
 			default:
-				_transactions.removeRef(xact);
+				_transactions.removeAll(xact);
 				continue;
 		}
 
 		if (xact->tType != KWalletTransaction::ChangePassword) {
                     QDBusConnection::sessionBus().send(xact->msg.createReply(res));
 		}
-		_transactions.removeRef(xact);
+		_transactions.removeAll(xact);
 	}
 
 	processing = false;
@@ -253,21 +262,25 @@ int KWalletD::open(const QString& wallet, qlonglong wId, const QString& appid, c
 
 // Sets up a dialog that will be shown by kwallet.
 void KWalletD::setupDialog( QWidget* dialog, WId wId, const QString& appid, bool modal ) {
+#ifdef Q_WS_X11
 	if( wId != 0 )
-		KWin::setMainWindow( dialog, wId ); // correct, set dialog parent
+		KWindowSystem::setMainWindow( dialog, wId ); // correct, set dialog parent
 	else {
+#endif
 		if( appid.isEmpty())
-			kWarning() << "Using kwallet without parent window!" << endl;
+			kWarning() << "Using kwallet without parent window!";
 		else
-			kWarning() << "Application '" << appid << "' using kwallet without parent window!" << endl;
+			kWarning() << "Application '" << appid << "' using kwallet without parent window!";
 		// allow dialog activation even if it interrupts, better than trying hacks
 		// with keeping the dialog on top or on all desktops
 		kapp->updateUserTimestamp();
+#ifdef Q_WS_X11
 	}
 	if( modal )
-		KWin::setState( dialog->winId(), NET::Modal );
+		KWindowSystem::setState( dialog->winId(), NET::Modal );
 	else
-		KWin::clearState( dialog->winId(), NET::Modal );
+		KWindowSystem::clearState( dialog->winId(), NET::Modal );
+#endif
 	activeDialog = dialog;
 }
 
@@ -281,9 +294,11 @@ void KWalletD::checkActiveDialog() {
 	if( !activeDialog || activeDialog->isHidden())
 		return;
 	kapp->updateUserTimestamp();
-	KWin::setState( activeDialog->winId(), NET::KeepAbove );
-	KWin::setOnAllDesktops( activeDialog->winId(), true );
-	KWin::forceActiveWindow( activeDialog->winId());
+#ifdef Q_WS_X11
+	KWindowSystem::setState( activeDialog->winId(), NET::KeepAbove );
+	KWindowSystem::setOnAllDesktops( activeDialog->winId(), true );
+	KWindowSystem::forceActiveWindow( activeDialog->winId());
+#endif
 }
 
 
@@ -294,23 +309,25 @@ int KWalletD::doTransactionOpen(const QString& appid, const QString& wallet, qlo
 		setupDialog( wiz, wId, appid, modal );
 		int rc = wiz->exec();
 		if (rc == QDialog::Accepted) {
-			KConfig cfg("kwalletrc");
-			cfg.setGroup("Wallet");
+			bool useWallet = wiz->field("useWallet").toBool();
+			KConfig kwalletrc("kwalletrc");
+			KConfigGroup cfg(&kwalletrc, "Wallet");
 			cfg.writeEntry("First Use", false);
-			cfg.writeEntry("Enabled", wiz->_useWallet->isChecked());
-			cfg.writeEntry("Close When Idle", wiz->_closeIdle->isChecked());
-			cfg.writeEntry("Use One Wallet", !wiz->_networkWallet->isChecked());
+			cfg.writeEntry("Enabled", useWallet);
+			cfg.writeEntry("Close When Idle", wiz->field("closeWhenIdle").toBool());
+			cfg.writeEntry("Use One Wallet", !wiz->field("networkWallet").toBool());
 			cfg.sync();
 			reconfigure();
 
-			if (!wiz->_useWallet->isChecked()) {
+			if (!useWallet) {
 				delete wiz;
 				return -1;
 			}
 
 			// Create the wallet
 			KWallet::Backend *b = new KWallet::Backend(KWallet::Wallet::LocalWallet());
-			QByteArray p(wiz->_pass1->text().toUtf8(), wiz->_pass1->text().length());
+			QString pass = wiz->field("pass1").toString();
+			QByteArray p(pass.toUtf8(), pass.length());
 			b->open(p);
 			b->createFolder(KWallet::Wallet::PasswordFolder());
 			b->createFolder(KWallet::Wallet::FormDataFolder());
@@ -323,11 +340,10 @@ int KWalletD::doTransactionOpen(const QString& appid, const QString& wallet, qlo
 			return -1;
 		}
 	} else if (_firstUse) {
-		KConfig cfg("kwalletrc");
+		KConfig kwalletrc("kwalletrc");
+		KConfigGroup cfg(&kwalletrc, "Wallet");
 		_firstUse = false;
-		cfg.setGroup("Wallet");
 		cfg.writeEntry("First Use", false);
-		cfg.sync();
 	}
 
 	int rc = internalOpen(appid, wallet, false, WId(wId), modal);
@@ -336,7 +352,6 @@ int KWalletD::doTransactionOpen(const QString& appid, const QString& wallet, qlo
 
 
 int KWalletD::internalOpen(const QString& appid, const QString& wallet, bool isPath, WId w, bool modal) {
-	int rc = -1;
 	bool brandNew = false;
 
 	QString thisApp;
@@ -350,16 +365,11 @@ int KWalletD::internalOpen(const QString& appid, const QString& wallet, bool isP
 		return -1;
 	}
 
-	for (Q3IntDictIterator<KWallet::Backend> i(_wallets); i.current(); ++i) {
-		if (i.current()->walletName() == wallet) {
-			rc = i.currentKey();
-			break;
-		}
-	}
-
+	const QPair<int, KWallet::Backend*> walletInfo = findWallet(wallet);
+	int rc = walletInfo.first;
 	if (rc == -1) {
 		if (_wallets.count() > 20) {
-			kDebug() << "Too many wallets open." << endl;
+			kDebug() << "Too many wallets open.";
 			return -1;
 		}
 
@@ -376,12 +386,13 @@ int KWalletD::internalOpen(const QString& appid, const QString& wallet, bool isP
 				}
 				KPasswordDialog *kpd = new KPasswordDialog();
 				if (appid.isEmpty()) {
-					kpd->setPrompt(i18n("<qt>KDE has requested to open the wallet '<b>%1</b>'. Please enter the password for this wallet below.", Qt::escape(wallet)));
+					kpd->setPrompt(i18n("<qt>KDE has requested to open the wallet '<b>%1</b>'. Please enter the password for this wallet below.</qt>", Qt::escape(wallet)));
 				} else {
-					kpd->setPrompt(i18n("<qt>The application '<b>%1</b>' has requested to open the wallet '<b>%2</b>'. Please enter the password for this wallet below.", Qt::escape(appid), Qt::escape(wallet)));
+					kpd->setPrompt(i18n("<qt>The application '<b>%1</b>' has requested to open the wallet '<b>%2</b>'. Please enter the password for this wallet below.</qt>", Qt::escape(appid), Qt::escape(wallet)));
 				}
 				brandNew = false;
-				kpd->setButtonGuiItem(KDialog::Ok,KStandardGuiItem::open());
+				// don't use KStdGuiItem::open() here which has trailing ellipsis!
+				kpd->setButtonGuiItem(KDialog::Ok,KGuiItem( i18n( "&Open" ), "document-open"));
 				kpd->setCaption(i18n("KDE Wallet Service"));
 				while (!b->isOpen()) {
 					setupDialog( kpd, w, appid, modal );
@@ -389,7 +400,7 @@ int KWalletD::internalOpen(const QString& appid, const QString& wallet, bool isP
 						password = kpd->password();
 						int rc = b->open(password.toUtf8());
 						if (!b->isOpen()) {
-							kpd->setPrompt(i18n("<qt>Error opening the wallet '<b>%1</b>'. Please try again.<br>(Error code %2: %3)", Qt::escape(wallet), rc, KWallet::Backend::openRCToString(rc)));
+							kpd->setPrompt(i18n("<qt>Error opening the wallet '<b>%1</b>'. Please try again.<br />(Error code %2: %3)</qt>", Qt::escape(wallet), rc, KWallet::Backend::openRCToString(rc)));
 						}
 					} else {
 						break;
@@ -402,31 +413,31 @@ int KWalletD::internalOpen(const QString& appid, const QString& wallet, bool isP
 		} else {
 			KNewPasswordDialog *kpd = new KNewPasswordDialog();
 			if (wallet == KWallet::Wallet::LocalWallet() ||
-						 wallet == KWallet::Wallet::NetworkWallet()) 
+						 wallet == KWallet::Wallet::NetworkWallet())
 			{
 				// Auto create these wallets.
 				if (appid.isEmpty()) {
 					kpd->setPrompt(i18n("KDE has requested to open the wallet. This is used to store sensitive data in a secure fashion. Please enter a password to use with this wallet or click cancel to deny the application's request."));
 				} else {
-					kpd->setPrompt(i18n("<qt>The application '<b>%1</b>' has requested to open the KDE wallet. This is used to store sensitive data in a secure fashion. Please enter a password to use with this wallet or click cancel to deny the application's request.", Qt::escape(appid)));
+					kpd->setPrompt(i18n("<qt>The application '<b>%1</b>' has requested to open the KDE wallet. This is used to store sensitive data in a secure fashion. Please enter a password to use with this wallet or click cancel to deny the application's request.</qt>", Qt::escape(appid)));
 				}
 			} else {
 				if (appid.length() == 0) {
-					kpd->setPrompt(i18n("<qt>KDE has requested to create a new wallet named '<b>%1</b>'. Please choose a password for this wallet, or cancel to deny the application's request.", Qt::escape(wallet)));
+					kpd->setPrompt(i18n("<qt>KDE has requested to create a new wallet named '<b>%1</b>'. Please choose a password for this wallet, or cancel to deny the application's request.</qt>", Qt::escape(wallet)));
 				} else {
-					kpd->setPrompt(i18n("<qt>The application '<b>%1</b>' has requested to create a new wallet named '<b>%2</b>'. Please choose a password for this wallet, or cancel to deny the application's request.", Qt::escape(appid), Qt::escape(wallet)));
+					kpd->setPrompt(i18n("<qt>The application '<b>%1</b>' has requested to create a new wallet named '<b>%2</b>'. Please choose a password for this wallet, or cancel to deny the application's request.</qt>", Qt::escape(appid), Qt::escape(wallet)));
 				}
 			}
 			brandNew = true;
-			kpd->setCaption(i18n("KDE Wallet Service"));			
-			kpd->setButtonGuiItem(KDialog::Ok,KGuiItem(i18n("C&reate"),"filenew"));
+			kpd->setCaption(i18n("KDE Wallet Service"));
+			kpd->setButtonGuiItem(KDialog::Ok,KGuiItem(i18n("C&reate"),"document-new"));
 			while (!b->isOpen()) {
 				setupDialog( kpd, w, appid, modal );
 				if (kpd->exec() == KDialog::Accepted) {
 					password = kpd->password();
 					int rc = b->open(password.toUtf8());
 					if (!b->isOpen()) {
-						kpd->setPrompt(i18n("<qt>Error opening the wallet '<b>%1</b>'. Please try again.<br>(Error code %2: %3)", Qt::escape(wallet), rc, KWallet::Backend::openRCToString(rc)));
+						kpd->setPrompt(i18n("<qt>Error opening the wallet '<b>%1</b>'. Please try again.<br />(Error code %2: %3)</qt>", Qt::escape(wallet), rc, KWallet::Backend::openRCToString(rc)));
 					}
 				} else {
 					break;
@@ -475,7 +486,7 @@ int KWalletD::internalOpen(const QString& appid, const QString& wallet, bool isP
 			return -1;
 		}
 		_handles[appid].append(rc);
-		_wallets.find(rc)->ref();
+		_wallets.value(rc)->ref();
 	}
 
 	return rc;
@@ -493,14 +504,13 @@ bool KWalletD::isAuthorizedApp(const QString& appid, const QString& wallet, WId
 	}
 
 	if (!implicitAllow(wallet, thisApp)) {
-		KConfig cfg("kwalletrc");
-		cfg.setGroup("Auto Allow");
+		KConfigGroup cfg = KSharedConfig::openConfig("kwalletrc")->group("Auto Allow");
 		if (!cfg.entryIsImmutable(wallet)) {
 		    KBetterThanKDialog *dialog = new KBetterThanKDialog;
 		    if (appid.isEmpty()) {
-			dialog->setLabel(i18n("<qt>KDE has requested access to the open wallet '<b>%1</b>'.", Qt::escape(wallet)));
+			dialog->setLabel(i18n("<qt>KDE has requested access to the open wallet '<b>%1</b>'.</qt>", Qt::escape(wallet)));
 		    } else {
-			dialog->setLabel(i18n("<qt>The application '<b>%1</b>' has requested access to the open wallet '<b>%2</b>'.", Qt::escape(QString(appid)), Qt::escape(wallet)));
+			dialog->setLabel(i18n("<qt>The application '<b>%1</b>' has requested access to the open wallet '<b>%2</b>'.</qt>", Qt::escape(QString(appid)), Qt::escape(wallet)));
 		    }
 		    setupDialog( dialog, w, appid, false );
 		    response = dialog->exec();
@@ -510,8 +520,7 @@ bool KWalletD::isAuthorizedApp(const QString& appid, const QString& wallet, WId
 
 	if (response == 0 || response == 1) {
 		if (response == 1) {
-			KConfig cfg("kwalletrc");
-			cfg.setGroup("Auto Allow");
+			KConfigGroup cfg = KSharedConfig::openConfig("kwalletrc")->group("Auto Allow");
 			QStringList apps = cfg.readEntry(wallet, QStringList());
 			if (!apps.contains(thisApp)) {
 				if (cfg.entryIsImmutable(wallet)) {
@@ -524,8 +533,7 @@ bool KWalletD::isAuthorizedApp(const QString& appid, const QString& wallet, WId
 			}
 		}
 	} else if (response == 3) {
-		KConfig cfg("kwalletrc");
-		cfg.setGroup("Auto Deny");
+		KConfigGroup cfg = KSharedConfig::openConfig("kwalletrc")->group("Auto Deny");
 		QStringList apps = cfg.readEntry(wallet, QStringList());
 		if (!apps.contains(thisApp)) {
 			apps += thisApp;
@@ -575,36 +583,27 @@ void KWalletD::changePassword(const QString& wallet, qlonglong wId, const QStrin
 
 
 void KWalletD::doTransactionChangePassword(const QString& appid, const QString& wallet, qlonglong wId) {
-	Q3IntDictIterator<KWallet::Backend> it(_wallets);
-	KWallet::Backend *w = 0L;
-	int handle = -1;
+
+	const QPair<int, KWallet::Backend*> walletInfo = findWallet(wallet);
+	int handle = walletInfo.first;
+	KWallet::Backend* w = walletInfo.second;
+
 	bool reclose = false;
-
-	for (; it.current(); ++it) {
-		if (it.current()->walletName() == wallet) {
-			break;
-		}
-	}
-
-	if (!it.current()) {
+	if (!w) {
 		handle = doTransactionOpen(appid, wallet, wId, false);
 		if (-1 == handle) {
 			KMessageBox::sorryWId(wId, i18n("Unable to open wallet. The wallet must be opened in order to change the password."), i18n("KDE Wallet Service"));
 			return;
 		}
 
-		w = _wallets.find(handle);
+		w = _wallets.value(handle);
 		reclose = true;
-	} else {
-		handle = it.currentKey();
-		w = it.current();
 	}
 
 	assert(w);
 
-	KNewPasswordDialog *kpd;
-	kpd = new KNewPasswordDialog();
-	kpd->setPrompt(i18n("<qt>Please choose a new password for the wallet '<b>%1</b>'.", Qt::escape(wallet)));
+	KNewPasswordDialog *kpd = new KNewPasswordDialog();
+	kpd->setPrompt(i18n("<qt>Please choose a new password for the wallet '<b>%1</b>'.</qt>", Qt::escape(wallet)));
 	kpd->setCaption(i18n("KDE Wallet Service"));
 	kpd->setAllowEmptyPasswords(true);
 	setupDialog( kpd, wId, appid, false );
@@ -635,18 +634,9 @@ void KWalletD::doTransactionChangePassword(const QString& appid, const QString&
 
 
 int KWalletD::close(const QString& wallet, bool force) {
-	int handle = -1;
-	KWallet::Backend *w = 0L;
-
-	for (Q3IntDictIterator<KWallet::Backend> it(_wallets);
-						it.current();
-							++it) {
-		if (it.current()->walletName() == wallet) {
-			handle = it.currentKey();
-			w = it.current();
-			break;
-		}
-	}
+	const QPair<int, KWallet::Backend*> walletInfo = findWallet(wallet);
+	int handle = walletInfo.first;
+	KWallet::Backend* w = walletInfo.second;
 
 	return closeWallet(w, handle, force);
 }
@@ -679,7 +669,7 @@ int KWalletD::closeWallet(KWallet::Backend *w, int handle, bool force) {
 
 
 int KWalletD::close(int handle, bool force, const QString& appid) {
-	KWallet::Backend *w = _wallets.find(handle);
+	KWallet::Backend *w = _wallets.value(handle);
 	bool contains = false;
 
 	if (w) { // the handle is valid
@@ -720,14 +710,8 @@ int KWalletD::close(int handle, bool force, const QString& appid) {
 
 
 bool KWalletD::isOpen(const QString& wallet) {
-	for (Q3IntDictIterator<KWallet::Backend> it(_wallets);
-						it.current();
-							++it) {
-		if (it.current()->walletName() == wallet) {
-			return true;
-		}
-	}
-	return false;
+	const QPair<int, KWallet::Backend*> walletInfo = findWallet(wallet);
+	return walletInfo.second != 0;
 }
 
 
@@ -736,7 +720,7 @@ bool KWalletD::isOpen(int handle) {
 		return false;
 	}
 
-	KWallet::Backend *rc = _wallets.find(handle);
+	KWallet::Backend *rc = _wallets.value(handle);
 
 	if (rc == 0 && ++_failed > 5) {
 		_failed = 0;
@@ -1063,7 +1047,7 @@ void KWalletD::slotServiceUnregistered(const QString& app) {
 		QList<int> l = _handles[app];
 		for (QList<int>::Iterator i = l.begin(); i != l.end(); ++i) {
 			_handles[app].removeAll(*i);
-			KWallet::Backend *w = _wallets.find(*i);
+			KWallet::Backend *w = _wallets.value(*i);
 			if (w && !_leaveOpen && 0 == w->deref()) {
 				close(w->walletName(), true);
 			}
@@ -1087,7 +1071,7 @@ KWallet::Backend *KWalletD::getWallet(const QString& appid, int handle) {
 		return 0L;
 	}
 
-	KWallet::Backend *w = _wallets.find(handle);
+	KWallet::Backend *w = _wallets.value(handle);
 
 	if (w) { // the handle is valid
 		if (_handles.contains(appid)) { // we know this app
@@ -1146,16 +1130,15 @@ int KWalletD::renameEntry(int handle, const QString& folder, const QString& oldN
 QStringList KWalletD::users(const QString& wallet) const {
 	QStringList rc;
 
-	for (Q3IntDictIterator<KWallet::Backend> it(_wallets);
-						it.current();
-							++it) {
-		if (it.current()->walletName() == wallet) {
-			for (QHash<QString,QList<int> >::ConstIterator hit = _handles.begin(); hit != _handles.end(); ++hit) {
-				if (hit.value().contains(it.currentKey())) {
-					rc += hit.key();
-				}
+	const QPair<int, KWallet::Backend*> walletInfo = findWallet(wallet);
+	int handle = walletInfo.first;
+	KWallet::Backend* w = walletInfo.second;
+
+	if (w) {
+		for (QHash<QString,QList<int> >::ConstIterator hit = _handles.begin(); hit != _handles.end(); ++hit) {
+			if (hit.value().contains(handle)) {
+				rc.append(hit.key());
 			}
-			break;
 		}
 	}
 
@@ -1164,25 +1147,23 @@ QStringList KWalletD::users(const QString& wallet) const {
 
 
 bool KWalletD::disconnectApplication(const QString& wallet, const QString& application) {
-	for (Q3IntDictIterator<KWallet::Backend> it(_wallets);
-						it.current();
-							++it) {
-		if (it.current()->walletName() == wallet) {
-			if (_handles[application].contains(it.currentKey())) {
-				_handles[application].removeAll(it.currentKey());
+	const QPair<int, KWallet::Backend*> walletInfo = findWallet(wallet);
+	int handle = walletInfo.first;
+	KWallet::Backend* backend = walletInfo.second;
 
-				if (_handles[application].isEmpty()) {
-					_handles.remove(application);
-				}
+	if (handle != -1 && _handles[application].contains(handle)) {
+		_handles[application].removeAll(handle);
 
-				if (it.current()->deref() == 0) {
-					close(it.current()->walletName(), true);
-				}
-
-				emit applicationDisconnected(wallet, application);
-				return true;
-			}
+		if (_handles[application].isEmpty()) {
+			_handles.remove(application);
 		}
+
+		if (backend->deref() == 0) {
+			close(backend->walletName(), true);
+		}
+
+		emit applicationDisconnected(wallet, application);
+		return true;
 	}
 
 	return false;
@@ -1201,39 +1182,41 @@ void KWalletD::emitWalletListDirty() {
 
 void KWalletD::reconfigure() {
 	KConfig cfg("kwalletrc");
-	cfg.setGroup("Wallet");
-	_firstUse = cfg.readEntry("First Use", true);
-	_enabled = cfg.readEntry("Enabled", true);
-	_launchManager = cfg.readEntry("Launch Manager", true);
-	_leaveOpen = cfg.readEntry("Leave Open", false);
+	KConfigGroup walletGroup(&cfg, "Wallet");
+	_firstUse = walletGroup.readEntry("First Use", true);
+	_enabled = walletGroup.readEntry("Enabled", true);
+	_launchManager = walletGroup.readEntry("Launch Manager", true);
+	_leaveOpen = walletGroup.readEntry("Leave Open", false);
 	bool idleSave = _closeIdle;
-	_closeIdle = cfg.readEntry("Close When Idle", false);
-	_openPrompt = cfg.readEntry("Prompt on Open", true);
+	_closeIdle = walletGroup.readEntry("Close When Idle", false);
+	_openPrompt = walletGroup.readEntry("Prompt on Open", true);
 	int timeSave = _idleTime;
 	// in minutes!
-	_idleTime = cfg.readEntry("Idle Timeout", 10) * 60 * 1000;
+	_idleTime = walletGroup.readEntry("Idle Timeout", 10) * 60 * 1000;
 #ifdef Q_WS_X11
-	if ( kdesktop->isValid() ) {
-		if (cfg.readEntry("Close on Screensaver", false)) {
-			connect(kdesktop, SIGNAL(screenSaverStarted()), SLOT(closeAllWallets()));
+	if ( screensaver->isValid() ) {
+		if (walletGroup.readEntry("Close on Screensaver", false)) {
+			connect(screensaver, SIGNAL(ActiveChanged(bool)), SLOT(screenSaverChanged(bool)));
 		} else {
-			kdesktop->disconnect(SIGNAL(screenSaverStarted()), this, SLOT(closeAllWallets()));
+			screensaver->disconnect(SIGNAL(ActiveChanged(bool)), this, SLOT(screenSaverChanged(bool)));
 		}
 	}
 #endif
 	// Handle idle changes
 	if (_closeIdle) {
 		if (_idleTime != timeSave) { // Timer length changed
-			Q3IntDictIterator<KWallet::Backend> it(_wallets);
-			for (; it.current(); ++it) {
-				_timeouts->resetTimer(it.currentKey(), _idleTime);
+			Wallets::const_iterator it = _wallets.begin();
+			const Wallets::const_iterator end = _wallets.end();
+			for (; it != end; ++it) {
+				_timeouts->resetTimer(it.key(), _idleTime);
 			}
 		}
 
 		if (!idleSave) { // add timers for all the wallets
-			Q3IntDictIterator<KWallet::Backend> it(_wallets);
-			for (; it.current(); ++it) {
-				_timeouts->addTimer(it.currentKey(), _idleTime);
+			Wallets::const_iterator it = _wallets.begin();
+			const Wallets::const_iterator end = _wallets.end();
+			for (; it != end; ++it) {
+				_timeouts->addTimer(it.key(), _idleTime);
 			}
 		}
 	} else {
@@ -1242,28 +1225,25 @@ void KWalletD::reconfigure() {
 
 	// Update the implicit allow stuff
 	_implicitAllowMap.clear();
-	cfg.setGroup("Auto Allow");
-	QStringList entries = cfg.entryMap("Auto Allow").keys();
+	const KConfigGroup autoAllowGroup(&cfg, "Auto Allow");
+	QStringList entries = autoAllowGroup.entryMap().keys();
 	for (QStringList::Iterator i = entries.begin(); i != entries.end(); ++i) {
-		_implicitAllowMap[*i] = cfg.readEntry(*i, QStringList());
+		_implicitAllowMap[*i] = autoAllowGroup.readEntry(*i, QStringList());
 	}
 
 	// Update the implicit allow stuff
 	_implicitDenyMap.clear();
-	cfg.setGroup("Auto Deny");
-	entries = cfg.entryMap("Auto Deny").keys();
+	const KConfigGroup autoDenyGroup(&cfg, "Auto Deny");
+	entries = autoDenyGroup.entryMap().keys();
 	for (QStringList::Iterator i = entries.begin(); i != entries.end(); ++i) {
-		_implicitDenyMap[*i] = cfg.readEntry(*i, QStringList());
+		_implicitDenyMap[*i] = autoDenyGroup.readEntry(*i, QStringList());
 	}
 
 	// Update if wallet was enabled/disabled
 	if (!_enabled) { // close all wallets
 		while (!_wallets.isEmpty()) {
-			Q3IntDictIterator<KWallet::Backend> it(_wallets);
-			if (!it.current()) { // necessary?
-				break;
-			}
-			closeWallet(it.current(), it.currentKey(), true);
+			Wallets::const_iterator it = _wallets.begin();
+			closeWallet(it.value(), it.key(), true);
 		}
 	}
 }
@@ -1279,10 +1259,9 @@ bool KWalletD::folderDoesNotExist(const QString& wallet, const QString& folder)
 		return true;
 	}
 
-	for (Q3IntDictIterator<KWallet::Backend> it(_wallets); it.current(); ++it) {
-		if (it.current()->walletName() == wallet) {
-			return it.current()->folderDoesNotExist(folder);
-		}
+	const QPair<int, KWallet::Backend*> walletInfo = findWallet(wallet);
+	if (walletInfo.second) {
+		return walletInfo.second->folderDoesNotExist(folder);
 	}
 
 	KWallet::Backend *b = new KWallet::Backend(wallet);
@@ -1298,10 +1277,9 @@ bool KWalletD::keyDoesNotExist(const QString& wallet, const QString& folder, con
 		return true;
 	}
 
-	for (Q3IntDictIterator<KWallet::Backend> it(_wallets); it.current(); ++it) {
-		if (it.current()->walletName() == wallet) {
-			return it.current()->entryDoesNotExist(folder, key);
-		}
+	const QPair<int, KWallet::Backend*> walletInfo = findWallet(wallet);
+	if (walletInfo.second) {
+		return walletInfo.second->entryDoesNotExist(folder, key);
 	}
 
 	KWallet::Backend *b = new KWallet::Backend(wallet);
@@ -1323,7 +1301,7 @@ bool KWalletD::implicitDeny(const QString& wallet, const QString& app) {
 
 
 void KWalletD::timedOut(int id) {
-	KWallet::Backend *w = _wallets.find(id);
+	KWallet::Backend *w = _wallets.value(id);
 	if (w) {
 		closeWallet(w, id, true);
 	}
@@ -1331,13 +1309,15 @@ void KWalletD::timedOut(int id) {
 
 
 void KWalletD::closeAllWallets() {
-	Q3IntDict<KWallet::Backend> tw = _wallets;
+	Wallets walletsCopy = _wallets;
 
-	for (Q3IntDictIterator<KWallet::Backend> it(tw); it.current(); ++it) {
-		closeWallet(it.current(), it.currentKey(), true);
+	Wallets::const_iterator it = walletsCopy.begin();
+	const Wallets::const_iterator end = walletsCopy.end();
+	for (; it != end; ++it) {
+		closeWallet(it.value(), it.key(), true);
 	}
 
-	tw.clear();
+	walletsCopy.clear();
 
 	// All of this should be basically noop.  Let's just be safe.
 	_wallets.clear();
@@ -1360,6 +1340,11 @@ QString KWalletD::localWallet() {
 	return KWallet::Wallet::LocalWallet();
 }
 
+void KWalletD::screenSaverChanged(bool s)
+{
+	if (s)
+		closeAllWallets();
+}
 
 #include "kwalletd.moc"
 #include "kwalletdadaptor.moc"
