@@ -24,30 +24,28 @@
 #include <config.h>
 
 #include <kurl.h>
-#include <kde_file.h>
 #include <kio/netaccess.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
 
-#include <qfileinfo.h>
-#include <qeventloop.h>
-#include <qdir.h>
-#include <qhash.h>
-#include <qvariant.h>
+#include <QtCore/QFileInfo>
+#include <QtCore/QEventLoop>
+#include <QtCore/QDir>
+#include <QtCore/QHash>
+#include <QtCore/QVariant>
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
-#include <errno.h>
 #include <time.h>
 #include <sys/time.h>
 #include <sys/types.h>
-#include <utime.h>
 #include <kprotocolinfo.h>
 #include <kio/scheduler.h>
 #include <kio/directorysizejob.h>
 #include <kio/copyjob.h>
+#include "kiotesthelper.h"
 
 QTEST_KDEMAIN( JobTest, GUI )
 
@@ -84,25 +82,26 @@ static QString realSystemPath()
 
 void JobTest::initTestCase()
 {
-    qDebug( "initTestCase" );
+    s_referenceTimeStamp = QDateTime::currentDateTime().addSecs( -30 ); // 30 seconds ago
+
     // Start with a clean base dir
     cleanupTestCase();
     QDir dir; // TT: why not a static method?
     if ( !QFile::exists( homeTmpDir() ) ) {
         bool ok = dir.mkdir( homeTmpDir() );
         if ( !ok )
-            kFatal() << "Couldn't create " << homeTmpDir() << endl;
+            kFatal() << "Couldn't create " << homeTmpDir();
     }
     if ( !QFile::exists( otherTmpDir() ) ) {
         bool ok = dir.mkdir( otherTmpDir() );
         if ( !ok )
-            kFatal() << "Couldn't create " << otherTmpDir() << endl;
+            kFatal() << "Couldn't create " << otherTmpDir();
     }
     if ( KProtocolInfo::isKnownProtocol( "system" ) ) {
         if ( !QFile::exists( realSystemPath() ) ) {
             bool ok = dir.mkdir( realSystemPath() );
             if ( !ok )
-                kFatal() << "Couldn't create " << realSystemPath() << endl;
+                kFatal() << "Couldn't create " << realSystemPath();
         }
     }
 }
@@ -116,62 +115,6 @@ void JobTest::cleanupTestCase()
     }
 }
 
-static void setTimeStamp( const QString& path )
-{
-#ifdef Q_OS_UNIX
-    // Put timestamp in the past so that we can check that the
-    // copy actually preserves it.
-    struct timeval tp;
-    gettimeofday( &tp, 0 );
-    struct utimbuf utbuf;
-    utbuf.actime = tp.tv_sec - 30; // 30 seconds ago
-    utbuf.modtime = tp.tv_sec - 60; // 60 second ago
-    utime( QFile::encodeName( path ), &utbuf );
-    kDebug() << "Time changed for " << path << endl;
-#endif
-}
-
-static void createTestFile( const QString& path )
-{
-    QFile f( path );
-    if ( !f.open( QIODevice::WriteOnly ) )
-        kFatal() << "Can't create " << path << endl;
-    f.write( QByteArray( "Hello world" ) );
-    f.close();
-    setTimeStamp( path );
-}
-
-static void createTestSymlink( const QString& path )
-{
-    // Create symlink if it doesn't exist yet
-    KDE_struct_stat buf;
-    if ( KDE_lstat( QFile::encodeName( path ), &buf ) != 0 ) {
-        bool ok = symlink( "/IDontExist", QFile::encodeName( path ) ) == 0; // broken symlink
-        if ( !ok )
-            kFatal() << "couldn't create symlink: " << strerror( errno ) << endl;
-        QVERIFY( KDE_lstat( QFile::encodeName( path ), &buf ) == 0 );
-        QVERIFY( S_ISLNK( buf.st_mode ) );
-    } else {
-        QVERIFY( S_ISLNK( buf.st_mode ) );
-    }
-    qDebug( "symlink %s created", qPrintable( path ) );
-    QVERIFY( QFileInfo( path ).isSymLink() );
-}
-
-static void createTestDirectory( const QString& path )
-{
-    QDir dir;
-    bool ok = dir.mkdir( path );
-    if ( !ok && !dir.exists() )
-        kFatal() << "couldn't create " << path << endl;
-    createTestFile( path + "/testfile" );
-#ifndef Q_WS_WIN
-    createTestSymlink( path + "/testlink" );
-    QVERIFY( QFileInfo( path + "/testlink" ).isSymLink() );
-#endif
-    setTimeStamp( path );
-}
-
 void JobTest::enterLoop()
 {
     QEventLoop eventLoop;
@@ -182,7 +125,7 @@ void JobTest::enterLoop()
 
 void JobTest::get()
 {
-    kDebug() << k_funcinfo << endl;
+    kDebug() ;
     const QString filePath = homeTmpDir() + "fileFromHome";
     createTestFile( filePath );
     KUrl u( filePath );
@@ -322,26 +265,23 @@ void JobTest::copyLocalDirectory( const QString& src, const QString& _dest, int
 
     if ( flags & AlreadyExists ) {
         dest += '/' + u.fileName();
-        //kDebug() << "Expecting dest=" << dest << endl;
+        //kDebug() << "Expecting dest=" << dest;
     }
 
+    // CopyJob::setNextDirAttribute isn't implemented for Windows currently.
+#ifndef Q_WS_WIN
     {
-        // check that the timestamp is the same (#24443)
+        // Check that the timestamp is the same (#24443)
         QFileInfo srcInfo( src );
         QFileInfo destInfo( dest );
-#ifdef Q_WS_WIN
-        // win32 time may differs in msec part
-        QCOMPARE( srcInfo.lastModified().toString("dd.MM.yyyy hh:mm"),
-                  destInfo.lastModified().toString("dd.MM.yyyy hh:mm") );
-#else
         QCOMPARE( srcInfo.lastModified(), destInfo.lastModified() );
-#endif
     }
+#endif
 }
 
 void JobTest::copyFileToSamePartition()
 {
-    kDebug() << k_funcinfo << endl;
+    kDebug() ;
     const QString filePath = homeTmpDir() + "fileFromHome";
     const QString dest = homeTmpDir() + "fileFromHome_copied";
     createTestFile( filePath );
@@ -350,7 +290,7 @@ void JobTest::copyFileToSamePartition()
 
 void JobTest::copyDirectoryToSamePartition()
 {
-    kDebug() << k_funcinfo << endl;
+    kDebug() ;
     const QString src = homeTmpDir() + "dirFromHome";
     const QString dest = homeTmpDir() + "dirFromHome_copied";
     createTestDirectory( src );
@@ -359,7 +299,7 @@ void JobTest::copyDirectoryToSamePartition()
 
 void JobTest::copyDirectoryToExistingDirectory()
 {
-    kDebug() << k_funcinfo << endl;
+    kDebug() ;
     // just the same as copyDirectoryToSamePartition, but it means that
     // this time dest exists.
     const QString src = homeTmpDir() + "dirFromHome";
@@ -370,7 +310,7 @@ void JobTest::copyDirectoryToExistingDirectory()
 
 void JobTest::copyFileToOtherPartition()
 {
-    kDebug() << k_funcinfo << endl;
+    kDebug() ;
     const QString filePath = homeTmpDir() + "fileFromHome";
     const QString dest = otherTmpDir() + "fileFromHome_copied";
     createTestFile( filePath );
@@ -379,7 +319,7 @@ void JobTest::copyFileToOtherPartition()
 
 void JobTest::copyDirectoryToOtherPartition()
 {
-    kDebug() << k_funcinfo << endl;
+    kDebug() ;
     const QString src = homeTmpDir() + "dirFromHome";
     const QString dest = otherTmpDir() + "dirFromHome_copied";
     // src is already created by copyDirectoryToSamePartition()
@@ -398,13 +338,15 @@ void JobTest::moveLocalFile( const QString& src, const QString& dest )
     d.setPath( dest );
 
     // move the file with file_move
-    bool ok = KIO::NetAccess::file_move( u, d );
+    KIO::Job* job = KIO::file_move(u, d);
+    bool ok = KIO::NetAccess::synchronousRun(job, 0);
     QVERIFY( ok );
     QVERIFY( QFile::exists( dest ) );
     QVERIFY( !QFile::exists( src ) ); // not there anymore
 
     // move it back with KIO::move()
-    ok = KIO::NetAccess::move( d, u, 0 );
+    job = KIO::move( d, u );
+    ok = KIO::NetAccess::synchronousRun(job, 0);
     QVERIFY( ok );
     QVERIFY( !QFile::exists( dest ) );
     QVERIFY( QFile::exists( src ) ); // it's back
@@ -420,15 +362,17 @@ static void moveLocalSymlink( const QString& src, const QString& dest )
     d.setPath( dest );
 
     // move the symlink with move, NOT with file_move
-    bool ok = KIO::NetAccess::move( u, d );
+    KIO::Job* job = KIO::move( u, d );
+    bool ok = KIO::NetAccess::synchronousRun(job, 0);
     if ( !ok )
-        kWarning() << KIO::NetAccess::lastError() << endl;
+        kWarning() << KIO::NetAccess::lastError();
     QVERIFY( ok );
     QVERIFY ( KDE_lstat( QFile::encodeName( dest ), &buf ) == 0 );
     QVERIFY( !QFile::exists( src ) ); // not there anymore
 
     // move it back with KIO::move()
-    ok = KIO::NetAccess::move( d, u, 0 );
+    job = KIO::move( d, u );
+    ok = KIO::NetAccess::synchronousRun(job, 0);
     QVERIFY( ok );
     QVERIFY ( KDE_lstat( QFile::encodeName( dest ), &buf ) != 0 ); // doesn't exist anymore
     QVERIFY ( KDE_lstat( QFile::encodeName( src ), &buf ) == 0 ); // it's back
@@ -436,7 +380,7 @@ static void moveLocalSymlink( const QString& src, const QString& dest )
 
 void JobTest::moveLocalDirectory( const QString& src, const QString& dest )
 {
-    kDebug() << k_funcinfo << src << " " << dest << endl;
+    kDebug() << src << " " << dest;
     QVERIFY( QFile::exists( src ) );
     QVERIFY( QFileInfo( src ).isDir() );
     QVERIFY( QFileInfo( src + "/testfile" ).isFile() );
@@ -448,7 +392,8 @@ void JobTest::moveLocalDirectory( const QString& src, const QString& dest )
     KUrl d;
     d.setPath( dest );
 
-    bool ok = KIO::NetAccess::move( u, d, 0 );
+    KIO::Job* job = KIO::move( u, d );
+    bool ok = KIO::NetAccess::synchronousRun(job, 0);
     QVERIFY( ok );
     QVERIFY( QFile::exists( dest ) );
     QVERIFY( QFileInfo( dest ).isDir() );
@@ -461,7 +406,7 @@ void JobTest::moveLocalDirectory( const QString& src, const QString& dest )
 
 void JobTest::moveFileToSamePartition()
 {
-    kDebug() << k_funcinfo << endl;
+    kDebug() ;
     const QString filePath = homeTmpDir() + "fileFromHome";
     const QString dest = homeTmpDir() + "fileFromHome_moved";
     createTestFile( filePath );
@@ -470,7 +415,7 @@ void JobTest::moveFileToSamePartition()
 
 void JobTest::moveDirectoryToSamePartition()
 {
-    kDebug() << k_funcinfo << endl;
+    kDebug() ;
     const QString src = homeTmpDir() + "dirFromHome";
     const QString dest = homeTmpDir() + "dirFromHome_moved";
     createTestDirectory( src );
@@ -479,7 +424,7 @@ void JobTest::moveDirectoryToSamePartition()
 
 void JobTest::moveFileToOtherPartition()
 {
-    kDebug() << k_funcinfo << endl;
+    kDebug() ;
     const QString filePath = homeTmpDir() + "fileFromHome";
     const QString dest = otherTmpDir() + "fileFromHome_moved";
     createTestFile( filePath );
@@ -489,7 +434,7 @@ void JobTest::moveFileToOtherPartition()
 void JobTest::moveSymlinkToOtherPartition()
 {
 #ifndef Q_WS_WIN
-    kDebug() << k_funcinfo << endl;
+    kDebug() ;
     const QString filePath = homeTmpDir() + "testlink";
     const QString dest = otherTmpDir() + "testlink_moved";
     createTestSymlink( filePath );
@@ -499,7 +444,7 @@ void JobTest::moveSymlinkToOtherPartition()
 
 void JobTest::moveDirectoryToOtherPartition()
 {
-    kDebug() << k_funcinfo << endl;
+    kDebug() ;
 #ifndef Q_WS_WIN
     const QString src = homeTmpDir() + "dirFromHome";
     const QString dest = otherTmpDir() + "dirFromHome_moved";
@@ -510,9 +455,9 @@ void JobTest::moveDirectoryToOtherPartition()
 
 void JobTest::moveFileNoPermissions()
 {
-    kDebug() << k_funcinfo << endl;
+    kDebug() ;
 #ifdef Q_WS_WIN
-    kDebug() << "port to win32" << endl;
+    kDebug() << "port to win32";
 #else
     const QString src = "/etc/passwd";
     const QString dest = homeTmpDir() + "passwd";
@@ -541,18 +486,17 @@ void JobTest::moveFileNoPermissions()
 
 void JobTest::moveDirectoryNoPermissions()
 {
-    kDebug() << k_funcinfo << endl;
+    kDebug() ;
 #ifdef Q_WS_WIN
-    kDebug() << "port to win32" << endl;
+    kDebug() << "port to win32";
 #else
-#if 1
-    QString src = "/etc/rc.d";
+
+    // All of /etc is a bit much, so try to find something smaller:
+    QString src = "/etc/fonts";
     if ( !QFile::exists( src ) )
-        src= "/etc";
-#else
-    QString src = "/etc";
-#endif
-   const QString dest = homeTmpDir() + "mdnp";
+        src = "/etc";
+
+    const QString dest = homeTmpDir() + "mdnp";
     QVERIFY( QFile::exists( src ) );
     QVERIFY( QFileInfo( src ).isDir() );
     KUrl u;
@@ -565,8 +509,7 @@ void JobTest::moveDirectoryNoPermissions()
     QMap<QString, QString> metaData;
     bool ok = KIO::NetAccess::synchronousRun( job, 0, 0, 0, &metaData );
     QVERIFY( !ok );
-    qDebug( "%d", KIO::NetAccess::lastError() );
-    QVERIFY( KIO::NetAccess::lastError() == KIO::ERR_ACCESS_DENIED );
+    QCOMPARE( KIO::NetAccess::lastError(), (int)KIO::ERR_ACCESS_DENIED );
     QVERIFY( QFile::exists( dest ) ); // see moveFileNoPermissions
     QVERIFY( QFile::exists( src ) );
 #endif
@@ -605,9 +548,12 @@ void JobTest::listRecursive()
 #endif
             "fileFromHome,fileFromHome_copied");
 
-    qDebug( "%s", qPrintable( m_names.join( "," ) ) );
-    qDebug( "%s", ref_names.data() );
-    QCOMPARE( m_names.join( "," ).toLatin1(), ref_names );
+    const QString joinedNames = m_names.join( "," );
+    if (joinedNames.toLatin1() != ref_names) {
+        qDebug( "%s", qPrintable( joinedNames ) );
+        qDebug( "%s", ref_names.data() );
+    }
+    QCOMPARE( joinedNames.toLatin1(), ref_names );
 }
 
 void JobTest::directorySize()
@@ -620,9 +566,9 @@ void JobTest::directorySize()
     job->setUiDelegate( 0 );
     bool ok = KIO::NetAccess::synchronousRun( job, 0 );
     QVERIFY( ok );
-    kDebug() << "totalSize: " << job->totalSize() << endl;
-    kDebug() << "totalFiles: " << job->totalFiles() << endl;
-    kDebug() << "totalSubdirs: " << job->totalSubdirs() << endl;
+    kDebug() << "totalSize: " << job->totalSize();
+    kDebug() << "totalFiles: " << job->totalFiles();
+    kDebug() << "totalSubdirs: " << job->totalSubdirs();
 #ifdef Q_WS_WIN
     QCOMPARE(job->totalFiles(), 5ULL); // see expected result in listRecursive() above
     QCOMPARE(job->totalSubdirs(), 3ULL); // see expected result in listRecursive() above
@@ -647,12 +593,13 @@ void JobTest::directorySizeError()
 void JobTest::slotEntries( KIO::Job*, const KIO::UDSEntryList& lst )
 {
     for( KIO::UDSEntryList::ConstIterator it = lst.begin(); it != lst.end(); ++it ) {
-        QString displayName = (*it).stringValue( KIO::UDS_NAME );
-        //KUrl url = (*it).stringValue( KIO::UDS_URL );
+        QString displayName = (*it).stringValue( KIO::UDSEntry::UDS_NAME );
+        //KUrl url = (*it).stringValue( KIO::UDSEntry::UDS_URL );
         m_names.append( displayName );
     }
 }
 
+#if 0 // old performance tests
 class OldUDSAtom
 {
 public:
@@ -665,28 +612,28 @@ typedef QList<OldUDSAtom> OldUDSEntry; // well it was a QValueList :)
 static void fillOldUDSEntry( OldUDSEntry& entry, time_t now_time_t, const QString& nameStr )
 {
     OldUDSAtom atom;
-    atom.m_uds = KIO::UDS_NAME;
+    atom.m_uds = KIO::UDSEntry::UDS_NAME;
     atom.m_str = nameStr;
     entry.append( atom );
-    atom.m_uds = KIO::UDS_SIZE;
+    atom.m_uds = KIO::UDSEntry::UDS_SIZE;
     atom.m_long = 123456ULL;
     entry.append( atom );
-    atom.m_uds = KIO::UDS_MODIFICATION_TIME;
+    atom.m_uds = KIO::UDSEntry::UDS_MODIFICATION_TIME;
     atom.m_long = now_time_t;
     entry.append( atom );
-    atom.m_uds = KIO::UDS_ACCESS_TIME;
+    atom.m_uds = KIO::UDSEntry::UDS_ACCESS_TIME;
     atom.m_long = now_time_t;
     entry.append( atom );
-    atom.m_uds = KIO::UDS_FILE_TYPE;
+    atom.m_uds = KIO::UDSEntry::UDS_FILE_TYPE;
     atom.m_long = S_IFREG;
     entry.append( atom );
-    atom.m_uds = KIO::UDS_ACCESS;
+    atom.m_uds = KIO::UDSEntry::UDS_ACCESS;
     atom.m_long = 0644;
     entry.append( atom );
-    atom.m_uds = KIO::UDS_USER;
+    atom.m_uds = KIO::UDSEntry::UDS_USER;
     atom.m_str = nameStr;
     entry.append( atom );
-    atom.m_uds = KIO::UDS_GROUP;
+    atom.m_uds = KIO::UDSEntry::UDS_GROUP;
     atom.m_str = nameStr;
     entry.append( atom );
 }
@@ -697,15 +644,15 @@ typedef QHash<uint, QVariant> UDSEntryHV;
 static void fillUDSEntryHV( UDSEntryHV& entry, const QDateTime& now, const QString& nameStr )
 {
     entry.reserve( 8 );
-    entry.insert( KIO::UDS_NAME, nameStr );
+    entry.insert( KIO::UDSEntry::UDS_NAME, nameStr );
     // we might need a method to make sure people use unsigned long long
-    entry.insert( KIO::UDS_SIZE, 123456ULL );
-    entry.insert( KIO::UDS_MODIFICATION_TIME, now );
-    entry.insert( KIO::UDS_ACCESS_TIME, now );
-    entry.insert( KIO::UDS_FILE_TYPE, S_IFREG );
-    entry.insert( KIO::UDS_ACCESS, 0644 );
-    entry.insert( KIO::UDS_USER, nameStr );
-    entry.insert( KIO::UDS_GROUP, nameStr );
+    entry.insert( KIO::UDSEntry::UDS_SIZE, 123456ULL );
+    entry.insert( KIO::UDSEntry::UDS_MODIFICATION_TIME, now );
+    entry.insert( KIO::UDSEntry::UDS_ACCESS_TIME, now );
+    entry.insert( KIO::UDSEntry::UDS_FILE_TYPE, S_IFREG );
+    entry.insert( KIO::UDSEntry::UDS_ACCESS, 0644 );
+    entry.insert( KIO::UDSEntry::UDS_USER, nameStr );
+    entry.insert( KIO::UDSEntry::UDS_GROUP, nameStr );
 }
 
 // Which one is used depends on UDS_STRING vs UDS_LONG
@@ -725,14 +672,14 @@ typedef QHash<uint, UDSAtom4> UDSEntryHS; // hash+struct
 static void fillQHashStructEntry( UDSEntryHS& entry, time_t now_time_t, const QString& nameStr )
 {
     entry.reserve( 8 );
-    entry.insert( KIO::UDS_NAME, nameStr );
-    entry.insert( KIO::UDS_SIZE, 123456ULL );
-    entry.insert( KIO::UDS_MODIFICATION_TIME, now_time_t );
-    entry.insert( KIO::UDS_ACCESS_TIME, now_time_t );
-    entry.insert( KIO::UDS_FILE_TYPE, S_IFREG );
-    entry.insert( KIO::UDS_ACCESS, 0644 );
-    entry.insert( KIO::UDS_USER, nameStr );
-    entry.insert( KIO::UDS_GROUP, nameStr );
+    entry.insert( KIO::UDSEntry::UDS_NAME, nameStr );
+    entry.insert( KIO::UDSEntry::UDS_SIZE, 123456ULL );
+    entry.insert( KIO::UDSEntry::UDS_MODIFICATION_TIME, now_time_t );
+    entry.insert( KIO::UDSEntry::UDS_ACCESS_TIME, now_time_t );
+    entry.insert( KIO::UDSEntry::UDS_FILE_TYPE, S_IFREG );
+    entry.insert( KIO::UDSEntry::UDS_ACCESS, 0644 );
+    entry.insert( KIO::UDSEntry::UDS_USER, nameStr );
+    entry.insert( KIO::UDSEntry::UDS_GROUP, nameStr );
 }
 
 // Let's see if QMap makes any difference
@@ -740,14 +687,14 @@ typedef QMap<uint, UDSAtom4> UDSEntryMS; // map+struct
 
 static void fillQMapStructEntry( UDSEntryMS& entry, time_t now_time_t, const QString& nameStr )
 {
-    entry.insert( KIO::UDS_NAME, nameStr );
-    entry.insert( KIO::UDS_SIZE, 123456ULL );
-    entry.insert( KIO::UDS_MODIFICATION_TIME, now_time_t );
-    entry.insert( KIO::UDS_ACCESS_TIME, now_time_t );
-    entry.insert( KIO::UDS_FILE_TYPE, S_IFREG );
-    entry.insert( KIO::UDS_ACCESS, 0644 );
-    entry.insert( KIO::UDS_USER, nameStr );
-    entry.insert( KIO::UDS_GROUP, nameStr );
+    entry.insert( KIO::UDSEntry::UDS_NAME, nameStr );
+    entry.insert( KIO::UDSEntry::UDS_SIZE, 123456ULL );
+    entry.insert( KIO::UDSEntry::UDS_MODIFICATION_TIME, now_time_t );
+    entry.insert( KIO::UDSEntry::UDS_ACCESS_TIME, now_time_t );
+    entry.insert( KIO::UDSEntry::UDS_FILE_TYPE, S_IFREG );
+    entry.insert( KIO::UDSEntry::UDS_ACCESS, 0644 );
+    entry.insert( KIO::UDSEntry::UDS_USER, nameStr );
+    entry.insert( KIO::UDSEntry::UDS_GROUP, nameStr );
 }
 
 
@@ -796,17 +743,18 @@ void JobTest::newApiPerformance()
         KIO::filesize_t size;
         KUrl url;
 
+		
         for (int i = 0; i < lookupIterations; ++i) {
             OldUDSEntry::ConstIterator it2 = entry.begin();
             for( ; it2 != entry.end(); it2++ ) {
                 switch ((*it2).m_uds) {
-                case KIO::UDS_NAME:
+                case KIO::UDSEntry::UDS_NAME:
                     displayName = (*it2).m_str;
                     break;
-                case KIO::UDS_URL:
+                case KIO::UDSEntry::UDS_URL:
                     url = (*it2).m_str;
                     break;
-                case KIO::UDS_SIZE:
+                case KIO::UDSEntry::UDS_SIZE:
                     size = (*it2).m_long;
                     break;
                 }
@@ -847,9 +795,9 @@ void JobTest::newApiPerformance()
 
         // Normally the code would look like this, but let's change it to time it like the old api
         /*
-        QString displayName = entry.value( KIO::UDS_NAME ).toString();
-        KUrl url = entry.value( KIO::UDS_URL ).toString();
-        KIO::filesize_t size = entry.value( KIO::UDS_SIZE ).toULongLong();
+        QString displayName = entry.value( KIO::UDSEntry::UDS_NAME ).toString();
+        KUrl url = entry.value( KIO::UDSEntry::UDS_URL ).toString();
+        KIO::filesize_t size = entry.value( KIO::UDSEntry::UDS_SIZE ).toULongLong();
         */
 
         QString displayName;
@@ -859,15 +807,15 @@ void JobTest::newApiPerformance()
         for (int i = 0; i < lookupIterations; ++i) {
 
             // For a field that we assume to always be there
-            displayName = entry.value( KIO::UDS_NAME ).toString();
+            displayName = entry.value( KIO::UDSEntry::UDS_NAME ).toString();
 
             // For a field that might not be there
-            UDSEntryHV::const_iterator it = entry.find( KIO::UDS_URL );
+            UDSEntryHV::const_iterator it = entry.find( KIO::UDSEntry::UDS_URL );
             const UDSEntryHV::const_iterator end = entry.end();
             if ( it != end )
                  url = it.value().toString();
 
-            it = entry.find( KIO::UDS_SIZE );
+            it = entry.find( KIO::UDSEntry::UDS_SIZE );
             if ( it != end )
                 size = it.value().toULongLong();
         }
@@ -907,15 +855,15 @@ void JobTest::newApiPerformance()
         for (int i = 0; i < lookupIterations; ++i) {
 
             // For a field that we assume to always be there
-            displayName = entry.value( KIO::UDS_NAME ).m_str;
+            displayName = entry.value( KIO::UDSEntry::UDS_NAME ).m_str;
 
             // For a field that might not be there
-            UDSEntryHS::const_iterator it = entry.find( KIO::UDS_URL );
+            UDSEntryHS::const_iterator it = entry.find( KIO::UDSEntry::UDS_URL );
             const UDSEntryHS::const_iterator end = entry.end();
             if ( it != end )
                  url = it.value().m_str;
 
-            it = entry.find( KIO::UDS_SIZE );
+            it = entry.find( KIO::UDSEntry::UDS_SIZE );
             if ( it != end )
                 size = it.value().m_long;
         }
@@ -954,15 +902,15 @@ void JobTest::newApiPerformance()
         for (int i = 0; i < lookupIterations; ++i) {
 
             // For a field that we assume to always be there
-            displayName = entry.value( KIO::UDS_NAME ).m_str;
+            displayName = entry.value( KIO::UDSEntry::UDS_NAME ).m_str;
 
             // For a field that might not be there
-            UDSEntryMS::const_iterator it = entry.find( KIO::UDS_URL );
+            UDSEntryMS::const_iterator it = entry.find( KIO::UDSEntry::UDS_URL );
             const UDSEntryMS::const_iterator end = entry.end();
             if ( it != end )
                  url = it.value().m_str;
 
-            it = entry.find( KIO::UDS_SIZE );
+            it = entry.find( KIO::UDSEntry::UDS_SIZE );
             if ( it != end )
                 size = it.value().m_long;
         }
@@ -974,6 +922,7 @@ void JobTest::newApiPerformance()
         QVERIFY( url.isEmpty() );
     }
 }
+#endif
 
 void JobTest::calculateRemainingSeconds()
 {
@@ -991,7 +940,7 @@ void JobTest::calculateRemainingSeconds()
 void JobTest::copyFileToSystem()
 {
     if ( !KProtocolInfo::isKnownProtocol( "system" ) ) {
-        kDebug() << k_funcinfo << "no kio_system, skipping test" << endl;
+        kDebug() << "no kio_system, skipping test";
         return;
     }
 
@@ -1008,7 +957,7 @@ void JobTest::copyFileToSystem()
 
 void JobTest::copyFileToSystem( bool resolve_local_urls )
 {
-    kDebug() << k_funcinfo << resolve_local_urls << endl;
+    kDebug() << resolve_local_urls;
     extern KIO_EXPORT bool kio_resolve_local_urls;
     kio_resolve_local_urls = resolve_local_urls;
 
@@ -1019,7 +968,7 @@ void JobTest::copyFileToSystem( bool resolve_local_urls )
     KUrl d = systemTmpDir();
     d.addPath( "fileFromHome_copied" );
 
-    kDebug() << "copying " << u << " to " << d << endl;
+    kDebug() << "copying " << u << " to " << d;
 
     // copy the file with file_copy
     m_mimetype.clear();
