@@ -20,8 +20,8 @@
 #ifndef JOBTEST_H
 #define JOBTEST_H
 
-#include <qstring.h>
-#include <qobject.h>
+#include <QtCore/QString>
+#include <QtCore/QObject>
 #include <kio/job.h>
 
 class JobTest : public QObject
@@ -53,7 +53,7 @@ private Q_SLOTS:
     void moveDirectoryToOtherPartition();
     void moveFileNoPermissions();
     void moveDirectoryNoPermissions();
-    void newApiPerformance();
+    //void newApiPerformance();
     void calculateRemainingSeconds();
 
     // Remote tests
