@@ -23,28 +23,26 @@
 #ifndef __file_h__
 #define __file_h__
 
+#include "kioslave_file_export.h"
+#include <kio/global.h>
+#include <kio/slavebase.h>
+
+#include <QtCore/QObject>
+#include <QtCore/QHash>
+
+
 #include <sys/types.h>
 #include <sys/stat.h>
 
 #include <stdio.h>
 #include <unistd.h>
 
-#include <QObject>
-#include <QHash>
-#include <QString>
-
-#include <kio/global.h>
-#include <kio/slavebase.h>
-
-// Note that this header file is installed, so think twice
-// before breaking binary compatibility (read: it is forbidden :)
-
 class KIOSLAVE_FILE_EXPORT FileProtocol : public QObject, public KIO::SlaveBase
 {
   Q_OBJECT
 public:
   FileProtocol( const QByteArray &pool, const QByteArray &app);
-  virtual ~FileProtocol() { }
+  virtual ~FileProtocol();
 
   virtual void get( const KUrl& url );
   virtual void put( const KUrl& url, int _mode,
@@ -60,15 +58,21 @@ public:
   virtual void listDir( const KUrl& url );
   virtual void mkdir( const KUrl& url, int permissions );
   virtual void chmod( const KUrl& url, int permissions );
+  virtual void chown( const KUrl& url, const QString& owner, const QString& group );
+  virtual void setModificationTime( const KUrl& url, const QDateTime& mtime );
   virtual void del( const KUrl& url, bool isfile);
-  virtual void open( const KUrl& url, int access );
+  virtual void open( const KUrl &url, QIODevice::OpenMode mode );
+  virtual void read( KIO::filesize_t size );
+  virtual void write( const QByteArray &data );
+  virtual void seek( KIO::filesize_t offset );
+  virtual void close();
 
   /**
    * Special commands supported by this slave:
    * 1 - mount
    * 2 - unmount
    */
-  virtual void special( const QByteArray &data);
+  virtual void special( const QByteArray &data );
   void unmount( const QString& point );
   void mount( bool _ro, const char *_fstype, const QString& dev, const QString& point );
   bool pumount( const QString &point );
@@ -90,9 +94,8 @@ protected:
 private:
   mutable QHash<uid_t, QString> mUsercache;
   mutable QHash<gid_t, QString> mGroupcache;
-
-  class FileProtocolPrivate;
-  FileProtocolPrivate *d;
+  int openFd;
+  QByteArray openPath;
 };
 
 #endif
