@@ -26,13 +26,13 @@
 #include <sys/types.h>
 #include <sys/socket.h>
 
-#include <QString>
-#include <QByteArray>
+
+#include <QtCore/QByteRef>
+
+#include <QtNetwork/QTcpSocket>
 
 #include <kurl.h>
 #include <kio/slavebase.h>
-#include <kstreamsocket.h>
-#include <kserversocket.h>
 
 struct FtpEntry
 {
@@ -58,7 +58,7 @@ public:
   Ftp( const QByteArray &pool, const QByteArray &app );
   virtual ~Ftp();
 
-  virtual void setHost( const QString& host, int port, const QString& user, const QString& pass );
+  virtual void setHost( const QString& host, quint16 port, const QString& user, const QString& pass );
 
   /**
    * Connects to a ftp server and logs us in
@@ -316,7 +316,7 @@ private:
    * @param sCopyFile   path of the local source file
    * @return 0 for success, -1 for server error, -2 for client error
    */
-  StatusCode ftpCopyPut(int& iError, int& iCopyFile, QString sCopyFile, const KUrl& url, int permissions, bool overwrite);
+  StatusCode ftpCopyPut(int& iError, int& iCopyFile, const QString &sCopyFile, const KUrl& url, int permissions, bool overwrite);
 
   /**
    * helper called from copy() to implement FTP -> FILE transfers
@@ -326,7 +326,7 @@ private:
    * @param sCopyFile   path of the local destination file
    * @return 0 for success, -1 for server error, -2 for client error
    */
-  StatusCode ftpCopyGet(int& iError, int& iCopyFile, QString sCopyFile, const KUrl& url, int permissions, bool overwrite);
+  StatusCode ftpCopyGet(int& iError, int& iCopyFile, const QString &sCopyFile, const KUrl& url, int permissions, bool overwrite);
 
 private: // data members
 
@@ -404,13 +404,13 @@ private: // data members
   /**
    * control connection socket, only set if openControl() succeeded
    */
-  KNetwork::KStreamSocket  *m_control;
+  QTcpSocket  *m_control;
   QByteArray m_lastControlLine;
 
   /**
    * data connection socket
    */
-  KNetwork::KStreamSocket  *m_data;
+  QTcpSocket  *m_data;
 };
 
 #endif // KDELIBS_FTP_H
