@@ -34,6 +34,8 @@
 // According to RFC2109 this is allowed though.
 //
 
+#include "kcookiejar.h"
+
 #include <config.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -54,19 +56,18 @@
 //#include <netinet/in.h>
 //#include <arpa/inet.h>
 
-#include <qstring.h>
-#include <qfile.h>
-#include <qdir.h>
-#include <qregexp.h>
+#include <QtCore/QString>
+#include <QtCore/QFile>
+#include <QtCore/QDir>
+#include <QtCore/QRegExp>
+#include <QtCore/QTextStream>
 
 #include <kurl.h>
-#include <krfcdate.h>
+#include <kdatetime.h>
 #include <kconfig.h>
 #include <ksavefile.h>
 #include <kdebug.h>
 
-#include "kcookiejar.h"
-
 
 // BR87227
 // Waba: Should the number of cookies be limited?
@@ -247,12 +248,11 @@ KCookieJar::KCookieJar()
     m_configChanged = false;
     m_cookiesChanged = false;
 
-    KConfig cfg("khtml/domain_info", true, false, "data");
-    QStringList countries = cfg.readEntry("twoLevelTLD", QStringList());
-    for(QStringList::ConstIterator it = countries.begin();
-        it != countries.end(); ++it)
-    {
-       m_twoLevelTLD.insert(*it, 1);
+    KConfig cfg( "data", "khtml/domain_info", KConfig::NoGlobals );
+    KConfigGroup group( &cfg, QString() );
+    QStringList countries = group.readEntry( "twoLevelTLD", QStringList() );
+    foreach ( const QString& country, countries ) {
+       m_twoLevelTLD.insert( country, 1 );
     }
 }
 
@@ -797,7 +797,7 @@ KHttpCookieList KCookieJar::makeCookies(const QString &_url,
             else if (cName == "expires")
             {
                 // Parse brain-dead netscape cookie-format
-                lastCookie->mExpireDate = KRFCDate::parseDate(Value);
+                lastCookie->mExpireDate = KDateTime::fromString(Value, KDateTime::RFCDate).toTime_t();
             }
             else if (cName == "path")
             {
@@ -1259,15 +1259,17 @@ bool KCookieJar::saveCookies(const QString &_filename)
        return false;
     saveFile.setPermissions(QFile::ReadUser|QFile::WriteUser);
 
-    FILE *fStream = saveFile.fstream();
+    QTextStream ts(&saveFile);
 
     time_t curTime = time(0);
 
-    fprintf(fStream, "# KDE Cookie File v2\n#\n");
+    ts << "# KDE Cookie File v2\n#\n";
 
-    fprintf(fStream, "%-20s %-20s %-12s %-10s %-4s %-20s %-4s %s\n",
-                     "# Host", "Domain", "Path", "Exp.date", "Prot",
-                     "Name", "Sec", "Value");
+    QString s;
+    s.sprintf("%-20s %-20s %-12s %-10s %-4s %-20s %-4s %s\n",
+              "# Host", "Domain", "Path", "Exp.date", "Prot",
+              "Name", "Sec", "Value");
+    ts << s.toLatin1().constData();
 
     for ( QStringList::Iterator it=m_domainList.begin(); it != m_domainList.end();
           it++ )
@@ -1292,7 +1294,7 @@ bool KCookieJar::saveCookies(const QString &_filename)
                 if (!domainPrinted)
                 {
                     domainPrinted = true;
-                    fprintf(fStream, "[%s]\n", domain.toLocal8Bit().data());
+                    ts << '[' << domain.toLocal8Bit().data() << "]\n";
                 }
                 // Store persistent cookies
                 QString path = L1("\"");
@@ -1301,7 +1303,8 @@ bool KCookieJar::saveCookies(const QString &_filename)
                 QString domain = L1("\"");
                 domain += cookie->domain();
                 domain += '"';
-                fprintf(fStream, "%-20s %-20s %-12s %10lu  %3d %-20s %-4i %s\n",
+                // TODO: replace with direct QTextStream output ?
+                s.sprintf("%-20s %-20s %-12s %10lu  %3d %-20s %-4i %s\n",
                         cookie->host().toLatin1().constData(), domain.toLatin1().constData(),
                         path.toLatin1().constData(), (unsigned long) cookie->expireDate(),
                         cookie->protocolVersion(),
@@ -1309,6 +1312,7 @@ bool KCookieJar::saveCookies(const QString &_filename)
                         (cookie->isSecure() ? 1 : 0) + (cookie->isHttpOnly() ? 2 : 0) +
                         (cookie->hasExplicitPath() ? 4 : 0) + (cookie->name().isEmpty() ? 8 : 0),
                         cookie->value().toLatin1().constData());
+                ts << s.toLatin1().constData();
                 cookie = cookieList->prev();
             }
             else
@@ -1468,11 +1472,11 @@ void KCookieJar::saveConfig(KConfig *_config)
     if (!m_configChanged)
         return;
 
-    _config->setGroup("Cookie Dialog");
-    _config->writeEntry("PreferredPolicy", m_preferredPolicy);
-    _config->writeEntry("ShowCookieDetails", m_showCookieDetails );
-    _config->setGroup("Cookie Policy");
-    _config->writeEntry("CookieGlobalAdvice", adviceToStr( m_globalAdvice));
+    KConfigGroup cg(_config, "Cookie Dialog");
+    cg.writeEntry("PreferredPolicy", m_preferredPolicy);
+    cg.writeEntry("ShowCookieDetails", m_showCookieDetails );
+    cg.changeGroup("Cookie Policy");
+    cg.writeEntry("CookieGlobalAdvice", adviceToStr( m_globalAdvice));
 
     QStringList domainSettings;
     for ( QStringList::Iterator it=m_domainList.begin();
@@ -1489,8 +1493,8 @@ void KCookieJar::saveConfig(KConfig *_config)
              domainSettings.append(value);
          }
     }
-    _config->writeEntry("CookieDomainAdvice", domainSettings);
-    _config->sync();
+    cg.writeEntry("CookieDomainAdvice", domainSettings);
+    cg.sync();
     m_configChanged = false;
 }
 
@@ -1504,16 +1508,16 @@ void KCookieJar::loadConfig(KConfig *_config, bool reparse )
     if ( reparse )
         _config->reparseConfiguration();
 
-    _config->setGroup("Cookie Dialog");
-    m_showCookieDetails = _config->readEntry( "ShowCookieDetails" , false );
-    m_preferredPolicy = _config->readEntry( "PreferredPolicy", 0 );
+    KConfigGroup cg(_config, "Cookie Dialog");
+    m_showCookieDetails = cg.readEntry( "ShowCookieDetails" , false );
+    m_preferredPolicy = cg.readEntry( "PreferredPolicy", 0 );
 
-    _config->setGroup("Cookie Policy");
-    QStringList domainSettings = _config->readEntry("CookieDomainAdvice", QStringList());
-    m_rejectCrossDomainCookies = _config->readEntry("RejectCrossDomainCookies", true);
-    m_autoAcceptSessionCookies = _config->readEntry("AcceptSessionCookies", true);
-    m_ignoreCookieExpirationDate = _config->readEntry("IgnoreExpirationDate", false);
-    QString value = _config->readEntry("CookieGlobalAdvice", L1("Ask"));
+    cg.changeGroup("Cookie Policy");
+    QStringList domainSettings = cg.readEntry("CookieDomainAdvice", QStringList());
+    m_rejectCrossDomainCookies = cg.readEntry("RejectCrossDomainCookies", true);
+    m_autoAcceptSessionCookies = cg.readEntry("AcceptSessionCookies", true);
+    m_ignoreCookieExpirationDate = cg.readEntry("IgnoreExpirationDate", false);
+    QString value = cg.readEntry("CookieGlobalAdvice", L1("Ask"));
     m_globalAdvice = strToAdvice(value);
 
     // Reset current domain settings first.
