@@ -24,13 +24,15 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 //
 // KDE Cookie Server
 
+#include "kcookieserver.h"
+
 #define SAVE_DELAY 3 // Save after 3 minutes
 
 #include <unistd.h>
 
-#include <qtimer.h>
-#include <q3ptrlist.h>
-#include <qfile.h>
+#include <QtCore/QTimer>
+#include <Qt3Support/Q3PtrList>
+#include <QtCore/QFile>
 
 #include <QtDBus/QtDBus>
 
@@ -42,8 +44,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include "kcookiejar.h"
 #include "kcookiewin.h"
-#include "kcookieserver.h"
-#include "kcookiejaradaptor.h"
+#include "kcookieserveradaptor.h"
 
 extern "C" {
     KDE_EXPORT KDEDModule *create_kcookiejar()
@@ -66,12 +67,12 @@ public:
    qlonglong windowId;
 };
 
-template class  Q3PtrList<CookieRequest>;
+template class  QList<CookieRequest*>;
 
-class RequestList : public Q3PtrList<CookieRequest>
+class RequestList : public QList<CookieRequest*>
 {
 public:
-   RequestList() : Q3PtrList<CookieRequest>() { }
+   RequestList() : QList<CookieRequest*>() { }
 };
 
 KCookieServer::KCookieServer()
@@ -265,23 +266,23 @@ void KCookieServer::checkCookies( KHttpCookieList *cookieList)
 
 
     // Check if we can handle any request
-    for ( CookieRequest *request = mRequestList->first(); request;)
+    RequestList reqToRemove;
+    RequestList::ConstIterator it = mRequestList->constBegin();
+    for ( ; it != mRequestList->constEnd(); ++it )
     {
+        CookieRequest *request = *it;
         if (!cookiesPending( request->url ))
         {
            QString res = mCookieJar->findCookies( request->url, request->DOM, request->windowId );
 
            QDBusConnection::sessionBus().send(request->reply.createReply(res));
-           CookieRequest *tmp = request;
-           request = mRequestList->next();
-           mRequestList->removeRef( tmp );
-           delete tmp;
-        }
-        else
-        {
-          request = mRequestList->next();
+           reqToRemove += request;
+           delete request;
         }
     }
+    it = reqToRemove.constBegin();
+    for( ; it != reqToRemove.constEnd(); ++it )
+        mRequestList->removeAll( *it );
     if (mCookieJar->changed() && !mTimer)
         saveCookieJar();
 }
@@ -341,8 +342,8 @@ void KCookieServer::putCookie( QStringList& out, KHttpCookie *cookie,
 }
 
 bool KCookieServer::cookieMatches( KHttpCookiePtr c,
-                                   QString domain, QString fqdn,
-                                   QString path, QString name )
+                                   const QString &domain, const QString &fqdn,
+                                   const QString &path, const QString &name )
 {
     if( c )
     {
@@ -359,13 +360,13 @@ bool KCookieServer::cookieMatches( KHttpCookiePtr c,
 
 // DBUS function
 QString
-KCookieServer::findCookies(QString url, qlonglong windowId, const QDBusMessage &msg)
+KCookieServer::findCookies(const QString &url, qlonglong windowId)
 {
    if (cookiesPending(url))
    {
       CookieRequest *request = new CookieRequest;
-      msg.setDelayedReply(true);
-      request->reply = msg;
+      message().setDelayedReply(true);
+      request->reply = message();
       request->url = url;
       request->DOM = false;
       request->windowId = windowId;
@@ -401,11 +402,11 @@ KCookieServer::findDomains()
 
 // DBUS function
 QStringList
-KCookieServer::findCookies(QList<int> fields,
-                           QString domain,
-                           QString fqdn,
-                           QString path,
-                           QString name)
+KCookieServer::findCookies(const QList<int> &fields,
+                           const QString &domain,
+                           const QString &fqdn,
+                           const QString &path,
+                           const QString &name)
 {
    QStringList result;
    bool allDomCookies = name.isEmpty();
@@ -433,14 +434,14 @@ KCookieServer::findCookies(QList<int> fields,
 
 // DBUS function
 QString
-KCookieServer::findDOMCookies(QString url)
+KCookieServer::findDOMCookies(const QString &url)
 {
    return findDOMCookies(url, 0);
 }
 
 // DBUS function
 QString
-KCookieServer::findDOMCookies(QString url, qlonglong windowId)
+KCookieServer::findDOMCookies(const QString &url, qlonglong windowId)
 {
    // We don't wait for pending cookies because it locks up konqueror
    // which can cause a deadlock if it happens to have a popup-menu up.
@@ -453,15 +454,15 @@ KCookieServer::findDOMCookies(QString url, qlonglong windowId)
 
 // DBUS function
 void
-KCookieServer::addCookies(QString arg1, QByteArray arg2, qlonglong arg3)
+KCookieServer::addCookies(const QString &arg1, const QByteArray &arg2, qlonglong arg3)
 {
    addCookies(arg1, arg2, arg3, false);
 }
 
 // DBUS function
 void
-KCookieServer::deleteCookie(QString domain, QString fqdn,
-                            QString path, QString name)
+KCookieServer::deleteCookie(const QString &domain, const QString &fqdn,
+                            const QString &path, const QString &name)
 {
    const KHttpCookieList* list = mCookieJar->getCookieList( domain, fqdn );
    if ( list && !list->isEmpty() )
@@ -482,7 +483,7 @@ KCookieServer::deleteCookie(QString domain, QString fqdn,
 
 // DBUS function
 void
-KCookieServer::deleteCookiesFromDomain(QString domain)
+KCookieServer::deleteCookiesFromDomain(const QString &domain)
 {
    mCookieJar->eatCookiesForDomain(domain);
    if (!mTimer)
@@ -507,7 +508,7 @@ KCookieServer::deleteSessionCookies( qlonglong windowId )
 }
 
 void
-KCookieServer::deleteSessionCookiesFor(QString fqdn, qlonglong windowId)
+KCookieServer::deleteSessionCookiesFor(const QString &fqdn, qlonglong windowId)
 {
   mCookieJar->eatSessionCookies( fqdn, windowId );
   if(!mTimer)
@@ -525,14 +526,14 @@ KCookieServer::deleteAllCookies()
 
 // DBUS function
 void
-KCookieServer::addDOMCookies(QString arg1, QByteArray arg2, qlonglong arg3)
+KCookieServer::addDOMCookies(const QString &arg1, const QByteArray &arg2, qlonglong arg3)
 {
    addCookies(arg1, arg2, arg3, true);
 }
 
 // DBUS function
 void
-KCookieServer::setDomainAdvice(QString url, QString advice)
+KCookieServer::setDomainAdvice(const QString &url, const QString &advice)
 {
    QString fqdn;
    QString dummy;
@@ -550,7 +551,7 @@ KCookieServer::setDomainAdvice(QString url, QString advice)
 
 // DBUS function
 QString
-KCookieServer::getDomainAdvice(QString url)
+KCookieServer::getDomainAdvice(const QString &url)
 {
    KCookieAdvice advice = KCookieDunno;
    QString fqdn;
