@@ -34,32 +34,20 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 // The same applies to the QT_NO_ACCEL ifdef below. I hope it doesn't make
 // too much trouble... (Simon)
 
-#include "kcookiejar.h"
 #include "kcookiewin.h"
+#include "kcookiejar.h"
 
-#include <QButtonGroup>
-#include <qlabel.h>
-#include <qwidget.h>
-#include <qlayout.h>
-#include <qgroupbox.h>
-#include <qdatetime.h>
-#include <qmessagebox.h>
-#include <qpushbutton.h>
-#include <qradiobutton.h>
-#include <qshortcut.h>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtGui/QGroupBox>
+#include <QtCore/QDate>
+#include <QtGui/QPushButton>
+#include <QtGui/QRadioButton>
+#include <QtGui/QShortcut>
 
-#ifndef QT_NO_TOOLTIP
-#include <qtooltip.h>
-#endif
-
-#ifndef QT_NO_WHATSTHIS
-#endif
-
-#include <kidna.h>
-#include <kwin.h>
+#include <kwindowsystem.h>
 #include <klocale.h>
 #include <kglobal.h>
-#include <kurllabel.h>
 #include <klineedit.h>
 #include <kiconloader.h>
 #include <kapplication.h>
@@ -80,7 +68,7 @@ KCookieWin::KCookieWin( QWidget *parent, KHttpCookieList cookieList,
 	setButtons(User1|User2|Details);
 #ifndef Q_WS_QWS //FIXME(E): Implement for Qt Embedded
     setCaption( i18n("Cookie Alert") );
-    setWindowIcon( SmallIcon("cookie") );
+    setWindowIcon( KIcon("cookie") );
     // all cookies in the list should have the same window at this time, so let's take the first
 # ifdef Q_WS_X11
     if( cookieList.first()->windowIds().count() > 0 )
@@ -90,7 +78,7 @@ KCookieWin::KCookieWin( QWidget *parent, KHttpCookieList cookieList,
     else
     {
         // No window associated... make sure the user notices our dialog.
-        KWin::setState( winId(), NET::KeepAbove );
+        KWindowSystem::setState( winId(), NET::KeepAbove );
         kapp->updateUserTimestamp();
     }
 # endif
@@ -101,10 +89,10 @@ KCookieWin::KCookieWin( QWidget *parent, KHttpCookieList cookieList,
     // Cookie image and message to user
     KHBox* hBox = new KHBox( vBox1 );
     QLabel* icon = new QLabel( hBox );
-    icon->setPixmap( QMessageBox::standardIcon(QMessageBox::Warning) );
+    icon->setPixmap(KIcon("dialog-warning").pixmap(IconSize(K3Icon::Desktop)));
     icon->setAlignment( Qt::AlignCenter );
     icon->setFixedSize( 2*icon->sizeHint() );
-   
+
     int count = cookieList.count();
 
     KVBox* vBox = new KVBox( hBox );
@@ -124,7 +112,7 @@ KCookieWin::KCookieWin( QWidget *parent, KHttpCookieList cookieList,
       host += portNum;
     }
 
-    txt = QString("<b>%1</b>").arg( KIDNA::toUnicode(host) );
+    txt = QString("<b>%1</b>").arg( QUrl::fromAce(host.toLatin1()) );
     if (cookie->isCrossDomain())
        txt += i18n(" <b>[Cross Domain]</b>");
     lbl = new QLabel( txt, vBox );
