@@ -4,6 +4,7 @@
  *  Copyright (C) 1999-2000 Harri Porten (porten@kde.org)
  *  Copyright (C) 2003 Apple Computer, Inc.
  *  Copyright (C) 2003 Peter Kelly (pmk@post.com)
+ *  Copyright (C) 2006 Alexey Proskuryakov (ap@nypop.com)
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -21,15 +22,15 @@
  *
  */
 
-#include "config.h"
 #include "array_object.h"
+#include <config.h>
 #include "array_object.lut.h"
 
 #include "error_object.h"
 #include "lookup.h"
 #include "operations.h"
 #include "PropertyNameArray.h"
-#include <kxmlcore/HashSet.h>
+#include <wtf/HashSet.h>
 #include <stdio.h>
 
 
@@ -70,7 +71,7 @@ ArrayInstance::~ArrayInstance()
 }
 
 JSValue* ArrayInstance::getItem(unsigned i) const
-{ 
+{
     if (i >= length)
         return jsUndefined();
     JSValue* val = (i < storageLength) ?
@@ -86,7 +87,7 @@ JSValue *ArrayInstance::lengthGetter(ExecState*, JSObject*, const Identifier&, c
 
 bool ArrayInstance::getOwnPropertySlot(ExecState* exec, const Identifier& propertyName, PropertySlot& slot)
 {
-  if (propertyName == lengthPropertyName) {
+  if (propertyName == exec->propertyNames().length) {
     slot.setCustom(this, lengthGetter);
     return true;
   }
@@ -100,7 +101,7 @@ bool ArrayInstance::getOwnPropertySlot(ExecState* exec, const Identifier& proper
       JSValue *v = storage[index];
       if (!v || v->isUndefined())
         return false;      
-      slot.setValueSlot(this, &storage[index]);
+      slot.setValueSlot(this, &storage[index], PropertySlot::PermitDirectWrite);
       return true;
     }
   }
@@ -119,7 +120,7 @@ bool ArrayInstance::getOwnPropertySlot(ExecState *exec, unsigned index, Property
     JSValue *v = storage[index];
     if (!v || v->isUndefined())
       return false;
-    slot.setValueSlot(this, &storage[index]);
+    slot.setValueSlot(this, &storage[index], PropertySlot::PermitDirectWrite);
     return true;
   }
 
@@ -129,7 +130,7 @@ bool ArrayInstance::getOwnPropertySlot(ExecState *exec, unsigned index, Property
 // Special implementation of [[Put]] - see ECMA 15.4.5.1
 void ArrayInstance::put(ExecState *exec, const Identifier &propertyName, JSValue *value, int attr)
 {
-  if (propertyName == lengthPropertyName) {
+  if (propertyName == exec->propertyNames().length) {
     unsigned int newLen = value->toUInt32(exec);
     if (value->toNumber(exec) != double(newLen)) {
       throwError(exec, RangeError, "Invalid array length.");
@@ -177,7 +178,7 @@ void ArrayInstance::put(ExecState *exec, unsigned index, JSValue *value, int att
 
 bool ArrayInstance::deleteProperty(ExecState *exec, const Identifier &propertyName)
 {
-  if (propertyName == lengthPropertyName)
+  if (propertyName == exec->propertyNames().length)
     return false;
   
   bool ok;
@@ -413,6 +414,7 @@ const ClassInfo ArrayPrototype::info = {"Array", &ArrayInstance::info, &arrayTab
   forEach        ArrayProtoFunc::ForEach        DontEnum|Function 1
   some           ArrayProtoFunc::Some           DontEnum|Function 1
   indexOf        ArrayProtoFunc::IndexOf        DontEnum|Function 1
+  lastIndexOf    ArrayProtoFunc::LastIndexOf    DontEnum|Function 1
   filter         ArrayProtoFunc::Filter         DontEnum|Function 1
   map            ArrayProtoFunc::Map            DontEnum|Function 1
 @end
@@ -436,7 +438,7 @@ ArrayProtoFunc::ArrayProtoFunc(ExecState *exec, int i, int len, const Identifier
                         (exec->lexicalInterpreter()->builtinFunctionPrototype()), name)
   , id(i)
 {
-  put(exec,lengthPropertyName,jsNumber(len),DontDelete|ReadOnly|DontEnum);
+  put(exec, exec->propertyNames().length,jsNumber(len),DontDelete|ReadOnly|DontEnum);
 }
 
 static JSValue *getProperty(ExecState *exec, JSObject *obj, unsigned index)
@@ -450,7 +452,7 @@ static JSValue *getProperty(ExecState *exec, JSObject *obj, unsigned index)
 // ECMA 15.4.4
 JSValue *ArrayProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, const List &args)
 {
-  unsigned length = thisObj->get(exec,lengthPropertyName)->toUInt32(exec);
+  unsigned length = thisObj->get(exec, exec->propertyNames().length)->toUInt32(exec);
 
   JSValue *result = 0; // work around gcc 4.0 bug in uninitialized variable warning
   
@@ -483,7 +485,7 @@ JSValue *ArrayProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, cons
       bool fallback = false;
       if (id == ToLocaleString) {
         JSObject *o = element->toObject(exec);
-        JSValue *conversionFunction = o->get(exec, toLocaleStringPropertyName);
+        JSValue *conversionFunction = o->get(exec, exec->propertyNames().toLocaleString);
         if (conversionFunction->isObject() && static_cast<JSObject *>(conversionFunction)->implementsCall()) {
           str += static_cast<JSObject *>(conversionFunction)->call(exec, o, List())->toString(exec);
         } else {
@@ -495,7 +497,7 @@ JSValue *ArrayProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, cons
       if (id == ToString || id == Join || fallback) {
         if (element->isObject()) {
           JSObject *o = static_cast<JSObject *>(element);
-          JSValue *conversionFunction = o->get(exec, toStringPropertyName);
+          JSValue *conversionFunction = o->get(exec, exec->propertyNames().toString);
           if (conversionFunction->isObject() && static_cast<JSObject *>(conversionFunction)->implementsCall()) {
             str += static_cast<JSObject *>(conversionFunction)->call(exec, o, List())->toString(exec);
           } else {
@@ -526,7 +528,7 @@ JSValue *ArrayProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, cons
         unsigned int k = 0;
         // Older versions tried to optimize out getting the length of thisObj
         // by checking for n != 0, but that doesn't work if thisObj is an empty array.
-        length = curObj->get(exec,lengthPropertyName)->toUInt32(exec);
+        length = curObj->get(exec, exec->propertyNames().length)->toUInt32(exec);
         while (k < length) {
           if (JSValue *v = getProperty(exec, curObj, k))
             arr->put(exec, n, v);
@@ -542,18 +544,18 @@ JSValue *ArrayProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, cons
       curArg = *it;
       curObj = static_cast<JSObject *>(it++); // may be 0
     }
-    arr->put(exec,lengthPropertyName, jsNumber(n), DontEnum | DontDelete);
+    arr->put(exec, exec->propertyNames().length, jsNumber(n), DontEnum | DontDelete);
 
     result = arr;
     break;
   }
   case Pop:{
     if (length == 0) {
-      thisObj->put(exec, lengthPropertyName, jsNumber(length), DontEnum | DontDelete);
+      thisObj->put(exec, exec->propertyNames().length, jsNumber(length), DontEnum | DontDelete);
       result = jsUndefined();
     } else {
       result = thisObj->get(exec, length - 1);
-      thisObj->put(exec, lengthPropertyName, jsNumber(length - 1), DontEnum | DontDelete);
+      thisObj->put(exec, exec->propertyNames().length, jsNumber(length - 1), DontEnum | DontDelete);
     }
     break;
   }
@@ -561,7 +563,7 @@ JSValue *ArrayProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, cons
     for (int n = 0; n < args.size(); n++)
       thisObj->put(exec, length + n, args[n]);
     length += args.size();
-    thisObj->put(exec,lengthPropertyName, jsNumber(length), DontEnum | DontDelete);
+    thisObj->put(exec, exec->propertyNames().length, jsNumber(length), DontEnum | DontDelete);
     result = jsNumber(length);
     break;
   }
@@ -589,7 +591,7 @@ JSValue *ArrayProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, cons
   }
   case Shift: {
     if (length == 0) {
-      thisObj->put(exec, lengthPropertyName, jsNumber(length), DontEnum | DontDelete);
+      thisObj->put(exec, exec->propertyNames().length, jsNumber(length), DontEnum | DontDelete);
       result = jsUndefined();
     } else {
       result = thisObj->get(exec, 0);
@@ -600,7 +602,7 @@ JSValue *ArrayProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, cons
           thisObj->deleteProperty(exec, k-1);
       }
       thisObj->deleteProperty(exec, length - 1);
-      thisObj->put(exec, lengthPropertyName, jsNumber(length - 1), DontEnum | DontDelete);
+      thisObj->put(exec, exec->propertyNames().length, jsNumber(length - 1), DontEnum | DontDelete);
     }
     break;
   }
@@ -643,7 +645,7 @@ JSValue *ArrayProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, cons
       if (JSValue *v = getProperty(exec, thisObj, k))
         resObj->put(exec, n, v);
     }
-    resObj->put(exec, lengthPropertyName, jsNumber(n), DontEnum | DontDelete);
+    resObj->put(exec, exec->propertyNames().length, jsNumber(n), DontEnum | DontDelete);
     break;
   }
   case Sort:{
@@ -670,7 +672,7 @@ JSValue *ArrayProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, cons
     }
 
     if (length == 0) {
-      thisObj->put(exec, lengthPropertyName, jsNumber(0), DontEnum | DontDelete);
+      thisObj->put(exec, exec->propertyNames().length, jsNumber(0), DontEnum | DontDelete);
       result = thisObj;
       break;
     }
@@ -736,7 +738,7 @@ JSValue *ArrayProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, cons
       if (JSValue *v = getProperty(exec, thisObj, k+begin))
         resObj->put(exec, k, v);
     }
-    resObj->put(exec, lengthPropertyName, jsNumber(deleteCount), DontEnum | DontDelete);
+    resObj->put(exec, exec->propertyNames().length, jsNumber(deleteCount), DontEnum | DontDelete);
 
     unsigned int additionalArgs = maxInt( args.size() - 2, 0 );
     if ( additionalArgs != deleteCount )
@@ -768,7 +770,7 @@ JSValue *ArrayProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, cons
     {
       thisObj->put(exec, k+begin, args[k+2]);
     }
-    thisObj->put(exec, lengthPropertyName, jsNumber(length - deleteCount + additionalArgs), DontEnum | DontDelete);
+    thisObj->put(exec, exec->propertyNames().length, jsNumber(length - deleteCount + additionalArgs), DontEnum | DontDelete);
     break;
   }
   case UnShift: { // 15.4.4.13
@@ -783,7 +785,7 @@ JSValue *ArrayProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, cons
     for ( unsigned int k = 0; k < nrArgs; ++k )
       thisObj->put(exec, k, args[k]);
     result = jsNumber(length + nrArgs);
-    thisObj->put(exec, lengthPropertyName, result, DontEnum | DontDelete);
+    thisObj->put(exec, exec->propertyNames().length, result, DontEnum | DontDelete);
     break;
   }
   case Filter:
@@ -798,7 +800,7 @@ JSValue *ArrayProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, cons
     
     if (id == Filter) 
       resultArray = static_cast<JSObject *>(exec->lexicalInterpreter()->builtinArray()->construct(exec, List::empty()));
-    else {
+    else {
       List args;
       args.append(jsNumber(length));
       resultArray = static_cast<JSObject *>(exec->lexicalInterpreter()->builtinArray()->construct(exec, args));
@@ -901,7 +903,32 @@ JSValue *ArrayProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, cons
 
     return jsNumber(-1);
   }
+  case LastIndexOf: {
+       // JavaScript 1.6 Extension by Mozilla
+      // Documentation: http://developer.mozilla.org/en/docs/Core_JavaScript_1.5_Reference:Global_Objects:Array:lastIndexOf 
 
+    int index = length - 1;
+    double d = args[1]->toInteger(exec);
+
+    if (d < 0) {
+        d += length;
+        if (d < 0) 
+            return jsNumber(-1);
+    }
+    if (d < length)
+        index = static_cast<int>(d);
+          
+    JSValue* searchElement = args[0];
+    for (; index >= 0; --index) {
+        JSValue* e = getProperty(exec, thisObj, index);
+        if (!e)
+            e = jsUndefined();
+        if (strictEqual(exec, searchElement, e))
+            return jsNumber(index);
+    }
+
+    return jsNumber(-1);
+}
   default:
     assert(0);
     result = 0;
@@ -918,10 +945,10 @@ ArrayObjectImp::ArrayObjectImp(ExecState *exec,
   : InternalFunctionImp(funcProto)
 {
   // ECMA 15.4.3.1 Array.prototype
-  put(exec, prototypePropertyName, arrayProto, DontEnum|DontDelete|ReadOnly);
+  put(exec, exec->propertyNames().prototype, arrayProto, DontEnum|DontDelete|ReadOnly);
 
   // no. of arguments for constructor
-  put(exec, lengthPropertyName, jsNumber(1), ReadOnly|DontDelete|DontEnum);
+  put(exec, exec->propertyNames().length, jsNumber(1), ReadOnly|DontDelete|DontEnum);
 }
 
 bool ArrayObjectImp::implementsConstruct() const
@@ -945,7 +972,7 @@ JSObject *ArrayObjectImp::construct(ExecState *exec, const List &args)
 }
 
 // ECMA 15.6.1
-JSValue *ArrayObjectImp::callAsFunction(ExecState *exec, JSObject */*thisObj*/, const List &args)
+JSValue *ArrayObjectImp::callAsFunction(ExecState *exec, JSObject * /*thisObj*/, const List &args)
 {
   // equivalent to 'new Array(....)'
   return construct(exec,args);
