@@ -20,8 +20,8 @@
  *
  */
 
-#include "config.h"
 #include "debugger.h"
+#include <config.h>
 #include "ustring.h"
 
 #include "internal.h"
@@ -33,7 +33,6 @@ using namespace KJS;
 namespace KJS {
   struct AttachedInterpreter
   {
-  public:
     AttachedInterpreter(Interpreter *i, AttachedInterpreter *ai) : interp(i), next(ai) { ++Debugger::debuggersPresent; }
     ~AttachedInterpreter() { --Debugger::debuggersPresent; }
     Interpreter *interp;
@@ -63,7 +62,6 @@ void Debugger::attach(Interpreter* interp)
   if (other)
     other->detach(interp);
   interp->setDebugger(this);
-
   rep->interps = new AttachedInterpreter(interp, rep->interps);
 }
 
@@ -81,6 +79,20 @@ void Debugger::detach(Interpreter* interp)
     } else
       p = &q->next;
   }
+
+  if (interp)
+    latestExceptions.remove(interp);
+  else
+    latestExceptions.clear();
+}
+
+bool Debugger::hasHandledException(ExecState *exec, JSValue *exception)
+{
+    if (latestExceptions.get(exec->dynamicInterpreter()).get() == exception)
+        return true;
+
+    latestExceptions.set(exec->dynamicInterpreter(), exception);
+    return false;
 }
 
 bool Debugger::sourceParsed(ExecState * /*exec*/, int /*sourceId*/, const UString &/*sourceURL*/, 
@@ -95,25 +107,25 @@ bool Debugger::sourceUnused(ExecState * /*exec*/, int /*sourceId*/)
 }
 
 bool Debugger::exception(ExecState * /*exec*/, int /*sourceId*/, int /*lineno*/,
-                         JSObject * /*exceptionObj*/)
+                         JSValue * /*exception*/)
 {
   return true;
 }
 
-bool Debugger::atStatement(ExecState */*exec*/, int /*sourceId*/, int /*firstLine*/,
+bool Debugger::atStatement(ExecState * /*exec*/, int /*sourceId*/, int /*firstLine*/,
                            int /*lastLine*/)
 {
   return true;
 }
 
-bool Debugger::callEvent(ExecState */*exec*/, int /*sourceId*/, int /*lineno*/,
-                         JSObject */*function*/, const List &/*args*/)
+bool Debugger::callEvent(ExecState * /*exec*/, int /*sourceId*/, int /*lineno*/,
+                         JSObject * /*function*/, const List &/*args*/)
 {
   return true;
 }
 
-bool Debugger::returnEvent(ExecState */*exec*/, int /*sourceId*/, int /*lineno*/,
-                           JSObject */*function*/)
+bool Debugger::returnEvent(ExecState * /*exec*/, int /*sourceId*/, int /*lineno*/,
+                           JSObject * /*function*/)
 {
   return true;
 }
