@@ -169,9 +169,10 @@
  *	the result overflows to +-Infinity or underflows to 0.
  */
 
-#include "config.h"
-#include "global.h"
 #include "dtoa.h"
+#include <config.h>
+
+#include "global.h"
 
 #if PLATFORM(BIG_ENDIAN)
 #define IEEE_MC68k
@@ -2969,7 +2970,8 @@ dtoa
 					if (dval(d) > 0.5 + dval(eps))
 						goto bump_up;
 					else if (dval(d) < 0.5 - dval(eps)) {
-						while(*--s == '0');
+						while(*--s == '0')
+							;
 						s++;
 						goto ret1;
 						}
@@ -3288,7 +3290,8 @@ dtoa
 #ifdef Honor_FLT_ROUNDS
 trimzeros:
 #endif
-		while(*--s == '0');
+		while(*--s == '0')
+			;
 		s++;
 		}
  ret:
