@@ -4,6 +4,7 @@
  *  Copyright (C) 1999-2002 Harri Porten (porten@kde.org)
  *  Copyright (C) 2001 Peter Kelly (pmk@post.com)
  *  Copyright (C) 2003 Apple Computer, Inc.
+ *  Copyright (C) 2007 Maksim Orlovich (maksim@kde.org)
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -22,9 +23,9 @@
  *
  */
 
-#include "config.h"
 #include "function.h"
-
+#include <config.h>
+#include "scriptfunction.h"
 #include "internal.h"
 #include "function_object.h"
 #include "lexer.h"
@@ -40,22 +41,53 @@
 #include <string.h>
 #include <ctype.h>
 
-#include <kxmlcore/unicode/Unicode.h>
+using namespace WTF;
 
 namespace KJS {
 
+// ----------------------------- LookupOptimizer ------------------------------
+class LookupOptimizer : public NodeVisitor {
+public:
+  LookupOptimizer(ExecState* exec, FunctionBodyNode* body) : m_exec(exec), m_body(body) {}
+
+  void optimize() {
+    visit(m_body);
+  }
+  
+  virtual Node* visit(Node* node)
+  {
+    //Do not recurse inside nodes that introduce new scopes:
+    //that includes 'with' and various function literals.
+    if (node->introducesNewScope()) return 0;
+
+    //Catch can introduce a new scope as well, but 
+    //the rest of try is fine..
+    if (node->isTryNode()) {
+       static_cast<TryNode*>(node)->recurseVisitNonCatch(this);
+       return 0;
+    }
+
+    //Now try optimizing..
+    if (Node* resultNode = node->optimizeLocalAccess(m_exec, m_body)) {
+      //We optimized this node, but it may make sense to optimize 
+      //inside it as well, so recurse, too. 
+      NodeVisitor::visit(resultNode);
+      return resultNode;
+    }
+
+    //Just recurse..
+    return NodeVisitor::visit(node);
+  }
+private:
+  ExecState*        m_exec;
+  FunctionBodyNode* m_body;
+};
+
 // ----------------------------- FunctionImp ----------------------------------
 
 const ClassInfo FunctionImp::info = {"Function", &InternalFunctionImp::info, 0, 0};
 
-  class Parameter {
-  public:
-    Parameter(const Identifier &n) : name(n) { }
-    Identifier name;
-    OwnPtr<Parameter> next;
-  };
-
-FunctionImp::FunctionImp(ExecState *exec, const Identifier &n, FunctionBodyNode* b)
+FunctionImp::FunctionImp(ExecState* exec, const Identifier& n, FunctionBodyNode* b)
   : InternalFunctionImp(static_cast<FunctionPrototype*>
                         (exec->lexicalInterpreter()->builtinFunctionPrototype()), n)
   , body(b)
@@ -72,9 +104,9 @@ FunctionImp::~FunctionImp()
 {
 }
 
-JSValue *FunctionImp::callAsFunction(ExecState* exec, JSObject* thisObj, const List& args)
+JSValue* FunctionImp::callAsFunction(ExecState* exec, JSObject* thisObj, const List& args)
 {
-  JSObject *globalObj = exec->dynamicInterpreter()->globalObject();
+  JSObject* globalObj = exec->dynamicInterpreter()->globalObject();
 
   // enter a new execution context
   Context ctx(globalObj, exec->dynamicInterpreter(), thisObj, body.get(),
@@ -82,13 +114,32 @@ JSValue *FunctionImp::callAsFunction(ExecState* exec, JSObject* thisObj, const L
   ExecState newExec(exec->dynamicInterpreter(), &ctx);
   if (exec->hadException())
     newExec.setException(exec->exception());
+    
+  // Compute the set of all local variables, and functions.
+  // and optimize access to them the first time we're called.
+  // The AST building already took care of parameter declarations for us.
+  if (!body->builtSymbolList()) {
+   // now handle other locals (functions, variables)
+    body->processDecls(&newExec);
+    body->setBuiltSymbolList();
 
-  // assign user supplied arguments to parameters
-  processParameters(&newExec, args);
-  // add variable declarations (initialized to undefined)
-  processVarDecls(&newExec);
+    LookupOptimizer optimizer(&newExec, body.get());
+    optimizer.optimize();
+  }
 
-  Debugger *dbg = exec->dynamicInterpreter()->debugger();
+  ActivationImp* activation = static_cast<ActivationImp*>(ctx.activationObject());
+
+  // Here, we actually fill stuff in, going by increasing priorities: 
+  // first, initialize flags and set to undefined...
+  activation->setupLocals();
+  
+  // Next, assign user supplied arguments to parameters
+  passInParameters(&newExec, args);
+
+  // Now, fill in function objects. These should override everything else
+  activation->setupFunctionLocals(&newExec);
+
+  Debugger* dbg = exec->dynamicInterpreter()->debugger();
   int sid = -1;
   int lineno = -1;
   if (dbg) {
@@ -148,34 +199,11 @@ JSValue *FunctionImp::callAsFunction(ExecState* exec, JSObject* thisObj, const L
     return jsUndefined();
 }
 
-void FunctionImp::addParameter(const Identifier &n)
-{
-  OwnPtr<Parameter> *p = &param;
-  while (*p)
-    p = &(*p)->next;
-
-  p->set(new Parameter(n));
-}
-
-UString FunctionImp::parameterString() const
-{
-  UString s;
-  const Parameter *p = param.get();
-  while (p) {
-    if (!s.isEmpty())
-        s += ", ";
-    s += p->name.ustring();
-    p = p->next.get();
-  }
-
-  return s;
-}
-
-
 // ECMA 10.1.3q
-void FunctionImp::processParameters(ExecState *exec, const List &args)
+void FunctionImp::passInParameters(ExecState* exec, const List& args)
 {
-  JSObject* variable = exec->context()->variableObject();
+  assert (exec->context()->variableObject()->isActivation());
+  ActivationImp* variable = static_cast<ActivationImp*>(exec->context()->variableObject());
 
 #ifdef KJS_VERBOSE
   fprintf(stderr, "---------------------------------------------------\n"
@@ -183,33 +211,20 @@ void FunctionImp::processParameters(ExecState *exec, const List &args)
 	  name().isEmpty() ? "(internal)" : name().ascii());
 #endif
 
-  if (param) {
-    ListIterator it = args.begin();
-    Parameter *p = param.get();
-    JSValue  *v = *it;
-    while (p) {
-      if (it != args.end()) {
-#ifdef KJS_VERBOSE
-	fprintf(stderr, "setting parameter %s ", p->name.ascii());
-	printInfo(exec,"to", *it);
-#endif
-	variable->put(exec, p->name, v);
-	v = ++it;
-      } else
-	variable->put(exec, p->name, jsUndefined());
-      p = p->next.get();
+  ListIterator it = args.begin();
+  for (int paramPos = 0; paramPos < body->numParams(); ++paramPos) {
+    int writeTo = body->paramSymbolID(paramPos);
+    JSValue*  v = jsUndefined();
+    if (it != args.end()) {
+      v = *it;
+      ++it;
     }
-  }
 #ifdef KJS_VERBOSE
-  else {
-    for (int i = 0; i < args.size(); i++)
-      printInfo(exec,"setting argument", args[i]);
-  }
+    fprintf(stderr, "setting parameter %s", body->paramName(paramPos));
+    printInfo(exec,"to", v);
 #endif
-}
-
-void FunctionImp::processVarDecls(ExecState * /*exec*/)
-{
+    variable->putLocal(writeTo, v);
+  }
 }
 
 JSValue *FunctionImp::argumentsGetter(ExecState* exec, JSObject*, const Identifier& propertyName, const PropertySlot& slot)
@@ -225,45 +240,68 @@ JSValue *FunctionImp::argumentsGetter(ExecState* exec, JSObject*, const Identifi
   return jsNull();
 }
 
+JSValue *FunctionImp::callerGetter(ExecState* exec, JSObject*, const Identifier&, const PropertySlot& slot)
+{
+    FunctionImp* thisObj = static_cast<FunctionImp*>(slot.slotBase());
+    Context* context = exec->m_context;
+    while (context) {
+        if (context->function() == thisObj)
+            break;
+        context = context->callingContext();
+    }
+
+    if (!context)
+        return jsNull();
+
+    Context* callingContext = context->callingContext();
+    if (!callingContext)
+        return jsNull();
+
+    FunctionImp* callingFunction = callingContext->function();
+    if (!callingFunction)
+        return jsNull();
+
+    return callingFunction;
+}
+
 JSValue *FunctionImp::lengthGetter(ExecState*, JSObject*, const Identifier&, const PropertySlot& slot)
 {
   FunctionImp *thisObj = static_cast<FunctionImp *>(slot.slotBase());
-  const Parameter *p = thisObj->param.get();
-  int count = 0;
-  while (p) {
-    ++count;
-    p = p->next.get();
-  }
-  return jsNumber(count);
+  return jsNumber(thisObj->body->numParams());
 }
 
-bool FunctionImp::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
+bool FunctionImp::getOwnPropertySlot(ExecState* exec, const Identifier& propertyName, PropertySlot& slot)
 {
     // Find the arguments from the closest context.
-    if (propertyName == exec->dynamicInterpreter()->argumentsIdentifier()) {
+    if (propertyName == exec->propertyNames().arguments) {
         slot.setCustom(this, argumentsGetter);
         return true;
     }
-    
+
     // Compute length of parameters.
-    if (propertyName == lengthPropertyName) {
+    if (propertyName == exec->propertyNames().length) {
         slot.setCustom(this, lengthGetter);
         return true;
     }
-    
+
+    if (propertyName == exec->propertyNames().caller) {
+        slot.setCustom(this, callerGetter);
+        return true;
+    }
+
     return InternalFunctionImp::getOwnPropertySlot(exec, propertyName, slot);
 }
 
 void FunctionImp::put(ExecState *exec, const Identifier &propertyName, JSValue *value, int attr)
 {
-    if (propertyName == exec->dynamicInterpreter()->argumentsIdentifier() || propertyName == lengthPropertyName)
+    if (propertyName == exec->propertyNames().arguments || propertyName == exec->propertyNames().length)
         return;
     InternalFunctionImp::put(exec, propertyName, value, attr);
 }
 
 bool FunctionImp::deleteProperty(ExecState *exec, const Identifier &propertyName)
 {
-    if (propertyName == exec->dynamicInterpreter()->argumentsIdentifier() || propertyName == lengthPropertyName)
+    if (propertyName == exec->propertyNames().arguments || propertyName == exec->propertyNames().length)
         return false;
     return InternalFunctionImp::deleteProperty(exec, propertyName);
 }
@@ -277,26 +315,16 @@ bool FunctionImp::deleteProperty(ExecState *exec, const Identifier &propertyName
  */
 Identifier FunctionImp::getParameterName(int index)
 {
-  int i = 0;
-  Parameter *p = param.get();
-  
-  if(!p)
-    return Identifier::null();
-  
-  // skip to the parameter we want
-  while (i++ < index && (p = p->next.get()))
-    ;
-  
-  if (!p)
-    return Identifier::null();
-  
-  Identifier name = p->name;
+  if (index >= body->numParams())
+    return CommonIdentifiers::shared()->nullIdentifier;
+
+  Identifier name = body->paramName(index);
 
   // Are there any subsequent parameters with the same name?
-  while ((p = p->next.get()))
-    if (p->name == name)
-      return Identifier::null();
-  
+  for (int pos = index + 1; pos < body->numParams(); ++pos)
+    if (body->paramName(pos) == name)
+      return CommonIdentifiers::shared()->nullIdentifier;
+
   return name;
 }
 
@@ -305,8 +333,8 @@ Identifier FunctionImp::getParameterName(int index)
 // ### is "Function" correct here?
 const ClassInfo DeclaredFunctionImp::info = {"Function", &FunctionImp::info, 0, 0};
 
-DeclaredFunctionImp::DeclaredFunctionImp(ExecState *exec, const Identifier &n,
-					 FunctionBodyNode *b, const ScopeChain &sc)
+DeclaredFunctionImp::DeclaredFunctionImp(ExecState* exec, const Identifier& n,
+					 FunctionBodyNode* b, const ScopeChain& sc)
   : FunctionImp(exec, n, b)
 {
   setScope(sc);
@@ -321,7 +349,7 @@ bool DeclaredFunctionImp::implementsConstruct() const
 JSObject *DeclaredFunctionImp::construct(ExecState *exec, const List &args)
 {
   JSObject *proto;
-  JSValue *p = get(exec,prototypePropertyName);
+  JSValue *p = get(exec, exec->propertyNames().prototype);
   if (p->isObject())
     proto = static_cast<JSObject*>(p);
   else
@@ -346,17 +374,12 @@ Completion DeclaredFunctionImp::execute(ExecState *exec)
   return Completion(Normal, jsUndefined()); // TODO: or ReturnValue ?
 }
 
-void DeclaredFunctionImp::processVarDecls(ExecState *exec)
-{
-  body->processVarDecls(exec);
-}
-
 // ------------------------------ IndexToNameMap ---------------------------------
 
-// We map indexes in the arguments array to their corresponding argument names. 
-// Example: function f(x, y, z): arguments[0] = x, so we map 0 to Identifier("x"). 
+// We map indexes in the arguments array to their corresponding argument names.
+// Example: function f(x, y, z): arguments[0] = x, so we map 0 to Identifier("x").
 
-// Once we have an argument name, we can get and set the argument's value in the 
+// Once we have an argument name, we can get and set the argument's value in the
 // activation object.
 
 // We use Identifier::null to indicate that a given argument's value
@@ -366,9 +389,9 @@ IndexToNameMap::IndexToNameMap(FunctionImp *func, const List &args)
 {
   _map = new Identifier[args.size()];
   this->size = args.size();
-  
+
   int i = 0;
-  ListIterator iterator = args.begin(); 
+  ListIterator iterator = args.begin();
   for (; iterator != args.end(); i++, iterator++)
     _map[i] = func->getParameterName(i); // null if there is no corresponding parameter
 }
@@ -381,16 +404,16 @@ bool IndexToNameMap::isMapped(const Identifier &index) const
 {
   bool indexIsNumber;
   int indexAsNumber = index.toUInt32(&indexIsNumber);
-  
+
   if (!indexIsNumber)
     return false;
-  
+
   if (indexAsNumber >= size)
     return false;
 
   if (_map[indexAsNumber].isNull())
     return false;
-  
+
   return true;
 }
 
@@ -400,8 +423,8 @@ void IndexToNameMap::unMap(const Identifier &index)
   int indexAsNumber = index.toUInt32(&indexIsNumber);
 
   assert(indexIsNumber && indexAsNumber < size);
-  
-  _map[indexAsNumber] = Identifier::null();
+
+  _map[indexAsNumber] = CommonIdentifiers::shared()->nullIdentifier;;
 }
 
 Identifier& IndexToNameMap::operator[](int index)
@@ -415,7 +438,7 @@ Identifier& IndexToNameMap::operator[](const Identifier &index)
   int indexAsNumber = index.toUInt32(&indexIsNumber);
 
   assert(indexIsNumber && indexAsNumber < size);
-  
+
   return (*this)[indexAsNumber];
 }
 
@@ -425,15 +448,15 @@ const ClassInfo Arguments::info = {"Arguments", 0, 0, 0};
 
 // ECMA 10.1.8
 Arguments::Arguments(ExecState *exec, FunctionImp *func, const List &args, ActivationImp *act)
-: JSObject(exec->lexicalInterpreter()->builtinObjectPrototype()), 
+: JSObject(exec->lexicalInterpreter()->builtinObjectPrototype()),
 _activationObject(act),
 indexToNameMap(func, args)
 {
-  putDirect(calleePropertyName, func, DontEnum);
-  putDirect(lengthPropertyName, args.size(), DontEnum);
-  
+  putDirect(exec->propertyNames().callee, func, DontEnum);
+  putDirect(exec->propertyNames().length, args.size(), DontEnum);
+
   int i = 0;
-  ListIterator iterator = args.begin(); 
+  ListIterator iterator = args.begin();
   for (; iterator != args.end(); i++, iterator++) {
     if (!indexToNameMap.isMapped(Identifier::from(i))) {
       JSObject::put(exec, Identifier::from(i), *iterator, DontEnum);
@@ -441,7 +464,7 @@ indexToNameMap(func, args)
   }
 }
 
-void Arguments::mark() 
+void Arguments::mark()
 {
   JSObject::mark();
   if (_activationObject && !_activationObject->marked())
@@ -473,7 +496,7 @@ void Arguments::put(ExecState *exec, const Identifier &propertyName, JSValue *va
   }
 }
 
-bool Arguments::deleteProperty(ExecState *exec, const Identifier &propertyName) 
+bool Arguments::deleteProperty(ExecState *exec, const Identifier &propertyName)
 {
   if (indexToNameMap.isMapped(propertyName)) {
     indexToNameMap.unMap(propertyName);
@@ -489,21 +512,40 @@ const ClassInfo ActivationImp::info = {"Activation", 0, 0, 0};
 
 // ECMA 10.1.6
 ActivationImp::ActivationImp(FunctionImp *function, const List &arguments)
-    : _function(function), _arguments(true), _argumentsObject(0)
+    : _function(function), _arguments(true), _locals(0)
 {
   _arguments.copyFrom(arguments);
   // FIXME: Do we need to support enumerating the arguments property?
 }
 
+void ActivationImp::setupLocals() {
+  int numLocals = _function->body->numLocals();
+  _locals  = new Local[numLocals + 1];
+  _locals[0].value = 0;
+  _locals[0].attr  = numLocals + 1; 
+  for (int l = 1; l < numLocals + 1; ++l) {
+    _locals[l].value = jsUndefined();
+    _locals[l].attr  = _function->body->getLocalAttr(l); 
+  }
+}
+
+void ActivationImp::setupFunctionLocals(ExecState *exec) {
+  int numLocals = _function->body->numLocals();
+  for (int l = 1; l < numLocals + 1; ++l) {
+    if (FuncDeclNode* funcDecl = _function->body->getLocalFuncDecl(l))
+      _locals[l].value = funcDecl->makeFunctionObject(exec);
+  }
+}
+
 JSValue *ActivationImp::argumentsGetter(ExecState* exec, JSObject*, const Identifier&, const PropertySlot& slot)
 {
   ActivationImp *thisObj = static_cast<ActivationImp *>(slot.slotBase());
 
   // default: return builtin arguments array
-  if (!thisObj->_argumentsObject)
+  if (!thisObj->_locals[0].value)
     thisObj->createArgumentsObject(exec);
-  
-  return thisObj->_argumentsObject;
+
+  return thisObj->_locals[0].value;
 }
 
 PropertySlot::GetValueFunc ActivationImp::getArgumentsGetter()
@@ -516,13 +558,24 @@ bool ActivationImp::getOwnPropertySlot(ExecState *exec, const Identifier& proper
     // do this first so property map arguments property wins over the below
     // we don't call JSObject because we won't have getter/setter properties
     // and we don't want to support __proto__
+    
+    // See if we're doing fallback  lookup on a local..
+    int id = _function->body->lookupSymbolID(propertyName);
 
-    if (JSValue **location = getDirectLocation(propertyName)) {
-        slot.setValueSlot(this, location);
+    if (validLocal(id)) {
+      slot.setValueSlot(this, &_locals[id].value, _locals[id].attr & ReadOnly);
+      return true;
+    }
+
+    bool ro;
+    if (JSValue** location = getDirectLocation(propertyName, ro)) {
+        slot.setValueSlot(this, location, ro);
         return true;
     }
 
-    if (propertyName == exec->dynamicInterpreter()->argumentsIdentifier()) {
+    // Important: if you add more dynamic properties here, 
+    // make sure to make the optimizeResolver call honor them.
+    if (propertyName == exec->propertyNames().arguments) {
         slot.setCustom(this, getArgumentsGetter());
         return true;
     }
@@ -532,7 +585,12 @@ bool ActivationImp::getOwnPropertySlot(ExecState *exec, const Identifier& proper
 
 bool ActivationImp::deleteProperty(ExecState *exec, const Identifier &propertyName)
 {
-    if (propertyName == exec->dynamicInterpreter()->argumentsIdentifier())
+    // If someone tries to delete a local, return false, that's not permitted
+    int id = _function->body->lookupSymbolID(propertyName);
+    if (validLocal(id))
+        return false;
+    
+    if (propertyName == exec->propertyNames().arguments)
         return false;
     return JSObject::deleteProperty(exec, propertyName);
 }
@@ -542,33 +600,49 @@ void ActivationImp::put(ExecState*, const Identifier& propertyName, JSValue* val
   // There's no way that an activation object can have a prototype or getter/setter properties
   assert(!_prop.hasGetterSetterProperties());
   assert(prototype() == jsNull());
+  
+  // See if we're setting a local..
+  int id = _function->body->lookupSymbolID(propertyName);
+  if (validLocal(id)) {
+    putLocalChecked(id, value);
+    return;
+  }
 
+  //### Document this, ugh.
   _prop.put(propertyName, value, attr, (attr == None || attr == DontDelete));
 }
 
 void ActivationImp::mark()
 {
-    if (_function && !_function->marked()) 
+    if (_function && !_function->marked())
         _function->mark();
     _arguments.mark();
-    if (_argumentsObject && !_argumentsObject->marked())
-        _argumentsObject->mark();
+    for (int pos = 0; pos < numLocals(); ++pos) {
+      JSValue *val = _locals[pos].value;
+      if (val && !val->marked())
+        val->mark();
+    }
     JSObject::mark();
 }
 
+ActivationImp::~ActivationImp()
+{
+    delete[] _locals;
+}
+
 void ActivationImp::createArgumentsObject(ExecState *exec) const
 {
-  _argumentsObject = new Arguments(exec, _function, _arguments, const_cast<ActivationImp *>(this));
+    _locals[0].value = new Arguments(exec, _function, _arguments, const_cast<ActivationImp*>(this));
 }
 
 // ------------------------------ GlobalFunc -----------------------------------
 
 
-GlobalFuncImp::GlobalFuncImp(ExecState*, FunctionPrototype* funcProto, int i, int len, const Identifier& name)
+GlobalFuncImp::GlobalFuncImp(ExecState* exec, FunctionPrototype* funcProto, int i, int len, const Identifier& name)
   : InternalFunctionImp(funcProto, name)
   , id(i)
 {
-  putDirect(lengthPropertyName, len, DontDelete|ReadOnly|DontEnum);
+  putDirect(exec->propertyNames().length, len, DontDelete|ReadOnly|DontEnum);
 }
 
 CodeType GlobalFuncImp::codeType() const
@@ -594,7 +668,7 @@ static JSValue *encode(ExecState *exec, const List &args, const char *do_not_esc
   return jsString(r);
 }
 
-static JSValue *decode(ExecState *exec, const List &args, const char *do_not_unescape, bool strict)
+static JSValue *decode(ExecState *exec, const List &args, const char *do_not_unescape)
 {
   UString s = "", str = args[0]->toString(exec);
   int k = 0, len = str.size();
@@ -636,19 +710,9 @@ static JSValue *decode(ExecState *exec, const List &args, const char *do_not_une
           }
         }
       }
-      if (charLen == 0) {
-        if (strict)
+      if (charLen == 0)
           return throwError(exec, URIError);
-        // The only case where we don't use "strict" mode is the "unescape" function.
-        // For that, it's good to support the wonky "%u" syntax for compatibility with WinIE.
-        if (k <= len - 6 && p[1] == 'u'
-            && isxdigit(p[2].uc) && isxdigit(p[3].uc)
-            && isxdigit(p[4].uc) && isxdigit(p[5].uc)) {
-	  charLen = 6;
-	  u = Lexer::convertUnicode(p[2].uc, p[3].uc, p[4].uc, p[5].uc);
-        }
-      }
-      if (charLen && (u.uc == 0 || u.uc >= 128 || !strchr(do_not_unescape, u.low()))) {
+      if (u.uc == 0 || u.uc >= 128 || !strchr(do_not_unescape, u.low())) {
         c = u;
         k += charLen - 1;
       }
@@ -667,13 +731,30 @@ static bool isStrWhiteSpace(unsigned short c)
         case 0x000B:
         case 0x000C:
         case 0x000D:
-        case 0x0020:
-        case 0x00A0:
         case 0x2028:
         case 0x2029:
+        // Unicode category Zs
+        case 0x0020:  // SPACE
+        case 0x00A0:  // NO-BREAK SPACE
+        case 0x1680:  // OGHAM SPACE MARK
+        case 0x180E:  // MONGOLIAN VOWEL SEPARATOR
+        case 0x2000:  // EN QUAD
+        case 0x2001:  // EM QUAD
+        case 0x2002:  // EN SPACE
+        case 0x2003:  // EM SPACE
+        case 0x2004:  // THREE-PER-EM SPACE
+        case 0x2005:  // FOUR-PER-EM SPACE
+        case 0x2006:  // SIX-PER-EM SPACE
+        case 0x2007:  // FIGURE SPACE
+        case 0x2008:  // PUNCTUATION SPACE
+        case 0x2009:  // THIN SPACE
+        case 0x200A:  // HAIR SPACE
+        case 0x202F:  // NARROW NO-BREAK SPACE
+        case 0x205F:  // MEDIUM MATHEMATICAL SPACE
+        case 0x3000:  // IDEOGRAPHIC SPACE
             return true;
         default:
-            return KXMLCore::Unicode::isSeparatorSpace(c);
+            return false;
     }
 }
 
@@ -793,7 +874,7 @@ JSValue *GlobalFuncImp::callAsFunction(ExecState *exec, JSObject * /*thisObj*/,
         return x;
       else {
         UString s = x->toString(exec);
-        
+
         int sid;
         int errLine;
         UString errMsg;
@@ -818,13 +899,13 @@ JSValue *GlobalFuncImp::callAsFunction(ExecState *exec, JSObject * /*thisObj*/,
                        progNode.get(),
                        EvalCode,
                        exec->context());
-        
+
         ExecState newExec(exec->dynamicInterpreter(), &ctx);
         if (exec->hadException())
             newExec.setException(exec->exception());
-        
+
         // execute the code
-        progNode->processVarDecls(&newExec);
+        progNode->processDecls(&newExec);
         Completion c = progNode->execute(&newExec);
 
         // if an exception occurred, propogate it back to the previous execution object
@@ -854,10 +935,10 @@ JSValue *GlobalFuncImp::callAsFunction(ExecState *exec, JSObject * /*thisObj*/,
     break;
   }
   case DecodeURI:
-    res = decode(exec, args, do_not_unescape_when_decoding_URI, true);
+    res = decode(exec, args, do_not_unescape_when_decoding_URI);
     break;
   case DecodeURIComponent:
-    res = decode(exec, args, "", true);
+    res = decode(exec, args, "");
     break;
   case EncodeURI:
     res = encode(exec, args, do_not_escape_when_encoding_URI);
@@ -868,7 +949,7 @@ JSValue *GlobalFuncImp::callAsFunction(ExecState *exec, JSObject * /*thisObj*/,
   case Escape:
     {
       UString r = "", s, str = args[0]->toString(exec);
-      const UChar *c = str.data();
+      const UChar* c = str.data();
       for (int k = 0; k < str.size(); k++, c++) {
         int u = c->uc;
         if (u > 255) {
@@ -892,7 +973,7 @@ JSValue *GlobalFuncImp::callAsFunction(ExecState *exec, JSObject * /*thisObj*/,
       UString s = "", str = args[0]->toString(exec);
       int k = 0, len = str.size();
       while (k < len) {
-        const UChar *c = str.data() + k;
+        const UChar* c = str.data() + k;
         UChar u;
         if (*c == UChar('%') && k <= len - 6 && *(c+1) == UChar('u')) {
           if (Lexer::isHexDigit((c+2)->uc) && Lexer::isHexDigit((c+3)->uc) &&
