@@ -22,8 +22,8 @@
  *
  */
 
-#include "config.h"
 #include "interpreter.h"
+#include <config.h>
 
 #include "SavedBuiltins.h"
 #include "array_object.h"
@@ -45,8 +45,11 @@
 #include "string_object.h"
 #include "types.h"
 #include "value.h"
+#ifdef KJS_DEBUG_MEM
+#include "lexer.h"
+#endif
 
-#if PLATFORM(MAC)
+#if USE(BINDINGS)
 #include "runtime.h"
 #endif
 
@@ -240,8 +243,6 @@ void Interpreter::init()
     m_startTimeoutCheckCount = 0;
     m_pauseTimeoutCheckCount = 0;
     m_compatMode = NativeMode;
-    m_argumentsPropertyName = &argumentsPropertyName;
-    m_specialPrototypePropertyName = &specialPrototypePropertyName;
 
     interpreterMap().set(m_globalObject, this);
 
@@ -273,8 +274,7 @@ Interpreter::~Interpreter()
     next->prev = prev;
     prev->next = next;
     s_hook = next;
-    if (s_hook == this)
-    {
+    if (s_hook == this) {
         // This was the last interpreter
         s_hook = 0;
     }
@@ -289,8 +289,6 @@ JSObject* Interpreter::globalObject() const
 
 void Interpreter::initGlobalObject()
 {
-    Identifier::init();
-
     FunctionPrototype *funcProto = new FunctionPrototype(&m_globalExec);
     m_FunctionPrototype = funcProto;
     ObjectPrototype *objProto = new ObjectPrototype(&m_globalExec, funcProto);
@@ -345,7 +343,7 @@ void Interpreter::initGlobalObject()
     m_UriError = new NativeErrorImp(&m_globalExec, funcProto, m_UriErrorPrototype);
     
     // ECMA 15.3.4.1
-    funcProto->put(&m_globalExec, constructorPropertyName, m_Function, DontEnum);
+    funcProto->put(&m_globalExec, m_globalExec.propertyNames().constructor, m_Function, DontEnum);
     
     m_globalObject->put(&m_globalExec, "Object", m_Object, DontEnum);
     m_globalObject->put(&m_globalExec, "Function", m_Function, DontEnum);
@@ -366,21 +364,21 @@ void Interpreter::initGlobalObject()
     m_globalObject->put(&m_globalExec, "URIError",m_UriError, Internal);
     
     // Set the constructorPropertyName property of all builtin constructors
-    objProto->put(&m_globalExec, constructorPropertyName, m_Object, DontEnum | DontDelete | ReadOnly);
-    funcProto->put(&m_globalExec, constructorPropertyName, m_Function, DontEnum | DontDelete | ReadOnly);
-    arrayProto->put(&m_globalExec, constructorPropertyName, m_Array, DontEnum | DontDelete | ReadOnly);
-    booleanProto->put(&m_globalExec, constructorPropertyName, m_Boolean, DontEnum | DontDelete | ReadOnly);
-    stringProto->put(&m_globalExec, constructorPropertyName, m_String, DontEnum | DontDelete | ReadOnly);
-    numberProto->put(&m_globalExec, constructorPropertyName, m_Number, DontEnum | DontDelete | ReadOnly);
-    dateProto->put(&m_globalExec, constructorPropertyName, m_Date, DontEnum | DontDelete | ReadOnly);
-    regexpProto->put(&m_globalExec, constructorPropertyName, m_RegExp, DontEnum | DontDelete | ReadOnly);
-    errorProto->put(&m_globalExec, constructorPropertyName, m_Error, DontEnum | DontDelete | ReadOnly);
-    m_EvalErrorPrototype->put(&m_globalExec, constructorPropertyName, m_EvalError, DontEnum | DontDelete | ReadOnly);
-    m_RangeErrorPrototype->put(&m_globalExec, constructorPropertyName, m_RangeError, DontEnum | DontDelete | ReadOnly);
-    m_ReferenceErrorPrototype->put(&m_globalExec, constructorPropertyName, m_ReferenceError, DontEnum | DontDelete | ReadOnly);
-    m_SyntaxErrorPrototype->put(&m_globalExec, constructorPropertyName, m_SyntaxError, DontEnum | DontDelete | ReadOnly);
-    m_TypeErrorPrototype->put(&m_globalExec, constructorPropertyName, m_TypeError, DontEnum | DontDelete | ReadOnly);
-    m_UriErrorPrototype->put(&m_globalExec, constructorPropertyName, m_UriError, DontEnum | DontDelete | ReadOnly);
+    objProto->put(&m_globalExec, m_globalExec.propertyNames().constructor, m_Object, DontEnum | DontDelete | ReadOnly);
+    funcProto->put(&m_globalExec, m_globalExec.propertyNames().constructor, m_Function, DontEnum | DontDelete | ReadOnly);
+    arrayProto->put(&m_globalExec, m_globalExec.propertyNames().constructor, m_Array, DontEnum | DontDelete | ReadOnly);
+    booleanProto->put(&m_globalExec, m_globalExec.propertyNames().constructor, m_Boolean, DontEnum | DontDelete | ReadOnly);
+    stringProto->put(&m_globalExec, m_globalExec.propertyNames().constructor, m_String, DontEnum | DontDelete | ReadOnly);
+    numberProto->put(&m_globalExec, m_globalExec.propertyNames().constructor, m_Number, DontEnum | DontDelete | ReadOnly);
+    dateProto->put(&m_globalExec, m_globalExec.propertyNames().constructor, m_Date, DontEnum | DontDelete | ReadOnly);
+    regexpProto->put(&m_globalExec, m_globalExec.propertyNames().constructor, m_RegExp, DontEnum | DontDelete | ReadOnly);
+    errorProto->put(&m_globalExec, m_globalExec.propertyNames().constructor, m_Error, DontEnum | DontDelete | ReadOnly);
+    m_EvalErrorPrototype->put(&m_globalExec, m_globalExec.propertyNames().constructor, m_EvalError, DontEnum | DontDelete | ReadOnly);
+    m_RangeErrorPrototype->put(&m_globalExec, m_globalExec.propertyNames().constructor, m_RangeError, DontEnum | DontDelete | ReadOnly);
+    m_ReferenceErrorPrototype->put(&m_globalExec, m_globalExec.propertyNames().constructor, m_ReferenceError, DontEnum | DontDelete | ReadOnly);
+    m_SyntaxErrorPrototype->put(&m_globalExec, m_globalExec.propertyNames().constructor, m_SyntaxError, DontEnum | DontDelete | ReadOnly);
+    m_TypeErrorPrototype->put(&m_globalExec, m_globalExec.propertyNames().constructor, m_TypeError, DontEnum | DontDelete | ReadOnly);
+    m_UriErrorPrototype->put(&m_globalExec, m_globalExec.propertyNames().constructor, m_UriError, DontEnum | DontDelete | ReadOnly);
     
     // built-in values
     m_globalObject->put(&m_globalExec, "NaN",        jsNaN(), DontEnum|DontDelete);
@@ -412,6 +410,16 @@ ExecState* Interpreter::globalExec()
   return &m_globalExec;
 }
 
+void Interpreter::setGlobalPackage(Package* p)
+{
+    globPkg = p;
+}
+
+Package* Interpreter::globalPackage()
+{
+    return globPkg;
+}
+
 Completion Interpreter::checkSyntax(const UString& sourceURL, int startingLineNumber, const UString& code)
 {
     return checkSyntax(sourceURL, startingLineNumber, code.data(), code.size());
@@ -456,8 +464,12 @@ Completion Interpreter::evaluate(const UString& sourceURL, int startingLineNumbe
     }
     
     // no program node means a syntax error occurred
-    if (!progNode)
-        return Completion(Throw, Error::create(&m_globalExec, SyntaxError, errMsg, errLine, sid, sourceURL));
+    if (!progNode) {
+        Completion res(Throw, Error::create(&m_globalExec, SyntaxError, errMsg, errLine, sid, sourceURL));
+	if (shouldPrintExceptions())
+	  printException(res, sourceURL);
+	return res;
+    }
     
     m_globalExec.clearException();
     
@@ -478,24 +490,14 @@ Completion Interpreter::evaluate(const UString& sourceURL, int startingLineNumbe
         // execute the code
         Context ctx(globalObj, this, thisObj, progNode.get());
         ExecState newExec(this, &ctx);
-        progNode->processVarDecls(&newExec);
+        progNode->processDecls(&newExec);
         res = progNode->execute(&newExec);
     }
     
     m_recursion--;
     
-    if (shouldPrintExceptions() && res.complType() == Throw) {
-        JSLock lock;
-        ExecState* exec = globalExec();
-        CString f = sourceURL.UTF8String();
-        CString message = res.value()->toObject(exec)->toString(exec).UTF8String();
-        int line = res.value()->toObject(exec)->get(exec, "line")->toUInt32(exec);
-#if PLATFORM(WIN_OS)
-        printf("%s line %d: %s\n", f.c_str(), line, message.c_str());
-#else
-        printf("[%d] %s line %d: %s\n", getpid(), f.c_str(), line, message.c_str());
-#endif
-    }
+    if (shouldPrintExceptions() && res.complType() == Throw)
+        printException(res, sourceURL);
 
     return res;
 }
@@ -671,13 +673,12 @@ Interpreter* Interpreter::interpreterWithGlobalObject(JSObject* globalObject)
 }
 
 #ifdef KJS_DEBUG_MEM
-#include "lexer.h"
 void Interpreter::finalCheck()
 {
   fprintf(stderr,"Interpreter::finalCheck()\n");
   Collector::collect();
 
-  Node::finalCheck();
+//  Node::finalCheck();
   Collector::finalCheck();
   Lexer::globalClear();
   UString::globalClear();
@@ -696,8 +697,22 @@ void Interpreter::setShouldPrintExceptions(bool print)
   printExceptions = print;
 }
 
+void Interpreter::printException(const Completion& c, const UString& sourceURL)
+{
+    JSLock lock;
+    ExecState* exec = globalExec();
+    CString f = sourceURL.UTF8String();
+    CString message = c.value()->toObject(exec)->toString(exec).UTF8String();
+    int line = c.value()->toObject(exec)->get(exec, "line")->toUInt32(exec);
+#if PLATFORM(WIN_OS)
+    printf("%s line %d: %s\n", f.c_str(), line, message.c_str());
+#else
+    printf("[%d] %s line %d: %s\n", getpid(), f.c_str(), line, message.c_str());
+#endif
+}
+
 // bindings are OS X WebKit-only for now
-#if PLATFORM(MAC)
+#if USE(BINDINGS)
 void *Interpreter::createLanguageInstanceForValue(ExecState *exec, int language, JSObject *value, const Bindings::RootObject *origin, const Bindings::RootObject *current)
 {
     return Bindings::Instance::createLanguageInstanceForValue (exec, (Bindings::Instance::BindingLanguage)language, value, origin, current);
