@@ -2,6 +2,7 @@
 /*
  *  This file is part of the KDE libraries
  *  Copyright (C) 1999-2000 Harri Porten (porten@kde.org)
+ *  Copyright (C) 2006 Apple Computer, Inc.
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -20,24 +21,24 @@
  *
  */
 
-#include "config.h"
 #include "lexer.h"
+#include <config.h>
 
 #include <ctype.h>
 #include <string.h>
+#include <limits.h>
 
 #include "dtoa.h"
 #include "interpreter.h"
 #include "nodes.h"
-#include <kxmlcore/unicode/Unicode.h>
+#include <wtf/unicode/libc/UnicodeLibC.h>
 
-static bool isDecimalDigit(unsigned short c);
+using namespace WTF;
+using namespace Unicode;
 
 // we can't specify the namespace in yacc's C output, so do it here
 using namespace KJS;
 
-static Lexer *currLexer = 0;
-
 #ifndef KDE_USE_FINAL
 #include "grammar.h"
 #endif
@@ -53,6 +54,12 @@ int kjsyylex()
   return Lexer::curr()->lex();
 }
 
+namespace KJS {
+
+static Lexer* currLexer = 0;
+
+static bool isDecimalDigit(int c);
+
 Lexer::Lexer()
   : yylineno(1),
     size8(128), size16(128), restrKeyword(false),
@@ -115,7 +122,10 @@ void Lexer::setCode(const UString &sourceURL, int startingLineNumber, const KJS:
 #endif
 
   // read first characters
-  shift(4);
+  current = (length > 0) ? code[0].uc : -1;
+  next1 = (length > 1) ? code[1].uc : -1;
+  next2 = (length > 2) ? code[2].uc : -1;
+  next3 = (length > 3) ? code[3].uc : -1;
 }
 
 void Lexer::shift(unsigned int p)
@@ -124,13 +134,8 @@ void Lexer::shift(unsigned int p)
     current = next1;
     next1 = next2;
     next2 = next3;
-    do {
-      if (pos >= length) {
-        next3 = -1;
-        break;
-      }
-      next3 = code[pos++].uc;
-    } while (KXMLCore::Unicode::isFormatChar(next3));
+    pos++;
+    next3 = (pos + 3 < length) ? code[pos + 3].uc : -1;
   }
 }
 
@@ -206,7 +211,7 @@ int Lexer::lex()
         }
       } else if (current == '"' || current == '\'') {
         state = InString;
-        stringType = current;
+        stringType = static_cast<unsigned short>(current);
       } else if (isIdentStart(current)) {
         record16(current);
         state = InIdentifierOrKeyword;
@@ -280,7 +285,7 @@ int Lexer::lex()
         nextLine();
         state = InString;
       } else {
-        record16(singleEscape(current));
+        record16(singleEscape(static_cast<unsigned short>(current)));
         state = InString;
       }
       break;
@@ -549,7 +554,9 @@ int Lexer::lex()
     token = NUMBER;
     break;
   case Bad:
+#ifdef KJS_DEBUG_LEX
     fprintf(stderr, "KJS: yylex: ERROR.\n");
+#endif
     error = true;
     return -1;
   default:
@@ -563,7 +570,32 @@ int Lexer::lex()
 
 bool Lexer::isWhiteSpace() const
 {
-  return current == '\t' || current == 0x0b || current == 0x0c || KXMLCore::Unicode::isSeparatorSpace(current);
+    switch (current) {
+    case 0x0009:  // TAB
+    case 0x000B:  // VERTICAL TAB
+    case 0x000C:  // FORM FEED
+    case 0x0020:  // SPACE
+    case 0x00A0:  // NO-BREAK SPACE
+    case 0x1680:  // OGHAM SPACE MARK
+    case 0x180E:  // MONGOLIAN VOWEL SEPARATOR
+    case 0x2000:  // EN QUAD
+    case 0x2001:  // EM QUAD
+    case 0x2002:  // EN SPACE
+    case 0x2003:  // EM SPACE
+    case 0x2004:  // THREE-PER-EM SPACE
+    case 0x2005:  // FOUR-PER-EM SPACE
+    case 0x2006:  // SIX-PER-EM SPACE
+    case 0x2007:  // FIGURE SPACE
+    case 0x2008:  // PUNCTUATION SPACE
+    case 0x2009:  // THIN SPACE
+    case 0x200A:  // HAIR SPACE
+    case 0x202F:  // NARROW NO-BREAK SPACE
+    case 0x205F:  // MEDIUM MATHEMATICAL SPACE
+    case 0x3000:  // IDEOGRAPHIC SPACE
+        return true;
+    default:
+        return false;
+    }
 }
 
 bool Lexer::isLineTerminator()
@@ -577,49 +609,37 @@ bool Lexer::isLineTerminator()
   return cr || lf || current == 0x2028 || current == 0x2029;
 }
 
-bool Lexer::isIdentStart(unsigned short c)
+bool Lexer::isIdentStart(int c)
 {
-  return (KXMLCore::Unicode::category(c) & (KXMLCore::Unicode::Letter_Uppercase
-        | KXMLCore::Unicode::Letter_Lowercase
-        | KXMLCore::Unicode::Letter_Titlecase
-        | KXMLCore::Unicode::Letter_Modifier
-        | KXMLCore::Unicode::Letter_Other))
+  return (category(c) & (WTF::Unicode::Letter_Uppercase | Letter_Lowercase | Letter_Titlecase | Letter_Modifier | Letter_Other))
     || c == '$' || c == '_';
 }
 
-bool Lexer::isIdentPart(unsigned short c)
+bool Lexer::isIdentPart(int c)
 {
-  return (KXMLCore::Unicode::category(c) & (KXMLCore::Unicode::Letter_Uppercase
-        | KXMLCore::Unicode::Letter_Lowercase
-        | KXMLCore::Unicode::Letter_Titlecase
-        | KXMLCore::Unicode::Letter_Modifier
-        | KXMLCore::Unicode::Letter_Other
-        | KXMLCore::Unicode::Mark_NonSpacing
-        | KXMLCore::Unicode::Mark_SpacingCombining
-        | KXMLCore::Unicode::Number_DecimalDigit
-        | KXMLCore::Unicode::Punctuation_Connector))
+  return (category(c) & (WTF::Unicode::Letter_Uppercase | Letter_Lowercase | Letter_Titlecase | Letter_Modifier | Letter_Other
+	| Mark_NonSpacing | Mark_SpacingCombining | Number_DecimalDigit | Punctuation_Connector))
     || c == '$' || c == '_';
 }
 
-static bool isDecimalDigit(unsigned short c)
+static bool isDecimalDigit(int c)
 {
   return (c >= '0' && c <= '9');
 }
 
-bool Lexer::isHexDigit(unsigned short c)
+bool Lexer::isHexDigit(int c)
 {
   return (c >= '0' && c <= '9' ||
           c >= 'a' && c <= 'f' ||
           c >= 'A' && c <= 'F');
 }
 
-bool Lexer::isOctalDigit(unsigned short c) const
+bool Lexer::isOctalDigit(int c)
 {
   return (c >= '0' && c <= '7');
 }
 
-int Lexer::matchPunctuator(unsigned short c1, unsigned short c2,
-                              unsigned short c3, unsigned short c4)
+int Lexer::matchPunctuator(int c1, int c2, int c3, int c4)
 {
   if (c1 == '>' && c2 == '>' && c3 == '>' && c4 == '=') {
     shift(4);
@@ -733,7 +753,7 @@ int Lexer::matchPunctuator(unsigned short c1, unsigned short c2,
   }
 }
 
-unsigned short Lexer::singleEscape(unsigned short c) const
+unsigned short Lexer::singleEscape(unsigned short c)
 {
   switch(c) {
   case 'b':
@@ -759,36 +779,34 @@ unsigned short Lexer::singleEscape(unsigned short c) const
   }
 }
 
-unsigned short Lexer::convertOctal(unsigned short c1, unsigned short c2,
-                                      unsigned short c3) const
+unsigned short Lexer::convertOctal(int c1, int c2, int c3)
 {
-  return ((c1 - '0') * 64 + (c2 - '0') * 8 + c3 - '0');
+  return static_cast<unsigned short>((c1 - '0') * 64 + (c2 - '0') * 8 + c3 - '0');
 }
 
-unsigned char Lexer::convertHex(unsigned short c)
+unsigned char Lexer::convertHex(int c)
 {
   if (c >= '0' && c <= '9')
-    return (c - '0');
-  else if (c >= 'a' && c <= 'f')
-    return (c - 'a' + 10);
-  else
-    return (c - 'A' + 10);
+    return static_cast<unsigned char>(c - '0');
+  if (c >= 'a' && c <= 'f')
+    return static_cast<unsigned char>(c - 'a' + 10);
+  return static_cast<unsigned char>(c - 'A' + 10);
 }
 
-unsigned char Lexer::convertHex(unsigned short c1, unsigned short c2)
+unsigned char Lexer::convertHex(int c1, int c2)
 {
   return ((convertHex(c1) << 4) + convertHex(c2));
 }
 
-KJS::UChar Lexer::convertUnicode(unsigned short c1, unsigned short c2,
-                                     unsigned short c3, unsigned short c4)
+KJS::UChar Lexer::convertUnicode(int c1, int c2, int c3, int c4)
 {
   return KJS::UChar((convertHex(c1) << 4) + convertHex(c2),
                (convertHex(c3) << 4) + convertHex(c4));
 }
 
-void Lexer::record8(unsigned short c)
+void Lexer::record8(int c)
 {
+  assert(c >= 0);
   assert(c <= 0xff);
 
   // enlarge buffer if full
@@ -836,7 +854,7 @@ bool Lexer::scanRegExp()
     else if (current != '/' || lastWasEscape == true || inBrackets == true)
     {
         // keep track of '[' and ']'
-        if ( !lastWasEscape ) {
+        if (!lastWasEscape) {
           if ( current == '[' && !inBrackets )
             inBrackets = true;
           if ( current == ']' && inBrackets )
@@ -899,7 +917,7 @@ Identifier *Lexer::makeIdentifier(KJS::UChar*, unsigned int)
   identifiers[numIdentifiers++] = identifier;
   return identifier;
 }
- 
+
 // FIXME: this completely ignores its parameters, instead using buffer16 and pos16 - wtf?
 UString *Lexer::makeUString(KJS::UChar*, unsigned int)
 {
@@ -912,3 +930,5 @@ UString *Lexer::makeUString(KJS::UChar*, unsigned int)
   strings[numStrings++] = string;
   return string;
 }
+
+}
