@@ -1,6 +1,7 @@
 /*
  *  This file is part of the KDE libraries
  *  Copyright (C) 2002 Harri Porten (porten@kde.org)
+ *  Copyright (C) 2003, 2004, 2005, 2006, 2007 Apple Inc. All rights reserved.
  *  Copyright (C) 2003 Apple Computer, Inc.
  *
  *  This library is free software; you can redistribute it and/or
@@ -20,57 +21,114 @@
  *
  */
 
-#include "config.h"
+#include <ctype.h>
+#include <stdio.h>
+#include <config.h>
 #include "nodes.h"
+#include "function.h"
+#include "scriptfunction.h"
+
+#define NOINLINE
+#if COMPILER(CWP)
+#pragma auto_inline off
+#elif COMPILER(MSVC)
+#pragma auto_inline(off)
+#elif COMPILER(GCC)
+// #undef  NOINLINE
+// #define NOINLINE    __attribute__ (noinline)
+#endif
 
 namespace KJS {
+  const bool kDontQuote = false, kQuote = true;
+
   /**
    * A simple text streaming class that helps with code indentation.
    */
   class SourceStream {
   public:
-    enum Format {
-      Endl, Indent, Unindent
-    };
+    enum eEndl     { Endl };
+    enum eIndent   { Indent };
+    enum eUnindent { Unindent };
 
-    UString toString() const { return str; }
-    SourceStream& operator<<(const Identifier &);
-    SourceStream& operator<<(const UString &);
-    SourceStream& operator<<(const char *);
-    SourceStream& operator<<(char);
-    SourceStream& operator<<(Format f);
-    SourceStream& operator<<(const Node *);
-    template <typename T> SourceStream& operator<<(RefPtr<T> n) { return this->operator<<(n.get()); }
+    static const int kBufSize = 2048;
+    typedef unsigned short UTF16;
+    SourceStream () : indent(0), bufUsed(0) {}
+    const UString& toString() { flush(); return str; }
+    SourceStream& operator<<(const Identifier& s) NOINLINE;
+    SourceStream& operator<<(const UString& s) NOINLINE;
+    SourceStream& operator<<(const char* s) NOINLINE;
+    SourceStream& operator<<(char s) NOINLINE;
+    SourceStream& operator<<(eEndl) NOINLINE;
+    SourceStream& operator<<(const Node* n) NOINLINE;
+    SourceStream& operator<<(Operator op) NOINLINE;
+    inline SourceStream& operator<<(eIndent)    { indent += 2; return *this; }
+    inline SourceStream& operator<<(eUnindent)  { indent -= 2; return *this; }
+    SourceStream& append(const Node* expr1, const char* sep, const Node* expr2) NOINLINE;
+    SourceStream& append(const RefPtr<Node>& expr1, const char* sep, const RefPtr<Node>& expr2) NOINLINE;
+    SourceStream& append(const UTF16* src, int srcLen) NOINLINE;
+    SourceStream& append(const UString& inStr, bool quote) NOINLINE;
+    template <typename T>
+    inline SourceStream& operator<<(const RefPtr<T>& n) { return this->operator<<(n.get()); }
   private:
-    UString str; /* TODO: buffer */
-    UString ind;
+    UString str;
+    int indent;
+    int bufUsed;
+    UTF16 buffer[kBufSize];
+    void flush() NOINLINE;
+    void put(UTF16 ch) { buffer[bufUsed++] = ch; }
+    void put(char ch) { buffer[bufUsed++] = static_cast<unsigned char>(ch); }
   };
 }
 
 using namespace KJS;
 
+SourceStream& SourceStream::operator<<(Operator op)
+{
+  assert(op == OpPlusPlus || op == OpMinusMinus);
+  return *this << ((op == OpPlusPlus) ? "++" : "--");
+}
+
+void SourceStream::flush()
+{
+  if (bufUsed)
+  {
+    str.append(reinterpret_cast<const UChar*>(buffer), bufUsed);
+    bufUsed = 0;
+  }
+}
+
 SourceStream& SourceStream::operator<<(char c)
 {
-  str += UString(c);
+  if (bufUsed == kBufSize)
+    flush();
+  put(c);
   return *this;
 }
 
 SourceStream& SourceStream::operator<<(const char *s)
 {
-  str += UString(s);
+  assert(strlen(s) < 100);
+  if (bufUsed > kBufSize - 100)
+    flush();
+
+  unsigned char ch;
+  int i = bufUsed;
+  --s;
+  for (UTF16* dst = &buffer[i] - 1; (ch = *++s) != 0; ++i)
+    *++dst = ch;
+  bufUsed = i;
+
   return *this;
 }
 
 SourceStream& SourceStream::operator<<(const UString &s)
 {
-  str += s;
-  return *this;
+  return append(&s.data()->uc, s.size());
 }
 
 SourceStream& SourceStream::operator<<(const Identifier &s)
 {
-  str += s.ustring();
-  return *this;
+  return append(s.ustring(), kDontQuote);
 }
 
 SourceStream& SourceStream::operator<<(const Node *n)
@@ -80,23 +138,109 @@ SourceStream& SourceStream::operator<<(const Node *n)
   return *this;
 }
 
-SourceStream& SourceStream::operator<<(Format f)
+SourceStream& SourceStream::operator<<(eEndl)
 {
-  switch (f) {
-    case Endl:
-      str += "\n" + ind;
-      break;
-    case Indent:
-      ind += "  ";
-      break;
-    case Unindent:
-      ind = ind.substr(0, ind.size() - 2);
-      break;
+  if (bufUsed > kBufSize - 1 - indent)
+    flush();
+  put('\n');
+
+  if (indent > 0)
+  {
+    UTF16* dst = &buffer[bufUsed];
+    for (int i = indent; i > 0; --i)
+      *dst++ = ' ';
+    bufUsed += indent;
   }
 
   return *this;
 }
 
+SourceStream& SourceStream::append(const Node* expr1, const char* sep, const Node* expr2)
+{
+  return *this << expr1 << sep << expr2;
+}
+
+SourceStream&
+SourceStream::append(const RefPtr<Node>& expr1, const char* sep, const RefPtr<Node>& expr2)
+{
+  return *this << expr1 << sep << expr2;
+}
+
+SourceStream& SourceStream::append(const UTF16* src, int srcLen)
+{
+  if (kBufSize - bufUsed < srcLen)
+    flush();
+  if (kBufSize - bufUsed < srcLen)
+    str.append(reinterpret_cast<const UChar*>(src), srcLen);
+  else
+  {
+    UTF16* dst = &buffer[bufUsed];
+    bufUsed += srcLen;
+//    while (--srcLen >= 0)
+    while (srcLen-- > 0)
+      *dst++ = *src++;
+  }
+
+  return *this;
+}
+
+// Append a quoted string
+SourceStream& SourceStream::append(const UString& inStr, bool quote)
+{
+  if (quote)
+    *this << '"';
+  const UTF16* src = &inStr.data()->uc;
+  const size_t size = inStr.size();
+  for (size_t i = 0; i < size; ++i) {
+    if (bufUsed >= kBufSize - 8)
+      flush();
+    UTF16 c = *src++, esc = '\\';
+    switch (c) {
+      case '\"':                break;
+      case '\n':    c = 'n';    break;
+      case '\r':    c = 'r';    break;
+      case '\t':    c = 't';    break;
+      case '\\':                break;
+      default:
+        if (c >= 128 || !isprint(c)) {
+          char hexValue[8];
+          int len = sprintf(hexValue, (c < 256) ? "\\x%02X" : "\\u%04X", c);
+          UTF16* dst = &buffer[bufUsed];
+          bufUsed += len;
+          for (int j = 0; j < len; ++j)
+            dst[j] = hexValue[j];
+          continue;
+        }
+        esc = 0;    // don't escape
+        break;
+    }
+    if (esc) put(esc);
+    put(c);
+  }
+
+  if (quote)
+    *this << '"';
+  return *this;
+}
+
+UString DeclaredFunctionImp::toSource() const
+{
+  SourceStream str;
+  str << "function ";
+  str.append(functionName().ustring(), kDontQuote) << '(';
+  const FunctionBodyNode* body = this->body.get();
+  const int numParams = body->numParams();
+  for (int i = 0; i < numParams; ++i) {
+    if (i > 0)
+        str << ", ";
+    str << body->paramName(i).ustring();
+  }
+  str << ") ";
+  body->streamTo(str);
+
+  return str.toString();
+}
+
 UString Node::toString() const
 {
   SourceStream str;
@@ -109,42 +253,54 @@ void NullNode::streamTo(SourceStream &s) const { s << "null"; }
 
 void BooleanNode::streamTo(SourceStream &s) const
 {
-  s << (value ? "true" : "false");
+    s << (value() ? "true" : "false");
 }
 
-void NumberNode::streamTo(SourceStream &s) const { s << UString::from(value); }
+void NumberNode::streamTo(SourceStream &s) const
+{
+    s << UString::from(value());
+}
 
 void StringNode::streamTo(SourceStream &s) const
 {
-  s << '"' << value << '"';
+    s.append(value(), kQuote);
 }
 
-void RegExpNode::streamTo(SourceStream &s) const { s <<  pattern; }
+void RegExpNode::streamTo(SourceStream &s) const
+{
+    s <<  '/' << pattern << '/' << flags;
+}
 
 void ThisNode::streamTo(SourceStream &s) const { s << "this"; }
 
-void ResolveNode::streamTo(SourceStream &s) const { s << ident; }
+void VarAccessNode::streamTo(SourceStream &s) const { s << ident; }
 
 void GroupNode::streamTo(SourceStream &s) const
 {
-  s << "(" << group << ")";
+  s << '(' << group << ')';
 }
 
 void ElementNode::streamTo(SourceStream &s) const
 {
   for (const ElementNode *n = this; n; n = n->next.get()) {
     for (int i = 0; i < n->elision; i++)
-      s << ",";
+      s << ',';
     s << n->node;
+    if (n->next)
+        s << ',';
   }
 }
 
 void ArrayNode::streamTo(SourceStream &s) const
 {
-  s << "[" << element;
+  s << '[' << element;
   for (int i = 0; i < elision; i++)
-    s << ",";
-  s << "]";
+    s << ',';
+  // Parser consumes one elision comma if there's array elements 
+  // present in the expression.
+  if (opt && element)
+    s << ',';
+  s << ']';
 }
 
 void ObjectLiteralNode::streamTo(SourceStream &s) const
@@ -177,7 +333,7 @@ void PropertyNode::streamTo(SourceStream &s) const
       else
         s << "set ";
 
-      s << name << "(" << func->param << ")" << func->body;
+      s << name << '(' << func->param << ')' << func->body;
       break;
     }
   }
@@ -188,17 +344,17 @@ void PropertyNameNode::streamTo(SourceStream &s) const
   if (str.isNull())
     s << UString::from(numeric);
   else
-    s << str;
+    s.append(str.ustring(), kQuote);
 }
 
 void BracketAccessorNode::streamTo(SourceStream &s) const
 {
-  s << expr1 << "[" << expr2 << "]";
+  s.append(expr1, "[", expr2) << ']';
 }
 
 void DotAccessorNode::streamTo(SourceStream &s) const
 {
-  s << expr << "." << ident;
+  s << expr << '.' << ident;
 }
 
 void ArgumentListNode::streamTo(SourceStream &s) const
@@ -210,7 +366,7 @@ void ArgumentListNode::streamTo(SourceStream &s) const
 
 void ArgumentsNode::streamTo(SourceStream &s) const
 {
-  s << "(" << list << ")";
+  s << '(' << list << ')';
 }
 
 void NewExprNode::streamTo(SourceStream &s) const
@@ -223,71 +379,48 @@ void FunctionCallValueNode::streamTo(SourceStream &s) const
   s << expr << args;
 }
 
-void FunctionCallResolveNode::streamTo(SourceStream &s) const
+void FunctionCallReferenceNode::streamTo(SourceStream &s) const
 {
-  s << ident << args;
+  s << expr << args;
 }
 
 void FunctionCallBracketNode::streamTo(SourceStream &s) const
 {
-  s << base << "[" << subscript << "]" << args;
+  s << base << '[' << subscript << ']' << args;
 }
 
 void FunctionCallParenBracketNode::streamTo(SourceStream &s) const
 {
-  s << "(" << base << "[" << subscript << "])" << args;
+  s << '(' << base << '[' << subscript << "])" << args;
 }
 
 void FunctionCallDotNode::streamTo(SourceStream &s) const
 {
-  s << base << "." << ident << args;
+  s << base << '.' << ident << args;
 }
 
 void FunctionCallParenDotNode::streamTo(SourceStream &s) const
 {
-  s << "(" << base << "." << ident << ")" << args;
+  s << '(' << base << '.' << ident << ")" << args;
 }
 
-void PostfixResolveNode::streamTo(SourceStream &s) const
+void PostfixNode::streamTo(SourceStream &s) const
 {
-  s << m_ident;
+  s << m_loc << m_oper;
+}
+
+void PostfixErrorNode::streamTo(SourceStream& s) const
+{
+  s << m_expr;
   if (m_oper == OpPlusPlus)
     s << "++";
   else
     s << "--";
 }
 
-void PostfixBracketNode::streamTo(SourceStream &s) const
+void DeleteReferenceNode::streamTo(SourceStream &s) const
 {
-  s << m_base << "[" << m_subscript << "]";
-  if (m_oper == OpPlusPlus)
-    s << "++";
-  else
-    s << "--";
-}
-
-void PostfixDotNode::streamTo(SourceStream &s) const
-{
-  s << m_base << "." << m_ident;
-  if (m_oper == OpPlusPlus)
-    s << "++";
-  else
-    s << "--";
-}
-
-void DeleteResolveNode::streamTo(SourceStream &s) const
-{
-  s << "delete " << m_ident;
-}
-
-void DeleteBracketNode::streamTo(SourceStream &s) const
-{
-  s << "delete " << m_base << "[" << m_subscript << "]";
-}
-
-void DeleteDotNode::streamTo(SourceStream &s) const
-{
-  s << "delete " << m_base << "." << m_ident;
+  s << "delete " << loc;
 }
 
 void DeleteValueNode::streamTo(SourceStream &s) const
@@ -305,150 +438,129 @@ void TypeOfValueNode::streamTo(SourceStream &s) const
   s << "typeof " << m_expr;
 }
 
-void TypeOfResolveNode::streamTo(SourceStream &s) const
+void TypeOfReferenceNode::streamTo(SourceStream &s) const
 {
-  s << "typeof " << m_ident;
+  s << "typeof " << loc;
 }
 
-void PrefixResolveNode::streamTo(SourceStream &s) const
+void PrefixNode::streamTo(SourceStream &s) const
 {
-  if (m_oper == OpPlusPlus)
-    s << "++";
-  else
-    s << "--";
-  s << m_ident;
+  s << m_oper << m_loc;
 }
 
-void PrefixBracketNode::streamTo(SourceStream &s) const
-{
-  if (m_oper == OpPlusPlus)
-    s << "++";
-  else
-    s << "--";
-  s << m_base << "[" << m_subscript << "]";
-}
-
-void PrefixDotNode::streamTo(SourceStream &s) const
-{
-  if (m_oper == OpPlusPlus)
-    s << "++";
-  else
-    s << "--";
-  s << m_base << "." << m_ident;
+void PrefixErrorNode::streamTo(SourceStream& s) const 
+{ 
+  if (m_oper == OpPlusPlus) 
+    s << "++"; 
+  else 
+    s << "--"; 
+  s << m_expr; 
 }
 
 void UnaryPlusNode::streamTo(SourceStream &s) const
 {
-  s << "+" << expr;
+  s << '+' << expr;
 }
 
 void NegateNode::streamTo(SourceStream &s) const
 {
-  s << "-" << expr;
+  s << '-' << expr;
 }
 
 void BitwiseNotNode::streamTo(SourceStream &s) const
 {
-  s << "~" << expr;
+  s << '~' << expr;
 }
 
 void LogicalNotNode::streamTo(SourceStream &s) const
 {
-  s << "!" << expr;
+  s << '!' << expr;
 }
 
-void MultNode::streamTo(SourceStream &s) const
+void BinaryOperatorNode::streamTo(SourceStream& s) const
 {
-  s << term1 << oper << term2;
-}
-
-void AddNode::streamTo(SourceStream &s) const
-{
-  s << term1 << oper << term2;
-}
-
-void ShiftNode::streamTo(SourceStream &s) const
-{
-  s << term1;
-  if (oper == OpLShift)
-    s << "<<";
-  else if (oper == OpRShift)
-    s << ">>";
-  else
-    s << ">>>";
-  s << term2;
-}
-
-void RelationalNode::streamTo(SourceStream &s) const
-{
-  s << expr1;
-  switch (oper) {
-  case OpLess:
-    s << " < ";
-    break;
-  case OpGreater:
-    s << " > ";
-    break;
-  case OpLessEq:
-    s << " <= ";
-    break;
-  case OpGreaterEq:
-    s << " >= ";
-    break;
-  case OpInstanceOf:
-    s << " instanceof ";
-    break;
-  case OpIn:
-    s << " in ";
-    break;
-  default:
-    ;
-  }
-  s << expr2;
-}
-
-void EqualNode::streamTo(SourceStream &s) const
-{
-  s << expr1;
- switch (oper) {
- case OpEqEq:
-   s << " == ";
-   break;
- case OpNotEq:
-   s << " != ";
-   break;
- case OpStrEq:
-   s << " === ";
-   break;
- case OpStrNEq:
-   s << " !== ";
-   break;
- default:
-   ;
- }
-  s << expr2;
-}
-
-void BitOperNode::streamTo(SourceStream &s) const
-{
-  s << expr1;
-  if (oper == OpBitAnd)
-    s << " & ";
-  else if (oper == OpBitXOr)
-    s << " ^ ";
-  else
-    s << " | ";
-  s << expr2;
+    const char* opStr;
+    switch (oper) {
+    case OpMult:
+	opStr = " * ";
+	break;
+    case OpDiv:
+	opStr = " / ";
+	break;
+    case OpMod:
+	opStr = " % ";
+	break;
+    case OpPlus:
+	opStr = " + ";
+	break;
+    case OpMinus:
+	opStr = " - ";
+	break;
+    case OpLShift:
+	opStr = " << ";
+	break;
+    case OpRShift:
+	opStr = " >> ";
+	break;
+    case OpURShift:
+	opStr = " >>> ";
+	break;
+    case OpLess:
+	opStr = " < ";
+	break;
+    case OpGreaterEq:
+	opStr = " >= ";
+	break;
+    case OpGreater:
+	opStr = " > ";
+	break;
+    case OpLessEq:
+	opStr = " <= ";
+	break;
+    case OpIn:
+	opStr = " in ";
+	break;
+    case OpInstanceOf:
+	opStr = " instanceof ";
+	break;
+    case OpEqEq:
+	opStr = " == ";
+	break;
+    case OpNotEq:
+	opStr = " != ";
+	break;
+    case OpStrEq:
+	opStr = " === ";
+	break;
+    case OpStrNEq:
+	opStr = " !== ";
+	break;
+    case OpBitAnd:
+	opStr = " & ";
+	break;
+    case OpBitXOr:
+	opStr = " ^ ";
+	break;
+    case OpBitOr:
+	opStr = " | ";
+	break;
+    default:
+	assert(!"Unhandled case in BinaryOperatorNode::streamTo()");
+	opStr = " ??? ";
+	break;
+    }
+    s.append(expr1, opStr, expr2);
 }
 
 void BinaryLogicalNode::streamTo(SourceStream &s) const
 {
-  s << expr1 << (oper == OpAnd ? " && " : " || ") << expr2;
+  s.append(expr1, (oper == OpAnd ? " && " : " || "), expr2);
 }
 
 void ConditionalNode::streamTo(SourceStream &s) const
 {
-  s << logical << " ? " << expr1 << " : " << expr2;
+  s << logical << " ? ";
+  s.append(expr1, " : ", expr2);
 }
 
 static void streamAssignmentOperatorTo(SourceStream &s, Operator oper)
@@ -497,30 +609,40 @@ static void streamAssignmentOperatorTo(SourceStream &s, Operator oper)
   s << opStr;
 }
 
-void AssignResolveNode::streamTo(SourceStream &s) const
+void AssignNode::streamTo(SourceStream &s) const
 {
-  s << m_ident;
+  s << m_loc;
   streamAssignmentOperatorTo(s, m_oper);
   s << m_right;
+//  s.append(m_ident, opStr, m_right);
 }
 
 void AssignBracketNode::streamTo(SourceStream &s) const
 {
-  s << m_base << "[" << m_subscript << "]";
+  s << m_base << '[' << m_subscript << ']';
   streamAssignmentOperatorTo(s, m_oper);
   s << m_right;
 }
 
 void AssignDotNode::streamTo(SourceStream &s) const
 {
-  s << m_base << "." << m_ident;
+  s << m_base << '.' << m_ident;
   streamAssignmentOperatorTo(s, m_oper);
   s << m_right;
 }
 
+
+
+void AssignErrorNode::streamTo(SourceStream& s) const 
+{ 
+    s << m_left; 
+    streamAssignmentOperatorTo(s, m_oper); 
+    s << m_right; 
+}
+
 void CommaNode::streamTo(SourceStream &s) const
 {
-  s << expr1 << ", " << expr2;
+  s.append(expr1, ", ", expr2);
 }
 
 void AssignExprNode::streamTo(SourceStream &s) const
@@ -542,28 +664,33 @@ void VarDeclListNode::streamTo(SourceStream &s) const
 
 void VarStatementNode::streamTo(SourceStream &s) const
 {
-  s << SourceStream::Endl << "var " << next << ";";
+  s << SourceStream::Endl << "var " << next << ';';
+}
+
+void StaticVarStatementNode::streamTo(SourceStream &s) const
+{
+  s << originalStatement;
 }
 
 void BlockNode::streamTo(SourceStream &s) const
 {
-  s << SourceStream::Endl << "{" << SourceStream::Indent
-    << source << SourceStream::Unindent << SourceStream::Endl << "}";
+  s << SourceStream::Endl << '{' << SourceStream::Indent
+    << source << SourceStream::Unindent << SourceStream::Endl << '}';
 }
 
 void EmptyStatementNode::streamTo(SourceStream &s) const
 {
-  s << SourceStream::Endl << ";";
+  s << SourceStream::Endl << ';';
 }
 
 void ExprStatementNode::streamTo(SourceStream &s) const
 {
-  s << SourceStream::Endl << expr << ";";
+  s << SourceStream::Endl << expr << ';';
 }
 
 void IfNode::streamTo(SourceStream &s) const
 {
-  s << SourceStream::Endl << "if (" << expr << ")" << SourceStream::Indent
+  s << SourceStream::Endl << "if (" << expr << ')' << SourceStream::Indent
     << statement1 << SourceStream::Unindent;
   if (statement2)
     s << SourceStream::Endl << "else" << SourceStream::Indent
@@ -579,7 +706,7 @@ void DoWhileNode::streamTo(SourceStream &s) const
 
 void WhileNode::streamTo(SourceStream &s) const
 {
-  s << SourceStream::Endl << "while (" << expr << ")" << SourceStream::Indent
+  s << SourceStream::Endl << "while (" << expr << ')' << SourceStream::Indent
     << statement << SourceStream::Unindent;
 }
 
@@ -589,7 +716,7 @@ void ForNode::streamTo(SourceStream &s) const
     << expr1  // TODO: doesn't properly do "var i = 0"
     << "; " << expr2
     << "; " << expr3
-    << ")" << SourceStream::Indent << statement << SourceStream::Unindent;
+    << ')' << SourceStream::Indent << statement << SourceStream::Unindent;
 }
 
 void ForInNode::streamTo(SourceStream &s) const
@@ -602,7 +729,7 @@ void ForInNode::streamTo(SourceStream &s) const
 
   if (init)
     s << " = " << init;
-  s << " in " << expr << ")" << SourceStream::Indent
+  s << " in " << expr << ')' << SourceStream::Indent
     << statement << SourceStream::Unindent;
 }
 
@@ -610,24 +737,24 @@ void ContinueNode::streamTo(SourceStream &s) const
 {
   s << SourceStream::Endl << "continue";
   if (!ident.isNull())
-    s << " " << ident;
-  s << ";";
+    s << ' ' << ident;
+  s << ';';
 }
 
 void BreakNode::streamTo(SourceStream &s) const
 {
   s << SourceStream::Endl << "break";
   if (!ident.isNull())
-    s << " " << ident;
-  s << ";";
+    s << ' ' << ident;
+  s << ';';
 }
 
 void ReturnNode::streamTo(SourceStream &s) const
 {
   s << SourceStream::Endl << "return";
   if (value)
-    s << " " << value;
-  s << ";";
+    s << ' ' << value;
+  s << ';';
 }
 
 void WithNode::streamTo(SourceStream &s) const
@@ -643,7 +770,7 @@ void CaseClauseNode::streamTo(SourceStream &s) const
     s << "case " << expr;
   else
     s << "default";
-  s << ":" << SourceStream::Indent;
+  s << ':' << SourceStream::Indent;
   if (source)
     s << source;
   s << SourceStream::Unindent;
@@ -669,25 +796,25 @@ void SwitchNode::streamTo(SourceStream &s) const
 {
   s << SourceStream::Endl << "switch (" << expr << ") {"
     << SourceStream::Indent << block << SourceStream::Unindent
-    << SourceStream::Endl << "}";
+    << SourceStream::Endl << '}';
 }
 
 void LabelNode::streamTo(SourceStream &s) const
 {
-  s << SourceStream::Endl << label << ":" << SourceStream::Indent
+  s << SourceStream::Endl << label << ':' << SourceStream::Indent
     << statement << SourceStream::Unindent;
 }
 
 void ThrowNode::streamTo(SourceStream &s) const
 {
-  s << SourceStream::Endl << "throw " << expr << ";";
+  s << SourceStream::Endl << "throw " << expr << ';';
 }
 
 void TryNode::streamTo(SourceStream &s) const
 {
-  s << "try " << tryBlock;
+  s << SourceStream::Endl << "try " << tryBlock;
   if (catchBlock)
-    s << SourceStream::Endl << "catch (" << exceptionIdent << ")" << catchBlock;
+    s << SourceStream::Endl << "catch (" << exceptionIdent << ')' << catchBlock;
   if (finallyBlock)
     s << SourceStream::Endl << "finally " << finallyBlock;
 }
@@ -701,12 +828,12 @@ void ParameterNode::streamTo(SourceStream &s) const
 
 void FuncDeclNode::streamTo(SourceStream &s) const
 {
-  s << SourceStream::Endl << "function " << ident << "(" << param << ")" << body;
+  s << SourceStream::Endl << "function " << ident << '(' << param << ')' << body;
 }
 
 void FuncExprNode::streamTo(SourceStream &s) const
 {
-  s << "function " << ident << "(" << param << ")" << body;
+  s << "function " << ident << '(' << param << ')' << body;
 }
 
 void SourceElementsNode::streamTo(SourceStream &s) const
@@ -715,22 +842,23 @@ void SourceElementsNode::streamTo(SourceStream &s) const
     s << n->node;
 }
 
-void PackageIdentNode::streamTo(SourceStream &s) const
+void ErrorNode::streamTo(SourceStream& s) const
 {
-    if (idents)
-        s << idents << ".";
-    s << id;
+  s << kid;
 }
 
 void PackageNameNode::streamTo(SourceStream &s) const
 {
-    if (idents)
-        s << idents;
-    else
-        s << "\"" << str << "\"";
+    if (names)
+        s << names << '.';
+    s << id;
 }
 
 void ImportStatement::streamTo(SourceStream &s) const
 {
-    s << SourceStream::Endl << "import " << name << ";";
+    s << SourceStream::Endl << "import ";
+    if (!al.isEmpty())
+        s << al << " = ";
+    s << name << (wld ? ".*;" : ";");
 }
+
