@@ -1,4 +1,5 @@
 // -*- c-basic-offset: 2 -*-
+// krazy:excludeall=doublequote_chars (UStrings aren't QStrings)
 /*
  *  This file is part of the KDE libraries
  *  Copyright (C) 1999-2000,2003 Harri Porten (porten@kde.org)
@@ -19,15 +20,15 @@
  *
  */
 
-#include "config.h"
 #include "number_object.h"
+#include <config.h>
 #include "number_object.lut.h"
 
 #include "dtoa.h"
 #include "error_object.h"
 #include "operations.h"
-#include <kxmlcore/MathExtras.h>
-#include <kxmlcore/Vector.h>
+#include <wtf/MathExtras.h>
+#include <wtf/Vector.h>
 
 using namespace KJS;
 
@@ -52,22 +53,22 @@ NumberPrototype::NumberPrototype(ExecState *exec,
 
   // The constructor will be added later, after NumberObjectImp has been constructed
 
-  putDirectFunction(new NumberProtoFunc(exec, funcProto, NumberProtoFunc::ToString,       1, toStringPropertyName), DontEnum);
-  putDirectFunction(new NumberProtoFunc(exec, funcProto, NumberProtoFunc::ToLocaleString, 0, toLocaleStringPropertyName), DontEnum);
-  putDirectFunction(new NumberProtoFunc(exec, funcProto, NumberProtoFunc::ValueOf,        0, valueOfPropertyName), DontEnum);
-  putDirectFunction(new NumberProtoFunc(exec, funcProto, NumberProtoFunc::ToFixed,        1, toFixedPropertyName), DontEnum);
-  putDirectFunction(new NumberProtoFunc(exec, funcProto, NumberProtoFunc::ToExponential,  1, toExponentialPropertyName), DontEnum);
-  putDirectFunction(new NumberProtoFunc(exec, funcProto, NumberProtoFunc::ToPrecision,    1, toPrecisionPropertyName), DontEnum);
+  putDirectFunction(new NumberProtoFunc(exec, funcProto, NumberProtoFunc::ToString,       1, exec->propertyNames().toString), DontEnum);
+  putDirectFunction(new NumberProtoFunc(exec, funcProto, NumberProtoFunc::ToLocaleString, 0, exec->propertyNames().toLocaleString), DontEnum);
+  putDirectFunction(new NumberProtoFunc(exec, funcProto, NumberProtoFunc::ValueOf,        0, exec->propertyNames().valueOf), DontEnum);
+  putDirectFunction(new NumberProtoFunc(exec, funcProto, NumberProtoFunc::ToFixed,        1, exec->propertyNames().toFixed), DontEnum);
+  putDirectFunction(new NumberProtoFunc(exec, funcProto, NumberProtoFunc::ToExponential,  1, exec->propertyNames().toExponential), DontEnum);
+  putDirectFunction(new NumberProtoFunc(exec, funcProto, NumberProtoFunc::ToPrecision,    1, exec->propertyNames().toPrecision), DontEnum);
 }
 
 
 // ------------------------------ NumberProtoFunc ---------------------------
 
-NumberProtoFunc::NumberProtoFunc(ExecState*, FunctionPrototype* funcProto, int i, int len, const Identifier& name)
+NumberProtoFunc::NumberProtoFunc(ExecState* exec, FunctionPrototype* funcProto, int i, int len, const Identifier& name)
    : InternalFunctionImp(funcProto, name)
    , id(i)
 {
-  putDirect(lengthPropertyName, len, DontDelete|ReadOnly|DontEnum);
+  putDirect(exec->propertyNames().length, len, DontDelete|ReadOnly|DontEnum);
 }
 
 static UString integer_part_noexp(double d)
@@ -75,7 +76,7 @@ static UString integer_part_noexp(double d)
     int decimalPoint;
     int signDummy;
     char *result = kjs_dtoa(d, 0, 0, &decimalPoint, &signDummy, NULL);
-    int length = strlen(result);
+    size_t length = strlen(result);
 
     // sign for non-zero, negative numbers
     UString str = d < 0 ? "-" : "";
@@ -86,7 +87,7 @@ static UString integer_part_noexp(double d)
     } else {
         Vector<char, 1024> buf(decimalPoint + 1);
 
-        if (length <= decimalPoint) {
+        if (static_cast<int>(length) <= decimalPoint) {
             strcpy(buf, result);
             memset(buf + length, '0', decimalPoint - length);
         } else
@@ -136,9 +137,8 @@ static double intPow10(int e)
   }
 
   if (negative)
-    return 1.0 / result;
-  else
-    return result;
+    return static_cast<double>(1.0 / result);
+  return static_cast<double>(result);
 }
 
 // ECMA 15.7.4.2 - 15.7.4.7
@@ -261,7 +261,7 @@ JSValue *NumberProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, con
 
       int decimalAdjust = 0;
       if (!fractionDigits->isUndefined()) {
-          double logx = floor(log10(x));
+          double logx = floor(log10(fabs(x)));
           x /= pow(10.0, logx);
           double fx = floor(x * pow(10.0, f)) / pow(10.0, f);
           double cx = ceil(x * pow(10.0, f)) / pow(10.0, f);
@@ -282,7 +282,7 @@ JSValue *NumberProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, con
           return jsString("NaN");
 
       char *result = kjs_dtoa(x, 0, 0, &decimalPoint, &sign, NULL);
-      int length = strlen(result);
+      size_t length = strlen(result);
       decimalPoint += decimalAdjust;
 
       int i = 0;
@@ -296,18 +296,18 @@ JSValue *NumberProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, con
           buf[i++] = result[0];
 
           if (fractionDigits->isUndefined())
-              f = length-1;
+              f = static_cast<int>(length) - 1;
 
           if (length > 1 && f > 0) {
               buf[i++] = '.';
-              int haveFDigits = length-1;
+              int haveFDigits = static_cast<int>(length) - 1;
               if (f < haveFDigits) {
                   strncpy(buf+i,result+1, f);
                   i += f;
               }
               else {
                   strcpy(buf+i,result+1);
-                  i += length-1;
+                  i += static_cast<int>(length) - 1;
                   for (int j = 0; j < f-haveFDigits; j++)
                       buf[i++] = '0';
               }
@@ -322,12 +322,12 @@ JSValue *NumberProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, con
               exponential = exponential * -1;
           }
           if (exponential >= 100) {
-              buf[i++] = '0' + exponential / 100;
+              buf[i++] = static_cast<char>('0' + exponential / 100);
           }
           if (exponential >= 10) {
-              buf[i++] = '0' + (exponential % 100) / 10;
+              buf[i++] = static_cast<char>('0' + (exponential % 100) / 10);
           }
-          buf[i++] = '0' + exponential % 10;
+          buf[i++] = static_cast<char>('0' + exponential % 10);
           buf[i++] = '\0';
       }
 
@@ -367,7 +367,7 @@ JSValue *NumberProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, con
               e = e - 1;
               tens = intPow10(e - p + 1);
               n = floor(x / tens);
-              if (n >= pow(10.0,p)) {
+              if (n >= pow(10.0, p)) {
                   // violated constraint. try something else.
                   n = pow(10.0, p - 1);
                   e = e + 1;
@@ -426,14 +426,14 @@ const ClassInfo NumberObjectImp::info = {"Function", &InternalFunctionImp::info,
   MIN_VALUE             NumberObjectImp::MinValue       DontEnum|DontDelete|ReadOnly
 @end
 */
-NumberObjectImp::NumberObjectImp(ExecState*, FunctionPrototype* funcProto, NumberPrototype* numberProto)
+NumberObjectImp::NumberObjectImp(ExecState* exec, FunctionPrototype* funcProto, NumberPrototype* numberProto)
   : InternalFunctionImp(funcProto)
 {
   // Number.Prototype
-  putDirect(prototypePropertyName, numberProto,DontEnum|DontDelete|ReadOnly);
+  putDirect(exec->propertyNames().prototype, numberProto,DontEnum|DontDelete|ReadOnly);
 
   // no. of arguments for constructor
-  putDirect(lengthPropertyName, jsNumber(1), ReadOnly|DontDelete|DontEnum);
+  putDirect(exec->propertyNames().length, jsNumber(1), ReadOnly|DontDelete|DontEnum);
 }
 
 bool NumberObjectImp::getOwnPropertySlot(ExecState* exec, const Identifier& propertyName, PropertySlot& slot)
@@ -483,7 +483,7 @@ JSObject *NumberObjectImp::construct(ExecState *exec, const List &args)
 }
 
 // ECMA 15.7.2
-JSValue *NumberObjectImp::callAsFunction(ExecState *exec, JSObject * /*thisObj*/, const List &args)
+JSValue *NumberObjectImp::callAsFunction(ExecState *exec, JSObject* /*thisObj*/, const List &args)
 {
   if (args.isEmpty())
     return jsNumber(0);
