@@ -4,6 +4,7 @@
  *  Copyright (C) 1999-2001 Harri Porten (porten@kde.org)
  *  Copyright (C) 2001 Peter Kelly (pmk@post.com)
  *  Copyright (C) 2003, 2004, 2005, 2006 Apple Computer, Inc.
+ *  Copyright (C) 2007 Eric Seidel (eric@webkit.org)
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -22,8 +23,8 @@
  *
  */
 
-#include "config.h"
 #include "object.h"
+#include <config.h>
 
 #include "error_object.h"
 #include "lookup.h"
@@ -43,6 +44,7 @@
 #endif
 
 #define JAVASCRIPT_CALL_TRACING 0
+#define JAVASCRIPT_MARK_TRACING 0
 
 #if JAVASCRIPT_CALL_TRACING
 static bool _traceJavaScript = false;
@@ -119,11 +121,24 @@ void JSObject::mark()
 {
   JSCell::mark();
 
+#if JAVASCRIPT_MARK_TRACING
+  static int markStackDepth = 0;
+  markStackDepth++;
+  for (int i = 0; i < markStackDepth; i++)
+    putchar('-');
+  
+  printf("%s (%p)\n", className().UTF8String().c_str(), this);
+#endif
+  
   JSValue *proto = _proto;
   if (!proto->marked())
     proto->mark();
 
   _prop.mark();
+  
+#if JAVASCRIPT_MARK_TRACING
+  markStackDepth--;
+#endif
 }
 
 JSType JSObject::type() const
@@ -139,9 +154,7 @@ const ClassInfo *JSObject::classInfo() const
 UString JSObject::className() const
 {
   const ClassInfo *ci = classInfo();
-  if ( ci )
-    return ci->className;
-  return "Object";
+  return ci ? ci->className : "Object";
 }
 
 JSValue *JSObject::get(ExecState *exec, const Identifier &propertyName) const
@@ -197,7 +210,14 @@ void JSObject::put(ExecState *exec, const Identifier &propertyName, JSValue *val
   assert(value);
 
   // non-standard netscape extension
-  if (propertyName == exec->dynamicInterpreter()->specialPrototypeIdentifier()) {
+  if (propertyName == exec->propertyNames().underscoreProto) {
+    JSObject* proto = value->getObject();
+    while (proto) {
+      if (proto == this)
+        throwError(exec, GeneralError, "cyclic __proto__ value");
+      proto = proto->prototype() ? proto->prototype()->getObject() : 0;
+    }
+    
     setPrototype(value);
     return;
   }
@@ -342,21 +362,21 @@ static ALWAYS_INLINE JSValue *tryGetAndCallProperty(ExecState *exec, const JSObj
 // ECMA 8.6.2.6
 JSValue *JSObject::defaultValue(ExecState *exec, JSType hint) const
 {
-  Identifier firstPropertyName;
-  Identifier secondPropertyName;
+  const Identifier* firstPropertyName;
+  const Identifier* secondPropertyName;
   /* Prefer String for Date objects */
   if ((hint == StringType) || (hint != StringType) && (hint != NumberType) && (_proto == exec->lexicalInterpreter()->builtinDatePrototype())) {
-    firstPropertyName = toStringPropertyName;
-    secondPropertyName = valueOfPropertyName;
+    firstPropertyName = &exec->propertyNames().toString;
+    secondPropertyName = &exec->propertyNames().valueOf;
   } else {
-    firstPropertyName = valueOfPropertyName;
-    secondPropertyName = toStringPropertyName;
+    firstPropertyName = &exec->propertyNames().valueOf;
+    secondPropertyName = &exec->propertyNames().toString;
   }
 
   JSValue *v;
-  if ((v = tryGetAndCallProperty(exec, this, firstPropertyName)))
+  if ((v = tryGetAndCallProperty(exec, this, *firstPropertyName)))
     return v;
-  if ((v = tryGetAndCallProperty(exec, this, secondPropertyName)))
+  if ((v = tryGetAndCallProperty(exec, this, *secondPropertyName)))
     return v;
 
   if (exec->hadException())
@@ -442,9 +462,9 @@ bool JSObject::implementsHasInstance() const
 
 bool JSObject::hasInstance(ExecState* exec, JSValue* value)
 {
-    JSValue* proto = get(exec, prototypePropertyName);
+    JSValue* proto = get(exec, exec->propertyNames().prototype);
     if (!proto->isObject()) {
-        throwError(exec, TypeError, "intanceof called on an object with an invalid prototype property.");
+        throwError(exec, TypeError, "instanceof called on an object with an invalid prototype property.");
         return false;
     }
     
@@ -522,7 +542,7 @@ UString JSObject::toString(ExecState *exec) const
 {
   JSValue *prim = toPrimitive(exec,StringType);
   if (exec->hadException()) // should be picked up soon in nodes.cpp
-    return "";
+    return UString(UString::empty);
   return prim->toString(exec);
 }
 
@@ -531,11 +551,6 @@ JSObject *JSObject::toObject(ExecState * /*exec*/) const
   return const_cast<JSObject*>(this);
 }
 
-void JSObject::putDirect(const Identifier &propertyName, JSValue *value, int attr)
-{
-    _prop.put(propertyName, value, attr);
-}
-
 void JSObject::putDirect(const Identifier &propertyName, int value, int attr)
 {
     _prop.put(propertyName, jsNumber(value), attr);
@@ -573,28 +588,29 @@ const char * const * const Error::errorNames = errorNamesArr;
 JSObject *Error::create(ExecState *exec, ErrorType errtype, const UString &message,
                          int lineno, int sourceId, const UString &sourceURL)
 {
+  Interpreter* interp = exec->lexicalInterpreter();
   JSObject *cons;
   switch (errtype) {
   case EvalError:
-    cons = exec->lexicalInterpreter()->builtinEvalError();
+    cons = interp->builtinEvalError();
     break;
   case RangeError:
-    cons = exec->lexicalInterpreter()->builtinRangeError();
+    cons = interp->builtinRangeError();
     break;
   case ReferenceError:
-    cons = exec->lexicalInterpreter()->builtinReferenceError();
+    cons = interp->builtinReferenceError();
     break;
   case SyntaxError:
-    cons = exec->lexicalInterpreter()->builtinSyntaxError();
+    cons = interp->builtinSyntaxError();
     break;
   case TypeError:
-    cons = exec->lexicalInterpreter()->builtinTypeError();
+    cons = interp->builtinTypeError();
     break;
   case URIError:
-    cons = exec->lexicalInterpreter()->builtinURIError();
+    cons = interp->builtinURIError();
     break;
   default:
-    cons = exec->lexicalInterpreter()->builtinError();
+    cons = interp->builtinError();
     break;
   }
 
