@@ -25,12 +25,13 @@
 #ifndef KJS_OBJECT_H
 #define KJS_OBJECT_H
 
+#include "global.h"
 #include "JSType.h"
 #include "interpreter.h"
 #include "property_map.h"
 #include "property_slot.h"
 #include "scope_chain.h"
-#include <kxmlcore/AlwaysInline.h>
+#include <wtf/AlwaysInline.h>
 
 namespace KJS {
 
@@ -106,7 +107,7 @@ namespace KJS {
      *
      * @param proto The prototype
      */
-    JSObject(JSValue* proto, bool destructorIsThreadSafe = true);
+    explicit JSObject(JSValue* proto, bool destructorIsThreadSafe = true);
 
     /**
      * Creates a new JSObject with a prototype of jsNull()
@@ -431,8 +432,12 @@ namespace KJS {
     JSValue *getDirect(const Identifier& propertyName) const
         { return _prop.get(propertyName); }
     JSValue **getDirectLocation(const Identifier& propertyName)
-        { return _prop.getLocation(propertyName); }
-    void putDirect(const Identifier &propertyName, JSValue *value, int attr = 0);
+        { bool dummy; return _prop.getLocation(propertyName, dummy); }
+    JSValue **getDirectLocation(const Identifier& propertyName, bool& ro)
+        { return _prop.getLocation(propertyName, ro); }
+
+    void putDirect(const Identifier &propertyName, JSValue *value, int attr = 0)
+        { _prop.put(propertyName, value, attr); }
     void putDirect(const Identifier &propertyName, int value, int attr = 0);
 
     // convenience to add a function property under the function's own built-in name
@@ -453,7 +458,7 @@ namespace KJS {
     void saveProperties(SavedProperties &p) const { _prop.save(p); }
     void restoreProperties(const SavedProperties &p) { _prop.restore(p); }
 
-    virtual bool isActivation() { return false; }
+    virtual bool isActivation() const { return false; }
   protected:
     PropertyMap _prop;
   private:
@@ -543,7 +548,7 @@ inline bool JSCell::isObject(const ClassInfo *info) const
 // this method is here to be after the inline declaration of JSCell::isObject
 inline bool JSValue::isObject(const ClassInfo *c) const
 {
-    return !JSImmediate::isImmediate(this) && downcast()->isObject(c);
+    return !JSImmediate::isImmediate(this) && asCell()->isObject(c);
 }
 
 // It may seem crazy to inline a function this large but it makes a big difference
@@ -551,6 +556,7 @@ inline bool JSValue::isObject(const ClassInfo *c) const
 inline bool JSObject::getPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
     JSObject *object = this;
+    slot.setPotentiallyWriteable();
     while (true) {
         if (object->getOwnPropertySlot(exec, propertyName, slot))
             return true;
@@ -559,6 +565,8 @@ inline bool JSObject::getPropertySlot(ExecState *exec, const Identifier& propert
         if (!proto->isObject())
             return false;
 
+        slot.setReadOnly();
+
         object = static_cast<JSObject *>(proto);
     }
 }
@@ -568,17 +576,18 @@ inline bool JSObject::getPropertySlot(ExecState *exec, const Identifier& propert
 // base class call to this.
 ALWAYS_INLINE bool JSObject::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot& slot)
 {
-    if (JSValue **location = getDirectLocation(propertyName)) {
+    bool ro;
+    if (JSValue **location = getDirectLocation(propertyName, ro)) {
         if (_prop.hasGetterSetterProperties() && location[0]->type() == GetterSetterType)
             fillGetterPropertySlot(slot, location);
         else
-            slot.setValueSlot(this, location);
+            slot.setValueSlot(this, location, ro);
         return true;
     }
 
     // non-standard Netscape extension
-    if (propertyName == exec->dynamicInterpreter()->specialPrototypeIdentifier()) {
-        slot.setValueSlot(this, &_proto);
+    if (propertyName == exec->propertyNames().underscoreProto) {
+        slot.setValueSlot(this, &_proto, PropertySlot::PermitDirectWrite);
         return true;
     }
 
