@@ -19,15 +19,15 @@
  *
  */
 
-#include "config.h"
 #include "property_map.h"
+#include <config.h>
 
 #include "object.h"
 #include "protect.h"
 #include "PropertyNameArray.h"
 #include <algorithm>
-#include <kxmlcore/FastMalloc.h>
-#include <kxmlcore/Vector.h>
+#include <wtf/FastMalloc.h>
+#include <wtf/Vector.h>
 
 using std::max;
 
@@ -105,7 +105,7 @@ static inline UString::Rep* deletedSentinel() { return reinterpret_cast<UString:
 // Returns true if the key is not null or the deleted sentinel, false otherwise
 static inline bool isValid(UString::Rep* key)
 {
-    return reinterpret_cast<uintptr_t>(key) & ~0x1;
+    return ((reinterpret_cast<uintptr_t>(key) & ~0x1) != 0);
 }
 
 PropertyMap::~PropertyMap()
@@ -245,7 +245,7 @@ JSValue *PropertyMap::get(const Identifier &name) const
     return 0;
 }
 
-JSValue **PropertyMap::getLocation(const Identifier &name)
+JSValue **PropertyMap::getLocation(const Identifier &name, bool& readOnly)
 {
     assert(!name.isNull());
     
@@ -254,8 +254,10 @@ JSValue **PropertyMap::getLocation(const Identifier &name)
     if (!_table) {
 #if USE_SINGLE_ENTRY
         UString::Rep *key = _singleEntry.key;
-        if (rep == key)
+        if (rep == key) {
+            readOnly = ((_singleEntry.attributes & ReadOnly) == ReadOnly);
             return &_singleEntry.value;
+        }
 #endif
         return 0;
     }
@@ -270,8 +272,10 @@ JSValue **PropertyMap::getLocation(const Identifier &name)
     numCollisions += entries[i].key && entries[i].key != rep;
 #endif
     while (UString::Rep *key = entries[i].key) {
-        if (rep == key)
+        if (rep == key) {
+            readOnly = ((entries[i].attributes & ReadOnly) == ReadOnly);
             return &entries[i].value;
+        }
         if (k == 0)
             k = 1 | (h % sizeMask);
         i = (i + k) & sizeMask;
@@ -578,7 +582,7 @@ bool PropertyMap::containsGettersOrSetters() const
 {
     if (!_table) {
 #if USE_SINGLE_ENTRY
-        return _singleEntry.attributes & GetterSetter;
+        return ((_singleEntry.attributes & GetterSetter) != 0);
 #endif
         return false;
     }
