@@ -21,20 +21,105 @@
  *
  */
 
-#include "config.h"
-#include "lexer.h"
 #include "regexp.h"
+#include <config.h>
+#include "lexer.h"
 
 #include <assert.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <kxmlcore/Vector.h>
-using KXMLCore::Vector;
+#include <wtf/Vector.h>
+using WTF::Vector;
 
 namespace KJS {
 
+#ifdef PCRE_CONFIG_UTF8
 RegExp::UTF8SupportState RegExp::utf8Support = RegExp::Unknown;
+#endif
+
+// JS regexps can contain Unicode escape sequences (\uxxxx) which
+// are rather uncommon elsewhere. As our regexp libs don't understand
+// them we do the unescaping ourselves internally.
+// Also make sure to expand out any nulls as pcre_compile
+// expects null termination..
+static UString sanitizePattern(const UString &p)
+{
+  UString newPattern;
+
+  const char* const nil = "\\x00";
+  if (p.find("\\u") >= 0 || p.find(KJS::UChar('\0')) >= 0) {
+    bool escape = false;
+    for (int i = 0; i < p.size(); ++i) {
+      UChar c = p[i];
+      if (escape) {
+        escape = false;
+        // we only care about \u
+        if (c == 'u') {
+	  // standard unicode escape sequence looks like \uxxxx but
+	  // other browsers also accept less then 4 hex digits
+	  unsigned short u = 0;
+	  int j = 0;
+	  for (j = 0; j < 4; ++j) {
+	    if (i + 1 < p.size() && Lexer::isHexDigit(p[i + 1].unicode())) {
+	      u = (u << 4) + Lexer::convertHex(p[i + 1].unicode());
+	      ++i;
+	    } else {
+	      // sequence incomplete. restore index.
+	      // TODO: cleaner way to propagate warning
+	      fprintf(stderr, "KJS: saw %d digit \\u sequence.\n", j);
+	      i -= j;
+	      break;
+	    }
+	  }
+	  if (j < 4) {
+	    // sequence was incomplete. treat \u as u which IE always
+	    // and FF sometimes does.
+	     newPattern.append(UString('u'));
+	  } else {
+            c = UChar(u);
+            switch (u) {
+            case 0:
+	      // Make sure to encode 0, to avoid terminating the string
+	       newPattern += UString(nil);
+	      break;
+            case '^':
+            case '$':
+            case '\\':
+            case '.':
+            case '*':
+            case '+':
+            case '?':
+            case '(': case ')':
+            case '{': case '}':
+            case '[': case ']':
+            case '|':
+	      // escape pattern characters have to remain escaped
+	       newPattern.append(UString('\\'));
+	      // intentional fallthrough
+            default:
+	      newPattern += UString(&c, 1);
+	      break;
+	    }
+          }
+          continue;
+        }
+        newPattern += UString('\\');
+        newPattern += UString(&c, 1);
+      } else {
+        if (c == '\\')
+          escape = true;
+        else if (c == '\0')
+          newPattern += UString(nil);
+        else
+          newPattern += UString(&c, 1);
+      }
+    }
+    return newPattern;
+  } else {
+    return p;
+  }
+}
 
 RegExp::RegExp(const UString &p, char flags)
   : _pat(p), _flags(flags), _valid(true), _numSubPatterns(0), _buffer(0), _originalPos(0)
@@ -48,52 +133,7 @@ RegExp::RegExp(const UString &p, char flags)
   }
 #endif
 
-  // JS regexps can contain Unicode escape sequences (\uxxxx) which
-  // are rather uncommon elsewhere. As our regexp libs don't understand
-  // them we do the unescaping ourselves internally.
-  // Also make sure to expand out any nulls as pcre_compile 
-  // expects null termination..
-  UString intern;
-  const char* const nil = "\\x00";
-  if (p.find("\\u") >= 0 || p.find(KJS::UChar('\0')) >= 0) {
-    bool escape = false;
-    for (int i = 0; i < p.size(); ++i) {
-      UChar c = p[i];
-      if (escape) {
-        escape = false;
-        // we only care about \uxxxx
-        if (c == 'u' && i + 4 < p.size()) {
-          int c0 = p[i+1].unicode();
-          int c1 = p[i+2].unicode();
-          int c2 = p[i+3].unicode();
-          int c3 = p[i+4].unicode();
-          if (Lexer::isHexDigit(c0) && Lexer::isHexDigit(c1) &&
-              Lexer::isHexDigit(c2) && Lexer::isHexDigit(c3)) {
-            c = Lexer::convertUnicode(c0, c1, c2, c3);
-            if (c.unicode() == 0) {
-                // Make sure to encode 0, to avoid terminating the string
-                intern += UString(nil);
-            } else {
-                intern += UString(&c, 1);
-            }
-            i += 4;
-            continue;
-          }
-        }
-        intern += UString('\\');
-        intern += UString(&c, 1);
-      } else {
-        if (c == '\\')
-          escape = true;
-        else if (c == '\0')
-          intern += UString(nil);
-        else
-          intern += UString(&c, 1);
-      }
-    }
-  } else {
-    intern = p;
-  }
+  UString intern = sanitizePattern(p);
 
 #ifdef HAVE_PCREPOSIX
 
@@ -106,12 +146,12 @@ RegExp::RegExp(const UString &p, char flags)
     options |= PCRE_MULTILINE;
 
   if (utf8Support == Supported)
-    options |= PCRE_UTF8;
+    options |= (PCRE_UTF8 | PCRE_NO_UTF8_CHECK);
 
   const char *errorMessage;
   int errorOffset;
 
-  // Fill our buffer with an encoded version, whether utf-8, or, 
+  // Fill our buffer with an encoded version, whether utf-8, or,
   // if PCRE is incapable, truncated.
   prepareMatch(intern);
   _regex = pcre_compile(_buffer, options, &errorMessage, &errorOffset, NULL);
@@ -150,7 +190,7 @@ RegExp::RegExp(const UString &p, char flags)
 #ifndef NDEBUG
     char errorMessage[80];
     regerror(errorCode, &_regex, errorMessage, sizeof errorMessage);
-    fprintf(stderr, "KJS: regcomp failed with '%s'", errorMessage);
+    fprintf(stderr, "KJS: regcomp failed with '%s'\n", errorMessage);
 #endif
     _valid = false;
   }
@@ -178,8 +218,8 @@ void RegExp::prepareUtf8(const UString& s)
   // even past the \0 since the non-empty handling may jump one past the end
   _originalPos = new int[length * 3 + 2];
 
-  // Convert to runs of 8-bit characters, and generate indeces
-  // Note that we do NOT combine surrogate pairs here, as 
+  // Convert to runs of 8-bit characters, and generate indices
+  // Note that we do NOT combine surrogate pairs here, as
   // regexps operate on them as separate characters
   char *p      = _buffer;
   int  *posOut = _originalPos;
@@ -223,8 +263,8 @@ void RegExp::prepareASCII (const UString& s)
   _originalPos = 0;
 
   // Best-effort attempt to get something done
-  // when we don't have utf 8 available -- use 
-  // truncated version, and pray for the best 
+  // when we don't have utf 8 available -- use
+  // truncated version, and pray for the best
   CString truncated = s.cstring();
   _buffer = new char[truncated.size() + 1];
   memcpy(_buffer, truncated.c_str(), truncated.size());
@@ -236,9 +276,11 @@ void RegExp::prepareMatch(const UString &s)
 {
   delete[] _originalPos; // Just to be sure..
   delete[] _buffer;
+#ifdef PCRE_CONFIG_UTF8
   if (utf8Support == Supported)
     prepareUtf8(s);
   else
+#endif
     prepareASCII(s);
 
 #ifndef NDEBUG
@@ -246,7 +288,7 @@ void RegExp::prepareMatch(const UString &s)
 #endif
 }
 
-void RegExp::doneMatch() 
+void RegExp::doneMatch()
 {
   delete[] _originalPos; _originalPos = 0;
   delete[] _buffer;      _buffer      = 0;
@@ -297,11 +339,13 @@ UString RegExp::match(const UString &s, int i, int *pos, int **ovector)
     startPos = i;
   }
 
-  const int numMatches = pcre_exec(_regex, NULL, _buffer, _bufferSize, startPos, 0, offsetVector, offsetVectorSize);
+  int baseFlags = utf8Support == Supported ? PCRE_NO_UTF8_CHECK : 0;
+  const int numMatches = pcre_exec(_regex, NULL, _buffer, _bufferSize, startPos, baseFlags, offsetVector, offsetVectorSize);
 
   //Now go through and patch up the offsetVector
-  for (int c = 0; c < 2 * numMatches; ++c)
-    if (offsetVector[c] != -1)
+  if (utf8Support == Supported)
+    for (int c = 0; c < 2 * numMatches; ++c)
+      if (offsetVector[c] != -1)
         offsetVector[c] = _originalPos[offsetVector[c]];
 
   if (numMatches < 0) {
@@ -321,6 +365,9 @@ UString RegExp::match(const UString &s, int i, int *pos, int **ovector)
 
 #else
 
+  if (!_valid)
+    return UString::null();
+
   const unsigned maxMatch = 10;
   regmatch_t rmatch[maxMatch];
 
