@@ -1,4 +1,5 @@
 // -*- c-basic-offset: 2 -*-
+// krazy:excludeall=doublequote_chars (UStrings aren't QStrings)
 /*
  *  This file is part of the KDE libraries
  *  Copyright (C) 1999-2000 Harri Porten (porten@kde.org)
@@ -20,8 +21,8 @@
  *
  */
 
-#include "config.h"
 #include "regexp_object.h"
+#include <config.h>
 
 #include "regexp_object.lut.h"
 
@@ -50,23 +51,22 @@ RegExpPrototype::RegExpPrototype(ExecState *exec,
                                        FunctionPrototype *funcProto)
   : JSObject(objProto)
 {
-  // The constructor will be added later in RegExpObject's constructor (?)
+  static const Identifier* execPropertyName = new Identifier("exec");
+  static const Identifier* testPropertyName = new Identifier("test");
+  static const Identifier* compilePropertyName = new Identifier("compile");
 
-  static const Identifier execPropertyName("exec");
-  static const Identifier testPropertyName("test");
-  static const Identifier compilePropertyName("compile");
-  putDirectFunction(new RegExpProtoFunc(exec, funcProto, RegExpProtoFunc::Exec, 0, execPropertyName), DontEnum);
-  putDirectFunction(new RegExpProtoFunc(exec, funcProto, RegExpProtoFunc::Test, 0, testPropertyName), DontEnum);
-  putDirectFunction(new RegExpProtoFunc(exec, funcProto, RegExpProtoFunc::ToString, 0, toStringPropertyName), DontEnum);
-  putDirectFunction(new RegExpProtoFunc(exec, funcProto, RegExpProtoFunc::Compile,  1, compilePropertyName), DontEnum);
+  putDirectFunction(new RegExpProtoFunc(exec, funcProto, RegExpProtoFunc::Exec, 0, *execPropertyName), DontEnum);
+  putDirectFunction(new RegExpProtoFunc(exec, funcProto, RegExpProtoFunc::Test, 0, *testPropertyName), DontEnum);
+  putDirectFunction(new RegExpProtoFunc(exec, funcProto, RegExpProtoFunc::ToString, 0,  exec->propertyNames().toString), DontEnum);
+  putDirectFunction(new RegExpProtoFunc(exec, funcProto, RegExpProtoFunc::Compile,  1, *compilePropertyName), DontEnum);
 }
 
 // ------------------------------ RegExpProtoFunc ---------------------------
 
-RegExpProtoFunc::RegExpProtoFunc(ExecState*, FunctionPrototype* funcProto, int i, int len, const Identifier& name)
+RegExpProtoFunc::RegExpProtoFunc(ExecState* exec, FunctionPrototype* funcProto, int i, int len, const Identifier& name)
    : InternalFunctionImp(funcProto, name), id(i)
 {
-  putDirect(lengthPropertyName, len, DontDelete|ReadOnly|DontEnum);
+  putDirect(exec->propertyNames().length, len, DontDelete | ReadOnly | DontEnum);
 }
 
 JSValue *RegExpProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, const List &args)
@@ -208,17 +208,17 @@ const ClassInfo RegExpObjectImp::info = {"Function", &InternalFunctionImp::info,
 @end
 */
 
-RegExpObjectImp::RegExpObjectImp(ExecState *exec,
+RegExpObjectImp::RegExpObjectImp(ExecState* exec,
                                  FunctionPrototype *funcProto,
                                  RegExpPrototype *regProto)
 
   : InternalFunctionImp(funcProto), lastInput(""), lastNumSubPatterns(0), multiline(false)
 {
   // ECMA 15.10.5.1 RegExp.prototype
-  putDirect(prototypePropertyName, regProto, DontEnum|DontDelete|ReadOnly);
+  putDirect(exec->propertyNames().prototype, regProto, DontEnum | DontDelete | ReadOnly);
 
   // no. of arguments for constructor
-  putDirect(lengthPropertyName, jsNumber(2), ReadOnly|DontDelete|DontEnum);
+  putDirect(exec->propertyNames().length, jsNumber(2), ReadOnly | DontDelete | DontEnum);
 }
 
 /* 
@@ -254,7 +254,7 @@ JSObject *RegExpObjectImp::arrayOfMatches(ExecState *exec, const UString &result
   // The returned array contains 'result' as first item, followed by the list of matches
   list.append(jsString(result));
   if ( lastOvector )
-    for ( unsigned i = 1 ; i < lastNumSubPatterns + 1 ; ++i )
+    for ( unsigned int i = 1 ; i < lastNumSubPatterns + 1 ; ++i )
     {
       int start = lastOvector[2*i];
       if (start == -1)
@@ -270,9 +270,9 @@ JSObject *RegExpObjectImp::arrayOfMatches(ExecState *exec, const UString &result
   return arr;
 }
 
-JSValue *RegExpObjectImp::getBackref(unsigned i) const
+JSValue *RegExpObjectImp::getBackref(int i) const
 {
-  if (lastOvector && i < lastNumSubPatterns + 1) {
+  if (lastOvector && i < int(lastNumSubPatterns + 1)) {
     UString substring = lastInput.substr(lastOvector[2*i], lastOvector[2*i+1] - lastOvector[2*i] );
     return jsString(substring);
   } 
@@ -328,7 +328,7 @@ bool RegExpObjectImp::getOwnPropertySlot(ExecState *exec, const Identifier& prop
   return getStaticValueSlot<RegExpObjectImp, InternalFunctionImp>(exec, &RegExpTable, this, propertyName, slot);
 }
 
-JSValue *RegExpObjectImp::getValueProperty(ExecState *exec, int token) const
+JSValue *RegExpObjectImp::getValueProperty(ExecState*, int token) const
 {
   switch (token) {
     case Dollar1:
@@ -373,7 +373,7 @@ void RegExpObjectImp::put(ExecState *exec, const Identifier &propertyName, JSVal
   lookupPut<RegExpObjectImp, InternalFunctionImp>(exec, propertyName, value, attr, &RegExpTable, this);
 }
 
-void RegExpObjectImp::putValueProperty(ExecState *exec, int token, JSValue *value, int attr)
+void RegExpObjectImp::putValueProperty(ExecState *exec, int token, JSValue *value, int /*attr*/)
 {
   switch (token) {
     case Input:
