@@ -25,7 +25,7 @@
 #include "internal.h"
 #include "function_object.h"
 #include "regexp.h"
-#include <kxmlcore/OwnArrayPtr.h>
+#include <wtf/OwnArrayPtr.h>
 
 namespace KJS {
   class ExecState;
@@ -91,7 +91,7 @@ namespace KJS {
     */
     static RegExp* makeEngine(ExecState *exec, const UString &p, JSValue *flagsInput);    
   private:
-    JSValue *getBackref(unsigned) const;
+    JSValue *getBackref(int) const;
     JSValue *getLastMatch() const;
     JSValue *getLastParen() const;
     JSValue *getLeftContext() const;
