@@ -20,18 +20,20 @@
  *
  */
 
-#include "config.h"
 #include "string_object.h"
 #include "string_object.lut.h"
+#include <config.h>
 
 #include "JSWrapperObject.h"
 #include "error_object.h"
 #include "operations.h"
 #include "PropertyNameArray.h"
 #include "regexp_object.h"
-#include <kxmlcore/unicode/Unicode.h>
+#include <wtf/unicode/libc/UnicodeLibC.h>
 
-using namespace KJS;
+using namespace WTF;
+
+namespace KJS {
 
 // ------------------------------ StringInstance ----------------------------
 
@@ -62,7 +64,7 @@ JSValue *StringInstance::indexGetter(ExecState* exec, JSObject*, const Identifie
 
 bool StringInstance::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot &slot)
 {
-  if (propertyName == lengthPropertyName) {
+  if (propertyName == exec->propertyNames().length) {
     slot.setCustom(this, lengthGetter);
     return true;
   }
@@ -83,14 +85,14 @@ bool StringInstance::getOwnPropertySlot(ExecState *exec, const Identifier& prope
 
 void StringInstance::put(ExecState *exec, const Identifier &propertyName, JSValue *value, int attr)
 {
-  if (propertyName == lengthPropertyName)
+  if (propertyName == exec->propertyNames().length)
     return;
   JSObject::put(exec, propertyName, value, attr);
 }
 
 bool StringInstance::deleteProperty(ExecState *exec, const Identifier &propertyName)
 {
-  if (propertyName == lengthPropertyName)
+  if (propertyName == exec->propertyNames().length)
     return false;
   return JSObject::deleteProperty(exec, propertyName);
 }
@@ -99,7 +101,7 @@ void StringInstance::getPropertyNames(ExecState* exec, PropertyNameArray& proper
 {
   int size = internalValue()->getString().size();
   for (int i = 0; i < size; i++)
-    propertyNames.add(Identifier(UString(i)));
+    propertyNames.add(Identifier(UString::from(i)));
   return JSObject::getPropertyNames(exec, propertyNames);
 }
 
@@ -107,49 +109,50 @@ void StringInstance::getPropertyNames(ExecState* exec, PropertyNameArray& proper
 const ClassInfo StringPrototype::info = {"String", &StringInstance::info, &stringTable, 0};
 /* Source for string_object.lut.h
 @begin stringTable 26
-  toString		StringProtoFunc::ToString	DontEnum|Function	0
-  valueOf		StringProtoFunc::ValueOf	DontEnum|Function	0
-  charAt		StringProtoFunc::CharAt	DontEnum|Function	1
-  charCodeAt		StringProtoFunc::CharCodeAt	DontEnum|Function	1
-  concat		StringProtoFunc::Concat	DontEnum|Function	1
-  indexOf		StringProtoFunc::IndexOf	DontEnum|Function	1
-  lastIndexOf		StringProtoFunc::LastIndexOf	DontEnum|Function	1
-  match			StringProtoFunc::Match	DontEnum|Function	1
-  replace		StringProtoFunc::Replace	DontEnum|Function	2
-  search		StringProtoFunc::Search	DontEnum|Function	1
-  slice			StringProtoFunc::Slice	DontEnum|Function	2
-  split			StringProtoFunc::Split	DontEnum|Function	2
-  substr		StringProtoFunc::Substr	DontEnum|Function	2
-  substring		StringProtoFunc::Substring	DontEnum|Function	2
-  toLowerCase		StringProtoFunc::ToLowerCase	DontEnum|Function	0
-  toUpperCase		StringProtoFunc::ToUpperCase	DontEnum|Function	0
-  toLocaleLowerCase	StringProtoFunc::ToLocaleLowerCase DontEnum|Function	0
-  toLocaleUpperCase     StringProtoFunc::ToLocaleUpperCase DontEnum|Function	0
+  toString              StringProtoFunc::ToString       DontEnum|Function       0
+  valueOf               StringProtoFunc::ValueOf        DontEnum|Function       0
+  charAt                StringProtoFunc::CharAt         DontEnum|Function       1
+  charCodeAt            StringProtoFunc::CharCodeAt     DontEnum|Function       1
+  concat                StringProtoFunc::Concat         DontEnum|Function       1
+  indexOf               StringProtoFunc::IndexOf        DontEnum|Function       1
+  lastIndexOf           StringProtoFunc::LastIndexOf    DontEnum|Function       1
+  match                 StringProtoFunc::Match          DontEnum|Function       1
+  replace               StringProtoFunc::Replace        DontEnum|Function       2
+  search                StringProtoFunc::Search         DontEnum|Function       1
+  slice                 StringProtoFunc::Slice          DontEnum|Function       2
+  split                 StringProtoFunc::Split          DontEnum|Function       2
+  substr                StringProtoFunc::Substr         DontEnum|Function       2
+  substring             StringProtoFunc::Substring      DontEnum|Function       2
+  toLowerCase           StringProtoFunc::ToLowerCase    DontEnum|Function       0
+  toUpperCase           StringProtoFunc::ToUpperCase    DontEnum|Function       0
+  toLocaleLowerCase     StringProtoFunc::ToLocaleLowerCase DontEnum|Function    0
+  toLocaleUpperCase     StringProtoFunc::ToLocaleUpperCase DontEnum|Function    0
+  localeCompare         StringProtoFunc::LocaleCompare  DontEnum|Function       1
 #
 # Under here: html extension, should only exist if KJS_PURE_ECMA is not defined
 # I guess we need to generate two hashtables in the .lut.h file, and use #ifdef
 # to select the right one... TODO. #####
-  big			StringProtoFunc::Big		DontEnum|Function	0
-  small			StringProtoFunc::Small	DontEnum|Function	0
-  blink			StringProtoFunc::Blink	DontEnum|Function	0
-  bold			StringProtoFunc::Bold	DontEnum|Function	0
-  fixed			StringProtoFunc::Fixed	DontEnum|Function	0
-  italics		StringProtoFunc::Italics	DontEnum|Function	0
-  strike		StringProtoFunc::Strike	DontEnum|Function	0
-  sub			StringProtoFunc::Sub		DontEnum|Function	0
-  sup			StringProtoFunc::Sup		DontEnum|Function	0
-  fontcolor		StringProtoFunc::Fontcolor	DontEnum|Function	1
-  fontsize		StringProtoFunc::Fontsize	DontEnum|Function	1
-  anchor		StringProtoFunc::Anchor	DontEnum|Function	1
-  link			StringProtoFunc::Link	DontEnum|Function	1
+  big                   StringProtoFunc::Big            DontEnum|Function       0
+  small                 StringProtoFunc::Small          DontEnum|Function       0
+  blink                 StringProtoFunc::Blink          DontEnum|Function       0
+  bold                  StringProtoFunc::Bold           DontEnum|Function       0
+  fixed                 StringProtoFunc::Fixed          DontEnum|Function       0
+  italics               StringProtoFunc::Italics        DontEnum|Function       0
+  strike                StringProtoFunc::Strike         DontEnum|Function       0
+  sub                   StringProtoFunc::Sub            DontEnum|Function       0
+  sup                   StringProtoFunc::Sup            DontEnum|Function       0
+  fontcolor             StringProtoFunc::Fontcolor      DontEnum|Function       1
+  fontsize              StringProtoFunc::Fontsize       DontEnum|Function       1
+  anchor                StringProtoFunc::Anchor         DontEnum|Function       1
+  link                  StringProtoFunc::Link           DontEnum|Function       1
 @end
 */
 // ECMA 15.5.4
-StringPrototype::StringPrototype(ExecState*, ObjectPrototype* objProto)
+StringPrototype::StringPrototype(ExecState* exec, ObjectPrototype* objProto)
   : StringInstance(objProto)
 {
   // The constructor will be added later, after StringObjectImp has been built
-  putDirect(lengthPropertyName, jsNumber(0), DontDelete|ReadOnly|DontEnum);
+  putDirect(exec->propertyNames().length, jsNumber(0), DontDelete | ReadOnly | DontEnum);
 }
 
 bool StringPrototype::getOwnPropertySlot(ExecState *exec, const Identifier& propertyName, PropertySlot &slot)
@@ -159,11 +162,11 @@ bool StringPrototype::getOwnPropertySlot(ExecState *exec, const Identifier& prop
 
 // ------------------------------ StringProtoFunc ---------------------------
 
-StringProtoFunc::StringProtoFunc(ExecState *exec, int i, int len, const Identifier& name)
+StringProtoFunc::StringProtoFunc(ExecState* exec, int i, int len, const Identifier& name)
   : InternalFunctionImp(static_cast<FunctionPrototype*>(exec->lexicalInterpreter()->builtinFunctionPrototype()), name)
   , id(i)
 {
-  putDirect(lengthPropertyName, len, DontDelete|ReadOnly|DontEnum);
+  putDirect(exec->propertyNames().length, len, DontDelete | ReadOnly | DontEnum);
 }
 
 static inline void expandSourceRanges(UString::Range * & array, int& count, int& capacity)
@@ -208,7 +211,7 @@ static inline void expandReplacements(UString * & array, int& count, int& capaci
   for (int i = 0; i < count; i++) {
     newArray[i] = array[i];
   }
-  
+
   delete [] array;
 
   capacity = newCapacity;
@@ -277,6 +280,13 @@ static inline UString substituteBackreferences(const UString &replacement, const
   return substitutedReplacement;
 }
 
+// ### use as fallback only. implement locale aware version.
+static inline int localeCompare(const UString &a, const UString &b)
+{
+  // ### other browsers have more detailed return values than -1, 0 and 1
+  return compare(a, b);
+}
+
 static JSValue *replace(ExecState *exec, const UString &source, JSValue *pattern, JSValue *replacement)
 {
   JSObject *replacementFunction = 0;
@@ -320,21 +330,21 @@ static JSValue *replace(ExecState *exec, const UString &source, JSValue *pattern
           List args;
 
           args.append(jsString(matchString));
-          
+
           for (unsigned i = 0; i < reg->subPatterns(); i++) {
               int matchStart = ovector[(i + 1) * 2];
               int matchLen = ovector[(i + 1) * 2 + 1] - matchStart;
-              
+
               args.append(jsString(source.substr(matchStart, matchLen)));
           }
-          
+
           args.append(jsNumber(completeMatchStart));
           args.append(jsString(source));
 
-          replacementString = replacementFunction->call(exec, exec->dynamicInterpreter()->globalObject(), 
+          replacementString = replacementFunction->call(exec, exec->dynamicInterpreter()->globalObject(),
                                                         args)->toString(exec);
       }
-      
+
       UString substitutedReplacement = substituteBackreferences(replacementString, source, ovector, reg);
       pushReplacement(replacements, replacementCount, replacementCapacity, substitutedReplacement);
 
@@ -348,7 +358,7 @@ static JSValue *replace(ExecState *exec, const UString &source, JSValue *pattern
           break;
       }
     } while (global);
-    
+
     reg->doneMatch();
 
     if (lastIndex < source.size())
@@ -361,7 +371,7 @@ static JSValue *replace(ExecState *exec, const UString &source, JSValue *pattern
 
     return jsString(result);
   }
-  
+
   // First arg is a string
   UString patternString = pattern->toString(exec);
   int matchPos = source.find(patternString);
@@ -369,15 +379,15 @@ static JSValue *replace(ExecState *exec, const UString &source, JSValue *pattern
   // Do the replacement
   if (matchPos == -1)
     return jsString(source);
-  
+
   if (replacementFunction) {
       List args;
-      
+
       args.append(jsString(source.substr(matchPos, matchLen)));
       args.append(jsNumber(matchPos));
       args.append(jsString(source));
-      
-      replacementString = replacementFunction->call(exec, exec->dynamicInterpreter()->globalObject(), 
+
+      replacementString = replacementFunction->call(exec, exec->dynamicInterpreter()->globalObject(),
                                                     args)->toString(exec);
   }
 
@@ -385,9 +395,9 @@ static JSValue *replace(ExecState *exec, const UString &source, JSValue *pattern
 }
 
 // ECMA 15.5.4.2 - 15.5.4.20
-JSValue *StringProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, const List &args)
+JSValue *StringProtoFunc::callAsFunction(ExecState* exec, JSObject* thisObj, const List& args)
 {
-  JSValue *result = NULL;
+  JSValue* result = NULL;
 
   // toString and valueOf are no generic function.
   if (id == ToString || id == ValueOf) {
@@ -476,7 +486,7 @@ JSValue *StringProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, con
     RegExpImp *imp = 0;
     if (a0->isObject() && static_cast<JSObject *>(a0)->inherits(&RegExpImp::info)) {
       reg = static_cast<RegExpImp *>(a0)->regExp();
-    } else { 
+    } else {
       /*
        *  ECMA 15.5.4.12 String.prototype.search (regexp)
        *  If regexp is not an object whose [[Class]] property is "RegExp", it is
@@ -484,6 +494,10 @@ JSValue *StringProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, con
        */
       reg = tmpReg = new RegExp(a0->toString(exec), RegExp::None);
     }
+    if (!reg->isValid()) {
+      delete tmpReg;
+      return throwError(exec, SyntaxError, "Invalid regular expression");
+    }
     RegExpObjectImp* regExpObj = static_cast<RegExpObjectImp*>(exec->lexicalInterpreter()->builtinRegExp());
     reg->prepareMatch(u);
     UString mstr = regExpObj->performMatch(reg, u, 0, &pos);
@@ -492,35 +506,35 @@ JSValue *StringProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, con
     } else {
       // Exec
       if ((reg->flags() & RegExp::Global) == 0) {
-	// case without 'g' flag is handled like RegExp.prototype.exec
-	if (mstr.isNull()) {
-	  result = jsNull();
-	} else {
-	  result = regExpObj->arrayOfMatches(exec,mstr);
-	}
+        // case without 'g' flag is handled like RegExp.prototype.exec
+        if (mstr.isNull()) {
+          result = jsNull();
+        } else {
+          result = regExpObj->arrayOfMatches(exec,mstr);
+        }
       } else {
-	// return array of matches
-	List list;
-	int lastIndex = 0;
-	while (pos >= 0) {
+        // return array of matches
+        List list;
+        int lastIndex = 0;
+        while (pos >= 0) {
           if (mstr.isNull())
             list.append(jsUndefined());
           else
-	    list.append(jsString(mstr));
-	  lastIndex = pos;
-	  pos += mstr.isEmpty() ? 1 : mstr.size();
-	  mstr = regExpObj->performMatch(reg, u, pos, &pos);
-	}
-	if (imp)
-	  imp->put(exec, "lastIndex", jsNumber(lastIndex), DontDelete|DontEnum);
-	if (list.isEmpty()) {
-	  // if there are no matches at all, it's important to return
-	  // Null instead of an empty array, because this matches
-	  // other browsers and because Null is a false value.
-	  result = jsNull(); 
-	} else {
-	  result = exec->lexicalInterpreter()->builtinArray()->construct(exec, list);
-	}
+            list.append(jsString(mstr));
+          lastIndex = pos;
+          pos += mstr.isEmpty() ? 1 : mstr.size();
+          mstr = regExpObj->performMatch(reg, u, pos, &pos);
+        }
+        if (imp)
+          imp->put(exec, "lastIndex", jsNumber(lastIndex), DontDelete|DontEnum);
+        if (list.isEmpty()) {
+          // if there are no matches at all, it's important to return
+          // Null instead of an empty array, because this matches
+          // other browsers and because Null is a false value.
+          result = jsNull();
+        } else {
+          result = exec->lexicalInterpreter()->builtinArray()->construct(exec, list);
+        }
       }
     }
     reg->doneMatch();
@@ -560,50 +574,50 @@ JSValue *StringProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, con
       RegExp *reg = static_cast<RegExpImp *>(a0)->regExp();
       reg->prepareMatch(u);
       if (u.isEmpty() && !reg->match(u, 0).isNull()) {
-	// empty string matched by regexp -> empty array
-	res->put(exec,lengthPropertyName, jsNumber(0));
-	break;
+        // empty string matched by regexp -> empty array
+        res->put(exec, exec->propertyNames().length, jsNumber(0));
+        break;
       }
       pos = 0;
       while (static_cast<uint32_t>(i) != limit && pos < u.size()) {
-	// TODO: back references
+        // TODO: back references
         int mpos;
         int *ovector = 0L;
-	UString mstr = reg->match(u, pos, &mpos, &ovector);
+        UString mstr = reg->match(u, pos, &mpos, &ovector);
         delete [] ovector; ovector = 0L;
-	if (mpos < 0)
-	  break;
-	pos = mpos + (mstr.isEmpty() ? 1 : mstr.size());
-	if (mpos != p0 || !mstr.isEmpty()) {
-	  res->put(exec,i, jsString(u.substr(p0, mpos-p0)));
-	  p0 = mpos + mstr.size();
-	  i++;
-	}
+        if (mpos < 0)
+          break;
+        pos = mpos + (mstr.isEmpty() ? 1 : mstr.size());
+        if (mpos != p0 || !mstr.isEmpty()) {
+          res->put(exec,i, jsString(u.substr(p0, mpos-p0)));
+          p0 = mpos + mstr.size();
+          i++;
+        }
       }
       reg->doneMatch();
     } else {
       u2 = a0->toString(exec);
       if (u2.isEmpty()) {
-	if (u.isEmpty()) {
-	  // empty separator matches empty string -> empty array
-	  put(exec,lengthPropertyName, jsNumber(0));
-	  break;
-	} else {
-	  while (static_cast<uint32_t>(i) != limit && i < u.size()-1)
-	    res->put(exec, i++, jsString(u.substr(p0++, 1)));
-	}
+        if (u.isEmpty()) {
+          // empty separator matches empty string -> empty array
+          put(exec, exec->propertyNames().length, jsNumber(0));
+          break;
+        } else {
+          while (static_cast<uint32_t>(i) != limit && i < u.size()-1)
+            res->put(exec, i++, jsString(u.substr(p0++, 1)));
+        }
       } else {
-	while (static_cast<uint32_t>(i) != limit && (pos = u.find(u2, p0)) >= 0) {
-	  res->put(exec, i, jsString(u.substr(p0, pos-p0)));
-	  p0 = pos + u2.size();
-	  i++;
-	}
+        while (static_cast<uint32_t>(i) != limit && (pos = u.find(u2, p0)) >= 0) {
+          res->put(exec, i, jsString(u.substr(p0, pos-p0)));
+          p0 = pos + u2.size();
+          i++;
+        }
       }
     }
     // add remaining string, if any
     if (static_cast<uint32_t>(i) != limit)
       res->put(exec, i++, jsString(u.substr(p0)));
-    res->put(exec,lengthPropertyName, jsNumber(i));
+    res->put(exec, exec->propertyNames().length, jsNumber(i));
     }
     break;
   case Substr: {
@@ -657,9 +671,9 @@ JSValue *StringProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, con
     uint16_t* dataPtr = reinterpret_cast<uint16_t*>(u.rep()->data());
     uint16_t* destIfNeeded;
 
-    int len = KXMLCore::Unicode::toLower(dataPtr, u.size(), destIfNeeded);
+    int len = Unicode::toLower(dataPtr, u.size(), destIfNeeded);
     if (len >= 0)
-        result = jsString(UString(reinterpret_cast<UChar *>(destIfNeeded ? destIfNeeded : dataPtr), len));
+        result = jsString(UString(reinterpret_cast<UChar*>(destIfNeeded ? destIfNeeded : dataPtr), len));
     else
         result = jsString(s);
 
@@ -673,7 +687,7 @@ JSValue *StringProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, con
     uint16_t* dataPtr = reinterpret_cast<uint16_t*>(u.rep()->data());
     uint16_t* destIfNeeded;
 
-    int len = KXMLCore::Unicode::toUpper(dataPtr, u.size(), destIfNeeded);
+    int len = Unicode::toUpper(dataPtr, u.size(), destIfNeeded);
     if (len >= 0)
         result = jsString(UString(reinterpret_cast<UChar *>(destIfNeeded ? destIfNeeded : dataPtr), len));
     else
@@ -682,6 +696,10 @@ JSValue *StringProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, con
     free(destIfNeeded);
     break;
   }
+  case LocaleCompare:
+    if (args.size() < 1)
+      return jsNumber(0);
+    return jsNumber(localeCompare(s, a0->toString(exec)));
 #ifndef KJS_PURE_ECMA
   case Big:
     result = jsString("<big>" + s + "</big>");
@@ -730,18 +748,18 @@ JSValue *StringProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, con
 
 // ------------------------------ StringObjectImp ------------------------------
 
-StringObjectImp::StringObjectImp(ExecState *exec,
-                                 FunctionPrototype *funcProto,
-                                 StringPrototype *stringProto)
+StringObjectImp::StringObjectImp(ExecState* exec,
+                                 FunctionPrototype* funcProto,
+                                 StringPrototype* stringProto)
   : InternalFunctionImp(funcProto)
 {
   // ECMA 15.5.3.1 String.prototype
-  putDirect(prototypePropertyName, stringProto, DontEnum|DontDelete|ReadOnly);
+  putDirect(exec->propertyNames().prototype, stringProto, DontEnum|DontDelete|ReadOnly);
 
-  putDirectFunction(new StringObjectFuncImp(exec, funcProto, fromCharCodePropertyName), DontEnum);
+  putDirectFunction(new StringObjectFuncImp(exec, funcProto, exec->propertyNames().fromCharCode), DontEnum);
 
   // no. of arguments for constructor
-  putDirect(lengthPropertyName, jsNumber(1), ReadOnly|DontDelete|DontEnum);
+  putDirect(exec->propertyNames().length, jsNumber(1), ReadOnly|DontDelete|DontEnum);
 }
 
 
@@ -760,7 +778,7 @@ JSObject *StringObjectImp::construct(ExecState *exec, const List &args)
 }
 
 // ECMA 15.5.1
-JSValue *StringObjectImp::callAsFunction(ExecState *exec, JSObject * /*thisObj*/, const List &args)
+JSValue *StringObjectImp::callAsFunction(ExecState *exec, JSObject* /*thisObj*/, const List &args)
 {
   if (args.isEmpty())
     return jsString("");
@@ -773,13 +791,13 @@ JSValue *StringObjectImp::callAsFunction(ExecState *exec, JSObject * /*thisObj*/
 // ------------------------------ StringObjectFuncImp --------------------------
 
 // ECMA 15.5.3.2 fromCharCode()
-StringObjectFuncImp::StringObjectFuncImp(ExecState*, FunctionPrototype* funcProto, const Identifier& name)
+StringObjectFuncImp::StringObjectFuncImp(ExecState* exec, FunctionPrototype* funcProto, const Identifier& name)
   : InternalFunctionImp(funcProto, name)
 {
-  putDirect(lengthPropertyName, jsNumber(1), DontDelete|ReadOnly|DontEnum);
+  putDirect(exec->propertyNames().length, jsNumber(1), DontDelete|ReadOnly|DontEnum);
 }
 
-JSValue *StringObjectFuncImp::callAsFunction(ExecState *exec, JSObject * /*thisObj*/, const List &args)
+JSValue *StringObjectFuncImp::callAsFunction(ExecState *exec, JSObject* /*thisObj*/, const List &args)
 {
   UString s;
   if (args.size()) {
@@ -797,3 +815,5 @@ JSValue *StringObjectFuncImp::callAsFunction(ExecState *exec, JSObject * /*thisO
 
   return jsString(s);
 }
+
+}
