@@ -1,6 +1,8 @@
 /* This file is part of the KDE libraries
-    Copyright (C) 2005, 2006 KJSEmbed Authors
-    See included AUTHORS file.
+    Copyright (C) 2005, 2006 Ian Reinhart Geiser <geiseri@kde.org>
+    Copyright (C) 2005, 2006 Matt Broadstone <mbroadst@gmail.com>
+    Copyright (C) 2005, 2006 Richard J. Moore <rich@kde.org>
+    Copyright (C) 2005, 2006 Erik L. Bunce <kde@bunce.us>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -17,14 +19,14 @@
     the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
     Boston, MA 02110-1301, USA.
 */
-#include <QDebug>
+#include "bind_qdialog.h"
+
+#include <QtCore/QDebug>
 
 #include <kjsembed/object_binding.h>
 #include <kjsembed/variant_binding.h>
 #include <kjs/object.h>
 
-#include "bind_qdialog.h"
-
 using namespace KJSEmbed;
 
 namespace DialogNS {
