@@ -1,6 +1,8 @@
 /* This file is part of the KDE libraries
-    Copyright (C) 2005, 2006 KJSEmbed Authors
-    See included AUTHORS file.
+    Copyright (C) 2005, 2006 Ian Reinhart Geiser <geiseri@kde.org>
+    Copyright (C) 2005, 2006 Matt Broadstone <mbroadst@gmail.com>
+    Copyright (C) 2005, 2006 Richard J. Moore <rich@kde.org>
+    Copyright (C) 2005, 2006 Erik L. Bunce <kde@bunce.us>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -17,21 +19,20 @@
     the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
     Boston, MA 02110-1301, USA.
 */
-#include <QObject>
-#include <QMetaObject>
-#include <QMetaProperty>
-#include <QMetaMethod>
-#include <QMetaType>
-#include <QVariant>
-#include <QVector>
-#include <QDebug>
-#include <qobjectdefs.h>
+#include "qobject_binding.h"
+
+#include <QtCore/QObject>
+#include <QtCore/QArgument>
+#include <QtCore/QMetaEnum>
+#include <QtCore/QMetaType>
+#include <QtCore/QVariant>
+#include <QtCore/QVector>
+#include <QtCore/QDebug>
 
 #include "slotproxy.h"
 #include "eventproxy.h"
 #include "jseventmapper.h"
 #include "pointer.h"
-#include "qobject_binding.h"
 #include "variant_binding.h"
 
 #include <kjs/array_instance.h>
@@ -394,28 +395,23 @@ KJS::UString QObjectBinding::toString(KJS::ExecState *exec) const
     return toUString( s );
 }
 
-PointerBase *getArg( KJS::ExecState *exec, const QList<QByteArray> &types, const KJS::List &args, int idx)
+PointerBase *getArg( KJS::ExecState *exec, const QList<QByteArray> &types, const KJS::List &args, int idx, QString& errorText)
 {
     //qDebug("Index %d, args size %d, types size %d", idx, args.size(), types.size() );
-    if ( args.size() <= idx )
-        return new NullPtr();
+
     if( types.size() == 0 && idx == 0 )
         return new NullPtr();
+    if ( args.size() <= idx )
+        return new NullPtr();
 
     if ( types.size() <= idx )
     {
-        KJS::throwError(exec, KJS::GeneralError, i18n("The slot sked for %1 arguments but there are only %2 arguments available.",
-                        idx,
-                        types.size()));
-        //KJSEmbed::throwError(exec,
-        //                     i18n("The slot asked for %1 arguments but there are only are %2 arguments available.")
-        //                        .arg(idx)
-        //                        .arg(types.size() ) );
-        return new NullPtr();
+        errorText = i18n("The slot sked for %1 arguments but there are only %2 arguments available.", idx, types.size());
+        return 0;
     }
 
     QVariant::Type varianttype = QVariant::nameToType( types[idx].constData() );
-    //qDebug( QString("type=%1 argtype=%2").arg(types[idx].constData()).arg(args[idx]->type()).toLatin1() );
+    //qDebug( QString("type=%1 argtype=%2 variantType=%3 (%4)").arg(types[idx].constData()).arg(args[idx]->type()).arg(varianttype).arg(QVariant::typeToName(varianttype)).toLatin1() );
     switch( varianttype ) {
         case QVariant::Int:
             if( args[idx]->type() == KJS::NumberType )
@@ -457,29 +453,151 @@ PointerBase *getArg( KJS::ExecState *exec, const QList<QByteArray> &types, const
             {
                 return new NullPtr();
             }
-            if( args[idx]->type() == KJS::ObjectType ) {
-                if(ObjectBinding *objImp = KJSEmbed::extractBindingImp<ObjectBinding>(exec, args[idx]))
+            if( args[idx]->type() == KJS::ObjectType ) 
+            {
+                if(QObjectBinding *objImp = KJSEmbed::extractBindingImp<QObjectBinding>(exec, args[idx]))
                 {
+                    //qDebug("\tQObjectBinding");
+                    QObject* qObj = objImp->qobject<QObject>();
+                    if (qObj)
+                    {
+                        QByteArray typeName = types[idx].constData();
+                        typeName.replace("*", "");
+
+                        // try the basic QObject inheritance check
+                        if (qObj->inherits(typeName))
+                            return new Value<void*>(qObj);
+
+                        // ok, we'll have to check the hard way, and we'll 
+                        // have to play fast and loose with namespace checking
+                        // since the QMetaMethod parameterTypes doesn't 
+                        // include implicit namespace information.
+
+                        QByteArray className;
+                        int pos;
+                        
+                        //qDebug() << "\tMaking sure " << qObj << " inherits from " << typeName << " inherits(typeName)=" << qObj->inherits(typeName);
+                        const QMetaObject* meta = qObj->metaObject();
+                        do 
+                        {
+                            //qDebug() << "1: Checking if " << typeName << " matches " << meta->className();
+                            //if (typeName == meta->className())
+                            {
+                                //qDebug("Yeah! we found a winnder!");
+                                return new Value<void*>(qObj);
+                            }
+                            
+                            // try with all leading namespacing stripped
+                            className = meta->className();
+                            if ((pos = className.lastIndexOf("::")) != -1)
+                                className.remove(0, pos + 2);
+                            
+                            //qDebug() << "2: Checking if " << typeName << " matches " << className;
+                            if (typeName == className)
+                            {
+                                //qDebug() << "Yeah! we found a winnder!" << typeName << " ~= " << className << "(" << meta->className() << ")";
+                                return new Value<void*>(qObj);
+                            }
+                            
+                            meta = meta->superClass();
+                            
+                        }
+                        while (meta);
+                       
+                    }
+                }
+                else if(ObjectBinding *objImp = KJSEmbed::extractBindingImp<ObjectBinding>(exec, args[idx]))
+                {
+                    //qDebug("\tObjectBinding");
                     return new Value<void*>(objImp->voidStar());
                 }
                 if(VariantBinding *valImp = KJSEmbed::extractBindingImp<VariantBinding>(exec,args[idx]))
                 {
-                    return new Value<void*>(valImp->variant().data());
+                    //qDebug() << "\tVariantBinding typeName="  << valImp->variant().typeName() << "type="  << valImp->variant().type() << "userType="  << valImp->variant().userType() << " variant=" << valImp->variant();
+                    QVariant var = valImp->variant();
+                    
+                    // if the variant is the appropriate type, return its data
+                    if ((var.type() == varianttype) ||
+                        ((var.type() == QVariant::UserType) &&
+                         (types[idx].constData() == var.typeName())))
+                        return new Value<void*>(valImp->variant().data());
+                    else if ((var.type() != QVariant::UserType) && 
+                           var.canConvert(varianttype))
+                    {
+                        // is convertable type, so convert it, and return if successful
+                        if (var.convert(varianttype))
+                            return new Value<void*>(valImp->variant().data());
+                    }
+                    else if ((var.type() == QVariant::UserType) &&
+                             var.canConvert<QObject*>())
+                    {
+                        QObject* qObj = var.value<QObject*>();
+                        if (!qObj)
+                            qObj = reinterpret_cast<QObject*>(var.value<QWidget*>());
+                        if (qObj)
+                        {
+                            QByteArray typeName = types[idx].constData();
+                            typeName.replace("*", "");
+                            if (qObj->inherits(typeName))
+                                return new Value<void*>(qObj);
+                        }
+                    }
                 }
             }
             break;
     }
 
     qDebug("Cast failure %s value Type %d", types[idx].constData(), args[idx]->type() );
-    KJS::throwError(exec, KJS::GeneralError, i18n("Cast failure %1 value Type %2",
-                    types[idx].constData() ,
-                    args[idx]->type()) );
-    //KJSEmbed::throwError(exec,
-    //        i18n("Cast failure %1 value Type %2")
-    //                .arg(types[idx].constData())
-    //                .arg(args[idx].type() ) );
+    // construct a meaningful exception message
+    QString jsType;
+    KJS::JSObject* jsObj = args[idx]->getObject();
+    if (jsObj)
+    {
+        const KJS::ClassInfo* ci = jsObj->classInfo();
+        if (ci && ci->className)
+            jsType = ci->className;
+        if (jsType.isEmpty())
+            jsType = toQString(jsObj->className());
+    }
+    
+    if (jsType.isEmpty())
+    {
+        switch(args[idx]->type())
+        {
+        case KJS::UnspecifiedType:
+            jsType = "jsUnspecified";
+            break;
+        case KJS::NumberType:
+            jsType = "jsNumber";
+            break;
+        case KJS::BooleanType:
+            jsType = "jsBoolean";
+            break;
+        case KJS::UndefinedType:
+            jsType = "jsUndefined";
+            break;
+        case KJS::NullType:
+            jsType = "jsNull";
+            break;
+        case KJS::StringType:
+            jsType = "jsString";
+            break;
+        case KJS::ObjectType:
+            jsType = "jsObject";
+            break;
+        case KJS::GetterSetterType:
+            jsType = "jsGetterSetter";
+            break;
+        default:
+            jsType = QString::number(args[idx]->type());
+            break;
+        }
+    }
 
-    return new NullPtr();
+    errorText = i18n("Failure to cast to %1 value from Type %2 (%3)",
+                     types[idx].constData(), jsType, toQString(args[idx]->toString(exec)));
+
+    return 0;
 }
 
 KJS::JSValue *SlotBinding::callAsFunction( KJS::ExecState *exec, KJS::JSObject *self, const KJS::List &args )
@@ -521,9 +639,12 @@ KJS::JSValue *SlotBinding::callAsFunction( KJS::ExecState *exec, KJS::JSObject *
     QVariant returnValue( returnTypeId );
     QGenericReturnArgument returnArgument(metaMember.typeName(), &returnValue);
     param[0] = returnArgument.data();
+    QString errorText;
     for( int idx = 0; idx < 10; ++idx)
     {
-        qtArgs[idx] = getArg(exec, types, args, idx);
+        qtArgs[idx] = getArg(exec, types, args, idx, errorText);
+        if (!qtArgs[0])
+            return KJS::throwError(exec, KJS::GeneralError, i18n("Call to method '%1' failed, unable to get argument %2: %3",  m_memberName.constData(), idx, errorText));
         param[idx+1] = qtArgs[idx]->voidStar();
     }
 
@@ -553,7 +674,7 @@ KJS::JSValue *SlotBinding::callAsFunction( KJS::ExecState *exec, KJS::JSObject *
                     QVariant v(tp, param[0]);
                     QObject* obj = v.value< QObject* >();
                     if( obj )
-                        return KJSEmbed::createQObject(exec, obj);
+                        return KJSEmbed::createQObject(exec, obj, KJSEmbed::ObjectBinding::QObjOwned);
                 } break;
                 default: break;
             }
@@ -569,7 +690,7 @@ SlotBinding::SlotBinding(KJS::ExecState *exec, const QMetaMethod &member )
 {
     m_memberName = extractMemberName(member);
     int count = member.parameterNames().count();
-    putDirect( KJS::lengthPropertyName, count, LengthFlags );
+    putDirect( exec->propertyNames().length, count, LengthFlags );
 }
 
 
@@ -577,19 +698,29 @@ KJS::JSObject* KJSEmbed::createQObject(KJS::ExecState *exec, QObject *value, KJS
 {
     if ( 0 == value )
         return new KJS::JSObject();
-    
+
     const QMetaObject *meta = value->metaObject();
     KJS::JSObject *parent = exec->dynamicInterpreter()->globalObject();
     KJS::JSObject *returnValue;
-
+    int pos;
     QString clazz;
     do
     {
         clazz = meta->className();
+        
+#ifdef CREATEQOBJ_DIAG
+        qDebug() << "clazz=" << clazz;
+#endif
+        // strip off namespace since they aren't included
+        if ((pos = clazz.lastIndexOf("::")) != -1)
+            clazz.remove(0, pos + 2);
+#ifdef CREATEQOBJ_DIAG
+        qDebug() << "cleaned clazz=" << clazz;
+#endif
         if ( parent->hasProperty( exec, KJS::Identifier(toUString(clazz)) ) )
         {
 #ifdef CREATEQOBJ_DIAG
-            qDebug() << "createQObject(): clazz=" << clazz << " value=" << value;// << " typeid(T)=" << typeid(T).name();
+            qDebug() << "createQObject(): clazz=" << clazz << " value=" << value;
 #endif
             Pointer<QObject> pov(value);
             returnValue = StaticConstructor::bind(exec, clazz, pov);
