@@ -20,8 +20,8 @@
 #include <kdebug.h>
 #include <klocale.h>
 #include <kiconloader.h>
-#include <QItemDelegate>
-#include <QPainter>
+#include <QtGui/QItemDelegate>
+#include <QtGui/QPainter>
 
 //BEGIN KNotifyEventListDelegate
 
@@ -42,12 +42,12 @@ void KNotifyEventList::KNotifyEventListDelegate::paint( QPainter* painter,
 	QString prstring=displayData.toString();
 
 	QItemDelegate::paint(painter, option, index);
-	
-	kDebug(300) << k_funcinfo << prstring << endl;
-	
+
+// 	kDebug(300) << prstring;
+
 	QRect rect=option.rect;
-	
-	
+
+
 	int mc_x=0;
 	foreach(QString key , prstring.split ("|"))
 	{
@@ -55,19 +55,19 @@ void KNotifyEventList::KNotifyEventListDelegate::paint( QPainter* painter,
 		if(key == "Sound" )
 			icon = SmallIcon("sound");
 		else if(key == "Popup" )
-			icon = SmallIcon("info");
+			icon = SmallIcon("document-properties");
 		else if(key == "Execute" )
 			icon = SmallIcon("exec");
 		else if(key == "Taskbar" )
 			icon = SmallIcon("kicker");
 		else if(key == "Logfile" )
 			icon = SmallIcon("log");
-		else 
+		else
 			continue;
-		
+
 		painter->drawPixmap( rect.left() + mc_x +4, rect.top() + (rect.height() - icon.height())/2, icon );
 		mc_x += icon.width()+4;
-	} 
+	}
 
 }
 
@@ -77,11 +77,11 @@ KNotifyEventList::KNotifyEventList(QWidget *parent)
  : QTreeWidget(parent)  , config(0l) , loconf(0l)
 {
   QStringList headerLabels;
-  headerLabels << i18n( "Title" ) << i18n( "Description" ) << i18n( "State" );
+  headerLabels << i18nc( "Title of the notified event", "Title" ) << i18nc( "Description of the notified event", "Description" ) << i18nc( "State of the notified event", "State" );
   setHeaderLabels( headerLabels );
 
   setItemDelegate(new KNotifyEventListDelegate);
-  
+
   connect(this, SIGNAL(currentItemChanged( QTreeWidgetItem * , QTreeWidgetItem *  )) , this , SLOT(slotSelectionChanged( QTreeWidgetItem * , QTreeWidgetItem *)));
 }
 
@@ -98,8 +98,8 @@ void KNotifyEventList::fill( const QString & appname , const QString & context_n
 	clear();
 	delete config;
 	delete loconf;
-	config= new KConfig(appname + '/' + appname + ".notifyrc" , true, false, "data"),
-	loconf= new KConfig(appname + ".notifyrc" , false , false );
+	config= new KConfig("data", appname + '/' + appname + ".notifyrc" , KConfig::NoGlobals),
+	loconf= new KConfig(appname + ".notifyrc" , KConfig::NoGlobals);
 
 	QStringList conflist = config->groupList();
 	QRegExp rx("^Event/([^/]*)$");
@@ -107,20 +107,20 @@ void KNotifyEventList::fill( const QString & appname , const QString & context_n
 
 	foreach (QString group , conflist )
 	{
-		config->setGroup(group);
+                KConfigGroup cg(config, group);
 		rx.indexIn(group);
 		QString id=rx.cap(1);
 
 		if(!context_name.isEmpty())
 		{
-			QStringList contexts = config->readEntry("Contexts", QStringList());
+			QStringList contexts = cg.readEntry("Contexts", QStringList());
 			if(!contexts.contains(context_name))
 				continue;
 
 			id=id+'/'+context_name+'/'+context_value;
 		}
-		QString name = config->readEntry("Name");
-		QString description = config->readEntry("Comment");
+		QString name = cg.readEntry("Name");
+		QString description = cg.readEntry("Comment");
 
 		m_elements << new KNotifyEventListItem(this, id, name, description, loconf , config );
 	}
@@ -187,7 +187,7 @@ void KNotifyEventListItem::update()
 
 	QPixmap pexec = SmallIcon("exec");
 	QPixmap pstderr = SmallIcon("terminal");
-	QPixmap pmessage = SmallIcon("info");
+	QPixmap pmessage = SmallIcon("document-properties");
 	QPixmap plogfile = SmallIcon("log");
 	QPixmap psound = SmallIcon("sound");
 	QPixmap ptaskbar = SmallIcon("kicker");
@@ -199,8 +199,4 @@ void KNotifyEventListItem::update()
 	setIcon(6 , actions.contains("Logfile") ? QIcon(plogfile) : QIcon() );*/
 }
 
-
-
-
-
 #include "knotifyeventlist.moc"
