@@ -23,8 +23,8 @@
 #include "knotifyconfigelement.h"
 #include <kconfig.h>
 
-#include <QString>
-#include <QTreeWidget>
+
+#include <QtGui/QTreeWidget>
 
 class KNotifyConfigElement;
 class KNotifyEventListItem;
