@@ -19,54 +19,94 @@
 */
 #include "browserextension.h"
 
-#include <qapplication.h>
-#include <qclipboard.h>
-#include <qtimer.h>
-#include <qobject.h>
-#include <qmap.h>
-#include <qmetaobject.h>
-#include <qregexp.h>
-#include <QTextDocument>
+#include <QtGui/QApplication>
+#include <QtGui/QClipboard>
+#include <QtCore/QTimer>
+#include <QtCore/QObject>
+#include <QtCore/QMap>
+#include <QtCore/QMetaEnum>
+#include <QtCore/QRegExp>
+#include <QtGui/QTextDocument>
 
 #include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kstaticdeleter.h>
 #include <kurifilter.h>
 #include <assert.h>
 
 using namespace KParts;
 
-const char *OpenURLEvent::s_strOpenURLEvent = "KParts/BrowserExtension/OpenURLevent";
 
-class OpenURLEvent::OpenURLEventPrivate
+class OpenUrlEvent::OpenUrlEventPrivate
 {
 public:
-  OpenURLEventPrivate()
+  OpenUrlEventPrivate( ReadOnlyPart *part,
+                       const KUrl &url,
+                       const OpenUrlArguments &args,
+                       const BrowserArguments &browserArgs )
+    : m_part( part )
+    , m_url( url )
+    , m_args(args)
+    , m_browserArgs(browserArgs)
   {
   }
-  ~OpenURLEventPrivate()
+  ~OpenUrlEventPrivate()
   {
   }
+  static const char *s_strOpenUrlEvent;
+  ReadOnlyPart *m_part;
+  KUrl m_url;
+  OpenUrlArguments m_args;
+  BrowserArguments m_browserArgs;
 };
 
-OpenURLEvent::OpenURLEvent( ReadOnlyPart *part, const KUrl &url, const URLArgs &args )
-: Event( s_strOpenURLEvent ), m_part( part ), m_url( url ), m_args( args )
+const char *OpenUrlEvent::OpenUrlEventPrivate::s_strOpenUrlEvent =
+                        "KParts/BrowserExtension/OpenURLevent";
+
+OpenUrlEvent::OpenUrlEvent( ReadOnlyPart *part, const KUrl &url,
+                            const OpenUrlArguments &args,
+                            const BrowserArguments &browserArgs )
+    : Event( OpenUrlEventPrivate::s_strOpenUrlEvent )
+    , d( new OpenUrlEventPrivate(part, url, args, browserArgs) )
 {
-//  d = new OpenURLEventPrivate();
 }
 
-OpenURLEvent::~OpenURLEvent()
+OpenUrlEvent::~OpenUrlEvent()
 {
-//  delete d;
+    delete d;
+}
+
+ReadOnlyPart *OpenUrlEvent::part() const
+{
+    return d->m_part;
+}
+
+KUrl OpenUrlEvent::url() const
+{
+    return d->m_url;
+}
+
+OpenUrlArguments OpenUrlEvent::arguments() const
+{
+    return d->m_args;
+}
+
+BrowserArguments OpenUrlEvent::browserArguments() const
+{
+    return d->m_browserArgs;
+}
+
+bool OpenUrlEvent::test( const QEvent *event )
+{
+    return Event::test( event, OpenUrlEventPrivate::s_strOpenUrlEvent );
 }
 
 namespace KParts
 {
 
-struct URLArgsPrivate
+struct BrowserArgumentsPrivate
 {
-    URLArgsPrivate() {
+    BrowserArgumentsPrivate() {
       doPost = false;
       redirectedRequest = false;
       lockHistory = false;
@@ -74,7 +114,6 @@ struct URLArgsPrivate
       forcesNewWindow = false;
     }
     QString contentType; // for POST
-    QMap<QString, QString> metaData;
     bool doPost;
     bool redirectedRequest;
     bool lockHistory;
@@ -84,133 +123,111 @@ struct URLArgsPrivate
 
 }
 
-URLArgs::URLArgs()
+BrowserArguments::BrowserArguments()
 {
-  reload = false;
-  xOffset = 0;
-  yOffset = 0;
+  softReload = false;
   trustedSource = false;
-  d = 0L; // Let's build it on demand for now
+  d = 0; // Let's build it on demand for now
 }
 
-
-URLArgs::URLArgs( bool _reload, int _xOffset, int _yOffset, const QString &_serviceType )
+BrowserArguments::BrowserArguments( const BrowserArguments &args )
 {
-  reload = _reload;
-  xOffset = _xOffset;
-  yOffset = _yOffset;
-  serviceType = _serviceType;
-  d = 0L; // Let's build it on demand for now
-}
-
-URLArgs::URLArgs( const URLArgs &args )
-{
-  d = 0L;
+  d = 0;
   (*this) = args;
 }
 
-URLArgs &URLArgs::operator=(const URLArgs &args)
+BrowserArguments &BrowserArguments::operator=(const BrowserArguments &args)
 {
   if (this == &args) return *this;
 
   delete d; d= 0;
 
-  reload = args.reload;
-  xOffset = args.xOffset;
-  yOffset = args.yOffset;
-  serviceType = args.serviceType;
+  softReload = args.softReload;
   postData = args.postData;
   frameName = args.frameName;
   docState = args.docState;
   trustedSource = args.trustedSource;
 
   if ( args.d )
-     d = new URLArgsPrivate( * args.d );
+      d = new BrowserArgumentsPrivate( * args.d );
 
   return *this;
 }
 
-URLArgs::~URLArgs()
+BrowserArguments::~BrowserArguments()
 {
   delete d;
   d = 0;
 }
 
-void URLArgs::setContentType( const QString & contentType )
+void BrowserArguments::setContentType( const QString & contentType )
 {
   if (!d)
-    d = new URLArgsPrivate;
+    d = new BrowserArgumentsPrivate;
   d->contentType = contentType;
 }
 
-void URLArgs::setRedirectedRequest( bool redirected )
+void BrowserArguments::setRedirectedRequest( bool redirected )
 {
   if (!d)
-     d = new URLArgsPrivate;
+     d = new BrowserArgumentsPrivate;
   d->redirectedRequest = redirected;
 }
 
-bool URLArgs::redirectedRequest () const
+bool BrowserArguments::redirectedRequest () const
 {
   return d ? d->redirectedRequest : false;
 }
 
-QString URLArgs::contentType() const
+QString BrowserArguments::contentType() const
 {
   return d ? d->contentType : QString();
 }
 
-QMap<QString, QString> &URLArgs::metaData()
-{
-  if (!d)
-     d = new URLArgsPrivate;
-  return d->metaData;
-}
-
-void URLArgs::setDoPost( bool enable )
+void BrowserArguments::setDoPost( bool enable )
 {
     if ( !d )
-        d = new URLArgsPrivate;
+        d = new BrowserArgumentsPrivate;
     d->doPost = enable;
 }
 
-bool URLArgs::doPost() const
+bool BrowserArguments::doPost() const
 {
     return d ? d->doPost : false;
 }
 
-void URLArgs::setLockHistory( bool lock )
+void BrowserArguments::setLockHistory( bool lock )
 {
   if (!d)
-     d = new URLArgsPrivate;
+     d = new BrowserArgumentsPrivate;
   d->lockHistory = lock;
 }
 
-bool URLArgs::lockHistory() const
+bool BrowserArguments::lockHistory() const
 {
     return d ? d->lockHistory : false;
 }
 
-void URLArgs::setNewTab( bool newTab )
+void BrowserArguments::setNewTab( bool newTab )
 {
   if (!d)
-     d = new URLArgsPrivate;
+     d = new BrowserArgumentsPrivate;
   d->newTab = newTab;
 }
 
-bool URLArgs::newTab() const
+bool BrowserArguments::newTab() const
 {
     return d ? d->newTab : false;
 }
 
-void URLArgs::setForcesNewWindow( bool forcesNewWindow )
+void BrowserArguments::setForcesNewWindow( bool forcesNewWindow )
 {
   if (!d)
-     d = new URLArgsPrivate;
+     d = new BrowserArgumentsPrivate;
   d->forcesNewWindow = forcesNewWindow;
 }
 
-bool URLArgs::forcesNewWindow() const
+bool BrowserArguments::forcesNewWindow() const
 {
     return d ? d->forcesNewWindow : false;
 }
@@ -218,95 +235,202 @@ bool URLArgs::forcesNewWindow() const
 namespace KParts
 {
 
-struct WindowArgsPrivate
+class WindowArgsPrivate : public QSharedData
 {
+public:
+    WindowArgsPrivate()
+        : x(-1), y(-1), width(-1), height(-1),
+          fullscreen(false),
+          menuBarVisible(true),
+          toolBarsVisible(true),
+          statusBarVisible(true),
+          resizable(true),
+          lowerWindow(false),
+          scrollBarsVisible(true)
+    {
+    }
+
+    // Position
+    int x;
+    int y;
+    // Size
+    int width;
+    int height;
+    bool fullscreen; //defaults to false
+    bool menuBarVisible; //defaults to true
+    bool toolBarsVisible; //defaults to true
+    bool statusBarVisible; //defaults to true
+    bool resizable; //defaults to true
+
+    bool lowerWindow; //defaults to false
+    bool scrollBarsVisible; //defaults to true
 };
 
 }
 
 WindowArgs::WindowArgs()
+    : d(new WindowArgsPrivate)
 {
-    x = y = width = height = -1;
-    fullscreen = false;
-    menuBarVisible = true;
-    toolBarsVisible = true;
-    statusBarVisible = true;
-    scrollBarsVisible = true;
-    resizable = true;
-    lowerWindow = false;
-    d = 0;
 }
 
 WindowArgs::WindowArgs( const WindowArgs &args )
+    : d(args.d)
 {
-    d = 0;
-    (*this) = args;
 }
 
 WindowArgs::~WindowArgs()
 {
-    delete d;
 }
 
 WindowArgs &WindowArgs::operator=( const WindowArgs &args )
 {
     if ( this == &args ) return *this;
 
-    delete d; d = 0;
-
-    x = args.x;
-    y = args.y;
-    width = args.width;
-    height = args.height;
-    fullscreen = args.fullscreen;
-    menuBarVisible = args.menuBarVisible;
-    toolBarsVisible = args.toolBarsVisible;
-    statusBarVisible = args.statusBarVisible;
-    scrollBarsVisible = args.scrollBarsVisible;
-    resizable = args.resizable;
-    lowerWindow = args.lowerWindow;
-
-    /*
-    if ( args.d )
-    {
-      [ ... ]
-    }
-    */
-
+    d = args.d;
     return *this;
 }
 
 WindowArgs::WindowArgs( const QRect &_geometry, bool _fullscreen, bool _menuBarVisible,
                         bool _toolBarsVisible, bool _statusBarVisible, bool _resizable )
+    : d(new WindowArgsPrivate)
 {
-    d = 0;
-    x = _geometry.x();
-    y = _geometry.y();
-    width = _geometry.width();
-    height = _geometry.height();
-    fullscreen = _fullscreen;
-    menuBarVisible = _menuBarVisible;
-    toolBarsVisible = _toolBarsVisible;
-    statusBarVisible = _statusBarVisible;
-    resizable = _resizable;
-    lowerWindow = false;
+    d->x = _geometry.x();
+    d->y = _geometry.y();
+    d->width = _geometry.width();
+    d->height = _geometry.height();
+    d->fullscreen = _fullscreen;
+    d->menuBarVisible = _menuBarVisible;
+    d->toolBarsVisible = _toolBarsVisible;
+    d->statusBarVisible = _statusBarVisible;
+    d->resizable = _resizable;
+    d->lowerWindow = false;
 }
 
 WindowArgs::WindowArgs( int _x, int _y, int _width, int _height, bool _fullscreen,
                         bool _menuBarVisible, bool _toolBarsVisible,
                         bool _statusBarVisible, bool _resizable )
+    : d(new WindowArgsPrivate)
 {
-    d = 0;
-    x = _x;
-    y = _y;
-    width = _width;
-    height = _height;
-    fullscreen = _fullscreen;
-    menuBarVisible = _menuBarVisible;
-    toolBarsVisible = _toolBarsVisible;
-    statusBarVisible = _statusBarVisible;
-    resizable = _resizable;
-    lowerWindow = false;
+    d->x = _x;
+    d->y = _y;
+    d->width = _width;
+    d->height = _height;
+    d->fullscreen = _fullscreen;
+    d->menuBarVisible = _menuBarVisible;
+    d->toolBarsVisible = _toolBarsVisible;
+    d->statusBarVisible = _statusBarVisible;
+    d->resizable = _resizable;
+    d->lowerWindow = false;
+}
+
+void WindowArgs::setX(int x)
+{
+    d->x = x;
+}
+
+int WindowArgs::x() const
+{
+    return d->x;
+}
+
+void WindowArgs::setY(int y)
+{
+    d->y = y;
+}
+
+int WindowArgs::y() const
+{
+    return d->y;
+}
+
+void WindowArgs::setWidth(int w)
+{
+    d->width = w;
+}
+
+int WindowArgs::width() const
+{
+    return d->width;
+}
+
+void WindowArgs::setHeight(int h)
+{
+    d->height = h;
+}
+
+int WindowArgs::height() const
+{
+    return d->height;
+}
+
+void WindowArgs::setFullScreen(bool fs)
+{
+    d->fullscreen = fs;
+}
+
+bool WindowArgs::isFullScreen() const
+{
+    return d->fullscreen;
+}
+
+void WindowArgs::setMenuBarVisible(bool visible)
+{
+    d->menuBarVisible = visible;
+}
+
+bool WindowArgs::isMenuBarVisible() const
+{
+    return d->menuBarVisible;
+}
+
+void WindowArgs::setToolBarsVisible(bool visible)
+{
+    d->toolBarsVisible = visible;
+}
+
+bool WindowArgs::toolBarsVisible() const
+{
+    return d->toolBarsVisible;
+}
+
+void WindowArgs::setStatusBarVisible(bool visible)
+{
+    d->statusBarVisible = visible;
+}
+
+bool WindowArgs::isStatusBarVisible() const
+{
+    return d->statusBarVisible;
+}
+
+void WindowArgs::setResizable(bool resizable)
+{
+    d->resizable = resizable;
+}
+
+bool WindowArgs::isResizable() const
+{
+    return d->resizable;
+}
+
+void WindowArgs::setLowerWindow(bool lower)
+{
+    d->lowerWindow = lower;
+}
+
+bool WindowArgs::lowerWindow() const
+{
+    return d->lowerWindow;
+}
+
+void WindowArgs::setScrollBarsVisible(bool visible)
+{
+    d->scrollBarsVisible = visible;
+}
+
+bool WindowArgs::scrollBarsVisible() const
+{
+    return d->scrollBarsVisible;
 }
 
 namespace KParts
@@ -325,45 +449,75 @@ public:
     }
 };
 
-class BrowserExtensionPrivate
+class BrowserExtension::BrowserExtensionPrivate
 {
 public:
-  BrowserExtensionPrivate()
-  {
-      m_browserInterface = 0;
-  }
-  ~BrowserExtensionPrivate()
-  {
-  }
+  BrowserExtensionPrivate( KParts::ReadOnlyPart *parent )
+    : m_urlDropHandlingEnabled(false),
+      m_browserInterface(0),
+      m_part( parent )
+  {}
 
   struct DelayedRequest {
     KUrl m_delayedURL;
-    KParts::URLArgs m_delayedArgs;
+    KParts::OpenUrlArguments m_delayedArgs;
+    KParts::BrowserArguments m_delayedBrowserArgs;
   };
+
   QList<DelayedRequest> m_requests;
   bool m_urlDropHandlingEnabled;
   KBitArray m_actionStatus;
   QMap<int, QString> m_actionText;
   BrowserInterface *m_browserInterface;
+
+  static void createActionSlotMap();
+
+  KParts::ReadOnlyPart *m_part;
+    OpenUrlArguments m_args;
+    BrowserArguments m_browserArgs;
 };
 
+K_GLOBAL_STATIC(BrowserExtension::ActionSlotMap, s_actionSlotMap)
+K_GLOBAL_STATIC(BrowserExtension::ActionNumberMap, s_actionNumberMap)
+
+void BrowserExtension::BrowserExtensionPrivate::createActionSlotMap()
+{
+    s_actionSlotMap->insert( "cut", SLOT( cut() ) );
+    s_actionSlotMap->insert( "copy", SLOT( copy() ) );
+    s_actionSlotMap->insert( "paste", SLOT( paste() ) );
+    s_actionSlotMap->insert( "rename", SLOT( rename() ) );
+    s_actionSlotMap->insert( "trash", SLOT( trash() ) );
+    s_actionSlotMap->insert( "del", SLOT( del() ) );
+    s_actionSlotMap->insert( "properties", SLOT( properties() ) );
+    s_actionSlotMap->insert( "editMimeType", SLOT( editMimeType() ) );
+    s_actionSlotMap->insert( "print", SLOT( print() ) );
+    // Tricky. Those aren't actions in fact, but simply methods that a browserextension
+    // can have or not. No need to return them here.
+    //s_actionSlotMap->insert( "reparseConfiguration", SLOT( reparseConfiguration() ) );
+    //s_actionSlotMap->insert( "refreshMimeTypes", SLOT( refreshMimeTypes() ) );
+    // nothing for setSaveViewPropertiesLocally either
+
+    // Create the action-number map
+    ActionSlotMap::ConstIterator it = s_actionSlotMap->constBegin();
+    ActionSlotMap::ConstIterator itEnd = s_actionSlotMap->constEnd();
+    for ( int i=0 ; it != itEnd ; ++it, ++i )
+    {
+        //kDebug(1202) << " action " << it.key() << " number " << i;
+        s_actionNumberMap->insert( it.key(), i );
+    }
+}
+
 }
 
-BrowserExtension::ActionSlotMap * BrowserExtension::s_actionSlotMap = 0L;
-static KStaticDeleter<BrowserExtension::ActionSlotMap> actionSlotMapsd;
-BrowserExtension::ActionNumberMap * BrowserExtension::s_actionNumberMap = 0L;
-static KStaticDeleter<BrowserExtension::ActionNumberMap> actionNumberMapsd;
-
 BrowserExtension::BrowserExtension( KParts::ReadOnlyPart *parent )
-: QObject( parent), m_part( parent )
+: QObject( parent ), d( new BrowserExtensionPrivate(parent) )
 {
-  //kDebug() << "BrowserExtension::BrowserExtension() " << this << endl;
-  d = new BrowserExtensionPrivate;
+  //kDebug() << "BrowserExtension::BrowserExtension() " << this;
   d->m_urlDropHandlingEnabled = false;
 
-  if ( !s_actionSlotMap )
+  if (s_actionSlotMap->isEmpty())
       // Create the action-slot map
-      createActionSlotMap();
+      BrowserExtensionPrivate::createActionSlotMap();
 
   // Build list with this extension's slot names.
   QList<QByteArray> slotNames;
@@ -378,8 +532,8 @@ BrowserExtension::BrowserExtension( KParts::ReadOnlyPart *parent )
 
   // Set the initial status of the actions depending on whether
   // they're supported or not
-  ActionSlotMap::ConstIterator it = s_actionSlotMap->begin();
-  ActionSlotMap::ConstIterator itEnd = s_actionSlotMap->end();
+  ActionSlotMap::ConstIterator it = s_actionSlotMap->constBegin();
+  ActionSlotMap::ConstIterator itEnd = s_actionSlotMap->constEnd();
   for ( int i=0 ; it != itEnd ; ++it, ++i )
   {
       // Does the extension have a slot with the name of this action ?
@@ -387,10 +541,10 @@ BrowserExtension::BrowserExtension( KParts::ReadOnlyPart *parent )
       d->m_actionStatus.setBit( i, slotNames.contains( it.key()+"()" ) );
   }
 
-  connect( m_part, SIGNAL( completed() ),
+  connect( d->m_part, SIGNAL( completed() ),
            this, SLOT( slotCompleted() ) );
-  connect( this, SIGNAL( openUrlRequest( const KUrl &, const KParts::URLArgs & ) ),
-           this, SLOT( slotOpenUrlRequest( const KUrl &, const KParts::URLArgs & ) ) );
+  connect( this, SIGNAL( openUrlRequest( const KUrl &, const KParts::OpenUrlArguments &, const KParts::BrowserArguments & ) ),
+           this, SLOT( slotOpenUrlRequest( const KUrl &, const KParts::OpenUrlArguments &, const KParts::BrowserArguments & ) ) );
   connect( this, SIGNAL( enableAction( const char *, bool ) ),
            this, SLOT( slotEnableAction( const char *, bool ) ) );
   connect( this, SIGNAL( setActionText( const char *, const QString& ) ),
@@ -399,18 +553,18 @@ BrowserExtension::BrowserExtension( KParts::ReadOnlyPart *parent )
 
 BrowserExtension::~BrowserExtension()
 {
-  //kDebug() << "BrowserExtension::~BrowserExtension() " << this << endl;
+  //kDebug() << "BrowserExtension::~BrowserExtension() " << this;
   delete d;
 }
 
-void BrowserExtension::setUrlArgs( const URLArgs &args )
+void BrowserExtension::setBrowserArguments( const BrowserArguments &args )
 {
-  m_args = args;
+  d->m_browserArgs = args;
 }
 
-URLArgs BrowserExtension::urlArgs() const
+BrowserArguments BrowserExtension::browserArguments() const
 {
-  return m_args;
+  return d->m_browserArgs;
 }
 
 int BrowserExtension::xOffset()
@@ -425,7 +579,8 @@ int BrowserExtension::yOffset()
 
 void BrowserExtension::saveState( QDataStream &stream )
 {
-  stream << m_part->url() << (qint32)xOffset() << (qint32)yOffset();
+    // TODO add d->m_part->mimeType()
+  stream << d->m_part->url() << (qint32)xOffset() << (qint32)yOffset();
 }
 
 void BrowserExtension::restoreState( QDataStream &stream )
@@ -434,13 +589,12 @@ void BrowserExtension::restoreState( QDataStream &stream )
   qint32 xOfs, yOfs;
   stream >> u >> xOfs >> yOfs;
 
-  URLArgs args( urlArgs() );
-  args.xOffset = xOfs;
-  args.yOffset = yOfs;
-
-  setUrlArgs( args );
-
-  m_part->openUrl( u );
+    OpenUrlArguments args;
+    args.setXOffset(xOfs);
+    args.setYOffset(yOfs);
+    // TODO add args.setMimeType
+    d->m_part->setArguments(args);
+    d->m_part->openUrl(u);
 }
 
 bool BrowserExtension::isURLDropHandlingEnabled() const
@@ -456,7 +610,7 @@ void BrowserExtension::setURLDropHandlingEnabled( bool enable )
 void BrowserExtension::slotCompleted()
 {
   //empty the argument stuff, to avoid bogus/invalid values when opening a new url
-  setUrlArgs( URLArgs() );
+    setBrowserArguments( BrowserArguments() );
 }
 
 void BrowserExtension::pasteRequest()
@@ -480,10 +634,10 @@ void BrowserExtension::pasteRequest()
 	    case KUriFilterData::LOCAL_FILE:
 	    case KUriFilterData::LOCAL_DIR:
 	    case KUriFilterData::NET_PROTOCOL:
-	        slotOpenUrlRequest( filterData.uri(), KParts::URLArgs() );
+	        slotOpenUrlRequest( filterData.uri() );
 		break;
 	    case KUriFilterData::ERROR:
-		KMessageBox::sorry( m_part->widget(), filterData.errorMsg() );
+		KMessageBox::sorry( d->m_part->widget(), filterData.errorMsg() );
 		break;
 	    default:
 		break;
@@ -493,20 +647,21 @@ void BrowserExtension::pasteRequest()
                     QStringList( QLatin1String( "kuriikwsfilter" ) ) ) &&
               url.length() < 250 )
     {
-        if ( KMessageBox::questionYesNo( m_part->widget(),
-		    i18n( "<qt>Do you want to search the Internet for <b>%1</b>?" ,  Qt::escape(url) ),
-		    i18n( "Internet Search" ), KGuiItem( i18n( "&Search" ), "find"),
+        if ( KMessageBox::questionYesNo( d->m_part->widget(),
+		    i18n( "<qt>Do you want to search the Internet for <b>%1</b>?</qt>" ,  Qt::escape(url) ),
+		    i18n( "Internet Search" ), KGuiItem( i18n( "&Search" ), "edit-find"),
 		    KStandardGuiItem::cancel(), "MiddleClickSearch" ) == KMessageBox::Yes)
-          slotOpenUrlRequest( filterData.uri(), KParts::URLArgs() );
+          slotOpenUrlRequest( filterData.uri() );
     }
 }
 
-void BrowserExtension::slotOpenUrlRequest( const KUrl &url, const KParts::URLArgs &args )
+void BrowserExtension::slotOpenUrlRequest( const KUrl &url, const KParts::OpenUrlArguments& args, const KParts::BrowserArguments &browserArgs )
 {
-    //kDebug() << this << " BrowserExtension::slotOpenURLRequest(): url=" << url.url() << endl;
+    //kDebug() << this << " BrowserExtension::slotOpenURLRequest(): url=" << url.url();
     BrowserExtensionPrivate::DelayedRequest req;
     req.m_delayedURL = url;
     req.m_delayedArgs = args;
+    req.m_delayedBrowserArgs = browserArgs;
     d->m_requests.append( req );
     QTimer::singleShot( 0, this, SLOT( slotEmitOpenUrlRequestDelayed() ) );
 }
@@ -516,7 +671,7 @@ void BrowserExtension::slotEmitOpenUrlRequestDelayed()
     if (d->m_requests.isEmpty()) return;
     BrowserExtensionPrivate::DelayedRequest req = d->m_requests.front();
     d->m_requests.pop_front();
-    emit openUrlRequestDelayed( req.m_delayedURL, req.m_delayedArgs );
+    emit openUrlRequestDelayed( req.m_delayedURL, req.m_delayedArgs, req.m_delayedBrowserArgs );
     // tricky: do not do anything here! (no access to member variables, etc.)
 }
 
@@ -532,15 +687,15 @@ BrowserInterface *BrowserExtension::browserInterface() const
 
 void BrowserExtension::slotEnableAction( const char * name, bool enabled )
 {
-    //kDebug() << "BrowserExtension::slotEnableAction " << name << " " << enabled << endl;
+    //kDebug() << "BrowserExtension::slotEnableAction " << name << " " << enabled;
     ActionNumberMap::ConstIterator it = s_actionNumberMap->find( name );
-    if ( it != s_actionNumberMap->end() )
+    if ( it != s_actionNumberMap->constEnd() )
     {
         d->m_actionStatus.setBit( it.value(), enabled );
-        //kDebug() << "BrowserExtension::slotEnableAction setting bit " << it.data() << " to " << enabled << endl;
+        //kDebug() << "BrowserExtension::slotEnableAction setting bit " << it.data() << " to " << enabled;
     }
     else
-        kWarning() << "BrowserExtension::slotEnableAction unknown action " << name << endl;
+        kWarning() << "BrowserExtension::slotEnableAction unknown action " << name;
 }
 
 bool BrowserExtension::isActionEnabled( const char * name ) const
@@ -551,14 +706,14 @@ bool BrowserExtension::isActionEnabled( const char * name ) const
 
 void BrowserExtension::slotSetActionText( const char * name, const QString& text )
 {
-    kDebug() << "BrowserExtension::slotSetActionText " << name << " " << text << endl;
+    kDebug() << "BrowserExtension::slotSetActionText " << name << " " << text;
     ActionNumberMap::ConstIterator it = s_actionNumberMap->find( name );
-    if ( it != s_actionNumberMap->end() )
+    if ( it != s_actionNumberMap->constEnd() )
     {
         d->m_actionText[ it.value() ] = text;
     }
     else
-        kWarning() << "BrowserExtension::slotSetActionText unknown action " << name << endl;
+        kWarning() << "BrowserExtension::slotSetActionText unknown action " << name;
 }
 
 QString BrowserExtension::actionText( const char * name ) const
@@ -578,43 +733,11 @@ BrowserExtension::ActionSlotMap BrowserExtension::actionSlotMap()
 
 BrowserExtension::ActionSlotMap * BrowserExtension::actionSlotMapPtr()
 {
-    if (!s_actionSlotMap)
-        createActionSlotMap();
+    if (s_actionSlotMap->isEmpty())
+        BrowserExtensionPrivate::createActionSlotMap();
     return s_actionSlotMap;
 }
 
-void BrowserExtension::createActionSlotMap()
-{
-    assert(!s_actionSlotMap);
-    s_actionSlotMap = actionSlotMapsd.setObject( s_actionSlotMap, new ActionSlotMap );
-
-    s_actionSlotMap->insert( "cut", SLOT( cut() ) );
-    s_actionSlotMap->insert( "copy", SLOT( copy() ) );
-    s_actionSlotMap->insert( "paste", SLOT( paste() ) );
-    s_actionSlotMap->insert( "rename", SLOT( rename() ) );
-    s_actionSlotMap->insert( "trash", SLOT( trash() ) );
-    s_actionSlotMap->insert( "del", SLOT( del() ) );
-    s_actionSlotMap->insert( "properties", SLOT( properties() ) );
-    s_actionSlotMap->insert( "editMimeType", SLOT( editMimeType() ) );
-    s_actionSlotMap->insert( "print", SLOT( print() ) );
-    // Tricky. Those aren't actions in fact, but simply methods that a browserextension
-    // can have or not. No need to return them here.
-    //s_actionSlotMap->insert( "reparseConfiguration", SLOT( reparseConfiguration() ) );
-    //s_actionSlotMap->insert( "refreshMimeTypes", SLOT( refreshMimeTypes() ) );
-    // nothing for setSaveViewPropertiesLocally either
-
-    // Create the action-number map
-    assert(!s_actionNumberMap);
-    s_actionNumberMap = actionNumberMapsd.setObject( s_actionNumberMap, new ActionNumberMap );
-    ActionSlotMap::ConstIterator it = s_actionSlotMap->begin();
-    ActionSlotMap::ConstIterator itEnd = s_actionSlotMap->end();
-    for ( int i=0 ; it != itEnd ; ++it, ++i )
-    {
-        //kDebug(1202) << " action " << it.key() << " number " << i << endl;
-        s_actionNumberMap->insert( it.key(), i );
-    }
-}
-
 BrowserExtension *BrowserExtension::childObject( QObject *obj )
 {
     return obj ? obj->findChild<KParts::BrowserExtension *>() : 0;
@@ -639,9 +762,8 @@ public:
 }
 
 BrowserHostExtension::BrowserHostExtension( KParts::ReadOnlyPart *parent )
- : QObject( parent )
+ : QObject( parent ), d( new BrowserHostExtensionPrivate )
 {
-  d = new BrowserHostExtensionPrivate;
   d->m_part = parent;
 }
 
@@ -660,7 +782,9 @@ const QList<KParts::ReadOnlyPart*> BrowserHostExtension::frames() const
   return QList<KParts::ReadOnlyPart*>();
 }
 
-bool BrowserHostExtension::openUrlInFrame( const KUrl &, const KParts::URLArgs & )
+bool BrowserHostExtension::openUrlInFrame( const KUrl &,
+                                           const KParts::OpenUrlArguments&,
+                                           const KParts::BrowserArguments & )
 {
   return false;
 }
@@ -668,35 +792,42 @@ bool BrowserHostExtension::openUrlInFrame( const KUrl &, const KParts::URLArgs &
 BrowserHostExtension *BrowserHostExtension::childObject( QObject *obj )
 {
     if ( !obj )
-        return 0L;
+        return 0;
 
     // we try to do it on our own, in hope that we are faster than
     // queryList, which looks kind of big :-)
-    foreach ( QObject * child, obj->children() )
-        if ( child->inherits( "KParts::BrowserHostExtension" ) )
-            return static_cast<KParts::BrowserHostExtension *>( child );
+    foreach ( QObject * child, obj->children() ) {
+        KParts::BrowserHostExtension* ext = qobject_cast<KParts::BrowserHostExtension *>(child);
+        if (ext)
+            return ext;
+    }
 
-    return 0L;
+    return 0;
 }
 
 BrowserHostExtension *
 BrowserHostExtension::findFrameParent(KParts::ReadOnlyPart *callingPart, const QString &frame)
 {
+    Q_UNUSED(callingPart);
+    Q_UNUSED(frame);
     return 0;
 }
 
-LiveConnectExtension::LiveConnectExtension( KParts::ReadOnlyPart *parent ) : QObject( parent) {}
+LiveConnectExtension::LiveConnectExtension( KParts::ReadOnlyPart *parent )
+ : QObject( parent ), d( 0 ) {}
+
+LiveConnectExtension::~LiveConnectExtension() {}
 
 bool LiveConnectExtension::get( const unsigned long, const QString &, Type &, unsigned long &, QString & ) {
     return false;
 }
 
 bool LiveConnectExtension::put( const unsigned long, const QString &, const QString & ) {
-      return false;
+    return false;
 }
 
 bool LiveConnectExtension::call( const unsigned long, const QString &, const QStringList &, Type &, unsigned long &, QString & ) {
-      return false;
+    return false;
 }
 
 void LiveConnectExtension::unregister( const unsigned long ) {}
@@ -704,15 +835,16 @@ void LiveConnectExtension::unregister( const unsigned long ) {}
 LiveConnectExtension *LiveConnectExtension::childObject( QObject *obj )
 {
     if ( !obj )
-        return 0L;
+        return 0;
 
     // we try to do it on our own, in hope that we are faster than
     // queryList, which looks kind of big :-)
-    foreach ( QObject * child, obj->children() )
-        if ( child->inherits( "KParts::LiveConnectExtension" ) )
-            return static_cast<KParts::LiveConnectExtension *>( child );
-
-    return 0L;
+    foreach ( QObject * child, obj->children() ) {
+        KParts::LiveConnectExtension* ext = qobject_cast<KParts::LiveConnectExtension *>( child );
+        if (ext)
+            return ext;
+    }
+    return 0;
 }
 
 #include "browserextension.moc"
