@@ -1,10 +1,10 @@
 #ifndef __browserinterface_h__
 #define __browserinterface_h__
 
-#include <qobject.h>
-#include <qvariant.h>
+#include <QtCore/QObject>
+#include <QtCore/QVariant>
 
-#include <kdelibs_export.h>
+#include <kparts/kparts_export.h>
 
 namespace KParts
 {
@@ -35,7 +35,7 @@ class KPARTS_EXPORT BrowserInterface : public QObject
 {
     Q_OBJECT
 public:
-    BrowserInterface( QObject *parent );
+    explicit BrowserInterface( QObject *parent );
     virtual ~BrowserInterface();
 
     /**
