@@ -24,7 +24,7 @@
 #include <kio/scheduler.h>
 #include <kio/copyjob.h>
 #include <klocale.h>
-#include <kprocess.h>
+#include <kshell.h>
 #include <kstringhandler.h>
 #include <kmimetypetrader.h>
 #include <ktemporaryfile.h>
@@ -38,16 +38,30 @@ class BrowserRun::BrowserRunPrivate
 {
 public:
   bool m_bHideErrorDialog;
+    bool m_bRemoveReferrer;
+    bool m_bTrustedSource;
+    KParts::OpenUrlArguments m_args;
+    KParts::BrowserArguments m_browserArgs;
+
+    KParts::ReadOnlyPart *m_part; // QGuardedPtr?
+    QPointer<QWidget> m_window;
+    QString m_mimeType;
 };
 
-BrowserRun::BrowserRun( const KUrl& url, const KParts::URLArgs& args,
+BrowserRun::BrowserRun( const KUrl& url, const KParts::OpenUrlArguments& args,
+                        const KParts::BrowserArguments& browserArgs,
                         KParts::ReadOnlyPart *part, QWidget* window,
                         bool removeReferrer, bool trustedSource, bool hideErrorDialog )
     : KRun( url, window, 0 /*mode*/, false /*is_local_file known*/, false /* no GUI */ ),
-      m_args( args ), m_part( part ), m_window( window ),
-      m_bRemoveReferrer( removeReferrer ), m_bTrustedSource( trustedSource ),d(new BrowserRunPrivate)
+      d(new BrowserRunPrivate)
 {
   d->m_bHideErrorDialog = hideErrorDialog;
+    d->m_bRemoveReferrer = removeReferrer;
+    d->m_bTrustedSource = trustedSource;
+    d->m_args = args;
+    d->m_browserArgs = browserArgs;
+    d->m_part = part;
+    d->m_window = window;
 }
 
 BrowserRun::~BrowserRun()
@@ -55,13 +69,23 @@ BrowserRun::~BrowserRun()
   delete d;
 }
 
+KParts::ReadOnlyPart* BrowserRun::part() const
+{
+    return d->m_part;
+}
+
+KUrl BrowserRun::url() const
+{
+    return m_strURL;
+}
+
 void BrowserRun::init()
 {
   if ( d->m_bHideErrorDialog )
   {
     // ### KRun doesn't call a virtual method when it finds out that the URL
     // is either malformed, or points to a non-existing local file...
-    // So we need to reimplement some of the checks, to handle m_bHideErrorDialog
+    // So we need to reimplement some of the checks, to handle d->m_bHideErrorDialog
     if ( !m_strURL.isValid() ) {
         redirectToError( KIO::ERR_MALFORMED_URL, m_strURL.url() );
         return;
@@ -73,7 +97,7 @@ void BrowserRun::init()
       struct stat buff;
       if ( stat( QFile::encodeName(m_strURL.path()), &buff ) == -1 )
       {
-        kDebug(1000) << "BrowserRun::init : " << m_strURL.prettyUrl() << " doesn't exist." << endl;
+        kDebug(1000) << "BrowserRun::init:" << m_strURL << "doesn't exist.";
         redirectToError( KIO::ERR_DOES_NOT_EXIST, m_strURL.path() );
         return;
       }
@@ -85,7 +109,7 @@ void BrowserRun::init()
 
 void BrowserRun::scanFile()
 {
-  kDebug(1000) << "BrowserRun::scanfile " << m_strURL.prettyUrl() << endl;
+  kDebug(1000) << "BrowserRun::scanfile" << m_strURL;
 
   // Let's check for well-known extensions
   // Not when there is a query in the URL, in any case.
@@ -96,44 +120,43 @@ void BrowserRun::scanFile()
     assert( mime );
     if ( mime->name() != "application/octet-stream" || m_bIsLocalFile )
     {
-      kDebug(1000) << "Scanfile: MIME TYPE is " << mime->name() << endl;
+      kDebug(1000) << "Scanfile: MIME TYPE is" << mime->name();
       foundMimeType( mime->name() );
       return;
     }
   }
 
-  if ( m_part )
-  {
-      QString proto = m_part->url().protocol().toLower();
+    QMap<QString, QString>& metaData = d->m_args.metaData();
+    if ( d->m_part ) {
+        const QString proto = d->m_part->url().protocol().toLower();
 
       if (proto == "https" || proto == "webdavs") {
-          m_args.metaData().insert("main_frame_request", "TRUE" );
-          m_args.metaData().insert("ssl_was_in_use", "TRUE" );
-          m_args.metaData().insert("ssl_activate_warnings", "TRUE" );
+            metaData.insert("main_frame_request", "TRUE" );
+            metaData.insert("ssl_was_in_use", "TRUE" );
+            metaData.insert("ssl_activate_warnings", "TRUE" );
       } else if (proto == "http" || proto == "webdav") {
-          m_args.metaData().insert("ssl_activate_warnings", "TRUE" );
-          m_args.metaData().insert("ssl_was_in_use", "FALSE" );
+            metaData.insert("ssl_activate_warnings", "TRUE" );
+            metaData.insert("ssl_was_in_use", "FALSE" );
       }
 
       // Set the PropagateHttpHeader meta-data if it has not already been set...
-      if (!m_args.metaData().contains("PropagateHttpHeader"))
-          m_args.metaData().insert("PropagateHttpHeader", "TRUE");
+        if (!metaData.contains("PropagateHttpHeader"))
+            metaData.insert("PropagateHttpHeader", "TRUE");
   }
 
   KIO::TransferJob *job;
-  if ( m_args.doPost() && m_strURL.protocol().startsWith("http"))
-  {
-      job = KIO::http_post( m_strURL, m_args.postData, false );
-      job->addMetaData( "content-type", m_args.contentType() );
+    if ( d->m_browserArgs.doPost() && m_strURL.protocol().startsWith("http")) {
+        job = KIO::http_post( m_strURL, d->m_browserArgs.postData, false );
+        job->addMetaData( "content-type", d->m_browserArgs.contentType() );
+    } else {
+        job = KIO::get(m_strURL, d->m_args.reload(), false);
   }
-  else
-      job = KIO::get(m_strURL, m_args.reload, false);
 
-  if ( m_bRemoveReferrer )
-     m_args.metaData().remove("referrer");
+    if ( d->m_bRemoveReferrer )
+        metaData.remove("referrer");
 
-  job->addMetaData( m_args.metaData() );
-  job->ui()->setWindow( m_window );
+    job->addMetaData( metaData );
+    job->ui()->setWindow( d->m_window );
   connect( job, SIGNAL( result( KJob *)),
            this, SLOT( slotBrowserScanFinished(KJob *)));
   connect( job, SIGNAL( mimetype( KIO::Job *, const QString &)),
@@ -143,13 +166,13 @@ void BrowserRun::scanFile()
 
 void BrowserRun::slotBrowserScanFinished(KJob *job)
 {
-  kDebug(1000) << "BrowserRun::slotBrowserScanFinished" << endl;
+  kDebug(1000) << "BrowserRun::slotBrowserScanFinished";
   if ( job->error() == KIO::ERR_IS_DIRECTORY )
   {
       // It is in fact a directory. This happens when HTTP redirects to FTP.
       // Due to the "protocol doesn't support listing" code in BrowserRun, we
       // assumed it was a file.
-      kDebug(1000) << "It is in fact a directory!" << endl;
+      kDebug(1000) << "It is in fact a directory!";
       // Update our URL in case of a redirection
       m_strURL = static_cast<KIO::TransferJob *>(job)->url();
       m_job = 0;
@@ -169,16 +192,16 @@ void BrowserRun::slotBrowserMimetype( KIO::Job *_job, const QString &type )
   Q_ASSERT( _job == m_job );
   KIO::TransferJob *job = static_cast<KIO::TransferJob *>(m_job);
   // Update our URL in case of a redirection
-  //kDebug(1000) << "old URL=" << m_strURL.url() << endl;
-  //kDebug(1000) << "new URL=" << job->url().url() << endl;
+  //kDebug(1000) << "old URL=" << m_strURL;
+  //kDebug(1000) << "new URL=" << job->url();
   m_strURL = job->url();
-  kDebug(1000) << "slotBrowserMimetype: found " << type << " for " << m_strURL.prettyUrl() << endl;
+  kDebug(1000) << "slotBrowserMimetype: found" << type << "for" << m_strURL;
 
   // Suggested filename given by the server (e.g. HTTP content-disposition)
   // When set, we should really be saving instead of embedding
   const QString suggestedFileName = job->queryMetaData("content-disposition");
   setSuggestedFileName(suggestedFileName); // store it (in KRun)
-  //kDebug(1000) << "suggestedFileName=" << suggestedFileName << endl;
+  //kDebug(1000) << "suggestedFileName=" << suggestedFileName;
 
   // Make a copy to avoid a dead reference
   QString _type = type;
@@ -198,19 +221,19 @@ BrowserRun::NonEmbeddableResult BrowserRun::handleNonEmbeddable( const QString&
     {
         if ( isTextExecutable(mimeType) )
             mimeType = QLatin1String("text/plain"); // view, don't execute
-        kDebug(1000) << "BrowserRun: ask for saving" << endl;
+        kDebug(1000) << "BrowserRun: ask for saving";
         KService::Ptr offer = KMimeTypeTrader::self()->preferredService(mimeType, "Application");
         // ... -> ask whether to save
         KParts::BrowserRun::AskSaveResult res = askSave( m_strURL, offer, mimeType, suggestedFileName() );
         if ( res == KParts::BrowserRun::Save ) {
             save( m_strURL, suggestedFileName() );
-            kDebug(1000) << "BrowserRun::handleNonEmbeddable: Save: returning Handled" << endl;
+            kDebug(1000) << "BrowserRun::handleNonEmbeddable: Save: returning Handled";
             m_bFinished = true;
             return Handled;
         }
         else if ( res == KParts::BrowserRun::Cancel ) {
             // saving done or canceled
-            kDebug(1000) << "BrowserRun::handleNonEmbeddable: Cancel: returning Handled" << endl;
+            kDebug(1000) << "BrowserRun::handleNonEmbeddable: Cancel: returning Handled";
             m_bFinished = true;
             return Handled;
         }
@@ -218,10 +241,10 @@ BrowserRun::NonEmbeddableResult BrowserRun::handleNonEmbeddable( const QString&
         {
             // If we were in a POST, we can't just pass a URL to an external application.
             // We must save the data to a tempfile first.
-            if ( m_args.doPost() )
+            if ( d->m_browserArgs.doPost() )
             {
-                kDebug(1000) << "BrowserRun: request comes from a POST, can't pass a URL to another app, need to save" << endl;
-                m_sMimeType = mimeType;
+                kDebug(1000) << "BrowserRun: request comes from a POST, can't pass a URL to another app, need to save";
+                d->m_mimeType = mimeType;
                 QString extension;
                 QString fileName = suggestedFileName().isEmpty() ? m_strURL.fileName() : suggestedFileName();
                 int extensionPos = fileName.lastIndexOf( '.' );
@@ -234,16 +257,16 @@ BrowserRun::NonEmbeddableResult BrowserRun::handleNonEmbeddable( const QString&
                 KUrl destURL;
                 destURL.setPath( tempFile.fileName() );
                 KIO::Job *job = KIO::file_copy( m_strURL, destURL, 0600, true /*overwrite*/, false /*no resume*/, true /*progress info*/ );
-                job->ui()->setWindow (m_window);
-                connect( job, SIGNAL( result( KJob *)),
-                         this, SLOT( slotCopyToTempFileResult(KJob *)) );
+                job->ui()->setWindow(d->m_window);
+                connect( job, SIGNAL(result(KJob *)),
+                         this, SLOT(slotCopyToTempFileResult(KJob *)) );
                 return Delayed; // We'll continue after the job has finished
             }
         }
     }
 
     // Check if running is allowed
-    if ( !m_bTrustedSource && // ... and untrusted source...
+    if ( !d->m_bTrustedSource && // ... and untrusted source...
          !allowExecution( mimeType, m_strURL ) ) // ...and the user said no (for executables etc.)
     {
         m_bFinished = true;
@@ -263,7 +286,8 @@ bool BrowserRun::allowExecution( const QString &mimeType, const KUrl &url )
     if ( !url.isLocalFile() ) // Don't permit to execute remote files
         return false;
 
-    return ( KMessageBox::warningContinueCancel( 0, i18n( "Do you really want to execute '%1'? " ,  url.prettyUrl() ),
+    return ( KMessageBox::warningContinueCancel( 0,
+                                                 i18n( "Do you really want to execute '%1'?", url.prettyUrl() ),
     i18n("Execute File?"), KGuiItem(i18n("Execute")) ) == KMessageBox::Continue );
 }
 
@@ -275,7 +299,7 @@ static QString makeQuestion( const KUrl& url, const QString& mimeType, const QSt
 
     // Test if the mimeType is not recognize as octet-stream.
     // If so then keep mime-type as comment
-    if (mime->name() != KMimeType::defaultMimeType()) {
+    if (mime && mime->name() != KMimeType::defaultMimeType()) {
         // The mime-type is known so display the comment instead of mime-type
         comment = mime->comment();
     }
@@ -288,6 +312,7 @@ static QString makeQuestion( const KUrl& url, const QString& mimeType, const QSt
 }
 
 //static
+// TODO should take a QWidget* parent argument
 BrowserRun::AskSaveResult BrowserRun::askSave( const KUrl & url, KService::Ptr offer, const QString& mimeType, const QString & suggestedFileName )
 {
     // SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC
@@ -302,8 +327,8 @@ BrowserRun::AskSaveResult BrowserRun::askSave( const KUrl & url, KService::Ptr o
                        : i18n("&Open With...");
 
     int choice = KMessageBox::questionYesNoCancel(
-        0L, question, url.host(),
-        KStandardGuiItem::saveAs(), KGuiItem(openText),
+        0, question, url.host(),
+        KStandardGuiItem::saveAs(), KGuiItem(openText), KStandardGuiItem::cancel(),
         QLatin1String("askSave")+ mimeType ); // dontAskAgainName, KEEP IN SYNC!!!
 
     return choice == KMessageBox::Yes ? Save : ( choice == KMessageBox::No ? Open : Cancel );
@@ -311,6 +336,7 @@ BrowserRun::AskSaveResult BrowserRun::askSave( const KUrl & url, KService::Ptr o
 }
 
 //static
+// TODO should take a QWidget* parent argument
 BrowserRun::AskSaveResult BrowserRun::askEmbedOrSave( const KUrl & url, const QString& mimeType, const QString & suggestedFileName, int /*flags*/ )
 {
     // SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC
@@ -328,7 +354,7 @@ BrowserRun::AskSaveResult BrowserRun::askEmbedOrSave( const KUrl & url, const QS
     // - other strange 'internal' mimetypes like print/manager...
     // KEEP IN SYNC!!!
     if ( mime->is( "text/html" ) ||
-         mime->is( "text/xml" ) ||
+         mime->is( "application/xml" ) ||
          mime->is( "inode/directory" ) ||
          mimeType.startsWith( "image" ) ||
          mime->is( "multipart/x-mixed-replace" ) ||
@@ -338,9 +364,10 @@ BrowserRun::AskSaveResult BrowserRun::askEmbedOrSave( const KUrl & url, const QS
 
     QString question = makeQuestion( url, mimeType, suggestedFileName );
 
+    // don't use KStandardGuiItem::open() here which has trailing ellipsis!
     int choice = KMessageBox::questionYesNoCancel(
-        0L, question, url.host(),
-        KStandardGuiItem::saveAs(), KStandardGuiItem::open(),
+        0, question, url.host(),
+        KStandardGuiItem::saveAs(), KGuiItem( i18n( "&Open" ), "document-open"), KStandardGuiItem::cancel(),
         QLatin1String("askEmbedOrSave")+ mimeType ); // dontAskAgainName, KEEP IN SYNC!!!
     return choice == KMessageBox::Yes ? Save : ( choice == KMessageBox::No ? Open : Cancel );
     // SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC
@@ -349,7 +376,7 @@ BrowserRun::AskSaveResult BrowserRun::askEmbedOrSave( const KUrl & url, const QS
 // Default implementation, overridden in KHTMLRun
 void BrowserRun::save( const KUrl & url, const QString & suggestedFileName )
 {
-    simpleSave( url, suggestedFileName, m_window );
+    simpleSave( url, suggestedFileName, d->m_window );
 }
 
 void BrowserRun::simpleSave( const KUrl & url, const QString & suggestedFileName,
@@ -361,13 +388,12 @@ void BrowserRun::simpleSave( const KUrl & url, const QString & suggestedFileName
     // only use the downloadmanager for non-local urls
     if ( !url.isLocalFile() )
     {
-        KConfig cfg("konquerorrc", false, false);
-        cfg.setGroup("HTML Settings");
+        KConfigGroup cfg = KSharedConfig::openConfig("konquerorrc", KConfig::NoGlobals)->group("HTML Settings");
         QString downloadManger = cfg.readPathEntry("DownloadManager");
         if (!downloadManger.isEmpty())
         {
             // then find the download manager location
-            kDebug(1000) << "Using: "<<downloadManger <<" as Download Manager" <<endl;
+            kDebug(1000) << "Using: "<<downloadManger <<" as Download Manager";
             QString cmd=KStandardDirs::findExe(downloadManger);
             if (cmd.isEmpty())
             {
@@ -383,14 +409,14 @@ void BrowserRun::simpleSave( const KUrl & url, const QString & suggestedFileName
                 // the duplicated code) with shiny new KDownload class for 3.2 (pfeiffer)
                 // Until the shiny new class comes about, send the suggestedFileName
                 // along with the actual URL to download. (DA)
-                cmd += " " + KProcess::quote(url.url());
+                cmd += " " + KShell::quoteArg(url.url());
                 if ( !suggestedFileName.isEmpty() )
-                    cmd +=" " + KProcess::quote(suggestedFileName);
+                    cmd +=" " + KShell::quoteArg(suggestedFileName);
 
-                kDebug(1000) << "Calling command  " << cmd << endl;
+                kDebug(1000) << "Calling command" << cmd;
                 // slave is already on hold (slotBrowserMimetype())
                 KIO::Scheduler::publishSlaveOnHold();
-                KRun::runCommand(cmd);
+                KRun::runCommand(cmd, window);
                 return;
             }
         }
@@ -419,7 +445,7 @@ void BrowserRun::simpleSave( const KUrl & url, const QString & suggestedFileName
 void BrowserRun::slotStatResult( KJob *job )
 {
     if ( job->error() ) {
-        kDebug(1000) << "BrowserRun::slotStatResult : " << job->errorString() << endl;
+        kDebug(1000) << "BrowserRun::slotStatResult:" << job->errorString();
         handleError( job );
     } else
         KRun::slotStatResult( job );
@@ -428,7 +454,7 @@ void BrowserRun::slotStatResult( KJob *job )
 void BrowserRun::handleError( KJob * job )
 {
     if ( !job ) { // Shouldn't happen, see docu.
-        kWarning(1000) << "BrowserRun::handleError called with job=0! hideErrorDialog=" << d->m_bHideErrorDialog << endl;
+        kWarning(1000) << "BrowserRun::handleError called with job=0! hideErrorDialog=" << d->m_bHideErrorDialog;
         return;
     }
 
@@ -462,7 +488,7 @@ void BrowserRun::redirectToError( int error, const QString& errorText )
     KUrl::List lst;
     lst << newURL << m_strURL;
     m_strURL = KUrl::join( lst );
-    //kDebug(1202) << "BrowserRun::handleError m_strURL=" << m_strURL.prettyUrl() << endl;
+    //kDebug(1202) << "BrowserRun::handleError m_strURL=" << m_strURL;
 
     m_job = 0;
     foundMimeType( "text/html" );
@@ -474,7 +500,7 @@ void BrowserRun::slotCopyToTempFileResult(KJob *job)
 	    job->uiDelegate()->showErrorMessage();
     } else {
         // Same as KRun::foundMimeType but with a different URL
-        (void) (KRun::runUrl( static_cast<KIO::FileCopyJob *>(job)->destUrl(), m_sMimeType, m_window ));
+        (void) (KRun::runUrl( static_cast<KIO::FileCopyJob *>(job)->destUrl(), d->m_mimeType, d->m_window ));
     }
     m_bFault = true; // see above
     m_bFinished = true;
@@ -492,4 +518,14 @@ bool BrowserRun::hideErrorDialog() const
     return d->m_bHideErrorDialog;
 }
 
+KParts::OpenUrlArguments& KParts::BrowserRun::arguments()
+{
+    return d->m_args;
+}
+
+KParts::BrowserArguments& KParts::BrowserRun::browserArguments()
+{
+    return d->m_browserArgs;
+}
+
 #include "browserrun.moc"
