@@ -17,47 +17,52 @@
    Boston, MA 02110-1301, USA.
 */
 
-#include <QSet>
+#include "historyprovider.h"
+
+#include <QtCore/QSet>
 
 #include <kapplication.h>
 
-#include "historyprovider.h"
-#include <kstaticdeleter.h>
-
 using namespace KParts;
 
-HistoryProvider * HistoryProvider::s_self = 0L;
-static KStaticDeleter<HistoryProvider> historyProviderSd;
-
-class HistoryProvider::HistoryProviderPrivate
+class KParts::HistoryProviderPrivate
 {
 public:
+    HistoryProviderPrivate()
+        : q(0)
+    {
+    }
+
+    ~HistoryProviderPrivate()
+    {
+        delete q;
+    }
+
     QSet<QString> dict;
+    HistoryProvider *q;
 };
 
+K_GLOBAL_STATIC(HistoryProviderPrivate, historyProviderPrivate)
+
 HistoryProvider * HistoryProvider::self()
 {
-    if ( !s_self ) {
-        historyProviderSd.setObject( s_self, new HistoryProvider() );
-        s_self->setObjectName( "history provider" );
+    if (!historyProviderPrivate->q) {
+        new HistoryProvider;
     }
-    return s_self;
+
+    return historyProviderPrivate->q;
 }
 
 HistoryProvider::HistoryProvider( QObject *parent )
-    : QObject( parent ),d(new HistoryProviderPrivate)
+    : QObject( parent ), d(historyProviderPrivate)
 {
-    if ( !s_self )
-	s_self = this;
-
+    Q_ASSERT(!historyProviderPrivate->q);
+    historyProviderPrivate->q = this;
+    setObjectName("history provider");
 }
 
 HistoryProvider::~HistoryProvider()
 {
-    delete d;
-
-    if ( s_self == this )
-	s_self = 0;
 }
 
 bool HistoryProvider::contains( const QString& item ) const
