@@ -26,7 +26,7 @@
 #include <kstatusbar.h>
 #include <khelpmenu.h>
 #include <kstandarddirs.h>
-#include <qapplication.h>
+#include <QtGui/QApplication>
 #include <kxmlguifactory.h>
 
 #include <kdebug.h>
@@ -57,13 +57,13 @@ public:
 }
 
 MainWindow::MainWindow( QWidget* parent, Qt::WindowFlags f )
-    : KMainWindow( parent, f ), d(new MainWindowPrivate())
+    : KXmlGuiWindow( parent, f ), d(new MainWindowPrivate())
 {
   PartBase::setPartObject( this );
 }
 
 MainWindow::MainWindow( QWidget* parent, const char *name, Qt::WindowFlags f )
-  : KMainWindow( parent, f ),d(new MainWindowPrivate())
+  : KXmlGuiWindow( parent, f ),d(new MainWindowPrivate())
 {
   setObjectName( name );
   PartBase::setPartObject( this );
@@ -124,8 +124,10 @@ void MainWindow::createGUI( Part * part )
     GUIActivateEvent ev( true );
     QApplication::sendEvent( part, &ev );
 
-    if ( autoSaveSettings() )
-        applyMainWindowSettings(KGlobal::config().data(), autoSaveGroup());
+    if ( autoSaveSettings() ) {
+        KConfigGroup cg(KGlobal::config(), autoSaveGroup());
+        applyMainWindowSettings(cg);
+    }
   }
 
   //setUpdatesEnabled( true );
@@ -174,7 +176,8 @@ void MainWindow::createShellGUI( bool create )
 void KParts::MainWindow::saveNewToolbarConfig()
 {
     createGUI( d->m_activePart );
-    applyMainWindowSettings(KGlobal::config().data());
+    KConfigGroup cg(KGlobal::config(), QByteArray());
+    applyMainWindowSettings(cg);
 }
 
 #include "mainwindow.moc"
