@@ -3,9 +3,9 @@
 #include "parts.h"
 #include "notepad.h"
 
-#include <qsplitter.h>
-#include <qcheckbox.h>
-#include <qdir.h>
+#include <QtGui/QSplitter>
+#include <QtGui/QCheckBox>
+#include <QtCore/QDir>
 #include <kcmdlineargs.h>
 #include <kiconloader.h>
 #include <kstandarddirs.h>
@@ -57,7 +57,7 @@ Shell::Shell()
     KAction * paQuit = new KAction( "&Quit", this );
     coll->addAction( "shell_quit", paQuit );
     connect(paQuit, SIGNAL(triggered()), this, SLOT(close()));
-    paQuit->setIcon(KIcon("exit"));
+    paQuit->setIcon(KIcon("application-exit"));
 
 //  (void)new KAction( "Yet another menu item", coll, "shell_yami" );
 //  (void)new KAction( "Yet another submenu item", coll, "shell_yasmi" );
@@ -93,11 +93,11 @@ void Shell::slotFileOpenRemote()
 void Shell::embedEditor()
 {
     if ( m_manager->activePart() == m_part2 )
-        createGUI( 0L );
+        createGUI( 0 );
 
     // replace part2 with the editor part
     delete m_part2;
-    m_part2 = 0L;
+    m_part2 = 0;
     m_editorpart = new NotepadPart( m_splitter, this );
     m_editorpart->setReadWrite(); // read-write mode
     m_manager->addPart( m_editorpart );
@@ -115,10 +115,10 @@ void Shell::slotFileCloseEditor()
 
     // Is this necessary ? (David)
     if ( m_manager->activePart() == m_editorpart )
-        createGUI( 0L );
+        createGUI( 0 );
 
     delete m_editorpart;
-    m_editorpart = 0L;
+    m_editorpart = 0;
     m_part2 = new Part2(this, m_splitter);
     m_manager->addPart( m_part2 );
     m_paEditFile->setEnabled(true);
@@ -136,7 +136,7 @@ void Shell::slotFileEdit()
 
 int main( int argc, char **argv )
 {
-    KCmdLineArgs::init( argc, argv, "kpartstest",0,0,0,0 );
+    KCmdLineArgs::init( argc, argv, "kpartstest", 0, ki18n("kpartstest"), 0);
     KApplication app;
 
     Shell *shell = new Shell;
