@@ -9,9 +9,9 @@
 #include <kcmdlineargs.h>
 #include <klibloader.h>
 
-#include <qwidget.h>
-#include <qdir.h>
-#include <qfile.h>
+#include <QtGui/QWidget>
+#include <QtCore/QDir>
+#include <QtCore/QFile>
 
 #include <kparts/componentfactory.h>
 
@@ -25,11 +25,11 @@ Shell::Shell()
     KGlobal::dirs()->addResourceDir( "data", KDESRCDIR );
     setXMLFile( "ghostviewtest_shell.rc" );
 
-    KAction * paOpen = new KAction( KIcon("fileopen"), "&Open file", this );
+    KAction * paOpen = new KAction( KIcon("document-open"), "&Open file", this );
     actionCollection()->addAction( "file_open", paOpen );
     connect( paOpen, SIGNAL(triggered()), this, SLOT(slotFileOpen()) );
 
-    KAction * paQuit = new KAction( KIcon("exit"), "&Quit", this );
+    KAction * paQuit = new KAction( KIcon("application-exit"), "&Quit", this );
     actionCollection()->addAction( "file_quit", paQuit );
     connect(paQuit, SIGNAL(triggered()), this, SLOT(close()));
 
@@ -86,17 +86,15 @@ void Shell::slotFileOpen()
         openUrl( url );
 }
 
-static KCmdLineOptions options[] =
-{
-    { "+file(s)",          "Files to load", 0 },
-    KCmdLineLastOption
-};
-static const char version[] = "v0.0.1 2000 (c) David Faure";
-static const char description[] = "This is a test shell for the kghostview part.";
-
 int main( int argc, char **argv )
 {
-    KCmdLineArgs::init(argc, argv, "ghostviewtest","ghostviewtest", description, version);
+    KCmdLineOptions options;
+    options.add("+file(s)", ki18n("Files to load"));
+
+    const char version[] = "v0.0.1 2000 (c) David Faure";
+    KLocalizedString description = ki18n("This is a test shell for the kghostview part.");
+
+    KCmdLineArgs::init(argc, argv, "ghostviewtest", 0, ki18n("ghostviewtest"), version, description);
     KCmdLineArgs::addCmdLineOptions( options ); // Add my own options.
     KApplication app;
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
