@@ -3,10 +3,10 @@
 #include <kparts/partmanager.h>
 #include <kparts/mainwindow.h>
 
-#include <qsplitter.h>
-#include <qfile.h>
-#include <qtextstream.h>
-#include <QTextEdit>
+#include <QtGui/QSplitter>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
+#include <QtGui/QTextEdit>
 
 #include <kaboutdata.h>
 #include <kapplication.h>
@@ -57,13 +57,13 @@ void NotepadPart::setReadWrite( bool rw )
 
 KAboutData* NotepadPart::createAboutData()
 {
-  return new KAboutData( "notepadpart", I18N_NOOP( "Notepad" ), "2.0" );
+  return new KAboutData( "notepadpart", 0, ki18n( "Notepad" ), "2.0" );
 }
 
 bool NotepadPart::openFile()
 {
-  kDebug() << "NotepadPart: opening " << m_file << endl;
-  QFile f(m_file);
+  kDebug() << "NotepadPart: opening " << localFilePath();
+  QFile f(localFilePath());
   QString s;
   if ( f.open(QIODevice::ReadOnly) ) {
     QTextStream t( &f );
@@ -73,7 +73,7 @@ bool NotepadPart::openFile()
   }
   m_edit->setPlainText(s);
 
-  emit setStatusBarText( m_url.prettyUrl() );
+  emit setStatusBarText( url().prettyUrl() );
 
   return true;
 }
@@ -82,7 +82,7 @@ bool NotepadPart::saveFile()
 {
   if ( !isReadWrite() )
     return false;
-  QFile f(m_file);
+  QFile f(localFilePath());
   QString s;
   if ( f.open(QIODevice::WriteOnly) ) {
     QTextStream t( &f );
