@@ -3,12 +3,12 @@
 
 #include "parts.h"
 
-#include <qcheckbox.h>
-#include <qfile.h>
-#include <qdir.h>
-#include <qtextstream.h>
-#include <QTextEdit>
-#include <qlineedit.h>
+#include <QtGui/QCheckBox>
+#include <QtCore/QFile>
+#include <QtCore/QDir>
+#include <QtCore/QTextStream>
+#include <QtGui/QTextEdit>
+#include <QtGui/QLineEdit>
 
 #include <kiconloader.h>
 #include <kapplication.h>
@@ -41,9 +41,9 @@ Part1::~Part1()
 
 bool Part1::openFile()
 {
-    kDebug() << "Part1: opening " << QFile::encodeName(m_file) << endl;
+    kDebug() << "Part1: opening " << QFile::encodeName(localFilePath());
     // Hehe this is from a tutorial I did some time ago :)
-    QFile f(m_file);
+    QFile f(localFilePath());
     QString s;
     if ( f.open(QIODevice::ReadOnly) ) {
         QTextStream t( &f );
@@ -55,7 +55,7 @@ bool Part1::openFile()
         return false;
     m_edit->setPlainText(s);
 
-    emit setStatusBarText( m_url.prettyUrl() );
+    emit setStatusBarText( url().prettyUrl() );
 
     return true;
 }
