@@ -1,5 +1,5 @@
 #include "notepad.h" // this plugin applies to a notepad part
-#include <QTextEdit>
+#include <QtGui/QTextEdit>
 #include "plugin_spellcheck.h"
 #include <kaction.h>
 #include <kactioncollection.h>
@@ -23,10 +23,10 @@ PluginSpellCheck::~PluginSpellCheck()
 
 void PluginSpellCheck::slotSpellCheck()
 {
-    kDebug() << "Plugin parent : " << parent()->objectName() << " (" << parent()->metaObject()->className() << ")" << endl;
+    kDebug() << "Plugin parent : " << parent()->objectName() << " (" << parent()->metaObject()->className() << ")";
     // The parent is assumed to be a NotepadPart
     if ( !parent()->inherits("NotepadPart") )
-       KMessageBox::error(0L,"You just called the spell-check action on a wrong part (not NotepadPart)");
+       KMessageBox::error(0,"You just called the spell-check action on a wrong part (not NotepadPart)");
     else
     {
          NotepadPart * part = (NotepadPart *) parent();
