@@ -17,18 +17,21 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include <qapplication.h>
-#include <qcursor.h>
-#include <qdatastream.h>
-#include <qevent.h>
-#include <qfileinfo.h>
-#include <qframe.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qpoint.h>
-#include <qtextstream.h>
+#include "kcmoduleproxy.h"
+#include "kcmoduleproxy_p.h"
 
-#include <qwidget.h>
+#include <QtGui/QApplication>
+#include <QtGui/QCursor>
+#include <QtCore/QDataStream>
+#include <QtGui/QKeyEvent>
+#include <QtCore/QFileInfo>
+#include <QtGui/QFrame>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtCore/QPoint>
+#include <QtCore/QTextStream>
+
+#include <QtGui/QImage>
 
 #include <QtDBus/QtDBus>
 
@@ -48,47 +51,8 @@
 
 #include <kcmoduleloader.h>
 
-#include "kcmoduleproxy.h"
 #include "ksettingswidgetadaptor.h"
 
-/***************************************************************/
-class KCModuleProxy::Private
-{
-	public:
-		Private( const KCModuleInfo & info, KCModuleProxy* _parent )
-			: kcm( 0 )
-			//, view( 0 )
-			, topLayout( 0 )
-			, rootInfo( 0 )
-			, modInfo( info )
-			, changed( false )
-			, bogusOccupier( false )
-			, parent( _parent )
-		{}
-
-		~Private()
-		{
-			delete rootInfo; // Delete before embedWidget!
-			delete kcm;
-		}
-
-		void loadModule();
-
-		QStringList args;
-		KCModule *kcm;
-		QVBoxLayout *topLayout; /* Contains QScrollView view, and root stuff */
-		QLabel *rootInfo;
-		QString dbusService;
-		QString dbusPath;
-		KCModuleInfo modInfo;
-		bool changed;
-		bool bogusOccupier;
-		KCModuleProxy* parent;
-};
-/***************************************************************/
-
-
-
 /*
  TODO:
 
@@ -106,6 +70,7 @@ class KCModuleProxy::Private
 /***************************************************************/
 KCModule* KCModuleProxy::realModule() const
 {
+    Q_D(const KCModuleProxy);
 	/*
 	 * Note, don't call any function that calls realModule() since
 	 * that leads to an infinite loop.
@@ -115,13 +80,13 @@ KCModule* KCModuleProxy::realModule() const
 	if( !d->kcm )
 	{
 		QApplication::setOverrideCursor( Qt::WaitCursor );
-		d->loadModule();
+        const_cast<KCModuleProxyPrivate *>(d)->loadModule();
 		QApplication::restoreOverrideCursor();
 	}
 	return d->kcm;
 }
 
-void KCModuleProxy::Private::loadModule()
+void KCModuleProxyPrivate::loadModule()
 {
 	if( !topLayout )
 	{
@@ -137,12 +102,12 @@ void KCModuleProxy::Private::loadModule()
 	if( QDBusConnection::sessionBus().registerService( dbusService ) || bogusOccupier )
 	{ /* We got the name we requested, because no one was before us,
 	   * or, it was an random application which had picked that name */
-		kDebug(711) << "Module not already loaded, loading module " << modInfo.moduleName() << " from library " << modInfo.library() << " using symbol " << modInfo.handle() << endl;
+		kDebug(711) << "Module not already loaded, loading module " << modInfo.moduleName() << " from library " << modInfo.library() << " using symbol " << modInfo.handle();
 
 		kcm = KCModuleLoader::loadModule( modInfo, KCModuleLoader::Inline, parent, args );
 
-		QObject::connect( kcm, SIGNAL(changed(bool)), parent, SLOT(moduleChanged(bool)) );
-		QObject::connect( kcm, SIGNAL(destroyed()), parent, SLOT(moduleDestroyed()) );
+        QObject::connect(kcm, SIGNAL(changed(bool)), parent, SLOT(_k_moduleChanged(bool)));
+        QObject::connect(kcm, SIGNAL(destroyed()), parent, SLOT(_k_moduleDestroyed()));
 		QObject::connect( kcm, SIGNAL(quickHelpChanged()), parent, SIGNAL(quickHelpChanged()) );
 		parent->setWhatsThis( kcm->quickHelp() );
 
@@ -180,7 +145,7 @@ void KCModuleProxy::Private::loadModule()
 	}
 	else
 	{
-		kDebug(711) << "Module already loaded, loading KCMError" << endl;
+		kDebug(711) << "Module already loaded, loading KCMError";
 
 		/* Figure out the name of where the module is already loaded */
 		QDBusInterface proxy( dbusService, dbusPath, "org.kde.internal.KSettingsWidget" );
@@ -189,7 +154,7 @@ void KCModuleProxy::Private::loadModule()
 		if( reply.isValid() )
 		{
 			QObject::connect( QDBusConnection::sessionBus().interface(), SIGNAL(serviceOwnerChanged(QString,QString,QString)),
-					parent, SLOT(ownerChanged(QString,QString,QString)) );
+                    parent, SLOT(_k_ownerChanged(QString,QString,QString)));
 			kcm = KCModuleLoader::reportError( KCModuleLoader::Inline,
 					i18nc( "Argument is application name", "This configuration section is "
 						"already opened in %1" ,  reply.value() ), " ", parent );
@@ -197,30 +162,33 @@ void KCModuleProxy::Private::loadModule()
 		}
 		else
 		{
-			kDebug(711) << "Calling KCModuleProxy's DBus interface for fetching the name failed." << endl;
+			kDebug(711) << "Calling KCModuleProxy's DBus interface for fetching the name failed.";
 			bogusOccupier = true;
 			loadModule();
 		}
 	}
 }
 
-void KCModuleProxy::ownerChanged( const QString & service, const QString &oldOwner, const QString &)
+void KCModuleProxyPrivate::_k_ownerChanged(const QString &service, const QString &oldOwner, const QString &)
 {
-	if( service == d->dbusService && !oldOwner.isEmpty() )
-	{
-		/* Violence: Get rid of KCMError & CO, so that
-		 * realModule() attempts to reload the module */
-		delete d->kcm;
-		d->kcm = 0;
-		realModule();
-		d->kcm->show();
-	}
+    if (service == dbusService && !oldOwner.isEmpty()) {
+        // Violence: Get rid of KCMError & CO, so that
+        // realModule() attempts to reload the module
+        delete kcm;
+        kcm = 0;
+        Q_Q(KCModuleProxy);
+        q->realModule();
+
+        Q_ASSERT(kcm);
+        kcm->show();
+    }
 }
 
 void KCModuleProxy::showEvent( QShowEvent * ev )
 {
+    Q_D(KCModuleProxy);
 
-	kDebug(711) << k_funcinfo << endl;
+	kDebug(711) ;
 	( void )realModule();
 
 	/* We have no kcm, if we're in root mode */
@@ -236,91 +204,80 @@ KCModuleProxy::~KCModuleProxy()
 	deleteClient();
 	KCModuleLoader::unloadModule(moduleInfo());
 
-	delete d;
+	delete d_ptr;
 }
 
 void KCModuleProxy::deleteClient()
 {
+    Q_D(KCModuleProxy);
 	delete d->kcm;
 	d->kcm = 0;
 
 	kapp->syncX();
 }
 
-void KCModuleProxy::moduleChanged( bool c )
+void KCModuleProxyPrivate::_k_moduleChanged(bool c)
 {
-	if(  d->changed == c )
-		return;
+    if(changed == c) {
+        return;
+    }
 
-	d->changed = c;
-	emit changed( c );
-	emit changed( this );
+    Q_Q(KCModuleProxy);
+    changed = c;
+    emit q->changed(c);
+    emit q->changed(this);
 }
 
-void KCModuleProxy::moduleDestroyed()
+void KCModuleProxyPrivate::_k_moduleDestroyed()
 {
-	d->kcm = 0;
+    kcm = 0;
 }
 
 KCModuleProxy::KCModuleProxy( const KService::Ptr& service, QWidget * parent,
 		const QStringList& args )
-	: QWidget( parent )
+    : QWidget(parent), d_ptr(new KCModuleProxyPrivate(this, KCModuleInfo(service), args))
 {
-	init( KCModuleInfo( service ));
-	d->args = args;
+    d_ptr->q_ptr = this;
 }
 
 KCModuleProxy::KCModuleProxy( const KCModuleInfo& info, QWidget * parent,
 		const QStringList& args )
-	: QWidget( parent )
+    : QWidget(parent), d_ptr(new KCModuleProxyPrivate(this, info, args))
 {
-	init( info );
-	d->args = args;
+    d_ptr->q_ptr = this;
 }
 
 KCModuleProxy::KCModuleProxy( const QString& serviceName, QWidget * parent,
 		const QStringList& args )
-	: QWidget( parent )
+    : QWidget(parent), d_ptr(new KCModuleProxyPrivate(this, KCModuleInfo(serviceName), args))
 {
-	init( KCModuleInfo( serviceName ));
-	d->args = args;
+    d_ptr->q_ptr = this;
 }
 
-void KCModuleProxy::init( const KCModuleInfo& info )
-{
-	kDebug(711) << k_funcinfo << endl;
-
-	d = new Private( info, this );
-
-	/* This is all we do for now; all the heavy work is
-	 * done in realModule(). It's called when the module
-	 * _actually_ is needed, in for example showEvent().
-	 * The module is loaded "on demand" -- lazy loading.
-	 */
-
-}
 
 void KCModuleProxy::load()
 {
-
+    Q_D(KCModuleProxy);
 	if( realModule() )
 	{
 		d->kcm->load();
-		moduleChanged( false );
+        d->_k_moduleChanged(false);
 	}
 }
 
 void KCModuleProxy::save()
 {
+    Q_D(KCModuleProxy);
 	if( d->changed && realModule() )
 	{
 		d->kcm->save();
-		moduleChanged( false );
+        d->_k_moduleChanged(false);
 	}
 }
 
 void KCModuleProxy::defaults()
 {
+    Q_D(KCModuleProxy);
 	if( realModule() )
 		d->kcm->defaults();
 }
@@ -359,30 +316,34 @@ KComponentData KCModuleProxy::componentData() const
 
 bool KCModuleProxy::changed() const
 {
+    Q_D(const KCModuleProxy);
 	return d->changed;
 }
 
-const KCModuleInfo& KCModuleProxy::moduleInfo() const
+KCModuleInfo KCModuleProxy::moduleInfo() const
 {
+    Q_D(const KCModuleProxy);
 	return d->modInfo;
 }
 
 QString KCModuleProxy::dbusService() const
 {
+    Q_D(const KCModuleProxy);
 	return d->dbusService;
 }
 
 QString KCModuleProxy::dbusPath() const
 {
+    Q_D(const KCModuleProxy);
 	return d->dbusPath;
 }
 
-void KCModuleProxy::emitQuickHelpChanged()
-{
-	emit quickHelpChanged();
-}
+//X void KCModuleProxy::emitQuickHelpChanged()
+//X {
+//X     emit quickHelpChanged();
+//X }
 
 /***************************************************************/
 #include "kcmoduleproxy.moc"
 
-// vim: sw=4 ts=4 noet
+// vim: ts=4
