@@ -26,6 +26,8 @@
 #include <kcmoduleinfo.h>
 #include <kpagedialog.h>
 
+class KCMultiDialogPrivate;
+
 /**
  * @short A method that offers a KPageDialog containing arbitrary
  *        KControl Modules.
@@ -35,6 +37,7 @@
 class KUTILS_EXPORT KCMultiDialog : public KPageDialog
 {
   Q_OBJECT
+    Q_DECLARE_PRIVATE(KCMultiDialog)
 
   public:
     /**
@@ -53,24 +56,36 @@ class KUTILS_EXPORT KCMultiDialog : public KPageDialog
     /**
      * Add a module.
      *
+     * The module is added according to its KCModuleInfo::weight(). The weight determines where in the list
+     * the module will appear. Lighter modules on top, heavier modules at the bottom.
+     *
      * @param module Specify the name of the module that is to be added
      *               to the list of modules the dialog will show.
      *
+     * @param args The arguments that should be given to the KCModule when its created
+     *
      * @returns The @see KPageWidgetItem associated with the new dialog page.
      **/
-    KPageWidgetItem* addModule( const QString& module );
+    KPageWidgetItem* addModule( const QString& module, const QStringList& 
+                                args = QStringList() );
 
     /**
      * Add a module.
      *
+     * The module is added according to its KCModuleInfo::weight(). The weight determines where in the list
+     * the module will appear. Lighter modules on top, heavier modules at the bottom.
+     *
      * @param moduleinfo Pass a KCModuleInfo object which will be
      *                   used for creating the module. It will be added
      *                   to the list of modules the dialog will show.
      *
      * @param parent The @see KPageWidgetItem that should appear as parents
      *               in the tree view or a 0 pointer if there is no parent.
+     *
+     * @param args The arguments that should be given to the KCModule when its created
      **/
-    KPageWidgetItem* addModule( const KCModuleInfo& moduleinfo, KPageWidgetItem *parent = 0 );
+    KPageWidgetItem* addModule( const KCModuleInfo& moduleinfo, KPageWidgetItem *parent = 0, 
+                                const QStringList& args = QStringList() );
 
     /**
      * Removes all modules from the dialog.
@@ -103,6 +118,13 @@ class KUTILS_EXPORT KCMultiDialog : public KPageDialog
      */
     void configCommitted( const QByteArray & componentName );
 
+    protected:
+        /**
+         * This constructor can be used by subclasses to provide a custom KPageWidget.
+         */
+        KCMultiDialog(KPageWidget *pageWidget, QWidget *parent, Qt::WFlags flags = 0);
+        KCMultiDialog(KCMultiDialogPrivate &dd, KPageWidget *pageWidget, QWidget *parent, Qt::WFlags flags = 0);
+
   protected Q_SLOTS:
     /**
      * This slot is called when the user presses the "Default" Button.
@@ -148,16 +170,10 @@ class KUTILS_EXPORT KCMultiDialog : public KPageDialog
      **/
     void slotHelpClicked();
 
-  private:
-    void init();
-    void apply();
-
-    class Private;
-    Private* const d;
-
-    Q_PRIVATE_SLOT( d, void _k_slotCurrentPageChanged( KPageWidgetItem* ) )
-    Q_PRIVATE_SLOT( d, void _k_clientChanged( bool ) )
-    Q_PRIVATE_SLOT( d, void _k_dialogClosed() )
+    private:
+        Q_PRIVATE_SLOT(d_func(), void _k_slotCurrentPageChanged(KPageWidgetItem *))
+        Q_PRIVATE_SLOT(d_func(), void _k_clientChanged())
+        Q_PRIVATE_SLOT(d_func(), void _k_dialogClosed())
 };
 
 #endif
