@@ -20,20 +20,22 @@
 #ifndef KSETTINGS_DIALOG_H
 #define KSETTINGS_DIALOG_H
 
-#include <qobject.h>
+#include "../kutils_export.h"
+#include "../kcmultidialog.h"
+
 #include <kservice.h>
-#include <QList>
+#include <kplugininfo.h>
 
 template<class T> class QList;
 class KPluginInfo;
-class KCMultiDialog;
 class KCModuleInfo;
 
 namespace KSettings
 {
+    class DialogPrivate;
 
 /**
- * @short Generic configuration dialog that even works over component boundaries
+ * @short Generic configuration dialog that works over component boundaries
  *
  * For more information see \ref KSettings.
  *
@@ -46,7 +48,7 @@ namespace KSettings
  *
  * You initialize \p m_cfgdlg with
  * \code
- * m_cfgdlg = new Dialog( Dialog::Static, this );
+ * m_cfgdlg = new Dialog( this );
  * \endcode
  * If you use a KPart that was not especially designed for your app you can use
  * the second constructor:
@@ -68,29 +70,12 @@ namespace KSettings
  *
  * @author Matthias Kretz <kretz@kde.org>
  */
-class KUTILS_EXPORT Dialog : public QObject
+class KUTILS_EXPORT Dialog : public KCMultiDialog
 {
     friend class PageNode;
+    Q_DECLARE_PRIVATE(Dialog)
     Q_OBJECT
     public:
-        /**
-         * Tells the dialog whether the entries in the listview are all static
-         * or whether it should add a Configure... button to select which parts
-         * of the optional functionality should be active or not.
-         */
-        enum ContentInListView
-        {
-            /**
-             * Static listview, while running no entries are added or deleted
-             */
-            Static,
-            /**
-             * Configurable listview. The user can select what functionality he
-             * wants.
-             */
-            Configurable
-        };
-
         /**
          * Construct a new Preferences Dialog for the application. It uses all
          * KCMs with X-KDE-ParentApp set to KGlobal::mainComponent().componentName().
@@ -101,7 +86,7 @@ class KUTILS_EXPORT Dialog : public QObject
          *                     dialog - centering the dialog over the parent
          *                     widget.
          */
-        Dialog( ContentInListView content = Static, QWidget * parent = 0 );
+        explicit Dialog(QWidget * parent = 0);
 
         /**
          * Construct a new Preferences Dialog with the pages for the selected
@@ -115,24 +100,7 @@ class KUTILS_EXPORT Dialog : public QObject
          *                     dialog - centering the dialog over the parent
          *                     widget.
          */
-         Dialog( const QStringList & components, QWidget * parent = 0 );
-
-        /**
-         * Construct a new Preferences Dialog with the pages for the selected
-         * instance names. For example if you want to have the configuration
-         * pages for the kviewviewer KPart you would pass a
-         * QStringList consisting of only the name of the part "kviewviewer".
-         *
-         * @param components   A list of the names of the components that your
-         *                     config dialog should merge the config pages in.
-         * @param content      Select whether you want a static or configurable
-         *                     config dialog.
-         * @param parent       The parent is only used as the parent for the
-         *                     dialog - centering the dialog over the parent
-         *                     widget.
-         */
-        Dialog( const QStringList & components, ContentInListView
-                content, QWidget * parent = 0 );
+         explicit Dialog(const QStringList & components, QWidget * parent = 0);
 
         ~Dialog();
 
@@ -140,16 +108,59 @@ class KUTILS_EXPORT Dialog : public QObject
          * If you use a Configurable dialog you need to pass KPluginInfo
          * objects that the dialog should configure.
          */
-        void addPluginInfos( const QList<KPluginInfo*> & plugininfos );
+        void addPluginInfos(const QList<KPluginInfo> &plugininfos);
 
-        KCMultiDialog * dialog();
-
-    public Q_SLOTS:
         /**
-         * Show the config dialog. The slot immediately returns since the dialog
-         * is non-modal.
+         * Sets the argument list that is given to all the KControlModule's when
+         * they are created.
+         * Use this if you have KControlModule's that need special arguments to
+         * work
+         *
+         * Note that this function only works before showing the
+         * KSettings::Dialog for the first time.
+         * @param arguments The list of arguments passed to each KCM
          */
-        void show();
+        void setKCMArguments(const QStringList& arguments);
+
+        /**
+         * Set the blacklisted component list. Any KCM that lists one
+         * of the components in the given blacklist is not loaded even if it
+         * would fit otherwise. This is a way to explicitly prevent loading of
+         * certain KControlModules.
+         *
+         * Note that this function only works before showing the
+         * KSettings::Dialog for the first time.
+         * @param blacklist the list of components that prevent a KCM from being
+         * loaded
+         */
+        void setComponentBlacklist(const QStringList& blacklist);
+
+        /**
+         * Tells the dialog whether the entries in the listview are all static
+         * or whether it should add checkboxes to select which parts
+         * of the optional functionality should be active or not.
+         *
+         * Note that this function only works before showing the dialog for the first time.
+         *
+         * Defaults to \p false.
+         *
+         * @param allowSelection \p true The user can select what functionality he wants.
+         * @param allowSelection \p false While running no entries are added or deleted
+         */
+        void setAllowComponentSelection(bool allowSelection);
+
+        bool allowComponentSelection() const;
+
+        /**
+         * Returns a list of all KPluginInfo objects the dialog uses.
+         */
+        QList<KPluginInfo> pluginInfos() const;
+
+    protected:
+        /**
+         * Reimplemented to lazy create the dialog on first show.
+         */
+        void showEvent(QShowEvent *);
 
     Q_SIGNALS:
         /**
@@ -161,46 +172,13 @@ class KUTILS_EXPORT Dialog : public QObject
          */
         void pluginSelectionChanged();
 
-    protected Q_SLOTS:
-        void configureTree();
-        void updateTreeList();
-
     private:
-        /**
-         * @internal
-         * Check whether the plugin associated with this KCM is enabled.
-         */
-        bool isPluginForKCMEnabled( KCModuleInfo * ) const;
-
-        QList<KService::Ptr> instanceServices() const;
-        QList<KService::Ptr> parentComponentsServices(
-                const QStringList & ) const;
-        /**
-         * @internal
-         * Read the .setdlg file and add it to the groupmap
-         */
-        void parseGroupFile( const QString & );
-
-        /**
-         * @internal
-         * If this module is put into a TreeList hierarchy this will return a
-         * list of the names of the parent modules.
-         */
-        QStringList parentModuleNames( KCModuleInfo * );
-
-        /**
-         * @internal
-         * This method is called only once. The KCMultiDialog is not created
-         * until it's really needed. So if some method needs to access d->dlg it
-         * checks for 0 and if it's not created this method will do it.
-         */
-        void createDialogFromServices();
-
-        class DialogPrivate;
-        DialogPrivate* const d;
+        //Q_PRIVATE_SLOT(d_func(), void _k_configureTree())
+        Q_PRIVATE_SLOT(d_func(), void _k_updateEnabledState(bool))
+        Q_PRIVATE_SLOT(d_func(), void _k_syncConfiguration())
+        Q_PRIVATE_SLOT(d_func(), void _k_reparseConfiguration(const QByteArray &))
 };
 
 }
 
-// vim: sw=4 sts=4 et
 #endif // KSETTINGS_DIALOG_H
