@@ -25,12 +25,12 @@
 KSettingsWidgetAdaptor::KSettingsWidgetAdaptor(QObject *parent)
     : QDBusAbstractAdaptor(parent)
 {
-	kDebug() << k_funcinfo << endl;
+	kDebug() ;
 	setAutoRelaySignals(true);
 }
 KSettingsWidgetAdaptor::~KSettingsWidgetAdaptor()
 {
-	kDebug() << k_funcinfo << endl;
+	kDebug() ;
 }
 
 QString KSettingsWidgetAdaptor::applicationName()
