@@ -29,9 +29,9 @@
 #include <ksavefile.h>
 #include <kstandarddirs.h>
 
-#include <qfile.h>
-#include <qfileinfo.h>
-#include <qregexp.h>
+#include <QtCore/QFile>
+#include <QtCore/QFileInfo>
+#include <QtCore/QRegExp>
 
 #include "blowfish.h"
 #include "sha1.h"
@@ -54,7 +54,11 @@ using namespace KWallet;
 #define KWMAGIC "KWALLET\n\r\0\r\n"
 #define KWMAGIC_LEN 12
 
-Backend::Backend(const QString& name, bool isPath) : _name(name), _ref(0) {
+class Backend::BackendPrivate
+{
+};
+
+Backend::Backend(const QString& name, bool isPath) : d(0), _name(name), _ref(0) {
 	KGlobal::dirs()->addResourceType("kwallet", "share/apps/kwallet");
 	if (isPath) {
 		_path = name;
@@ -70,6 +74,7 @@ Backend::~Backend() {
 	if (_open) {
 		close();
 	}
+	delete d;
 }
 
 
@@ -403,7 +408,7 @@ int Backend::open(const QByteArray& password) {
 	t++;
 
 	if (fsize < 0 || fsize > long(encrypted.size()) - blksz - 4) {
-		//kDebug() << "fsize: " << fsize << " encrypted.size(): " << encrypted.size() << " blksz: " << blksz << endl;
+		//kDebug() << "fsize: " << fsize << " encrypted.size(): " << encrypted.size() << " blksz: " << blksz;
 		encrypted.fill(0);
 		return -9;         // file structure error.
 	}
