@@ -1,6 +1,6 @@
-#include <qtextstream.h>
-#include <qapplication.h>
-#include <qtimer.h>
+#include <QtCore/QTextStream>
+#include <QtGui/QApplication>
+#include <QtCore/QTimer>
 
 #include <kaboutdata.h>
 #include <kcomponentdata.h>
@@ -9,9 +9,9 @@
 #include <kglobal.h>
 #include <kstandarddirs.h>
 #include <kwallet.h>
-#include <qdbusconnectioninterface.h>
-#include <qdbusconnection.h>
-#include <qdbusreply.h>
+#include <QtDBus/QDBusConnectionInterface>
+#include <QtDBus/QDBusConnection>
+#include <QtDBus/QDBusReply>
 
 static QTextStream _out( stdout, QIODevice::WriteOnly );
 
@@ -26,7 +26,7 @@ void openWallet()
 
 int main( int argc, char *argv[] )
 {
-	KAboutData aboutData( "kwalletsync", "kwalletsync", "version" );
+	KAboutData aboutData("kwalletsync", 0, ki18n("kwalletsync"), "version");
 	KComponentData componentData(&aboutData);
 	QApplication app( argc, argv );
 
