@@ -21,14 +21,20 @@
 #define PHONON_ABSTRACTAUDIOOUTPUT_P_H
 
 #include "abstractaudiooutput.h"
-#include "base_p.h"
+#include "medianode_p.h"
+#include "phonondefs_p.h"
 
 namespace Phonon
 {
-class AbstractAudioOutputPrivate : public BasePrivate
+class AbstractAudioOutputPrivate : public MediaNodePrivate
 {
-	K_DECLARE_PUBLIC( AbstractAudioOutput )
-	PHONON_PRIVATEABSTRACTCLASS( Base )
+    Q_DECLARE_PUBLIC(AbstractAudioOutput)
+    PHONON_PRIVATEABSTRACTCLASS
+    protected:
+        AbstractAudioOutputPrivate(CastId castId = AbstractAudioOutputPrivateType)
+            : MediaNodePrivate(castId)
+        {
+        }
 };
 } //namespace Phonon
 
