@@ -19,47 +19,42 @@
 #ifndef Phonon_ABSTRACTVIDEOOUTPUTBASE_H
 #define Phonon_ABSTRACTVIDEOOUTPUTBASE_H
 
-#include "base.h"
 #include "phonondefs.h"
-#include <QObject>
+#include "phonon_export.h"
+#include "medianode.h"
+#include <QtCore/QObject>
 
 class QString;
 
 namespace Phonon
 {
-	class AbstractVideoOutputPrivate;
+namespace Experimental
+{
+    class Visualization;
+    class VisualizationPrivate;
+} // namespace Experimental
 
-	class PHONONCORE_EXPORT AbstractVideoOutput : public Base
-	{
-		friend class VideoPath;
-		friend class VideoPathPrivate;
-		friend class Visualization;
-		K_DECLARE_PRIVATE( AbstractVideoOutput )
-		protected:
-			/**
-			 * \internal
-			 * Constructor that is called from derived classes.
-			 *
-			 * \param parent Standard QObject parent.
-			 */
-			AbstractVideoOutput( AbstractVideoOutputPrivate& d );
+    class AbstractVideoOutputPrivate;
 
-			/**
-			 * \internal
-			 * After construction of the Iface object this method is called
-			 * throughout the complete class hierarchy in order to set up the
-			 * properties that were already set on the public interface.
-			 *
-			 * An example implementation could look like this:
-			 * \code
-			 * ParentClass::setupIface();
-			 * m_iface->setPropertyA( d->propertyA );
-			 * m_iface->setPropertyB( d->propertyB );
-			 * \endcode
-			 */
-			void setupIface();
-	};
+    /** \class AbstractVideoOutput abstractvideooutput.h Phonon/AbstractVideoOutput
+     * \brief Common base class for all video outputs.
+     *
+     * \see VideoWidget
+     */
+    class PHONON_EXPORT AbstractVideoOutput : public MediaNode
+    {
+        friend class Experimental::Visualization;
+        friend class Experimental::VisualizationPrivate;
+        K_DECLARE_PRIVATE(AbstractVideoOutput)
+        protected:
+            /**
+             * \internal
+             * Constructor that is called from derived classes.
+             *
+             * \param parent Standard QObject parent.
+             */
+            AbstractVideoOutput(AbstractVideoOutputPrivate &d);
+    };
 } //namespace Phonon
 
-// vim: sw=4 ts=4 tw=80
 #endif // Phonon_ABSTRACTVIDEOOUTPUTBASE_H
