@@ -22,33 +22,35 @@
 
 #include "audiooutput.h"
 #include "abstractaudiooutput_p.h"
-#include <kaboutdata.h>
-#include <kglobal.h>
-#include <kcomponentdata.h>
+#include "platform_p.h"
 
 namespace Phonon
 {
 class AudioOutputPrivate : public AbstractAudioOutputPrivate
 {
-	K_DECLARE_PUBLIC( AudioOutput )
-	PHONON_PRIVATECLASS( AbstractAudioOutput )
+    Q_DECLARE_PUBLIC(AudioOutput)
+    PHONON_PRIVATECLASS
     public:
-        void deviceListChanged();
+        inline static AudioOutputPrivate *cast(MediaNodePrivate *x)
+        {
+            if (x && x->castId == MediaNodePrivate::AudioOutputType) {
+                return static_cast<AudioOutputPrivate *>(x);
+            }
+            return 0;
+        }
 
-	protected:
-		AudioOutputPrivate()
-            : volume(1.0),
+    protected:
+        AudioOutputPrivate(CastId castId = MediaNodePrivate::AudioOutputType)
+            : AbstractAudioOutputPrivate(castId),
+            volume(1.0),
             outputDeviceIndex(-1),
             deviceBeforeFallback(-1),
             outputDeviceOverridden(false),
             muted(false)
-		{
-			const KAboutData* ad = KGlobal::mainComponent().aboutData();
-			if( ad )
-				name = ad->programName();
-			else
-				name = KGlobal::mainComponent().componentName();
-		}
+        {
+            name = Platform::applicationName();
+            volume = Platform::loadVolume(name);
+        }
 
         enum DeviceChangeType {
             FallbackChange,
@@ -56,15 +58,16 @@ class AudioOutputPrivate : public AbstractAudioOutputPrivate
         };
         void handleAutomaticDeviceChange(int newIndex, DeviceChangeType type);
 
-        void _k_volumeChanged(float);
+        void _k_volumeChanged(qreal);
         void _k_revertFallback();
         void _k_audioDeviceFailed();
+        void _k_deviceListChanged();
 
-	private:
-		float volume;
-		Category category;
-		QString name;
-		int outputDeviceIndex;
+    private:
+        qreal volume;
+        Category category;
+        QString name;
+        int outputDeviceIndex;
         int deviceBeforeFallback;
         bool outputDeviceOverridden;
         bool muted;
