@@ -21,23 +21,29 @@
 #define PHONON_AUDIOOUTPUTINTERFACE_H
 
 #include "phononnamespace.h"
-#include <Qt/qglobal.h>
+#include <QtCore/QtGlobal>
 
 namespace Phonon
 {
-class PHONONCORE_EXPORT AudioOutputInterface
+/** \class AudioOutputInterface audiooutputinterface.h Phonon/AudioOutputInterface
+ * \short Interface for AudioOutput objects
+ *
+ * \ingroup Backend
+ * \author Matthias Kretz <kretz@kde.org>
+ */
+class AudioOutputInterface
 {
     public:
         virtual ~AudioOutputInterface() {}
 
-        virtual float volume() const = 0;
-        virtual void setVolume(float) = 0;
+        virtual qreal volume() const = 0;
+        virtual void setVolume(qreal) = 0;
 
         virtual int outputDevice() const = 0;
         virtual bool setOutputDevice(int) = 0;
 };
 } // namespace Phonon
 
-Q_DECLARE_INTERFACE(Phonon::AudioOutputInterface, "org.kde.Phonon.AudioOutputInterface/0.1" )
+Q_DECLARE_INTERFACE(Phonon::AudioOutputInterface, "AudioOutputInterface2.phonon.kde.org")
 
 #endif // PHONON_AUDIOOUTPUTINTERFACE_H
