@@ -20,11 +20,10 @@
 #ifndef Phonon_BACKENDCAPABILITIES_H
 #define Phonon_BACKENDCAPABILITIES_H
 
-#include <QObject>
-
-#include <kdelibs_export.h>
+#include "phonon_export.h"
 #include "objectdescription.h"
-#include <kglobal.h>
+
+#include <QtCore/QObject>
 
 template<class T> class QList;
 class QStringList;
@@ -33,14 +32,17 @@ namespace Phonon
 {
 
 /**
- * Singleton class describing the capabilities of the Backend.
+ * Collection of functions describing the capabilities of the Backend.
  *
+ * \ingroup BackendInformation
  * \author Matthias Kretz <kretz@kde.org>
  */
 namespace BackendCapabilities
 {
-    /**
+    /** \class Notifier backendcapabilities.h Phonon/BackendCapabilities
      * Notifications about backend capabilities.
+     *
+     * \ingroup BackendInformation
      */
     class Notifier : public QObject
     {
@@ -51,6 +53,15 @@ namespace BackendCapabilities
              * happen if the user has requested a backend change.
              */
             void capabilitiesChanged();
+
+            /**
+             * This signal is emitted when audio output devices were plugged or
+             * unplugged.
+             *
+             * Check BackendCapabilities::availableAudioOutputDevices to get the
+             * current list of available devices.
+             */
+            void availableAudioOutputDevicesChanged();
     };
 
     /**
@@ -68,48 +79,47 @@ namespace BackendCapabilities
      *
      * \see Notifier::capabilitiesChanged()
      */
-    PHONONCORE_EXPORT Notifier *notifier();
+    PHONON_EXPORT Notifier *notifier();
 
-    /**
-     * Tells whether the backend is audio only or can handle video files
-     * and display of videos.
-     *
-     * If the backend does not support video the classes
-     * VideoPath, VideoEffect and all AbstractVideoOutput subclasses won't
-     * do anything.
-     */
-    PHONONCORE_EXPORT bool supportsVideo();
-
-    /**
-     * Tells whether the backend implements the OSD interfaces.
-     *
-     * \todo there's no interfaces for it at this point
-     */
-    PHONONCORE_EXPORT bool supportsOSD();
-
-    /**
-     * Tells whether the backend supports subtitle rendering on the
-     * video output.
-     *
-     * \todo there's no interfaces for it at this point
-     */
-    PHONONCORE_EXPORT bool supportsSubtitles();
+//X     /**
+//X      * Tells whether the backend is audio only or can handle video files
+//X      * and display of videos.
+//X      *
+//X      * If the backend does not support video all AbstractVideoOutput subclasses won't
+//X      * do anything.
+//X      */
+//X     PHONON_EXPORT bool supportsVideo();
+//X 
+//X     /**
+//X      * Tells whether the backend implements the OSD interfaces.
+//X      *
+//X      * \todo there's no interfaces for it at this point
+//X      */
+//X     PHONON_EXPORT bool supportsOSD();
+//X 
+//X     /**
+//X      * Tells whether the backend supports subtitle rendering on the
+//X      * video output.
+//X      *
+//X      * \todo there's no interfaces for it at this point
+//X      */
+//X     PHONON_EXPORT bool supportsSubtitles();
 
     /**
      * Returns a list of mime types that the Backend can decode.
      *
-     * \see isMimeTypeKnown()
+     * \see isMimeTypeAvailable()
      */
-    PHONONCORE_EXPORT QStringList knownMimeTypes();
+    PHONON_EXPORT QStringList availableMimeTypes();
 
     /**
      * Often all you want to know is whether one given MIME type can be
-     * decoded by the backend. Use this method in favor of knownMimeTypes()
+     * decoded by the backend. Use this method in favor of availableMimeTypes()
      * as it can give you a negative answer without having a backend loaded.
      *
-     * \see knownMimeTypes();
+     * \see availableMimeTypes();
      */
-    PHONONCORE_EXPORT bool isMimeTypeKnown( const QString& mimeType );
+    PHONON_EXPORT bool isMimeTypeAvailable(const QString &mimeType);
 
 #if 0
     /**
@@ -123,7 +133,7 @@ namespace BackendCapabilities
      * 
      * \see knownAudioOutputDevices
      */
-    PHONONCORE_EXPORT QList<AudioOutputDevice> usableAudioOutputDevices();
+    PHONON_EXPORT QList<AudioOutputDevice> usableAudioOutputDevices();
 
     /**
      * Returns the audio output devices the backend has ever reported as
@@ -134,7 +144,7 @@ namespace BackendCapabilities
      *
      * \see usableAudioOutputDevices
      */
-    PHONONCORE_EXPORT QList<AudioOutputDevice> knownAudioOutputDevices();
+    PHONON_EXPORT QList<AudioOutputDevice> knownAudioOutputDevices();
 #endif
     /**
      * Returns the audio output devices the backend supports.
@@ -142,7 +152,7 @@ namespace BackendCapabilities
      * \return A list of AudioOutputDevice objects that give a name and
      * description for every supported audio output device.
      */
-    PHONONCORE_EXPORT QList<AudioOutputDevice> availableAudioOutputDevices();
+    PHONON_EXPORT QList<AudioOutputDevice> availableAudioOutputDevices();
 
     /**
      * Returns the audio capture devices the backend supports.
@@ -150,7 +160,7 @@ namespace BackendCapabilities
      * \return A list of AudioCaptureDevice objects that give a name and
      * description for every supported audio capture device.
      */
-    PHONONCORE_EXPORT QList<AudioCaptureDevice> availableAudioCaptureDevices();
+//    PHONON_EXPORT QList<AudioCaptureDevice> availableAudioCaptureDevices();
 
     /**
      * Returns the video output devices the backend supports.
@@ -158,7 +168,7 @@ namespace BackendCapabilities
      * \return A list of VideoOutputDevice objects that give a name and
      * description for every supported video output device.
      */
-    PHONONCORE_EXPORT QList<VideoOutputDevice> availableVideoOutputDevices();
+//    PHONON_EXPORT QList<VideoOutputDevice> availableVideoOutputDevices();
 
     /**
      * Returns the video capture devices the backend supports.
@@ -166,7 +176,7 @@ namespace BackendCapabilities
      * \return A list of VideoCaptureDevice objects that give a name and
      * description for every supported video capture device.
      */
-    PHONONCORE_EXPORT QList<VideoCaptureDevice> availableVideoCaptureDevices();
+//    PHONON_EXPORT QList<VideoCaptureDevice> availableVideoCaptureDevices();
 
     /**
      * Returns the visualization effects the backend supports.
@@ -174,7 +184,7 @@ namespace BackendCapabilities
      * \return A list of VisualizationEffect objects that give a name and
      * description for every supported visualization effect.
      */
-    PHONONCORE_EXPORT QList<VisualizationDescription> availableVisualizations();
+//    PHONON_EXPORT QList<VisualizationDescription> availableVisualizations();
 
     /**
      * Returns descriptions for the audio effects the backend supports.
@@ -182,15 +192,15 @@ namespace BackendCapabilities
      * \return A list of AudioEffectDescription objects that give a name and
      * description for every supported audio effect.
      */
-    PHONONCORE_EXPORT QList<AudioEffectDescription> availableAudioEffects();
+    PHONON_EXPORT QList<EffectDescription> availableAudioEffects();
 
-    /**
-     * Returns descriptions for the video effects the backend supports.
-     *
-     * \return A list of VideoEffectDescription objects that give a name and
-     * description for every supported video effect.
-     */
-    PHONONCORE_EXPORT QList<VideoEffectDescription> availableVideoEffects();
+//X     /**
+//X      * Returns descriptions for the video effects the backend supports.
+//X      *
+//X      * \return A list of VideoEffectDescription objects that give a name and
+//X      * description for every supported video effect.
+//X      */
+//X     PHONON_EXPORT QList<EffectDescription> availableVideoEffects();
 
     /**
      * Returns descriptions for the audio codecs the backend supports.
@@ -198,7 +208,7 @@ namespace BackendCapabilities
      * \return A list of AudioCodec objects that give a name and
      * description for every supported audio codec.
      */
-    PHONONCORE_EXPORT QList<AudioCodecDescription> availableAudioCodecs();
+//    PHONON_EXPORT QList<AudioCodecDescription> availableAudioCodecs();
 
     /**
      * Returns descriptions for the video codecs the backend supports.
@@ -206,7 +216,7 @@ namespace BackendCapabilities
      * \return A list of VideoCodec objects that give a name and
      * description for every supported video codec.
      */
-    PHONONCORE_EXPORT QList<VideoCodecDescription> availableVideoCodecs();
+//    PHONON_EXPORT QList<VideoCodecDescription> availableVideoCodecs();
 
     /**
      * Returns descriptions for the container formats the backend supports.
@@ -214,7 +224,7 @@ namespace BackendCapabilities
      * \return A list of ContainerFormat objects that give a name and
      * description for every supported container format.
      */
-    PHONONCORE_EXPORT QList<ContainerFormatDescription> availableContainerFormats();
+//    PHONON_EXPORT QList<ContainerFormatDescription> availableContainerFormats();
 } // namespace BackendCapabilities
 } // namespace Phonon
 
