@@ -1,5 +1,5 @@
 /*  This file is part of the KDE project
-    Copyright (C) 2006 Matthias Kretz <kretz@kde.org>
+    Copyright (C) 2006-2007 Matthias Kretz <kretz@kde.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -18,16 +18,57 @@
 */
 
 #include "outputdevicechoice.h"
+
+#include <QtCore/QList>
+#include <QtCore/QSettings>
+#include <QtGui/QHeaderView>
+#include <QtGui/QPalette>
+
 #include <phonon/backendcapabilities.h>
 #include <phonon/objectdescription.h>
 #include <phonon/phononnamespace.h>
+#include "../libkaudiodevicelist/audiodeviceenumerator.h"
+#include "../libkaudiodevicelist/audiodevice.h"
+
 #include <klocale.h>
-#include <QHeaderView>
-#include <ksimpleconfig.h>
-#include <phonon/audiodeviceenumerator.h>
-#include <phonon/audiodevice.h>
-#include <QList>
-#include <kconfiggroup.h>
+#include <kstandarddirs.h>
+
+#ifndef METATYPE_QLIST_INT_DEFINED
+#define METATYPE_QLIST_INT_DEFINED
+// Want this exactly once, see phonondefs_p.h kcm/outputdevicechoice.cpp
+Q_DECLARE_METATYPE(QList<int>)
+#endif
+
+class QSettingsGroup
+{
+    public:
+        QSettingsGroup(QSettings *settings, const QString &name)
+            : m_s(settings),
+            m_group(name + QLatin1Char('/'))
+        {
+        }
+
+        template<typename T>
+        inline T value(const QString &key, const T &def) const
+        {
+            return qvariant_cast<T>(value(key, QVariant::fromValue(def)));
+        }
+
+        QVariant value(const QString &key, const QVariant &def) const
+        {
+            return m_s->value(m_group + key, def);
+        }
+
+        template<typename T>
+        inline void setValue(const QString &key, const T &value)
+        {
+            m_s->setValue(m_group + key, QVariant::fromValue(value));
+        }
+
+    private:
+        QSettings *const m_s;
+        QString m_group;
+};
 
 class CategoryItem : public QStandardItem {
     public:
@@ -43,39 +84,54 @@ class CategoryItem : public QStandardItem {
     private:
         Phonon::Category m_cat;
 };
+
 OutputDeviceChoice::OutputDeviceChoice(QWidget *parent)
     : QWidget(parent)
 {
     setupUi(this);
-    removeButton->setIcon(KIcon("remove"));
+    removeButton->setIcon(KIcon("list-remove"));
+    deferButton->setIcon(KIcon("arrow-down"));
+    preferButton->setIcon(KIcon("arrow-up"));
     //categoryTree->setDragEnabled(true);
     //categoryTree->setAcceptDrops(true);
     //categoryTree->setDropIndicatorShown(true);
     //categoryTree->setDragDropMode(QAbstractItemView::InternalMove);
-    deviceList->setDragEnabled(true);
-    deviceList->setAcceptDrops(true);
-    deviceList->setDropIndicatorShown(true);
-    deviceList->setWrapping(true);
-    //deviceList->setSpacing(4);
+//X     deviceList->setDragEnabled(true);
+//X     deviceList->setAcceptDrops(true);
+//X     deviceList->setDropIndicatorShown(true);
     deviceList->setDragDropMode(QAbstractItemView::InternalMove);
-    /*qApp->setStyleSheet("QListView { background-image: url(/home/mkretz/KDE/src/kdelibs/phonon/kcm/speaker.svg);"
-           "background-position: bottom left;"
-          "background-repeat: no-repeat; }");*/
-    deviceList->setAlternatingRowColors(true);
+    const QColor bgColor = deviceList->viewport()->palette().color(deviceList->viewport()->backgroundRole());
+    const QString stylesheet = QString("QListView {"
+            "background-color: %1;"
+            "background-image: url(%2);"
+            "background-position: bottom left;"
+            "background-attachment: fixed;"
+            "background-repeat: no-repeat;"
+            "}")
+        .arg(bgColor.name())
+        .arg(KStandardDirs::locate("data", "kcm_phonon/listview-background.png"));
+    kDebug() << stylesheet;
+    deviceList->setStyleSheet(stylesheet);
+    deviceList->setAlternatingRowColors(false);
     QStandardItem *parentItem = m_categoryModel.invisibleRootItem();
     QStandardItem *outputItem = new QStandardItem(i18n("Audio Output"));
+    outputItem->setEditable(false);
     outputItem->setSelectable(false);
     parentItem->appendRow(outputItem);
+    /*
     m_captureItem = new QStandardItem(i18n("Audio Capture"));
+    m_captureItem->setEditable(false);
     parentItem->appendRow(m_captureItem);
+    */
 
     parentItem = outputItem;
     for (int i = 0; i <= Phonon::LastCategory; ++i) {
         m_outputModel[i] = new Phonon::AudioOutputDeviceModel;
         QStandardItem *item = new CategoryItem(static_cast<Phonon::Category>(i));
+        item->setEditable(false);
         parentItem->appendRow(item);
     }
-    parentItem = m_captureItem;
+    //parentItem = m_captureItem;
 
     categoryTree->setModel(&m_categoryModel);
     if (categoryTree->header()) {
@@ -84,19 +140,27 @@ OutputDeviceChoice::OutputDeviceChoice(QWidget *parent)
     categoryTree->expandAll();
 
     connect(categoryTree->selectionModel(),
-            SIGNAL(currentChanged(const QModelIndex&,const QModelIndex&)),
+            SIGNAL(currentChanged(const QModelIndex &,const QModelIndex &)),
             SLOT(updateDeviceList()));
 
     for (int i = 0; i <= Phonon::LastCategory; ++i) {
-        connect(m_outputModel[i], SIGNAL(rowsInserted(const QModelIndex&, int, int)), this, SIGNAL(changed()));
-        connect(m_outputModel[i], SIGNAL(rowsRemoved(const QModelIndex&, int, int)), this, SIGNAL(changed()));
+        connect(m_outputModel[i], SIGNAL(rowsInserted(const QModelIndex &, int, int)), this, SIGNAL(changed()));
+        connect(m_outputModel[i], SIGNAL(rowsRemoved(const QModelIndex &, int, int)), this, SIGNAL(changed()));
         connect(m_outputModel[i], SIGNAL(layoutChanged()), this, SIGNAL(changed()));
-        connect(m_outputModel[i], SIGNAL(dataChanged(const QModelIndex&, const QModelIndex&)), this, SIGNAL(changed()));
+        connect(m_outputModel[i], SIGNAL(dataChanged(const QModelIndex &, const QModelIndex &)), this, SIGNAL(changed()));
     }
-    connect(&m_captureModel, SIGNAL(rowsInserted(const QModelIndex&, int, int)), this, SIGNAL(changed()));
-    connect(&m_captureModel, SIGNAL(rowsRemoved(const QModelIndex&, int, int)), this, SIGNAL(changed()));
+    /*
+    connect(&m_captureModel, SIGNAL(rowsInserted(const QModelIndex &, int, int)), this, SIGNAL(changed()));
+    connect(&m_captureModel, SIGNAL(rowsRemoved(const QModelIndex &, int, int)), this, SIGNAL(changed()));
     connect(&m_captureModel, SIGNAL(layoutChanged()), this, SIGNAL(changed()));
-    connect(&m_captureModel, SIGNAL(dataChanged(const QModelIndex&, const QModelIndex&)), this, SIGNAL(changed()));
+    connect(&m_captureModel, SIGNAL(dataChanged(const QModelIndex &, const QModelIndex &)), this, SIGNAL(changed()));
+    */
+
+    connect(Phonon::BackendCapabilities::notifier(), SIGNAL(availableAudioOutputDevicesChanged()), SLOT(updateAudioOutputDevices()));
+
+    if (!categoryTree->currentIndex().isValid()) {
+        categoryTree->setCurrentIndex(m_categoryModel.index(0, 0).child(0, 0));
+    }
 }
 
 void OutputDeviceChoice::updateDeviceList()
@@ -104,30 +168,59 @@ void OutputDeviceChoice::updateDeviceList()
     QStandardItem *currentItem = m_categoryModel.itemFromIndex(categoryTree->currentIndex());
     if (deviceList->selectionModel()) {
         disconnect(deviceList->selectionModel(),
-                SIGNAL(currentRowChanged(const QModelIndex&,const QModelIndex&)),
+                SIGNAL(currentRowChanged(const QModelIndex &,const QModelIndex &)),
                 this, SLOT(updateButtonsEnabled()));
     }
     if (currentItem->type() == 1001) {
-        CategoryItem *catItem = static_cast<CategoryItem*>(currentItem);
+        CategoryItem *catItem = static_cast<CategoryItem *>(currentItem);
         deviceList->setModel(m_outputModel[catItem->category()]);
+        /*
     } else if (currentItem == m_captureItem) {
         deviceList->setModel(&m_captureModel);
+        */
     } else {
         deviceList->setModel(0);
     }
     updateButtonsEnabled();
     if (deviceList->selectionModel()) {
         connect(deviceList->selectionModel(),
-                SIGNAL(currentRowChanged(const QModelIndex&,const QModelIndex&)),
+                SIGNAL(currentRowChanged(const QModelIndex &,const QModelIndex &)),
                 this, SLOT(updateButtonsEnabled()));
     }
 }
 
+void OutputDeviceChoice::updateAudioOutputDevices()
+{
+    QList<Phonon::AudioOutputDevice> list = Phonon::BackendCapabilities::availableAudioOutputDevices();
+    QHash<int, Phonon::AudioOutputDevice> hash;
+    foreach (Phonon::AudioOutputDevice dev, list) {
+        hash.insert(dev.index(), dev);
+    }
+    for (int i = 0; i <= Phonon::LastCategory; ++i) {
+        QHash<int, Phonon::AudioOutputDevice> hashCopy(hash);
+        QList<Phonon::AudioOutputDevice> orderedList;
+        if (m_outputModel.value(i)) {
+            QList<int> order = m_outputModel.value(i)->tupleIndexOrder();
+            foreach (int idx, order) {
+                if (hashCopy.contains(idx)) {
+                    orderedList << hashCopy.take(idx);
+                }
+            }
+            foreach (Phonon::AudioOutputDevice dev, hashCopy) {
+                orderedList << dev;
+            }
+        } else {
+            orderedList = list;
+        }
+        m_outputModel[i]->setModelData(orderedList);
+    }
+}
+
 void OutputDeviceChoice::load()
 {
-    KSimpleConfig phononrc("phononrc", true);
-    KConfigGroup outputDeviceGroup(&phononrc, QLatin1String("AudioOutputDevice"));
-    KConfigGroup captureDeviceGroup(&phononrc, QLatin1String("AudioCaptureDevice"));
+    QSettings phononConfig(QLatin1String("kde.org"), QLatin1String("libphonon"));
+    QSettingsGroup outputDeviceGroup(&phononConfig, QLatin1String("AudioOutputDevice"));
+    QSettingsGroup captureDeviceGroup(&phononConfig, QLatin1String("AudioCaptureDevice"));
 
     QList<Phonon::AudioOutputDevice> list = Phonon::BackendCapabilities::availableAudioOutputDevices();
     QHash<int, Phonon::AudioOutputDevice> hash;
@@ -136,15 +229,12 @@ void OutputDeviceChoice::load()
     }
     for (int i = 0; i <= Phonon::LastCategory; ++i) {
         QHash<int, Phonon::AudioOutputDevice> hashCopy(hash);
-        QList<int> order = outputDeviceGroup.readEntry<QList<int> >(QLatin1String("Category") + QString::number(i), QList<int>());
+        QList<int> order = outputDeviceGroup.value(QLatin1String("Category") + QString::number(i), QList<int>());
         QList<Phonon::AudioOutputDevice> orderedList;
         foreach (int idx, order) {
             if (hashCopy.contains(idx)) {
                 orderedList << hashCopy.take(idx);
             }
-            //} else {
-                //orderedList << Phonon::AudioOutputDevice();
-            //}
         }
         foreach (Phonon::AudioOutputDevice dev, hashCopy) {
             orderedList << dev;
@@ -152,8 +242,9 @@ void OutputDeviceChoice::load()
         m_outputModel[i]->setModelData(orderedList);
     }
 
+    /*
     QList<Phonon::AudioCaptureDevice> list2 = Phonon::BackendCapabilities::availableAudioCaptureDevices();
-    QList<int> order = captureDeviceGroup.readEntry<QList<int> >(QLatin1String("DeviceOrder"), QList<int>());
+    QList<int> order = captureDeviceGroup.value(QLatin1String("DeviceOrder"), QList<int>());
     QList<Phonon::AudioCaptureDevice> orderedList;
     foreach (int idx, order) {
         for (int i = 0; i < list2.size(); ++i) {
@@ -167,24 +258,26 @@ void OutputDeviceChoice::load()
         orderedList << dev;
     }
     m_captureModel.setModelData(orderedList);
+    */
 }
 
 void OutputDeviceChoice::save()
 {
-    kDebug() << k_funcinfo << endl;
-    KSimpleConfig config("phononrc");
+    QSettings config(QLatin1String("kde.org"), QLatin1String("libphonon"));
     {
-        KConfigGroup globalGroup(&config, QLatin1String("AudioOutputDevice"));
+        QSettingsGroup globalGroup(&config, QLatin1String("AudioOutputDevice"));
         for (int i = 0; i <= Phonon::LastCategory; ++i) {
             if (m_outputModel.value(i)) {
-                globalGroup.writeEntry(QLatin1String("Category") + QString::number(i), m_outputModel.value(i)->tupleIndexOrder());
+                globalGroup.setValue(QLatin1String("Category") + QString::number(i), m_outputModel.value(i)->tupleIndexOrder());
             }
         }
     }
+    /*
     {
-        KConfigGroup globalGroup(&config, QLatin1String("AudioCaptureDevice"));
-        globalGroup.writeEntry(QLatin1String("DeviceOrder"), m_captureModel.tupleIndexOrder());
+        QSettingsGroup globalGroup(&config, QLatin1String("AudioCaptureDevice"));
+        globalGroup.setValue(QLatin1String("DeviceOrder"), m_captureModel.tupleIndexOrder());
     }
+    */
 }
 
 void OutputDeviceChoice::defaults()
@@ -194,14 +287,16 @@ void OutputDeviceChoice::defaults()
         m_outputModel[i]->setModelData(list);
     }
 
+    /*
     QList<Phonon::AudioCaptureDevice> list2 = Phonon::BackendCapabilities::availableAudioCaptureDevices();
     m_captureModel.setModelData(list2);
+    */
 }
 
 void OutputDeviceChoice::on_preferButton_clicked()
 {
     QAbstractItemModel *model = deviceList->model();
-    Phonon::AudioOutputDeviceModel *deviceModel = qobject_cast<Phonon::AudioOutputDeviceModel*>(model);
+    Phonon::AudioOutputDeviceModel *deviceModel = qobject_cast<Phonon::AudioOutputDeviceModel *>(model);
     if (deviceModel) {
         deviceModel->moveUp(deviceList->currentIndex());
         updateButtonsEnabled();
@@ -212,7 +307,7 @@ void OutputDeviceChoice::on_preferButton_clicked()
 void OutputDeviceChoice::on_deferButton_clicked()
 {
     QAbstractItemModel *model = deviceList->model();
-    Phonon::AudioOutputDeviceModel *deviceModel = qobject_cast<Phonon::AudioOutputDeviceModel*>(model);
+    Phonon::AudioOutputDeviceModel *deviceModel = qobject_cast<Phonon::AudioOutputDeviceModel *>(model);
     if (deviceModel) {
         deviceModel->moveDown(deviceList->currentIndex());
         updateButtonsEnabled();
@@ -225,7 +320,7 @@ void OutputDeviceChoice::on_removeButton_clicked()
     QModelIndex idx = deviceList->currentIndex();
 
     QAbstractItemModel *model = deviceList->model();
-    Phonon::AudioOutputDeviceModel *playbackModel = qobject_cast<Phonon::AudioOutputDeviceModel*>(model);
+    Phonon::AudioOutputDeviceModel *playbackModel = qobject_cast<Phonon::AudioOutputDeviceModel *>(model);
     if (playbackModel && idx.isValid()) {
         Phonon::AudioOutputDevice deviceToRemove = playbackModel->modelData(idx);
         QList<Phonon::AudioDevice> deviceList = Phonon::AudioDeviceEnumerator::availablePlaybackDevices();
@@ -248,8 +343,9 @@ void OutputDeviceChoice::on_removeButton_clicked()
                 }
             }
         }
+        /*
     } else {
-        Phonon::AudioCaptureDeviceModel *captureModel = qobject_cast<Phonon::AudioCaptureDeviceModel*>(model);
+        Phonon::AudioCaptureDeviceModel *captureModel = qobject_cast<Phonon::AudioCaptureDeviceModel *>(model);
         if (captureModel && idx.isValid()) {
             Phonon::AudioCaptureDevice deviceToRemove = captureModel->modelData(idx);
             QList<Phonon::AudioDevice> deviceList = Phonon::AudioDeviceEnumerator::availableCaptureDevices();
@@ -264,18 +360,19 @@ void OutputDeviceChoice::on_removeButton_clicked()
                 }
             }
         }
+        */
     }
 }
 
 void OutputDeviceChoice::updateButtonsEnabled()
 {
-    //kDebug() << k_funcinfo << endl;
+    //kDebug() ;
     if (deviceList->model()) {
-        //kDebug() << "model available" << endl;
+        //kDebug() << "model available";
         QModelIndex idx = deviceList->currentIndex();
         preferButton->setEnabled(idx.isValid() && idx.row() > 0);
         deferButton->setEnabled(idx.isValid() && idx.row() < deviceList->model()->rowCount() - 1);
-        removeButton->setEnabled(idx.isValid() && !(idx.flags() & Qt::ItemIsEnabled));
+        removeButton->setEnabled(idx.isValid() && !(idx.flags()  & Qt::ItemIsEnabled));
     } else {
         preferButton->setEnabled(false);
         deferButton->setEnabled(false);
