@@ -1,5 +1,5 @@
 /*  This file is part of the KDE project
-    Copyright (C) 2006 Matthias Kretz <kretz@kde.org>
+    Copyright (C) 2006-2007 Matthias Kretz <kretz@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -19,16 +19,20 @@
 
 #include "objectdescriptionmodel.h"
 #include "objectdescriptionmodel_p.h"
-#include <QList>
+#include "phonondefs_p.h"
+#include "platform_p.h"
+#include <QtCore/QList>
 #include "objectdescription.h"
-#include <kicon.h>
-#include <kdebug.h>
-#include <QMimeData>
+#include "phononnamespace_p.h"
+#include <QtCore/QMimeData>
+#include <QtCore/QStringList>
+#include <QtGui/QIcon>
+#include "factory.h"
 
-#ifdef Q_D
-#undef Q_D
+#ifdef USE_TROLLTECH_LABS_MODELTEST
+#include <QtCore/QSet>
+#include "modeltest.h"
 #endif
-#define Q_D(Class) Class##Private<type> * const d = d_func()
 
 #if Q_MOC_OUTPUT_REVISION != 59
 #ifdef __GNUC__
@@ -55,12 +59,14 @@ static const char qt_meta_stringdata_Phonon__ObjectDescriptionModel_AudioOutputD
 static const char qt_meta_stringdata_Phonon__ObjectDescriptionModel_AudioCaptureDeviceType[] = { "Phonon::AudioCaptureDevice\0" };
 static const char qt_meta_stringdata_Phonon__ObjectDescriptionModel_VideoOutputDeviceType[]  = { "Phonon::VideoOutputDevice\0" };
 static const char qt_meta_stringdata_Phonon__ObjectDescriptionModel_VideoCaptureDeviceType[] = { "Phonon::VideoCaptureDevice\0" };
-static const char qt_meta_stringdata_Phonon__ObjectDescriptionModel_AudioEffectType[]        = { "Phonon::AudioEffectDescription\0" };
-static const char qt_meta_stringdata_Phonon__ObjectDescriptionModel_VideoEffectType[]        = { "Phonon::VideoEffectDescription\0" };
+static const char qt_meta_stringdata_Phonon__ObjectDescriptionModel_EffectType[]             = { "Phonon::EffectDescription\0" };
 static const char qt_meta_stringdata_Phonon__ObjectDescriptionModel_AudioCodecType[]         = { "Phonon::AudioCodecDescription\0" };
 static const char qt_meta_stringdata_Phonon__ObjectDescriptionModel_VideoCodecType[]         = { "Phonon::VideoCodecDescription\0" };
 static const char qt_meta_stringdata_Phonon__ObjectDescriptionModel_ContainerFormatType[]    = { "Phonon::ContainerFormatDescription\0" };
 static const char qt_meta_stringdata_Phonon__ObjectDescriptionModel_VisualizationType[]      = { "Phonon::VisualizationDescription\0" };
+static const char qt_meta_stringdata_Phonon__ObjectDescriptionModel_AudioStreamType[]        = { "Phonon::AudioStreamDescription\0" };
+static const char qt_meta_stringdata_Phonon__ObjectDescriptionModel_VideoStreamType[]        = { "Phonon::VideoStreamDescription\0" };
+static const char qt_meta_stringdata_Phonon__ObjectDescriptionModel_SubtitleStreamType[]     = { "Phonon::SubtitleStreamDescription\0" };
 
 namespace Phonon
 {
@@ -69,7 +75,11 @@ template<> const QMetaObject ObjectDescriptionModel<AudioOutputDeviceType>::stat
     { &QAbstractListModel::staticMetaObject, qt_meta_stringdata_Phonon__ObjectDescriptionModel_AudioOutputDeviceType,
       qt_meta_data_Phonon__ObjectDescriptionModel, 0 }
 };
-template<> const QMetaObject ObjectDescriptionModel<AudioCaptureDeviceType>::staticMetaObject = {
+template<> const QMetaObject ObjectDescriptionModel<EffectType>::staticMetaObject = {
+    { &QAbstractListModel::staticMetaObject, qt_meta_stringdata_Phonon__ObjectDescriptionModel_EffectType,
+      qt_meta_data_Phonon__ObjectDescriptionModel, 0 }
+};
+/*template<> const QMetaObject ObjectDescriptionModel<AudioCaptureDeviceType>::staticMetaObject = {
     { &QAbstractListModel::staticMetaObject, qt_meta_stringdata_Phonon__ObjectDescriptionModel_AudioCaptureDeviceType,
       qt_meta_data_Phonon__ObjectDescriptionModel, 0 }
 };
@@ -81,14 +91,6 @@ template<> const QMetaObject ObjectDescriptionModel<VideoCaptureDeviceType>::sta
     { &QAbstractListModel::staticMetaObject, qt_meta_stringdata_Phonon__ObjectDescriptionModel_VideoCaptureDeviceType,
       qt_meta_data_Phonon__ObjectDescriptionModel, 0 }
 };
-template<> const QMetaObject ObjectDescriptionModel<AudioEffectType>::staticMetaObject = {
-    { &QAbstractListModel::staticMetaObject, qt_meta_stringdata_Phonon__ObjectDescriptionModel_AudioEffectType,
-      qt_meta_data_Phonon__ObjectDescriptionModel, 0 }
-};
-template<> const QMetaObject ObjectDescriptionModel<VideoEffectType>::staticMetaObject = {
-    { &QAbstractListModel::staticMetaObject, qt_meta_stringdata_Phonon__ObjectDescriptionModel_VideoEffectType,
-      qt_meta_data_Phonon__ObjectDescriptionModel, 0 }
-};
 template<> const QMetaObject ObjectDescriptionModel<AudioCodecType>::staticMetaObject = {
     { &QAbstractListModel::staticMetaObject, qt_meta_stringdata_Phonon__ObjectDescriptionModel_AudioCodecType,
       qt_meta_data_Phonon__ObjectDescriptionModel, 0 }
@@ -105,6 +107,18 @@ template<> const QMetaObject ObjectDescriptionModel<VisualizationType>::staticMe
     { &QAbstractListModel::staticMetaObject, qt_meta_stringdata_Phonon__ObjectDescriptionModel_VisualizationType,
       qt_meta_data_Phonon__ObjectDescriptionModel, 0 }
 };
+template<> const QMetaObject ObjectDescriptionModel<AudioStreamType>::staticMetaObject = {
+    { &QAbstractListModel::staticMetaObject, qt_meta_stringdata_Phonon__ObjectDescriptionModel_AudioStreamType,
+      qt_meta_data_Phonon__ObjectDescriptionModel, 0 }
+};
+template<> const QMetaObject ObjectDescriptionModel<VideoStreamType>::staticMetaObject = {
+    { &QAbstractListModel::staticMetaObject, qt_meta_stringdata_Phonon__ObjectDescriptionModel_VideoStreamType,
+      qt_meta_data_Phonon__ObjectDescriptionModel, 0 }
+};
+template<> const QMetaObject ObjectDescriptionModel<SubtitleStreamType>::staticMetaObject = {
+    { &QAbstractListModel::staticMetaObject, qt_meta_stringdata_Phonon__ObjectDescriptionModel_SubtitleStreamType,
+      qt_meta_data_Phonon__ObjectDescriptionModel, 0 }
+};*/
 
 template<ObjectDescriptionType type>
 const QMetaObject *ObjectDescriptionModel<type>::metaObject() const
@@ -119,7 +133,7 @@ void *ObjectDescriptionModel<type>::qt_metacast(const char *_clname)
         return 0;
     }
     if (!strcmp(_clname, ObjectDescriptionModel<type>::staticMetaObject.className())) {
-        return static_cast<void*>(const_cast<ObjectDescriptionModel<type>*>(this));
+        return static_cast<void *>(const_cast<ObjectDescriptionModel<type> *>(this));
     }
     return QAbstractListModel::qt_metacast(_clname);
 }
@@ -132,184 +146,174 @@ int ObjectDescriptionModel<type>::qt_metacall(QMetaObject::Call _c, int _id, voi
 }
 */
 
-template<ObjectDescriptionType type>
-ObjectDescriptionModel<type>::ObjectDescriptionModel( QObject* parent )
-	: QAbstractListModel( parent )
-	, d_ptr( new ObjectDescriptionModelPrivate<type> )
+int ObjectDescriptionModelData::rowCount(const QModelIndex &parent) const
 {
-	d_ptr->q_ptr = this;
+    if (parent.isValid())
+        return 0;
+
+    return d->data.size();
 }
 
-template<ObjectDescriptionType type>
-ObjectDescriptionModel<type>::ObjectDescriptionModel(const QList<ObjectDescription<type> > &data, QObject *parent)
-    : QAbstractListModel(parent),
-    d_ptr(new ObjectDescriptionModelPrivate<type>)
+QVariant ObjectDescriptionModelData::data(const QModelIndex &index, int role) const
 {
-    d_ptr->q_ptr = this;
-    setModelData(data);
-}
+    if (!index.isValid() || index.row() >= d->data.size() || index.column() != 0)
+        return QVariant();
 
-template<ObjectDescriptionType type>
-ObjectDescriptionModel<type>::~ObjectDescriptionModel()
-{
-	delete d_ptr;
-	d_ptr = 0;
-}
-
-template<ObjectDescriptionType type>
-void ObjectDescriptionModel<type>::setModelData( const QList<ObjectDescription<type> >& newData )
-{
-	Q_D( ObjectDescriptionModel );
-	d->data = newData;
-	reset();
-}
-
-template<ObjectDescriptionType type>
-QList<ObjectDescription<type> > ObjectDescriptionModel<type>::modelData() const
-{
-    Q_D(const ObjectDescriptionModel);
-    return d->data;
-}
-
-template<ObjectDescriptionType type>
-ObjectDescription<type> ObjectDescriptionModel<type>::modelData(const QModelIndex &index) const
-{
-    Q_D(const ObjectDescriptionModel);
-    if (!index.isValid() || index.row() >= d->data.size() || index.column() != 0) {
-        return ObjectDescription<type>();
-    }
-    return d->data.at(index.row());
-}
-
-template<ObjectDescriptionType type>
-int ObjectDescriptionModel<type>::rowCount( const QModelIndex& parent ) const
-{
-	if( parent.isValid() )
-		return 0;
-
-	Q_D( const ObjectDescriptionModel );
-	return d->data.size();
-}
-
-template<ObjectDescriptionType type>
-QVariant ObjectDescriptionModel<type>::data( const QModelIndex& index, int role ) const
-{
-	Q_D( const ObjectDescriptionModel );
-	if( !index.isValid() || index.row() >= d->data.size() || index.column() != 0 )
-		return QVariant();
-
-	switch( role )
-	{
-		case Qt::EditRole:
-		case Qt::DisplayRole:
-			return d->data.at( index.row() ).name();
-			break;
-		case Qt::ToolTipRole:
-			return d->data.at( index.row() ).description();
-			break;
-        case Qt::DecorationRole:
-            {
-                QVariant icon = d->data.at(index.row()).property("icon");
-                if (icon.isValid()) {
-                    if (icon.type() == QVariant::String) {
-                        return KIcon(icon.toString());
-                    } else if (icon.type() == QVariant::Icon) {
-                        return icon;
-                    }
+    switch(role)
+    {
+    case Qt::EditRole:
+    case Qt::DisplayRole:
+        return d->data.at(index.row())->name();
+        break;
+    case Qt::ToolTipRole:
+        return d->data.at(index.row())->description();
+        break;
+    case Qt::DecorationRole:
+        {
+            QVariant icon = d->data.at(index.row())->property("icon");
+            if (icon.isValid()) {
+                if (icon.type() == QVariant::String) {
+                    return Platform::icon(icon.toString());
+                } else if (icon.type() == QVariant::Icon) {
+                    return icon;
                 }
             }
-            return QVariant();
-		default:
-			return QVariant();
-	}
+        }
+        return QVariant();
+    default:
+        return QVariant();
+}
 }
 
-template<ObjectDescriptionType type>
-Qt::ItemFlags ObjectDescriptionModel<type>::flags(const QModelIndex &index) const
+Qt::ItemFlags ObjectDescriptionModelData::flags(const QModelIndex &index) const
 {
-    Q_D(const ObjectDescriptionModel);
     if(!index.isValid() || index.row() >= d->data.size() || index.column() != 0) {
         return Qt::ItemIsDropEnabled;
     }
 
-    QVariant available = d->data.at(index.row()).property("available");
+    QVariant available = d->data.at(index.row())->property("available");
     if (available.isValid() && available.type() == QVariant::Bool && !available.toBool()) {
         return Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled;
     }
     return Qt::ItemIsSelectable | Qt::ItemIsEnabled | Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled;
 }
 
-template<ObjectDescriptionType type>
-void ObjectDescriptionModel<type>::moveUp( const QModelIndex& index )
+QList<int> ObjectDescriptionModelData::tupleIndexOrder() const
 {
-	Q_D( ObjectDescriptionModel );
-	if( !index.isValid() || index.row() >= d->data.size() || index.row() < 1 || index.column() != 0 )
-		return;
-
-    emit layoutAboutToBeChanged();
-	QModelIndex above = index.sibling( index.row() - 1, index.column() );
-	d->data.swap( index.row(), above.row() );
-	QModelIndexList from, to;
-	from << index << above;
-	to << above << index;
-	changePersistentIndexList( from, to );
-    emit layoutChanged();
+    QList<int> ret;
+    for (int i = 0; i < d->data.size(); ++i) {
+        ret.append(d->data.at(i)->index());
+    }
+    return ret;
 }
 
-template<ObjectDescriptionType type>
-void ObjectDescriptionModel<type>::moveDown( const QModelIndex& index )
+int ObjectDescriptionModelData::tupleIndexAtPositionIndex(int positionIndex) const
 {
-	Q_D( ObjectDescriptionModel );
-	if( !index.isValid() || index.row() >= d->data.size() - 1 || index.column() != 0 )
-		return;
-
-    emit layoutAboutToBeChanged();
-	QModelIndex below = index.sibling( index.row() + 1, index.column() );
-	d->data.swap( index.row(), below.row() );
-	QModelIndexList from, to;
-	from << index << below;
-	to << below << index;
-	changePersistentIndexList( from, to );
-    emit layoutChanged();
+    return d->data.at(positionIndex)->index();
 }
 
-template<ObjectDescriptionType type>
-QList<int> ObjectDescriptionModel<type>::tupleIndexOrder() const
+QMimeData *ObjectDescriptionModelData::mimeData(ObjectDescriptionType type, const QModelIndexList &indexes) const
 {
-	Q_D( const ObjectDescriptionModel );
-	QList<int> ret;
-	for( int i = 0; i < d->data.size(); ++i )
-		ret.append( d->data.at( i ).index() );
-	return ret;
+    QMimeData *mimeData = new QMimeData;
+    QByteArray encodedData;
+    QDataStream stream(&encodedData, QIODevice::WriteOnly);
+    QModelIndexList::const_iterator end = indexes.constEnd();
+    QModelIndexList::const_iterator index = indexes.constBegin();
+    for(; index!=end; ++index) {
+        if ((*index).isValid()) {
+            stream << (*index).row();
+            stream << d->data.at((*index).row())->index();
+        }
+    }
+    //pDebug() << Q_FUNC_INFO << "setting mimeData to" << mimeTypes(type).first() << "=>" << encodedData.toHex();
+    mimeData->setData(mimeTypes(type).first(), encodedData);
+    return mimeData;
 }
 
-template<ObjectDescriptionType type>
-int ObjectDescriptionModel<type>::tupleIndexAtPositionIndex( int positionIndex ) const
+void ObjectDescriptionModelData::moveUp(const QModelIndex &index)
 {
-	return d_func()->data.at( positionIndex ).index();
+    if (!index.isValid() || index.row() >= d->data.size() || index.row() < 1 || index.column() != 0)
+        return;
+
+    emit d->model->layoutAboutToBeChanged();
+    QModelIndex above = index.sibling(index.row() - 1, index.column());
+    d->data.swap(index.row(), above.row());
+    QModelIndexList from, to;
+    from << index << above;
+    to << above << index;
+    d->model->changePersistentIndexList(from, to);
+    emit d->model->layoutChanged();
 }
 
-template<ObjectDescriptionType type>
-Qt::DropActions ObjectDescriptionModel<type>::supportedDropActions() const
+void ObjectDescriptionModelData::moveDown(const QModelIndex &index)
 {
-    //kDebug(600) << k_funcinfo << endl;
-    return Qt::CopyAction | Qt::MoveAction;
+    if (!index.isValid() || index.row() >= d->data.size() - 1 || index.column() != 0)
+        return;
+
+    emit d->model->layoutAboutToBeChanged();
+    QModelIndex below = index.sibling(index.row() + 1, index.column());
+    d->data.swap(index.row(), below.row());
+    QModelIndexList from, to;
+    from << index << below;
+    to << below << index;
+    d->model->changePersistentIndexList(from, to);
+    emit d->model->layoutChanged();
 }
 
-template<ObjectDescriptionType type>
-bool ObjectDescriptionModel<type>::dropMimeData(const QMimeData *data, Qt::DropAction action,
+ObjectDescriptionModelData::ObjectDescriptionModelData(QAbstractListModel *model)
+    : d(new ObjectDescriptionModelDataPrivate(model))
+{
+}
+
+ObjectDescriptionModelData::~ObjectDescriptionModelData()
+{
+    delete d;
+}
+
+void ObjectDescriptionModelData::setModelData(const QList<QExplicitlySharedDataPointer<ObjectDescriptionData> > &newData)
+{
+    d->data = newData;
+    d->model->reset();
+#ifdef USE_TROLLTECH_LABS_MODELTEST
+    static QSet<QAbstractListModel *> modelTested;
+    if (!modelTested.contains(d->model)) {
+        new ModelTest(d->model, d->model);
+        modelTested << d->model;
+    }
+#endif
+}
+
+QList<QExplicitlySharedDataPointer<ObjectDescriptionData> > ObjectDescriptionModelData::modelData() const
+{
+    return d->data;
+}
+
+QExplicitlySharedDataPointer<ObjectDescriptionData> ObjectDescriptionModelData::modelData(const QModelIndex &index) const
+{
+    if (!index.isValid() || index.row() >= d->data.size() || index.column() != 0) {
+        return QExplicitlySharedDataPointer<ObjectDescriptionData>(new ObjectDescriptionData(0));
+    }
+    return d->data.at(index.row());
+}
+
+Qt::DropActions ObjectDescriptionModelData::supportedDropActions() const
+{
+    //pDebug() << Q_FUNC_INFO;
+    return Qt::MoveAction;
+}
+
+bool ObjectDescriptionModelData::dropMimeData(ObjectDescriptionType type, const QMimeData *data, Qt::DropAction action,
         int row, int column, const QModelIndex &parent)
 {
     Q_UNUSED(action);
     Q_UNUSED(column);
-    //kDebug(600) << k_funcinfo << data << action << row << column << parent << endl;
+    //pDebug() << Q_FUNC_INFO << data << action << row << column << parent;
 
-    QString format = mimeTypes().first();
+    QString format = mimeTypes(type).first();
     if (!data->hasFormat(format)) {
         return false;
     }
 
-    Q_D(ObjectDescriptionModel);
     if (parent.isValid()) {
         row = parent.row();
     } else {
@@ -320,37 +324,43 @@ bool ObjectDescriptionModel<type>::dropMimeData(const QMimeData *data, Qt::DropA
 
     QByteArray encodedData = data->data(format);
     QDataStream stream(&encodedData, QIODevice::ReadOnly);
-    QList<ObjectDescription<type> > toInsert;
+    QList<QExplicitlySharedDataPointer<ObjectDescriptionData> > toInsert;
     while (!stream.atEnd()) {
+        int previousRow;
         int otherIndex;
-        stream >> otherIndex;
-        ObjectDescription<type> obj = ObjectDescription<type>::fromIndex(otherIndex);
+        stream >> previousRow >> otherIndex;
+        ObjectDescriptionData *obj = ObjectDescriptionData::fromIndex(type, otherIndex);
 
-        if (obj.isValid()) {
-            toInsert << obj;
+        if (obj->isValid()) {
+            toInsert << QExplicitlySharedDataPointer<ObjectDescriptionData>(obj);
+            if (previousRow < row) {
+                ++row;
+            }
         }
     }
-    beginInsertRows(QModelIndex(), row, row + toInsert.size() - 1);
-    foreach (const ObjectDescription<type> &obj, toInsert) {
+    if (row > d->data.size()) {
+        row = d->data.size();
+    }
+    d->model->beginInsertRows(QModelIndex(), row, row + toInsert.size() - 1);
+    foreach (const QExplicitlySharedDataPointer<ObjectDescriptionData> &obj, toInsert) {
         d->data.insert(row, obj);
     }
-    endInsertRows();
+    d->model->endInsertRows();
     return true;
 }
 
-template<ObjectDescriptionType type>
-bool ObjectDescriptionModel<type>::removeRows(int row, int count, const QModelIndex &parent)
+
+bool ObjectDescriptionModelData::removeRows(int row, int count, const QModelIndex &parent)
 {
-    //kDebug(600) << k_funcinfo << row << count << parent << endl;
-    Q_D(ObjectDescriptionModel);
+    //pDebug() << Q_FUNC_INFO << row << count << parent;
     if (parent.isValid() || row + count > d->data.size()) {
         return false;
     }
-    beginRemoveRows(parent, row, row + count - 1);
+    d->model->beginRemoveRows(parent, row, row + count - 1);
     for (;count > 0; --count) {
         d->data.removeAt(row);
     }
-    endRemoveRows();
+    d->model->endRemoveRows();
     return true;
 }
 
@@ -358,8 +368,7 @@ bool ObjectDescriptionModel<type>::removeRows(int row, int count, const QModelIn
 template<ObjectDescriptionType type>
 bool ObjectDescriptionModel<type>::insertRows(int row, int count, const QModelIndex &parent)
 {
-    kDebug(600) << k_funcinfo << row << count << parent << endl;
-    Q_D(ObjectDescriptionModel);
+    pDebug() << Q_FUNC_INFO << row << count << parent;
     if (parent.isValid() || row < 0 || row > d->data.size()) {
         return false;
     }
@@ -372,44 +381,26 @@ bool ObjectDescriptionModel<type>::insertRows(int row, int count, const QModelIn
 }
 */
 
-template<ObjectDescriptionType type>
-QStringList ObjectDescriptionModel<type>::mimeTypes() const
+QStringList ObjectDescriptionModelData::mimeTypes(ObjectDescriptionType type) const
 {
     return QStringList(QLatin1String("application/x-phonon-objectdescription") + QString::number(static_cast<int>(type)));
 }
 
-template<ObjectDescriptionType type>
-QMimeData *ObjectDescriptionModel<type>::mimeData(const QModelIndexList &indexes) const
-{
-    Q_D(const ObjectDescriptionModel);
+#define INSTANTIATE_META_FUNCTIONS(type) \
+template PHONON_EXPORT const QMetaObject *ObjectDescriptionModel<type>::metaObject() const; \
+template void *ObjectDescriptionModel<type>::qt_metacast(const char *)
 
-    QMimeData *mimeData = new QMimeData;
-    QByteArray encodedData;
-    QDataStream stream(&encodedData, QIODevice::WriteOnly);
-    QModelIndexList::const_iterator end = indexes.constEnd();
-    QModelIndexList::const_iterator index = indexes.constBegin();
-    for(; index!=end; ++index) {
-        if ((*index).isValid()) {
-            ObjectDescription<type> item = d->data.at((*index).row());
-            stream << item.index();
-        }
-    }
-    //kDebug(600) << k_funcinfo << "setting mimeData to " << encodedData << endl;
-    mimeData->setData(mimeTypes().first(), encodedData);
-    return mimeData;
-}
-
-template class ObjectDescriptionModel<AudioOutputDeviceType>;
-template class ObjectDescriptionModel<AudioCaptureDeviceType>;
-template class ObjectDescriptionModel<VideoOutputDeviceType>;
-template class ObjectDescriptionModel<VideoCaptureDeviceType>;
-template class ObjectDescriptionModel<AudioEffectType>;
-template class ObjectDescriptionModel<VideoEffectType>;
-template class ObjectDescriptionModel<AudioCodecType>;
-template class ObjectDescriptionModel<VideoCodecType>;
-template class ObjectDescriptionModel<ContainerFormatType>;
-template class ObjectDescriptionModel<VisualizationType>;
-
-}
-
-// vim: sw=4 ts=4
+INSTANTIATE_META_FUNCTIONS(AudioOutputDeviceType);
+INSTANTIATE_META_FUNCTIONS(EffectType);
+/*INSTANTIATE_META_FUNCTIONS(AudioCaptureDeviceType);
+INSTANTIATE_META_FUNCTIONS(VideoOutputDeviceType);
+INSTANTIATE_META_FUNCTIONS(VideoCaptureDeviceType);
+INSTANTIATE_META_FUNCTIONS(AudioCodecType);
+INSTANTIATE_META_FUNCTIONS(VideoCodecType);
+INSTANTIATE_META_FUNCTIONS(ContainerFormatType);
+INSTANTIATE_META_FUNCTIONS(VisualizationType);
+INSTANTIATE_META_FUNCTIONS(AudioStreamType);
+INSTANTIATE_META_FUNCTIONS(VideoStreamType);
+INSTANTIATE_META_FUNCTIONS(SubtitleStreamType);
+*/
+} // namespace Phonon
