@@ -17,83 +17,100 @@
 
 */
 
-#include "audiooutputtest.h"
+#include "loadfakebackend.h"
 #include "../audiooutput.h"
-#include <kglobal.h>
-#include <QLatin1String>
 #include "../phononnamespace.h"
+
+#include <QtCore/QObject>
+#include <QtCore/QString>
+
+#include <kglobal.h>
 #include <qtest_kde.h>
 
+class AudioOutputTest : public QObject
+{
+    Q_OBJECT
+    private slots:
+        void initTestCase();
+        void checkName();
+        void checkVolume();
+        void checkMute();
+        void checkCategory();
+        void cleanupTestCase();
+};
+
 using namespace Phonon;
 
 void AudioOutputTest::initTestCase()
 {
+    QCoreApplication::setApplicationName("audiopathtest");
+    Phonon::loadFakeBackend();
 }
 
 void AudioOutputTest::checkName()
 {
-	AudioOutput ao( Phonon::NotificationCategory, this );
-	QCOMPARE( ao.name(), QLatin1String( "qttest" ) );
-	QString n( "lsdf" );
-	ao.setName( n );
-	QCOMPARE( ao.name(), n );
+    AudioOutput ao(Phonon::NotificationCategory, this);
+    QCOMPARE(ao.name(), QLatin1String("audiopathtest"));
+    QString n("lsdf");
+    ao.setName(n);
+    QCOMPARE(ao.name(), n);
 }
 
 void AudioOutputTest::checkVolume()
 {
-	AudioOutput ao( Phonon::NotificationCategory, this );
-	QSignalSpy volumeSignalSpy( &ao, SIGNAL( volumeChanged( float ) ) );
-	float v = 1.0;
-	QCOMPARE( ao.volume(), v );
-	QCOMPARE( volumeSignalSpy.size(), 0 );
-	for( v = 0.0; v <= 10.0; v += 0.01 )
-	{
-		ao.setVolume( v );
-		QCOMPARE( ao.volume(), v );
-		QCOMPARE( volumeSignalSpy.size(), 1 );
-		QCOMPARE( qvariant_cast<float>( volumeSignalSpy.takeFirst().at( 0 ) ), v );
-	}
+    AudioOutput ao(Phonon::NotificationCategory, this);
+    QSignalSpy volumeSignalSpy(&ao, SIGNAL(volumeChanged(qreal)));
+    qreal v = 1.0;
+    QCOMPARE(static_cast<float>(ao.volume()), static_cast<float>(v));
+    QCOMPARE(volumeSignalSpy.size(), 0);
+    for (v = 0.0; v <= 10.0; v += 0.01)
+    {
+        ao.setVolume(v);
+        QCOMPARE(static_cast<float>(ao.volume()), static_cast<float>(v));
+        QCOMPARE(volumeSignalSpy.size(), 1);
+        QCOMPARE(qvariant_cast<float>(volumeSignalSpy.takeFirst().at(0)), static_cast<float>(v));
+    }
 }
 
 void AudioOutputTest::checkMute()
 {
     AudioOutput ao(Phonon::CommunicationCategory, this);
-    QSignalSpy volumeSignalSpy(&ao, SIGNAL(volumeChanged(float)));
+    QSignalSpy volumeSignalSpy(&ao, SIGNAL(volumeChanged(qreal)));
     QSignalSpy muteSignalSpy(&ao, SIGNAL(mutedChanged(bool)));
-    float v = 1.0;
-    QCOMPARE(ao.volume(), v);
+    qreal v = 1.0;
+    QCOMPARE(static_cast<float>(ao.volume()), static_cast<float>(v));
     QCOMPARE(ao.isMuted(), false);
 
     ao.setMuted(true);
     QCOMPARE(volumeSignalSpy.size(), 0);
     QCOMPARE(muteSignalSpy.size(), 1);
-    QCOMPARE(ao.volume(), v);
+    QCOMPARE(static_cast<float>(ao.volume()), static_cast<float>(v));
     QCOMPARE(ao.isMuted(), true);
     QCOMPARE(muteSignalSpy.takeFirst().at(0).toBool(), true);
 
     ao.setMuted(true);
     QCOMPARE(volumeSignalSpy.size(), 0);
     QCOMPARE(muteSignalSpy.size(), 0);
-    QCOMPARE(ao.volume(), v);
+    QCOMPARE(static_cast<float>(ao.volume()), static_cast<float>(v));
     QCOMPARE(ao.isMuted(), true);
 
     ao.setMuted(false);
     QCOMPARE(volumeSignalSpy.size(), 0);
     QCOMPARE(muteSignalSpy.size(), 1);
-    QCOMPARE(ao.volume(), v);
+    QCOMPARE(static_cast<float>(ao.volume()), static_cast<float>(v));
     QCOMPARE(ao.isMuted(), false);
     QCOMPARE(muteSignalSpy.takeFirst().at(0).toBool(), false);
 
     ao.setMuted(false);
     QCOMPARE(volumeSignalSpy.size(), 0);
     QCOMPARE(muteSignalSpy.size(), 0);
-    QCOMPARE(ao.volume(), v);
+    QCOMPARE(static_cast<float>(ao.volume()), static_cast<float>(v));
     QCOMPARE(ao.isMuted(), false);
 
     ao.setMuted(true);
     QCOMPARE(volumeSignalSpy.size(), 0);
     QCOMPARE(muteSignalSpy.size(), 1);
-    QCOMPARE(ao.volume(), v);
+    QCOMPARE(static_cast<float>(ao.volume()), static_cast<float>(v));
     QCOMPARE(ao.isMuted(), true);
     QCOMPARE(muteSignalSpy.takeFirst().at(0).toBool(), true);
 
@@ -101,20 +118,20 @@ void AudioOutputTest::checkMute()
     ao.setVolume(v);
     QCOMPARE(volumeSignalSpy.size(), 1);
     QCOMPARE(muteSignalSpy.size(), 0);
-    QCOMPARE(ao.volume(), v);
+    QCOMPARE(static_cast<float>(ao.volume()), static_cast<float>(v));
     QCOMPARE(ao.isMuted(), true);
-    QCOMPARE(qvariant_cast<float>(volumeSignalSpy.takeFirst().at(0)), v);
+    QCOMPARE(qvariant_cast<float>(volumeSignalSpy.takeFirst().at(0)), static_cast<float>(v));
 
     ao.setMuted(true);
     QCOMPARE(volumeSignalSpy.size(), 0);
     QCOMPARE(muteSignalSpy.size(), 0);
-    QCOMPARE(ao.volume(), v);
+    QCOMPARE(static_cast<float>(ao.volume()), static_cast<float>(v));
     QCOMPARE(ao.isMuted(), true);
 
     ao.setMuted(false);
     QCOMPARE(volumeSignalSpy.size(), 0);
     QCOMPARE(muteSignalSpy.size(), 1);
-    QCOMPARE(ao.volume(), v);
+    QCOMPARE(static_cast<float>(ao.volume()), static_cast<float>(v));
     QCOMPARE(ao.isMuted(), false);
     QCOMPARE(muteSignalSpy.takeFirst().at(0).toBool(), false);
 }
@@ -132,6 +149,6 @@ void AudioOutputTest::cleanupTestCase()
 {
 }
 
-QTEST_KDEMAIN( AudioOutputTest, NoGUI )
+QTEST_MAIN(AudioOutputTest)
 #include "audiooutputtest.moc"
 // vim: sw=4 ts=4
