@@ -23,8 +23,8 @@ namespace Phonon
 {
 namespace Fake
 {
-AbstractAudioOutput::AbstractAudioOutput( QObject* parent )
-	: QObject( parent )
+AbstractAudioOutput::AbstractAudioOutput(QObject *parent)
+    : QObject(parent)
 {
 }
 
@@ -34,5 +34,5 @@ AbstractAudioOutput::~AbstractAudioOutput()
 
 }} //namespace Phonon::Fake
 
-#include "abstractaudiooutput.moc"
+#include "moc_abstractaudiooutput.cpp"
 // vim: sw=4 ts=4
