@@ -20,50 +20,54 @@
 #ifndef Phonon_FAKE_BACKEND_H
 #define Phonon_FAKE_BACKEND_H
 
-#include <kdelibs_export.h>
-#include <QList>
-#include <QPointer>
-#include <QStringList>
 #include <phonon/objectdescription.h>
 #include <phonon/backendinterface.h>
 
+#include <QtCore/QList>
+#include <QtCore/QPointer>
+#include <QtCore/QStringList>
+
 class KUrl;
 
 namespace Phonon
 {
 namespace Fake
 {
-	class AudioOutput;
+    class AudioOutput;
 
-    class PHONON_FAKE_EXPORT Backend : public QObject, public BackendInterface
-	{
-		Q_OBJECT
+    class Backend : public QObject, public BackendInterface
+    {
+        Q_OBJECT
         Q_INTERFACES(Phonon::BackendInterface)
-		public:
-			Backend( QObject* parent, const QStringList& args );
-			virtual ~Backend();
+        public:
+            Backend(QObject *parent = 0, const QStringList & = QStringList());
+            virtual ~Backend();
 
-            QObject* createObject0(BackendInterface::Class0, QObject *parent);
-            QObject* createObject1(BackendInterface::Class1, QObject *parent, QVariant arg1);
+            QObject *createObject(BackendInterface::Class, QObject *parent, const QList<QVariant> &args);
 
-			Q_INVOKABLE bool supportsVideo() const;
-			Q_INVOKABLE bool supportsOSD() const;
-			Q_INVOKABLE bool supportsFourcc( quint32 fourcc ) const;
-			Q_INVOKABLE bool supportsSubtitles() const;
-			Q_INVOKABLE QStringList knownMimeTypes() const;
+            bool supportsVideo() const;
+            bool supportsOSD() const;
+            bool supportsFourcc(quint32 fourcc) const;
+            bool supportsSubtitles() const;
+            QStringList availableMimeTypes() const;
 
-			void freeSoundcardDevices();
+            void freeSoundcardDevices();
 
             QSet<int> objectDescriptionIndexes(ObjectDescriptionType type) const;
             QHash<QByteArray, QVariant> objectDescriptionProperties(ObjectDescriptionType type, int index) const;
 
-			Q_INVOKABLE char const* uiLibrary() const;
-			// Q_INVOKABLE char* uiSymbol() const;
+            bool startConnectionChange(QSet<QObject *>);
+            bool connectNodes(QObject *, QObject *);
+            bool disconnectNodes(QObject *, QObject *);
+            bool endConnectionChange(QSet<QObject *>);
 
-		private:
-			QStringList m_supportedMimeTypes;
-			QList<QPointer<AudioOutput> > m_audioOutputs;
-	};
+        Q_SIGNALS:
+            void objectDescriptionChanged(ObjectDescriptionType);
+
+        private:
+            QStringList m_supportedMimeTypes;
+            QList<QPointer<AudioOutput> > m_audioOutputs;
+    };
 }} // namespace Phonon::Fake
 
 // vim: sw=4 ts=4 tw=80
