@@ -1,5 +1,5 @@
 /*  This file is part of the KDE project
-    Copyright (C) 2006 Kevin Ottens <ervin@kde.org>
+    Copyright (C) 2006-2007 Kevin Ottens <ervin@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -18,24 +18,27 @@
 */
 
 #include "acadapter.h"
+#include "acadapter_p.h"
 
 #include "soliddefs_p.h"
 #include <solid/ifaces/acadapter.h>
 
-Solid::AcAdapter::AcAdapter( QObject *backendObject )
-    : Capability( backendObject )
+Solid::AcAdapter::AcAdapter(QObject *backendObject)
+    : DeviceInterface(*new AcAdapterPrivate(), backendObject)
 {
-    connect( backendObject, SIGNAL( plugStateChanged( bool ) ),
-             this, SIGNAL( plugStateChanged( bool ) ) );
+    connect(backendObject, SIGNAL(plugStateChanged(bool)),
+             this, SIGNAL(plugStateChanged(bool)));
 }
 
 Solid::AcAdapter::~AcAdapter()
 {
+
 }
 
 bool Solid::AcAdapter::isPlugged() const
 {
-    return_SOLID_CALL( Ifaces::AcAdapter*, backendObject(), false, isPlugged() );
+    Q_D(const AcAdapter);
+    return_SOLID_CALL(Ifaces::AcAdapter *, d->backendObject(), false, isPlugged());
 }
 
 #include "acadapter.moc"
