@@ -21,28 +21,28 @@
 #ifndef KSPELL_ASPELLCLIENT_H
 #define KSPELL_ASPELLCLIENT_H
 
-#include "client.h"
-#include <qobject.h>
+#include "client_p.h"
+#include <QtCore/QObject>
 
 #include "aspell.h"
 
-namespace KSpell2 {
-    class Speller;
+namespace Sonnet {
+    class SpellerPlugin;
 }
-using KSpell2::Speller;
+using Sonnet::SpellerPlugin;
 
-class ASpellClient : public KSpell2::Client
+class ASpellClient : public Sonnet::Client
 {
     Q_OBJECT
 public:
-    ASpellClient( QObject *parent, const QStringList & /* args */  );
+    ASpellClient(QObject *parent, const QStringList & /* args */);
     ~ASpellClient();
 
     virtual int reliability() const {
         return 20;
     }
 
-    virtual Speller* createSpeller(const QString &language);
+    virtual SpellerPlugin *createSpeller(const QString &language);
 
     virtual QStringList languages() const;
 
