@@ -21,12 +21,12 @@
 #include "enchantdict.h"
 
 #include <kgenericfactory.h>
-#include <qdebug.h>
+#include <QtCore/QDebug>
 
 typedef KGenericFactory<QSpellEnchantClient> EnchantClientFactory;
 K_EXPORT_COMPONENT_FACTORY(kspell_enchant, EnchantClientFactory("kspell_enchant"))
 
-using namespace KSpell2;
+using namespace Sonnet;
 
 static void enchantDictDescribeFn(const char * const lang_tag,
                                   const char * const provider_name,
@@ -58,7 +58,8 @@ QSpellEnchantClient::~QSpellEnchantClient()
     enchant_broker_free(m_broker);
 }
 
-Speller *QSpellEnchantClient::createSpeller(const QString &language)
+SpellerPlugin *QSpellEnchantClient::createSpeller(
+    const QString &language)
 {
     EnchantDict *dict = enchant_broker_request_dict(m_broker,
                                                     language.toUtf8());
