@@ -20,19 +20,19 @@
 #ifndef QSPELL_ENCHANTCLIENT_H
 #define QSPELL_ENCHANTCLIENT_H
 
-#include "speller.h"
-#include "client.h"
+#include "spellerplugin_p.h"
+#include "client_p.h"
 
-#include <qobject.h>
-#include <qset.h>
+#include <QtCore/QObject>
+#include <QtCore/QSet>
 #include <enchant/enchant.h>
 
-namespace KSpell2 {
-    class Speller;
+namespace Sonnet {
+    class SpellerPlugin;
 }
-using KSpell2::Speller;
+using Sonnet::SpellerPlugin;
 
-class QSpellEnchantClient : public KSpell2::Client
+class QSpellEnchantClient : public Sonnet::Client
 {
     Q_OBJECT
 public:
@@ -43,7 +43,7 @@ public:
         return 30;
     }
 
-    virtual Speller *createSpeller(const QString &language);
+    virtual SpellerPlugin *createSpeller(const QString &language);
 
     virtual QStringList languages() const;
 
