@@ -19,15 +19,15 @@
  */
 #include "enchantdict.h"
 
-#include <qtextcodec.h>
-#include <qdebug.h>
+#include <QtCore/QTextCodec>
+#include <QtCore/QDebug>
 
-using namespace KSpell2;
+using namespace Sonnet;
 
 QSpellEnchantDict::QSpellEnchantDict(EnchantBroker *broker,
                                      EnchantDict *dict,
                                      const QString &language)
-    : Speller(language),
+    : SpellerPlugin(language),
       m_broker(broker),
       m_dict(dict)
 {
