@@ -20,11 +20,11 @@
 #ifndef QSPELL_ENCHANTDICT_H
 #define QSPELL_ENCHANTDICT_H
 
-#include "speller.h"
+#include "spellerplugin_p.h"
 
 #include <enchant/enchant.h>
 
-class QSpellEnchantDict : public KSpell2::Speller
+class QSpellEnchantDict : public Sonnet::SpellerPlugin
 {
 public:
     ~QSpellEnchantDict();
